#!/usr/bin/perl
# Jumbled words text file generator favoring ZJQXKVBPGWYFMCU.
# Copyright 2015 by Gan Uesli Starling, KY8D

use Getopt::Long;
use File::stat;
use List::MoreUtils;

my $windoze_flag = 0;
$windoze_flag = 1 if $^O =~ m/MSWin/; # Comment out this line if on Windows and also know Perl.

# Set defaults.
my $VERSION = '2015-11-22';
my $max_filesize = 250;
my $path = './morse.txt';
my $punc = 5; # Frequency of punctuation, every Nth on average.
my $numr = 7;
my $back = 11;
my $rand = 19;
my $help_flag = 0;

&GetOptions(
    "size=i"  => \$max_filesize,
    "path=s"  => \$path,
    "othr=i"  => \$punc,
    "numr=i"  => \$numr,
    "back=i"  => \$back,
    "rand=i"  => \$rand,
    "help"    => \$help_flag,
);

sub quick_help {
    my $help_msg = <<END_HELP_MSG;
    
USAGE:
$0 [ options ]
  
OPTIONS:
--s[ize]    Output filesize in kB.
--p[ath]    Output filepath.
--o[thr]    Include other symbols (punctuation) every Nth word on average. Zero = off.
--b[ack]    Include backwards speelings every Nth word on average. Zero = off. 
--r[and]    Include random gobbledegook evern Nth word on average. Zero = off.
--h[elp]    This message

EXAMPLES (long):
  gus_jumbled_words.pl --path '/media/ramdisk/foo.txt' --size 250 --othr 0 --numr 0 --back 0 --rand 0
  gus_jumbled_words.pl --path '/media/ramdisk/bar.txt' --size 100 --othr 3 --numr 4 --back 5 --rand 6
  
EXAMPLE (short):
  gus_jumbled_words.pl --path '~/morse.txt' --s 50 --o 6 --n 7 --b 8 --r 9
  
DEFAULTS:
  gus_jumbled_words.pl --path './morse.txt' --size 120 --othr 5 --numr 7 --back 11 --rand 19
  
  
END_HELP_MSG

    print "$help_msg";
}

quick_help() if $help_flag;

if ($windoze_flag) {
    my $foo;
    print "gus_jumbled_words.pl by KY8D, version $VERSION\n";
    print "\nEnter user options (default value)...\n";
    print "Output filename ('$path'): ";
    chomp($foo = <STDIN>); $path = $foo if $foo =~ m/a-z/i;
    print "Output filesize in kB ($max_filesize): ";
    chomp($max_filexize = <STDIN>);
    print "\nHow often for the following? (0 = Off, 3 = About 1 in every 3)...\n";
    print "Punctuation? (5): ";
    chomp($foo = <STDIN>); $punc = $foo if $foo =~ m/[0-9]/; 
    print "Numerals? (7): ";
    chomp($foo = <STDIN>); $numr = $foo if $foo =~ m/[0-9]/; 
    print "Reverse spellings? (11): ";
    chomp($foo = <STDIN>); $back = $foo if $foo =~ m/[0-9]/; 
    print "Random garbage groups? (19): ";	
    chomp($foo = <STDIN>); $rand = $foo if $foo =~ m/[0-9]/; 
    print "\n";
}

$max_filesize *= 1024; # kBytes; 

my @U_words = qw(
abacus abduce abduced abduces abduct abducts abjure abjured abjurer abjures ablaut ablauts 
abluent ablush abluted abortus abought aboulia aboulic abound abounds about abrupt absurd 
absurds abubble abulia abulias abulic abus abuse abused abuser abusers abuses abusive 
abut abuts abuttal abutted abutter abuzz acajou acajous acarus acaudal account accrual 
accrue accrued accrues accurst accusal accuse accused accuser accuses acequia acerous acetous 
acetum acicula acinous acinus acquest acquire acquit acquits actual actuary actuate acuate 
acuity aculei aculeus acumen acumens acute acutely acuter acutes acutest adduce adduced 
adducer adduces adduct adducts adieu adieus adieux adipous adjourn adjudge adjunct adjure 
adjured adjurer adjures adjuror adjust adjusts adnoun adnouns adulate adult adultly adults 
adunc adust adytum adzuki adzukis aecium aeneous aeneus aerugo aerugos afflux afoul 
agamous agendum agouti agoutis agouty aground ague agues aguish ahull aidful aimful 
airbus ajuga ajugas alarum alarums album albumen albumin albums aleuron alfaqui algum 
algums aliquot aliunde allium alliums allude alluded alludes allure allured allurer allures 
alluvia almuce almuces almud almude almudes almuds almug almugs alodium aloud aludel 
aludels alula alulae alular alum alumin alumina alumine alumins alumna alumnae alumni 
alumnus alums alunite alyssum amadou amadous amateur ambush amicus amorous amount amounts 
amour amours ampoule ampul ampule ampules ampulla ampuls amputee amu amuck amucks 
amulet amulets amus amuse amused amuser amusers amuses amusia amusias amusive amylum 
amylums anchusa aneurin angelus anguine anguish angular animus ankus ankuses ankush annual 
annuals annuity annul annular annulet annuli annuls annulus antibug antiflu antifur antigun 
antique antrum antrums anural anuran anurans anuria anurias anuric anurous anus anuses 
anxious aoudad aoudads apercu apercus apiculi apodous apolune applaud appulse aqua aquae 
aquaria aquas aquatic aquavit aqueous aquifer aquiver arbour arbours arbute arbutes arbutus 
arcanum arcuate arcus arcuses ardour ardours arduous arenous argu argue argued arguer 
arguers argues argufy argus arguses armful armfuls armour armours armoury armsful armure 
armures around arousal arouse aroused arouser arouses artful arugola arugula arum arums 
aruspex asarum asarums ascus asexual asquint assault assuage assume assumed assumer assumes 
assure assured assurer assures assuror astound astute asunder asylum asylums atrium atriums 
attune attuned attunes aubade aubades auberge auburn auburns auction aucuba aucubas aud 
audad audads audial audible audibly audient audile audiles audings audio audios audit 
audited auditee auditor audits augend augends auger augers aught aughts augite augites 
augitic augment augur augural augured augurer augurs augury august auk auklet auklets 
auks auld aulder auldest aulic aunt auntie aunties auntly aunts aunty aura 
aurae aural aurally aurar auras aurate aurated aureate aurei aureola aureole aures 
aureus auric auricle auris aurist aurists aurochs aurora aurorae auroral auroras aurous 
aurum aurums ausform auspex auspice austere austral ausubo ausubos autarch autarky auteur 
auteurs author authors autism autisms autist autists auto autobus autoed automan automat 
automen autonym autopen autopsy autos autumn autumns auxeses auxesis auxetic auxin auxinic 
auxins avaunt avenue avenues avouch avulse avulsed avulses awful awfully awmous azimuth 
azuki azukis azulejo azure azures azurite azygous babassu babu babul babuls babus 
backout backup backups bacula baculum bagful bagfuls bagsful baguet baguets bahadur bailout 
baleful ballute bandeau baneful banquet barbule barbut barbuts barium bariums baroque barque 
barques bascule bashful basque basques bateau bateaux bathtub batteau battu battue battues 
baubee baubees bauble baubles baud bauds baulk baulked baulks baulky bausond bauxite 
bawsunt bayou bayous bearhug beau beauish beaus beaut beauts beauty beaux bebeeru 
because becloud becrust becurse becurst bedaub bedaubs bedbug bedbugs bedouin bedrug bedrugs 
bedu beduin beduins bedumb bedumbs bedunce befoul befouls beguile beguine begulf begulfs 
begum begums begun bejesus belaud belauds beluga belugas bemuse bemused bemuses benumb 
benumbs bequest bescour beshout besmut besmuts bestud bestuds bethump bezique bhut bhuts 
bijou bijous bijoux bilious billbug biofuel biscuit bismuth bisque bisques bitumen bivouac 
blaubok blellum blouse bloused blouses blouson blousy blowgun blowout blowup blowups blu 
blub blubbed blubber blubs blucher bludge bludged bludger bludges blue bluecap blued 
bluefin bluegum blueish bluejay bluely bluer blues bluest bluesy bluet bluets bluey 
blueys bluff bluffed bluffer bluffly bluffs bluings bluish blum blume blumed blumes 
blunder blunge blunged blunger blunges blunt blunted blunter bluntly blunts blur blurb 
blurbed blurbs blurred blurry blurs blurt blurted blurter blurts blush blushed blusher 
blushes bluster boatful bogus bogusly bohrium bohunk bohunks boletus bolus boluses bonduc 
bonducs bonus bonuses boojum boojums bookful bordure borough bosque bosques bosquet bosun 
bosuns botulin boubou boubous bouchee boucle boucles boudin boudins boudoir bouffe bouffes 
bough boughed boughs bought bougie bougies boulder boule boules boulle boulles bounce 
bounced bouncer bounces bouncy bound bounded bounden bounder bounds bounty bouquet bourbon 
bourdon bourg bourgs bourn bourne bournes bourns bourree bourse bourses boursin bous 
bouse boused bouses bousy bout bouton boutons bouts bouvier bowlful boxful boxfuls 
boxhaul bravura bravure breakup brewpub brimful briquet brogue brogues brought brucin brucine 
brucins brugh brughs bruin bruins bruise bruised bruiser bruises bruit bruited bruiter 
bruits brulot brulots brulyie brulzie brumal brumby brume brumes brumous brunch brunet 
brunets brung brunt brunts brush brushed brusher brushes brushup brushy brusk brusker 
brusque brut brutal brute bruted brutely brutes brutify brutish brutism bruts brux 
bruxed bruxes bruxism bub bubal bubale bubales bubalis bubals bubba bubbas bubbies 
bubble bubbled bubbler bubbles bubbly bubby bubinga bubkes bubo buboed buboes bubonic 
bubs bubu bubus buccal buck bucked buckeen bucker buckers bucket buckets buckeye 
buckish buckle buckled buckler buckles bucko buckoes buckos buckra buckram buckras bucks 
bucksaw bucolic bud budd budded budder budders buddha buddhas buddied buddies buddle 
buddles buddy budg budge budged budger budgers budges budget budgets budgie budgies 
budless budlike buds budworm buff buffalo buffed buffer buffers buffest buffet buffets 
buffi buffier buffo buffoon buffos buffs buffy bug bugaboo bugbane bugbear bugeye 
bugeyes bugg bugged bugger buggers buggery buggier buggies buggy bugl bugle bugled 
bugler buglers bugles bugloss bugout bugouts bugs bugseed bugsha bugshas buhl buhls 
buhr buhrs build builded builder builds buildup built buirdly bulb bulbar bulbed 
bulbel bulbels bulbil bulbils bulblet bulbous bulbs bulbul bulbuls bulg bulge bulged 
bulger bulgers bulges bulghur bulgier bulgur bulgurs bulgy bulimia bulimic bulk bulkage 
bulked bulkier bulkily bulks bulky bull bulla bullace bullae bullate bullbat bulldog 
bulled bullet bullets bullied bullier bullies bullion bullish bullock bullous bullpen bulls 
bully bulrush bulwark bum bumble bumbled bumbler bumbles bumboat bumelia bumf bumfs 
bumkin bumkins bumm bummalo bummed bummer bummers bummest bump bumped bumper bumpers 
bumph bumphs bumpier bumpily bumpkin bumps bumpy bums bun buna bunas bunch 
bunched bunches bunchy bunco buncoed buncos bund bundist bundle bundled bundler bundles 
bunds bundt bundts bung bunged bungee bungees bungle bungled bungler bungles bungs 
bunion bunions bunk bunked bunker bunkers bunko bunkoed bunkos bunks bunkum bunkums 
bunn bunnies bunns bunny bunraku buns bunt bunted bunter bunters bunts bunya 
bunyas buoy buoyage buoyant buoyed buoys bupkes bupkus buppie buppies buppy buqsha 
buqshas bur bura buran burans buras burb burble burbled burbler burbles burbly 
burbot burbots burbs burd burden burdens burdie burdies burdock burds bureau bureaus 
bureaux buret burets burette burg burgage burgee burgees burgeon burger burgers burgess 
burgh burghal burgher burghs burglar burgle burgled burgles burgoo burgoos burgout burgs 
burial burials buried burier buriers buries burin burins burk burka burkas burke 
burked burker burkers burkes burkite burl burlap burlaps burled burler burlers burlesk 
burley burleys burlier burlily burls burly burn burned burner burners burnet burnets 
burnie burnies burnish burnous burnout burns burnt burp burped burps burqa burqas 
burr burred burrer burrers burrier burrito burro burros burrow burrows burrs burry 
burs bursa bursae bursal bursar bursars bursary bursas bursate burse burseed bursera 
burses burst bursted burster bursts burthen burton burtons burweed bury bus busbar 
busbars busbies busboy busboys busby bused buses busgirl bush bushed bushel bushels 
busher bushers bushes bushido bushier bushily bushman bushmen bushpig bushtit bushwa bushwah 
bushwas bushy busied busier busies busiest busily busings busk busked busker buskers 
buskin buskins busks busload busman busmen buss bussed busses bust bustard busted 
buster busters bustic bustics bustier bustle bustled bustler bustles busts busty busy 
but butane butanes butanol butch butcher butches bute butene butenes buteo buteos 
butes butl butle butled butler butlers butlery butles buts butt buttals butte 
butted butter butters buttery buttes butties buttock button buttons buttony butts butty 
butut bututs butyl butyls butyral butyric butyrin butyryl buxom buxomer buxomly buy 
buyable buyback buyer buyers buyoff buyoffs buyout buyouts buys buzuki buzukia buzukis 
buzz buzzard buzzcut buzzed buzzer buzzers buzzes buzzwig byssus cachou cachous cacique 
cactus cadmium caducei caecum caesium caestus caesura cageful caique caiques cajaput cajeput 
cajuput calamus calcium calculi callous callus calque calqued calques calumet calumny cambium 
campout campus candour canful canfuls cangue cangues cannula cansful canthus cantus canula 
canulae canular canulas capful capfuls capouch capsule capture capuche caput caracul careful 
carful carfuls caribou carious carolus carouse carpus caseous casque casqued casques casual 
casuals casuist casus catchup catechu catgut catguts catsuit catsup catsups caucus caudad 
caudal caudate caudex caudle caudles caught caul cauld caulds caules cauline caulis 
caulk caulked caulker caulks cauls caus causal causals cause caused causer causers 
causes causey causeys caustic cautery caution cayuse cayuses cazique cecum cedula cedulas 
cellule censual censure census centaur centrum centu centum centums century cercus cereus 
cerium ceriums cerous cerumen ceruse ceruses cesium cesiums cestus cesura cesurae cesuras 
chabouk chabuk chabuks chalupa chalutz chanoyu chapeau charqui chateau chaufer chaunt chaunts 
checkup cheque chequer cheques cherub cherubs chetrum chiaus chibouk chillum chirrup chiru 
chirus chorus chough choughs chouse choused chouser chouses choush chub chubby chubs 
chuck chucked chuckle chucks chucky chuddah chuddar chudder chufa chufas chuff chuffed 
chuffer chuffs chuffy chug chugged chugger chugs chukar chukars chukka chukkar chukkas 
chukker chum chummed chummy chump chumped chumps chums chunk chunked chunks chunky 
chunnel chunter chuppa chuppah chuppas church churchy churl churls churn churned churner 
churns churr churred churro churros churrs chut chute chuted chutes chutist chutnee 
chutney chutzpa chylous chymous ciboule cilium cingula cinque cinques circuit circus circusy 
cirque cirques cirrous cirrus cistus citrous citrus citrusy clamour claque claquer claques 
claucht claught clausal clause clauses clavus cleanup clique cliqued cliques cliquey cliquy 
clonus cloque cloques closeup closure cloture cloud clouded clouds cloudy clough cloughs 
clour cloured clours clout clouted clouter clouts clu club clubbed clubber clubby 
clubman clubmen clubs cluck clucked clucks clue clued clues clumber clump clumped 
clumps clumpy clumsy clung clunk clunked clunker clunks clunky clupeid cluster clutch 
clutchy clutter clypeus coagula cobnut cobnuts coccous coccus cockup cockups coconut coenure 
coenuri coequal cofound cohune cohunes coitus coleus collude colobus colonus colour colours 
colugo colugos columel column columns colure colures combust commune commute comous compute 
conatus concur concurs concuss conduce conduct conduit conflux confuse confute congius congou 
congous conium coniums conjure conquer consul consuls consult consume contour contuse conus 
cookout copihue copious copout copouts copula copulae copular copulas coquet coquets coquina 
coquito corium cormous cornu cornua cornual cornus cornute cornuto corpus corrupt coruler 
costume coteau coteaux cothurn couch couched coucher couches coude cougar cougars cough 
coughed cougher coughs could couldst coulee coulees coulis couloir coulomb coulter council 
counsel count counted counter country counts county coup coupe couped coupes couple 
coupled coupler couples couplet coupon coupons coups courage courant courier courlan course 
coursed courser courses court courted courter courtly courts cousin cousins couteau couter 
couters couth couther couthie couths couture couvade coverup coypou coypous coypu coypus 
crackup cranium craunch crewcut crinum crinums crissum crittur crocus croquet croquis crouch 
croup croupe croupes croups croupy crouse croute croutes crouton cru cruces crucial 
crucian crucify cruck crucks crud crudded cruddy crude crudely cruder crudes crudest 
crudity cruds cruel crueler cruelly cruelty cruet cruets cruise cruised cruiser cruises 
cruller crumb crumbed crumber crumble crumbly crumbs crumbum crumby crummie crummy crump 
crumped crumpet crumple crumply crumps crunch crunchy crunode cruor cruors crupper crura 
crural crus crusade crusado cruse cruses cruset crusets crush crushed crusher crushes 
crusily crust crustal crusted crusts crusty crutch crux cruxes cruzado cu cuatro 
cuatros cub cubage cubages cubbies cubbish cubby cube cubeb cubebs cubed cuber 
cubers cubes cubic cubical cubicle cubicly cubics cubism cubisms cubist cubists cubit 
cubital cubiti cubits cubitus cuboid cuboids cubs cuckold cuckoo cuckoos cud cudbear 
cuddie cuddies cuddle cuddled cuddler cuddles cuddly cuddy cudgel cudgels cuds cudweed 
cue cued cues cuesta cuestas cuff cuffed cuffs cuif cuifs cuirass cuish 
cuishes cuisine cuisse cuisses cuittle cuke cukes culch culches culet culets culex 
culexes culices culicid cull cullay cullays culled culler cullers cullet cullets cullied 
cullies cullion cullis culls cully culm culmed culms culotte culpa culpae culprit 
cult cultch culti cultic cultish cultism cultist cults culture cultus culver culvers 
culvert cum cumarin cumber cumbers cumbia cumbias cumin cumins cummer cummers cummin 
cummins cumquat cumshaw cumuli cumulus cundum cundums cuneal cuneate cunn cunner cunners 
cunt cunts cup cupcake cupel cupeled cupeler cupels cupful cupfuls cupid cupids 
cuplike cupola cupolas cupp cuppa cuppas cupped cupper cuppers cuppier cuppy cupric 
cuprite cuprous cuprum cuprums cups cupsful cupula cupulae cupular cupule cupules cur 
curable curably curacao curacoa curacy curagh curaghs curara curaras curare curares curari 
curaris curate curated curates curator curb curbed curber curbers curbs curch curches 
curcuma curd curded curdier curdle curdled curdler curdles curds curdy cure cured 
curer curers cures curet curets curette curf curfew curfews curfs curia curiae 
curial curie curies curio curios curiosa curious curite curites curium curiums curl 
curled curler curlers curlew curlews curlier curlily curls curly curn curns curr 
currach curragh curran currans currant curred current currie curried currier curries currish 
currs curry curs curse cursed curser cursers curses cursive cursor cursors cursory 
curst curt curtail curtain curtal curtals curtate curter curtest curtesy curtly curtsey 
curtsy curule curv curve curved curves curvet curvets curvey curvier curvy cuscus 
cusec cusecs cushat cushats cushaw cushaws cushier cushily cushion cushy cusk cusks 
cusp cuspal cuspate cusped cuspid cuspids cuspis cusps cuss cussed cusser cussers 
cusses cusso cussos custard custody custom customs custos cut cutaway cutback cutbank 
cutch cutches cutdown cute cutely cuter cutes cutesie cutest cutesy cutey cuteys 
cuticle cutie cuties cutin cutins cutis cutises cutlas cutlass cutler cutlers cutlery 
cutlet cutlets cutline cutoff cutoffs cutout cutouts cutover cuts cutt cuttage cutter 
cutters cutties cuttle cuttled cuttles cutty cutup cutups cutwork cutworm cuvee cuvees 
cuvette cymous cyprus dadgum danseur dareful dasyure datum datums datura daturas daturic 
daub daube daubed dauber daubers daubery daubes daubier daubry daubs dauby daunder 
daunt daunted daunter daunts dauphin daut dauted dautie dauties dauts debauch debouch 
debug debugs debunk debunks debut debuted debuts decidua decorum decuman decuple decurve 
decury deduce deduced deduces deduct deducts default defocus defraud defuel defuels defunct 
defund defunds defuse defused defuser defuses defuze defuzed defuzes degauss degum degums 
degust degusts delouse delude deluded deluder deludes deluge deluged deluges deluxe demount 
demur demure demurer demurs dengue dengues denture denude denuded denuder denudes deplume 
depute deputed deputes deputy desugar detinue detour detours detrude deuc deuce deuced 
deuces deutzia devalue devious devour devours devout dhourra dhurna dhurnas dhurrie dhuti 
dhutis dibbuk dibbuks dictum dictums diffuse diluent dilute diluted diluter dilutes dilutor 
diluvia dimout dimouts dingus dinkum dinkums diquat diquats dirdum dirdums direful disbud 
disbuds discus discuss diseur diseurs diseuse disgust dishful dispute disrupt disturb disuse 
disused disuses diurnal diuron diurons divulge divulse doleful dolour dolours donut donuts 
doofus doomful dorbug dorbugs dorsum double doubled doubler doubles doublet doubly doubt 
doubted doubter doubts douce doucely douceur douche douched douches dough doughs dought 
doughty doughy doula doulas doum douma doumas doums dour doura dourah dourahs 
douras dourer dourest dourine dourly dous douse doused douser dousers douses doux 
draught drogue drogues dropout drought drouk drouked drouks drouth drouths drouthy drub 
drubbed drubber drubs drudge drudged drudger drudges drug drugged drugget druggie druggy 
drugs druid druidic druids drum drumble drumlin drumly drummed drummer drums drunk 
drunken drunker drunks drupe drupes druse druses duad duads dual dualism dualist 
duality dualize dually duals dub dubb dubbed dubber dubbers dubbin dubbins dubiety 
dubious dubnium dubs ducal ducally ducat ducats duce duces duchess duchies duchy 
duci duck ducked ducker duckers duckie duckier duckies duckpin ducks ducky duct 
ductal ducted ductile ducts ductule dud duddie duddy dude duded dudeen dudeens 
dudes dudgeon dudish duds due duel dueled dueler duelers duelist duelled dueller 
duelli duello duellos duels duende duendes dueness duenna duennas dues duet dueted 
duets duetted duff duffel duffels duffer duffers duffle duffles duffs dufus dufuses 
dug dugong dugongs dugout dugouts dugs duh dui duiker duikers duit duits 
duk duke duked dukedom dukes dulcet dulcets dulcify dulia dulias dull dullard 
dulled duller dullest dullish dulls dully dulness dulse dulses duly duma dumas 
dumb dumbed dumber dumbest dumbly dumbo dumbos dumbs dumdum dumdums dumka dumky 
dummied dummies dummy dump dumped dumper dumpers dumpier dumpily dumpish dumps dumpy 
dun dunam dunams dunce dunces dunch dunches duncish dune dunes dung dunged 
dungeon dungier dungs dungy dunite dunites dunitic dunk dunked dunker dunkers dunks 
dunlin dunlins dunn dunnage dunned dunner dunness dunnest dunnite duns dunt dunted 
dunts duo duodena duolog duologs duomi duomo duomos duopoly duos duotone dup 
dupable dupe duped duper dupers dupery dupes duple duplex dupp dupped dups 
dur dura durable durably dural duramen durance duras durbar durbars dure dured 
dures duress durian durians durion durions durmast durn durned durns duro duroc 
durocs duros durr durra durras durrie durries durrs durst durum durums dusk 
dusked duskier duskily duskish dusks dusky dust dustbin dusted duster dusters dustier 
dustily dustman dustmen dustoff dustpan dustrag dusts dustup dustups dusty dutch duteous 
duties dutiful duty duumvir duvet duvets duvetyn dybbuk dybbuks dysuria dysuric dyvour 
dyvours earbud earbuds eardrum earful earfuls earmuff earplug easeful eau eaux echinus 
eclogue ecotour ecru ecrus ecu ecus educ educate educe educed educes educt 
eductor educts eelpout efflux effulge effuse effused effuses eggcup eggcups ekuele eluant 
eluants eluate eluates elud elude eluded eluder eluders eludes eluent eluents elusion 
elusive elusory elut elute eluted elutes elution eluvia eluvial eluvium elytrum embolus 
embrue embrued embrues embrute emeu emeus emeute emeutes emu emulate emulous emus 
enamour encrust endu endue endued endues endure endured endurer endures enduro enduros 
englut engluts engulf engulfs ennui ennuis ennuye ennuyee enough enoughs enounce enquire 
enquiry ensoul ensouls ensu ensue ensued ensues ensure ensured ensurer ensures enthuse 
entrust enuf enur enure enured enures envious enwound epaulet ephebus epicure equable 
equably equal equaled equally equals equate equated equates equator equerry equid equids 
equine equines equinox equip equips equites equity erasure erbium erbiums eremuri erratum 
eruct eructed eructs erudite erugo erugos erupt erupted erupts escuage escudo escudos 
espouse esquire estrous estrual estrum estrums estrus estuary etude etudes etui etuis 
eucaine euchre euchred euchres euclase eucrite eudemon eugenia eugenic eugenol euglena eulogia 
eulogy eunuch eunuchs eupepsy euphony euphroe euploid eupnea eupneas eupneic eupnoea eureka 
euripi euripus euro euroky euros euryoky eustacy eustasy eustele eutaxy evacuee evolute 
evulse evulsed evulses exclude excuse excused excuser excuses execute exequy exergue exeunt 
exhaust exhume exhumed exhumer exhumes exodus expound expulse expunge extrude exud exudate 
exude exuded exudes exult exulted exults exurb exurban exurbia exurbs exuvia exuviae 
exuvial exuvium eyecup eyecups eyeful eyefuls fabliau fabular faceup factful factual facture 
facula faculae facular faculty fadeout failure faitour fallout famous famuli famulus fanum 
fanums faquir faquirs farceur fateful fatigue fatuity fatuous faucal faucals fauces faucet 
faucets faucial faugh fauld faulds fault faulted faults faulty faun fauna faunae 
faunal faunas fauns fauve fauves fauvism fauvist faux favour favours favus favuses 
fearful feature fecula feculae fecund felucca femur femurs fenuron fermium ferrous ferrule 
ferrum ferrums ferula ferulae ferulas ferule feruled ferules fervour fescue fescues fetus 
fetuses feu feuar feuars feud feudal feudary feuded feudist feuds feued feus 
fibrous fibula fibulae fibular fibulas fichu fichus ficus ficuses figural figure figured 
figurer figures filum fique fiques firebug fissure fistful fistula fitful fixture fixure 
fixures flaneur flareup flatus flaunt flaunts flaunty flauta flautas flavour fleuron fleury 
flexure floccus floruit flounce flouncy flour floured flours floury flout flouted flouter 
flouts flu flub flubbed flubber flubdub flubs flue flued fluency fluent flueric 
flues fluff fluffed fluffer fluffs fluffy fluid fluidal fluidic fluidly fluids fluish 
fluk fluke fluked flukes flukey flukier flukily fluky flum flume flumed flumes 
flummox flump flumped flumps flung flunk flunked flunker flunkey flunkie flunks flunky 
fluor fluoric fluorid fluorin fluors flurry flus flush flushed flusher flushes fluster 
flut flute fluted fluter fluters flutes flutey flutier flutist flutter fluty fluvial 
flux fluxed fluxes fluxion fluyt fluyts focus focused focuser focuses foetus foldout 
foldup foldups folious folium foliums fondu fondue fondued fondues fondus foregut forerun 
forkful formful formula fortune forum forums fou fouette fought foul foulard fouled 
fouler foulest foully fouls found founded founder foundry founds fount founts four 
fourgon fours fourth fourths foxhunt fractur fractus fraenum fraktur fraud frauds fraught 
frenula frenum frenums fretful friseur frounce frouzy frug frugal frugged frugs fruit 
fruited fruiter fruits fruity frump frumps frumpy frusta frustum fub fubar fubb 
fubbed fubs fubsier fubsy fuchsia fuchsin fucix fucoid fucoids fucose fucoses fucous 
fucus fucuses fud fuddies fuddle fuddled fuddles fuddy fudg fudge fudged fudges 
fuds fuehrer fuel fueled fueler fuelers fuelled fueller fuels fug fugal fugally 
fugato fugatos fugg fugged fuggier fuggily fuggy fugio fugios fugl fugle fugled 
fugles fugs fugu fugue fugued fugues fuguist fugus fuhrer fuhrers fuji fujis 
fulcra fulcrum fulfil fulfill fulfils fulgent fulgid fulham fulhams full fullam fullams 
fulled fuller fullers fullery fullest fulls fully fulmar fulmars fulmine fulness fulsome 
fulvous fum fumaric fumble fumbled fumbler fumbles fume fumed fumer fumers fumes 
fumet fumets fumette fumier fumiest fumuli fumulus fumy fun functor fund funded 
funder funders fundi fundic funds fundus funeral funest funfair funfest fungal fungals 
fungi fungic fungo fungoes fungoid fungous fungus funicle funk funked funker funkers 
funkia funkias funkier funkily funks funky funn funned funnel funnels funner funnest 
funnier funnies funnily funny funplex funs fur furan furane furanes furans furbish 
furcate furcula furfur furies furioso furious furl furled furler furlers furless furlong 
furls furmety furmity furnace furnish furor furore furores furors furr furred furrier 
furrily furrow furrows furrowy furry furs further furtive fury furze furzes furzier 
furzy fus fusain fusains fusaria fuscous fuse fused fusee fusees fusel fusels 
fuses fusible fusibly fusil fusile fusilli fusils fusion fusions fuss fussed fusser 
fussers fusses fussier fussily fusspot fussy fustian fustic fustics fustier fustily fusty 
fusuma futharc futhark futhorc futhork futile futon futons futtock futural future futures 
futz futzed futzes fuz fuze fuzed fuzee fuzees fuzes fuzil fuzils fuzz 
fuzzed fuzzes fuzzier fuzzily fuzzy gagaku gagakus gainful gallium gallnut gallous gallus 
galumph gamut gamuts gangue gangues garigue gaseous gateau gateaus gateaux gauche gaucher 
gaucho gauchos gaud gaudery gaudier gaudies gaudily gauds gaudy gauffer gaug gauge 
gauged gauger gaugers gauges gault gaults gaum gaumed gaums gaun gaunt gaunter 
gauntly gauntry gaur gaurs gauss gausses gauze gauzes gauzier gauzily gauzy gazump 
gazumps gemmule genius genu genua genuine genus genuses geoduck gerenuk gerund gerunds 
gesture getup getups geum geums ghaut ghauts ghoul ghoulie ghouls giaour giaours 
gibbous giddyup gigue gigues glamour gleeful globous globule glomus glout glouted glouts 
glu glucan glucans glucose glue glued gluepot gluer gluers glues gluey glug 
glugged glugs gluier gluiest gluily glum glume glumes glumly glummer glumpy glums 
glunch gluon gluons glut glute gluteal glutei gluten glutens glutes gluteus gluts 
glutted glutton gnu gnus goldbug goldurn gomuti gomutis gonium gouache goug gouge 
gouged gouger gougers gouges goulash gourami gourd gourde gourdes gourds gourmet gout 
goutier goutily gouts gouty gradual gradus grampus granule granum graupel gravure grayout 
grouch grouchy ground grounds group grouped grouper groupie groups grouse groused grouser 
grouses grout grouted grouter grouts grouty grownup grub grubbed grubber grubby grubs 
grudge grudged grudger grudges grue gruel grueled grueler gruels grues gruff gruffed 
gruffer gruffly gruffs gruffy grugru grugrus grum grumble grumbly grume grumes grummer 
grummet grumose grumous grump grumped grumphy grumps grumpy grunge grunger grunges grungy 
grunion grunt grunted grunter gruntle grunts grushie grutch grutten gruyere guaco guacos 
guaiac guaiacs guan guanaco guanase guanay guanays guanin guanine guanins guano guanos 
guans guar guarana guarani guard guarded guarder guards guars guava guavas guayule 
guck gucks gude gudes gudgeon guenon guenons guerdon guess guessed guesser guesses 
guest guested guests guff guffaw guffaws guffs guggle guggled guggles guglet guglets 
guid guide guided guider guiders guides guidon guidons guids guil guild guilder 
guilds guile guiled guiles guilt guilts guilty guimpe guimpes guinea guineas guipure 
guiro guiros guis guisard guise guised guises guitar guitars gul gulag gulags 
gular gulch gulches gulden guldens gules gulf gulfed gulfier gulfs gulfy gull 
gulled gullet gullets gulley gulleys gullied gullies gulls gully gulp gulped gulper 
gulpers gulpier gulps gulpy guls gum gumball gumbo gumboil gumboot gumbos gumdrop 
gumless gumlike gumline gumm gumma gummas gummata gummed gummer gummers gummier gummite 
gummose gummous gummy gums gumshoe gumtree gumweed gumwood gun gunboat gundog gundogs 
gunfire gunite gunites gunk gunkier gunks gunky gunless gunlock gunman gunmen gunn 
gunned gunnel gunnels gunnen gunner gunners gunnery gunnies gunny gunplay gunroom guns 
gunsel gunsels gunship gunshot gunwale guppies guppy gurg gurge gurged gurges gurgle 
gurgled gurgles gurglet gurnard gurnet gurnets gurney gurneys gurries gurry gursh gurshes 
guru gurus gush gushed gusher gushers gushes gushier gushily gushy gusset gussets 
gussie gussied gussies gussy gust gusted gustier gustily gusto gustoes gusts gusty 
gut gutless gutlike guts gutsier gutsily gutsy gutt gutta guttae guttate gutted 
gutter gutters guttery guttier guttle guttled guttler guttles gutty guv guvs guy 
guyed guyline guyot guyots guys guzzle guzzled guzzler guzzles gweduc gweduck gweducs 
gyplure gypsum gypsums gyrus habitue habitus habu habus hachure hackbut hafnium hagbush 
hagbut hagbuts hahnium haiku haikus haircut haku hakus haleru halibut halitus hallux 
halutz hamaul hamauls hamburg hamular hamuli hamulus handful handgun handout hangout hangul 
hangup hangups hanuman harbour harmful harumph hassium hateful hatful hatfuls hatsful hauberk 
haugh haughs haughty haul haulage hauled hauler haulers haulier haulm haulms haulmy 
hauls haunch haunt haunted haunter haunts hausen hausens haut hautboy haute hauteur 
haviour headful heaume heaumes heedful hegumen heinous helium heliums helluva helpful heuch 
heuchs heugh heughs hiatus hiccup hiccups hideous hideout hilum hilus hindgut hirsute 
hirudin hocus hocused hocuses hognut hognuts hokku hokum hokums holdout holdup holdups 
holibut holmium homburg honour honours hoodlum hookup hookups hopeful hotspur houdah houdahs 
hound hounded hounder hounds hour houri houris hourly hours hous house housed 
housel housels houser housers houses hub hubbies hubbly hubbub hubbubs hubby hubcap 
hubcaps hubris hubs huck huckle huckles hucks huddle huddled huddler huddles hue 
hued hueless hues huff huffed huffier huffily huffish huffs huffy hug huge 
hugely hugeous huger hugest hugg hugged hugger huggers hugs huh huic huipil 
huipils hula hulas hulk hulked hulkier hulks hulky hull hulled huller hullers 
hullo hulloa hulloas hulloed hulloes hulloo hulloos hullos hulls hum human humane 
humaner humanly humans humate humates humble humbled humbler humbles humbly humbug humbugs 
humdrum humeral humeri humerus humic humid humidex humidly humidor humm hummed hummer 
hummers hummock hummus humor humoral humored humors humour humours hump humped humper 
humpers humph humphed humphs humpier humps humpy hums humus humuses humvee humvees 
hun hunch hunched hunches hundred hung hunger hungers hungry hunh hunk hunker 
hunkers hunkey hunkeys hunkie hunkier hunkies hunks hunky hunnish huns hunt hunted 
hunter hunters hunts hup huppah huppahs hurdies hurdle hurdled hurdler hurdles hurds 
hurl hurled hurler hurlers hurley hurleys hurlies hurls hurly hurrah hurrahs hurray 
hurrays hurried hurrier hurries hurry hurst hursts hurt hurter hurters hurtful hurtle 
hurtled hurtles hurts husband hush hushaby hushed hushes hushful husk husked husker 
huskers huskier huskies huskily husks husky hussar hussars hussies hussy hustle hustled 
hustler hustles huswife hut hutch hutched hutches hutlike hutment huts hutt hutted 
hutzpa hutzpah hutzpas huzza huzzaed huzzah huzzahs huzzas hydrous iambus icterus ictus 
ictuses iglu iglus igneous iguana iguanas iguanid ileum ileus ileuses ilium illude 
illuded illudes illume illumed illumes illuvia imaum imaums imbrue imbrued imbrues imbrute 
imbu imbue imbued imbues immune immunes immure immured immures impetus impious impound 
impugn impugns impulse impure impurer impute imputed imputer imputes inbound inbuilt inburst 
include inconnu incrust incubi incubus incudal incudes incult incur incurs incurve incus 
incuse incused incuses indium indiums indu induce induced inducer induces induct inducts 
indue indued indues indulge indulin indult indults indusia infauna influx infuse infused 
infuser infuses ingenue ingroup ingulf ingulfs inhaul inhauls inhuman inhume inhumed inhumer 
inhumes injure injured injurer injures injury inocula inpour inpours input inputs inquest 
inquiet inquire inquiry inrun inruns inrush insculp insoul insouls insular insulin insult 
insults insure insured insurer insures intrude intrust intuit intuits inturn inturns inulase 
inulin inulins inur inure inured inures inurn inurned inurns inutile inwound iodous 
ionium ioniums iracund ireful iridium irrupt irrupts ischium issu issuant issue issued 
issuer issuers issues isthmus iterum jabiru jabirus jacobus jacuzzi jaguar jaguars jambeau 
jarful jarfuls jarsful jauk jauked jauks jaunce jaunced jaunces jaunt jaunted jaunts 
jaunty jaup jauped jaups jealous jehu jehus jejuna jejunal jejune jejunum jestful 
jesuit jesuits jeu jeux jocular jocund jodhpur jonquil jorum jorums joual jouals 
jouk jouked jouks joule joules jounce jounced jounces jouncy journal journey journo 
journos joust jousted jouster jousts joyful joyous juba jubas jubbah jubbahs jube 
jubes jubhah jubhahs jubile jubilee jubiles juco jucos judas judases judder judders 
judg judge judged judger judgers judges judo judoist judoka judokas judos jug 
juga jugal jugate jugful jugfuls jugg jugged juggle juggled juggler juggles jughead 
jugs jugsful jugula jugular jugulum jugum jugums juic juice juiced juicer juicers 
juices juicier juicily juicy jujitsu juju jujube jujubes jujuism jujuist jujus jujutsu 
juk juke jukebox juked jukes juku jukus julep juleps jumbal jumbals jumble 
jumbled jumbler jumbles jumbo jumbos jumbuck jump jumped jumper jumpers jumpier jumpily 
jumpoff jumps jumpy jun junco juncoes juncos jungle jungled jungles jungly junior 
juniors juniper junk junked junker junkers junket junkets junkie junkier junkies junkman 
junkmen junks junky junta juntas junto juntos jupe jupes jupon jupons jura 
jural jurally jurant jurants jurat jurats jurel jurels juridic juried juries jurist 
jurists juror jurors jury juryman jurymen jus jussive just justed juster justers 
justest justice justify justle justled justles justly justs jut jute jutes juts 
jutt jutted juttied jutties jutty juvenal kabuki kabukis kagu kagus kahuna kahunas 
kajeput kalium kaliums kanzu kanzus kaput kaputt karakul kashrut katsura kauri kauries 
kauris kaury kebbuck ketchup khoum khoums kiaugh kiaughs kibbutz kickup kickups kiddush 
kingcup kistful kludge kludged kludges kludgey kludgy klug kluge kluged kluges klutz 
klutzes klutzy knaur knaurs knout knouted knouts knubby knuckle knuckly knur knurl 
knurled knurls knurly knurs kombu kombus korun koruna korunas koruny koumis koumiss 
koumys koumyss kouprey kouroi kouros kousso koussos kraut krauts kreuzer kronur krubi 
krubis krubut krubuts kruller kuchen kuchens kudo kudos kudu kudus kudzu kudzus 
kue kues kufi kufis kugel kugels kukri kukris kulak kulaki kulaks kultur 
kulturs kumiss kummel kummels kumquat kumys kumyses kuna kune kunzite kurbash kurgan 
kurgans kurta kurtas kuru kurus kusso kussos kuvasz labarum labium labour labours 
labrum labrums lacquer lacquey lacuna lacunae lacunal lacunar lacunas lacune lacunes ladanum 
ladybug laguna lagunas lagune lagunes lalique landau landaus langue langues languet languid 
languor langur langurs lanugo lanugos lapful lapfuls lapsus larrup larrups larum larums 
latu lauan lauans laud lauded lauder lauders lauds laugh laughed laugher laughs 
launce launces launch launder laundry laura laurae lauras laurel laurels lauwine lawful 
lawsuit layout layouts layup layups lazuli lazulis league leagued leaguer leagues lecture 
legume legumes legumin lehua lehuas leisure leku lemur lemures lemurs leprous lettuce 
letup letups leu leucin leucine leucins leucite leucoma leud leudes leuds leukoma 
leukon leukons levulin lieu lieus lifeful ligula ligulae ligular ligulas ligule ligules 
ligure ligures likuta limbus limuli limulus linecut lineup lineups lingua linguae lingual 
lingula linkup linkups linocut linum linums linuron liquate liquefy liqueur liquid liquids 
liquify liquor liquors lithium litmus litu liturgy lobular lobule lobules locknut lockout 
lockup lockups locular locule loculed locules loculi loculus locum locums locus locust 
locusta locusts lookout lookup lookups loquat loquats lotus lotuses louche loud louden 
loudens louder loudest loudish loudly lough loughs louie louies louis louma loumas 
lounge lounged lounger lounges loungy loup loupe louped loupen loupes loups lour 
loured lours loury lous louse loused louses lousier lousily lousy lout louted 
loutish louts louver louvers louvre louvred louvres lovebug luau luaus lub lubber 
lubbers lube lubed lubes lubric lucarne luce lucence lucency lucent lucern lucerne 
lucerns luces lucid lucidly lucifer lucite lucites luck lucked luckie luckier luckies 
luckily lucks lucky lucre lucres lude ludes ludic lues luetic luetics luff 
luffa luffas luffed luffs lug luge luged luger lugers luges lugg luggage 
lugged lugger luggers luggie luggies lugs lugsail lugworm lull lullaby lulled luller 
lullers lulls lulu lulus lum luma lumas lumbago lumbar lumbars lumber lumbers 
lumen lumenal lumens lumina luminal lummox lump lumped lumpen lumpens lumper lumpers 
lumpier lumpily lumpish lumps lumpy lums luna lunacy lunar lunars lunas lunate 
lunated lunatic lunch lunched luncher lunches lune lunes lunet lunets lunette lung 
lungan lungans lunge lunged lungee lungees lunger lungers lunges lungful lungi lungis 
lungs lungyi lungyis lunier lunies luniest lunk lunker lunkers lunks lunt lunted 
lunts lunula lunulae lunular lunule lunules luny lupanar lupin lupine lupines lupins 
lupous lupulin lupus lupuses lur lurch lurched lurcher lurches lurdan lurdane lurdans 
lure lured lurer lurers lures lurex lurexes lurid luridly lurk lurked lurker 
lurkers lurks lush lushed lusher lushes lushest lushly lust lusted luster lusters 
lustful lustier lustily lustra lustral lustre lustred lustres lustrum lusts lusty lusus 
lususes lut lute lutea luteal luted lutein luteins luteous lutes luteum lutfisk 
luthern luthier lutings lutist lutists lutz lutzes luv luvs lux luxate luxated 
luxates luxe luxes luxury lyceum lyceums macaque macula maculae macular maculas macule 
maculed macules macumba maduro maduros magnum magnums maguey magueys magus mahout mahouts 
mahuang majagua makeup makeups makuta malleus mamluk mamluks manful manhunt manitou manitu 
manitus manque manteau mantua mantuas manual manuals manuary manumit manure manured manurer 
manures manus maqui maquila maquis marabou maraud marauds markup markups marque marquee 
marques marquis masque masquer masques masseur matchup mature matured maturer matures maud 
maudlin mauds mauger maugre maul mauled mauler maulers mauls maumet maumets maun 
maund maunder maunds maundy maut mauts mauve mauves maximum maybush mazuma mazumas 
mazurka measure meatus medium mediums medius medulla medusa medusae medusal medusan medusas 
mentum menu menudo menudos menus meou meoued meous mercury mesclun meshuga mesquit 
metump metumps mezquit mezuza mezuzah mezuzas mezuzot miaou miaoued miaous miaul miauled 
miauls midcult midgut midguts milieu milieus milieux milium millrun mindful minibus minimum 
minium miniums minuend minuet minuets minus minuses minute minuted minuter minutes minutia 
miscue miscued miscues miscut miscuts misrule missout missuit missus misteuk mistune misuse 
misused misuser misuses mixture mixup mixups mizuna mizunas moanful mockup mockups modicum 
modular module modules moduli modulo modulus modus moghul moghuls mogul moguled moguls 
mohur mohurs mollusc mollusk momus momuses monuron morceau morgue morgues morula morulae 
morular morulas mosque mosques mouch mouched mouches moue moues mouflon mouille moujik 
moujiks moulage mould moulded moulder moulds mouldy moulin moulins moult moulted moulter 
moults mound mounded mounds mount mounted mounter mounts mourn mourned mourner mourns 
mous mousaka mouse moused mouser mousers mouses mousey mousier mousily mousse moussed 
mousses mousy mouth mouthed mouther mouths mouthy mouton moutons mu much muches 
muchly mucho mucid mucin mucins muck mucked mucker muckers muckier muckily muckle 
muckles mucks mucky mucluc muclucs mucoid mucoids mucor mucors mucosa mucosae mucosal 
mucosas mucose mucous mucro mucus mucuses mud mudbug mudbugs mudcap mudcaps mudcat 
mudcats mudd mudded mudder mudders muddied muddier muddies muddily muddle muddled muddler 
muddles muddly muddy mudfish mudflap mudflat mudflow mudhen mudhens mudhole mudlark mudpack 
mudra mudras mudrock mudroom muds mudsill mueddin muesli mueslis muezzin muff muffed 
muffin muffins muffle muffled muffler muffles muffs mufti muftis mug mugful mugfuls 
mugg muggar muggars mugged muggee muggees mugger muggers muggier muggily muggins muggs 
muggur muggurs muggy mughal mughals mugs mugwort mugwump muhlies muhly mujik mujiks 
mukluk mukluks muktuk muktuks mul mulatto mulch mulched mulches mulct mulcted mulcts 
mule muled mules muleta muletas muley muleys mulish mull mulla mullah mullahs 
mullas mulled mullein mullen mullens muller mullers mullet mullets mulley mulleys mullion 
mullite mullock mulls multure mum mumble mumbled mumbler mumbles mumbly mumm mummed 
mummer mummers mummery mummied mummies mummify mumms mummy mump mumped mumper mumpers 
mumps mums mumu mumus mun munch munched muncher munches mundane mungo mungoes 
mungos muni munis munnion muns munster munt muntin muntins muntjac muntjak muon 
muonic muonium muons mur mura mural muraled murals muras murder murders mure 
mured murein mureins mures murex murexes muriate murices murid murids murine murines 
murk murker murkest murkier murkily murkly murks murky murmur murmurs murphy murr 
murra murrain murras murre murres murrey murreys murrha murrhas murries murrine murrs 
murry murther mus musca muscae muscat muscats muscid muscids muscle muscled muscles 
muscly muse mused museful muser musers muses musette museum museums mush mushed 
musher mushers mushes mushier mushily mushy music musical musick musicks musics musings 
musjid musjids musk muskeg muskegs musket muskets muskie muskier muskies muskily muskit 
muskits muskox muskrat musks musky muslin muslins muspike muss mussed mussel mussels 
musses mussier mussily mussy must mustang mustard musted mustee mustees muster musters 
musth musths mustier mustily musts musty mut mutable mutably mutagen mutant mutants 
mutase mutases mutate mutated mutates mutch mutches mute muted mutedly mutely muter 
mutes mutest mutine mutined mutines mutiny mutism mutisms muton mutons muts mutt 
mutter mutters mutton muttons muttony mutts mutual mutuals mutuel mutuels mutular mutule 
mutules muumuu muumuus muzhik muzhiks muzjik muzjiks muzzier muzzily muzzle muzzled muzzler 
muzzles muzzy naevus nairu nairus natrium natural nature natured natures naught naughts 
naughty nauplii nausea nauseas nautch nautili nebula nebulae nebular nebulas nebule nebuly 
needful negus neguses nelumbo nervous nervule nervure netsuke neuk neuks neum neume 
neumes neumic neums neural neurine neuroid neuroma neuron neurone neurons neurula neustic 
neuston neuter neuters neutral neutron nevus nexus nexuses nidus niduses nilgau nilgaus 
nilghau nimbus nimious niobium niobous nisus nitrous niveous noctuid noctule nocturn nocuous 
nodous nodular nodule nodules nodus nondrug nonfuel nonjury nonplus nonsuch nonsuit nonuple 
nonuse nonuser nonuses nostrum notum nougat nougats nought noughts noumena noun nounal 
nouns nourish nous nouses nouveau noxious nu nuance nuanced nuances nub nubbier 
nubbin nubbins nubble nubbles nubbly nubby nubia nubias nubile nubs nubuck nubucks 
nucelli nucha nuchae nuchal nuchals nucleal nuclear nuclei nuclein nucleon nucleus nuclide 
nude nudely nuder nudes nudest nudg nudge nudged nudger nudgers nudges nudie 
nudies nudism nudisms nudist nudists nudity nudnick nudnik nudniks nudzh nudzhed nudzhes 
nugget nuggets nuggety nuk nuke nuked nukes null nullah nullahs nulled nullify 
nullity nulls numb numbat numbats numbed number numbers numbest numbles numbly numbs 
numen numeral numeric numina nummary nun nunatak nuncio nuncios nuncle nuncles nunlike 
nunnery nunnish nuns nuptial nurd nurds nurl nurled nurls nurs nurse nursed 
nurser nursers nursery nurses nurture nus nut nutant nutate nutated nutates nutcase 
nutgall nutlet nutlets nutlike nutmeat nutmeg nutmegs nutpick nutria nutrias nuts nutsier 
nutsy nutt nutted nutter nutters nuttier nuttily nutty nutwood nuzzle nuzzled nuzzler 
nuzzles nylghau oakum oakums obelus oblique obloquy obolus obscure obsequy obtrude obtund 
obtunds obtuse obtuser obvious occiput occlude occult occults occupy occur occurs ocellus 
ochrous octopus octuple octuply ocular oculars oculi oculist oculus odeum odeums odious 
odium odiums odorful odorous odour odours oestrum oestrus oeuvre oeuvres offcut offcuts 
oidium oilcup oilcups oleum oleums omasum omentum ominous omnibus onerous onium onrush 
onus onuses opaque opaqued opaquer opaques opium opiums opossum oppugn oppugns optimum 
opulent opuntia opus opuses oquassa ordure ordures organum ormolu ormolus orotund oscula 
oscular oscule oscules osculum osmious osmium osmiums osmous osmund osmunda osmunds osseous 
ossuary ostium ouabain ouch ouched ouches oud ouds ought oughted oughts ouguiya 
ounce ounces ouph ouphe ouphes ouphs our ourang ourangs ourari ouraris ourebi 
ourebis ourie ours ourself ousel ousels oust ousted ouster ousters ousts out 
outact outacts outadd outadds outage outages outask outasks outate outback outbake outbark 
outbawl outbeam outbeg outbegs outbid outbids outbox outbrag outbred outbulk outburn outbuy 
outbuys outby outbye outcall outcast outchid outcity outcome outcook outcrop outcrow outcry 
outdare outdate outdid outdo outdoer outdoes outdone outdoor outdrag outdraw outdrew outdrop 
outduel outearn outeat outeats outecho outed outer outers outface outfall outfast outfawn 
outfeel outfelt outfind outfire outfish outfit outfits outflew outflow outfly outfool outfoot 
outfox outgain outgas outgave outgaze outgive outglow outgnaw outgo outgoes outgone outgrew 
outgrin outgrow outgun outguns outgush outhaul outhear outhit outhits outhowl outhunt outings 
outjinx outjump outjut outjuts outkeep outkept outkick outkill outkiss outlaid outlain outland 
outlast outlaw outlaws outlay outlays outlead outleap outled outlet outlets outlie outlier 
outlies outline outlive outlook outlove outman outmans outmode outmost outmove outpace outpass 
outpity outplan outplay outplod outplot outpoll outport outpost outpour outpray outpull outpush 
output outputs outr outrace outrage outran outrang outrank outrate outrave outre outread 
outride outrig outrigs outroar outrock outrode outroll outroot outrow outrows outrun outrung 
outruns outrush outs outsaid outsail outsang outsat outsaw outsay outsays outsee outseen 
outsees outsell outsert outset outsets outshot outside outsin outsins outsit outsits outsize 
outsoar outsold outsole outspan outsped outstay outsulk outsung outswam outswim outswum outtake 
outtalk outtask outtell outtold outtrot outturn outvie outvied outvies outvote outwait outwalk 
outwar outward outwars outwash outwear outweep outwent outwept outwile outwill outwind outwish 
outwit outwith outwits outwore outwork outworn outwrit outyell outyelp ouzel ouzels ouzo 
ouzos overbuy overcut overdub overdue overrun oversup overuse oviduct ovular ovulary ovulate 
ovule ovules ovum ozonous pablum pablums pabular pabulum pachuco padauk padauks padouk 
padouks pageful pagurid pailful painful pallium palmful palpus paludal pandour pandura panful 
panfuls panicum pantoum papadum pappous pappus papula papulae papular papule papules papyrus 
pareu pareus parlour parlous parous parquet parura paruras parure parures parvenu pasquil 
passus pasteup pasture paucity paughty paulin paulins paunch paunchy pauper paupers paus 
pausal pause paused pauser pausers pauses paviour payout payouts peanut peanuts peculia 
peepul peepuls pelorus penguin penuche penuchi penult penults penury peplum peplums peplus 
percuss perdu perdue perdues perdure perdus perfume perfumy perfuse perique peritus perjure 
perjury permute perturb peruke peruked perukes perusal peruse perused peruser peruses petasus 
petrous petunia pfui phallus phoebus phut phuts phylum piceous pickup pickups picquet 
picture picul piculs pignus pignut pignuts pigout pigouts pilau pilaus pileous pileum 
pileup pileups pileus pilous pilular pilule pilules pilus pinetum pinguid pinnula pinnule 
pinup pinups pious piously pipeful piqu piquant pique piqued piques piquet piquets 
piragua pirogue piroque pistou pistous piteous pitiful piu plague plagued plaguer plagues 
plaguey plaguy planula plaque plaques plateau plaudit playful plenum plenums pleura pleurae 
pleural pleuras pleuron plexus plough ploughs pluck plucked plucker plucks plucky plug 
plugged plugger plugola plugs plum plumage plumate plumb plumbed plumber plumbic plumbs 
plumbum plume plumed plumes plumier plummer plummet plummy plumose plump plumped plumpen 
plumper plumply plumps plums plumule plumy plunder plunge plunged plunger plunges plunk 
plunked plunker plunks plunky plural plurals plus pluses plush plusher plushes plushly 
plushy plusses plutei pluteus pluton plutons pluvial pluvian pneuma pneumas podium podiums 
poilu poilus pollute polypus pomatum pompous popgun popguns popular porous poseur poseurs 
possum possums posture potful potfuls potluck pouch pouched pouches pouchy pouf poufed 
pouff pouffe pouffed pouffes pouffs pouffy poufs poulard poult poulter poultry poults 
pounce pounced pouncer pounces pound poundal pounded pounder pounds pour poured pourer 
pourers pours poussie pout pouted pouter pouters poutful poutier poutine pouts pouty 
poyou poyous prahu prahus prau praus prebuy prebuys precoup precure precut precuts 
predusk prefund prelude premium premune prepuce prepupa prequel presume prevue prevued prevues 
priapus primula primus procure prodrug produce product profuse progun pronoun proteus protium 
proud prouder proudly prude prudent prudery prudes prudish prun prune pruned pruner 
pruners prunes prunus prurigo prussic pruta prutah prutot prutoth pseud pseudo pseudos 
pseuds ptui pub puberal puberty pubes pubic pubis public publics publish pubs 
puccoon puce puces puck pucka pucker puckers puckery puckish pucks pud pudd 
puddle puddled puddler puddles puddly pudency pudenda pudgier pudgily pudgy pudic puds 
pueblo pueblos puerile puff puffed puffer puffers puffery puffier puffily puffin puffins 
puffs puffy pug pugaree pugg pugged puggier puggish puggree puggry puggy pugh 
pugmark pugree pugrees pugs puisne puisnes puja pujah pujahs pujas puk puke 
puked pukes pukka pul pula pule puled puler pulers pules puli pulik 
pulings pulis pull pulled puller pullers pullet pullets pulley pulleys pullman pullout 
pulls pullup pullups pulp pulpal pulped pulper pulpers pulpier pulpily pulpit pulpits 
pulpous pulps pulpy pulque pulques puls pulsant pulsar pulsars pulsate pulse pulsed 
pulser pulsers pulses pulsion pulvini puma pumas pumelo pumelos pumice pumiced pumicer 
pumices pummel pummelo pummels pump pumped pumper pumpers pumpkin pumps pun puna 
punas punch punched puncher punches punchy pundit pundits pung pungent pungle pungled 
pungles pungs punier puniest punily punish punji punjis punk punka punkah punkahs 
punkas punker punkers punkest punkey punkeys punkie punkier punkies punkin punkins punkish 
punks punky punn punned punner punners punnet punnets punnier punny puns punster 
punt punted punter punters punties punto puntos punts punty puny pup pupa 
pupae pupal puparia pupas pupate pupated pupates pupfish pupil pupilar pupils pupp 
pupped puppet puppets puppies puppy pups pupu pupus pur purana puranas puranic 
purda purdah purdahs purdas pure puree pureed purees purely purer purest purfle 
purfled purfler purfles purg purge purged purger purgers purges puri purify purin 
purine purines purins puris purism purisms purist purists puritan purity purl purled 
purlieu purlin purline purlins purloin purls purple purpled purpler purples purply purport 
purpose purpura purpure purr purred purrs purs purse pursed purser pursers purses 
pursier pursily pursue pursued pursuer pursues pursuit pursy purtier purty purvey purveys 
purview pus puses push pushed pusher pushers pushes pushful pushier pushily pushpin 
pushrod pushup pushups pushy pusley pusleys puslike puss pusses pussier pussies pussley 
pussly pussy pustule put putamen putdown putlog putlogs putoff putoffs puton putons 
putout putouts putrefy putrid puts putsch putt putted puttee puttees putter putters 
putti puttie puttied puttier putties putto putts putty putz putzed putzes puzzle 
puzzled puzzler puzzles pylorus pyuria pyurias qiviut qiviuts qua quack quacked quacks 
quacky quad quadded quadrat quadric quads quaere quaeres quaff quaffed quaffer quaffs 
quag quagga quaggas quaggy quags quahaug quahog quahogs quai quaich quaichs quaigh 
quaighs quail quailed quails quaint quais quak quake quaked quaker quakers quakes 
quakier quakily quaky quale qualia qualify quality qualm qualms qualmy quamash quango 
quangos quant quanta quantal quanted quantic quants quantum quare quark quarks quarrel 
quarry quart quartan quarte quarter quartes quartet quartic quarto quartos quarts quartz 
quasar quasars quash quashed quasher quashes quasi quass quasses quassia quassin quate 
quatre quatres quaver quavers quavery quay quayage quays qubit qubits qubyte qubytes 
quean queans queasy queazy queen queened queenly queens queer queered queerer queerly 
queers quelea queleas quell quelled queller quells quench querida queried querier queries 
querist quern querns query quest quested quester questor quests quetzal queu queue 
queued queuer queuers queues quey queys quezal quezals quibble quiche quiches quick 
quicken quicker quickie quickly quicks quid quids quiet quieted quieten quieter quietly 
quiets quietus quiff quiffs quill quillai quilled quillet quills quilt quilted quilter 
quilts quin quinary quinate quince quinces quinela quinic quinin quinina quinine quinins 
quinnat quinoa quinoas quinoid quinol quinols quinone quins quinsy quint quinta quintal 
quintan quintar quintas quinte quintes quintet quintic quintin quints quip quipped quipper 
quippu quippus quippy quips quipu quipus quir quire quired quires quirk quirked 
quirks quirky quirt quirted quirts quit quitch quite quits quitted quitter quittor 
quiver quivers quivery quixote quiz quizzed quizzer quizzes quod quods quohog quohogs 
quoin quoined quoins quoit quoited quoits quokka quokkas quoll quolls quomodo quondam 
quorum quorums quot quota quotas quote quoted quoter quoters quotes quoth quotha 
qursh qurshes qurush rackful racquet radium radiums radius radula radulae radular radulas 
ragout ragouts railbus rainout raku rakus ramous ramus rancour ranula ranular ranulas 
rapture rasure rasures raucity raucous raunch raunchy readout reargue rebegun rebound rebuff 
rebuffs rebuild rebuilt rebuke rebuked rebuker rebukes rebury rebus rebuses rebut rebuts 
rebuy rebuys recluse recount recoup recoupe recoups recruit rectum rectums rectus recur 
recurs recurve recusal recuse recused recuses recut recuts redbud redbuds redbug redbugs 
redoubt redound redout redouts redub redubs reduce reduced reducer reduces redux reequip 
reflux refocus refound refuel refuels refuge refuged refugee refuges refugia refund refunds 
refusal refuse refused refuser refuses refutal refute refuted refuter refutes regauge regius 
reglue reglued reglues regnum regroup regular reguli regulus rehouse rehung reincur reissue 
rejudge relique reluct relucts relume relumed relumes remount remuda remudas reoccur replumb 
repour repours repugn repugns repulse repump repumps repute reputed reputes request requiem 
requin requins require requite reroute rerun reruns rescue rescued rescuer rescues reseau 
reseaus reseaux residua residue resound restful restudy restuff result results resume resumed 
resumer resumes resurge retinue retouch retune retuned retunes return returns retuse reunify 
reunion reunite reus reuse reused reuses reutter revalue revenue revue revues revuist 
rewound rhamnus rhenium rhesus rheum rheumic rheums rheumy rhodium rhombus rhubarb rhumb 
rhumba rhumbas rhumbs rhus rhuses ricinus rictus rigour rigours rimous riotous risque 
risus risuses ritual rituals rivulet robust robusta roebuck rogu rogue rogued roguery 
rogues roguish rollout romaunt rondeau rondure roomful roque roques roquet roquets rorqual 
rosebud rostrum rotgut rotguts rotund rotunda rouble roubles rouche rouches roue rouen 
rouens roues roug rouge rouged rouges rough roughed roughen rougher roughly roughs 
roughy rouille roulade rouleau round rounded roundel rounder roundly rounds roundup roup 
rouped roupet roupier roupily roups roupy rous rouse roused rouser rousers rouses 
roust rousted rouster rousts rout route routed router routers routes routh rouths 
routine routs roux ru ruana ruanas rub rubaboo rubace rubaces rubasse rubati 
rubato rubatos rubb rubbed rubber rubbers rubbery rubbies rubbish rubble rubbled rubbles 
rubbly rubby rubdown rube rubel rubella rubels rubeola rubes rubidic rubied rubier 
rubies rubiest rubigo rubigos rubious ruble rubles ruboff ruboffs rubout rubouts rubric 
rubrics rubs rubus ruby ruch ruche ruched ruches ruck rucked ruckle ruckled 
ruckles rucks ruckus ruction rudd rudder rudders ruddier ruddily ruddle ruddled ruddles 
ruddock rudds ruddy rude rudely ruder ruderal rudery rudesby rudest rue rued 
rueful ruer ruers rues ruff ruffe ruffed ruffes ruffian ruffle ruffled ruffler 
ruffles ruffly ruffs rufiyaa rufous rug ruga rugae rugal rugate rugbies rugby 
rugg rugged rugger ruggers ruglike rugola rugolas rugosa rugosas rugose rugous rugs 
ruin ruinate ruined ruiner ruiners ruinous ruins rul rulable rule ruled ruler 
rulers rules rulier ruliest rulings ruly rum rumaki rumakis rumba rumbaed rumbas 
rumble rumbled rumbler rumbles rumbly rumen rumens rumina ruminal rummage rummer rummers 
rummest rummier rummies rummy rumor rumored rumors rumour rumours rump rumple rumpled 
rumples rumply rumps rumpus rums run runaway runback rundle rundles rundlet rundown 
rune runes rung rungs runic runkle runkled runkles runless runlet runlets runn 
runnel runnels runner runners runnier runny runoff runoffs runout runouts runover runs 
runt runtier runtish runts runty runway runways rupee rupees rupiah rupiahs rupture 
rural rurally rurban ruse ruses rush rushed rushee rushees rusher rushers rushes 
rushier rushy rusine rusk rusks russet russets russety russify rust rusted rustic 
rustics rustier rustily rustle rustled rustler rustles rusts rusty rut ruth ruthful 
ruths rutile rutiles rutin rutins ruts rutt rutted ruttier ruttily ruttish rutty 
sacbut sacbuts saccule sacculi sackbut sackful sacque sacques sacrum sacrums saddhu saddhus 
sadhu sadhus sagbut sagbuts saguaro sagum sahuaro sajou sajous saluki salukis salute 
saluted saluter salutes sambhur sambuca sambuke sambur samburs samshu samshus samurai sanctum 
sandbur sanious sannup sannups santimu santour santur santurs sapajou sapour sapours sarcous 
sardius satsuma sau sauc sauce sauced saucer saucers sauces sauch sauchs saucier 
saucily saucy sauger saugers saugh saughs saughy saul sauls sault saults sauna 
saunaed saunas saunter saurel saurels saurian sauries saury sausage saute sauted sauteed 
sautes sautoir saviour savour savours savoury sawbuck sawdust saxtuba scaleup scapula scaup 
scauper scaups scaur scaurs schlub schlubs schlump schmuck schuit schuits schul schuln 
schuls schuss sciurid scopula scour scoured scourer scourge scours scouse scouses scout 
scouted scouter scouth scouths scouts screwup scrotum scrouge scrub scrubby scrubs scruff 
scruffs scruffy scrum scrums scrunch scruple scuba scubaed scubas scud scudded scudi 
scudo scuds scuff scuffed scuffer scuffle scuffs sculch sculk sculked sculker sculks 
scull sculled sculler sculls sculp sculped sculpin sculps sculpt sculpts scultch scum 
scumbag scumble scummed scummer scummy scums scunner scup scupper scups scurf scurfs 
scurfy scurril scurry scurvy scut scuta scutage scutate scutch scute scutes scuts 
scutter scuttle scutum scuzz scuzzes scuzzy scyphus seagull sebum sebums seclude secular 
secund secure secured securer secures seduce seduced seducer seduces sedum sedums segue 
segued segues seisure seizure sellout sendup sendups senryu sensual sensum seppuku septum 
septums sequel sequela sequels sequent sequin sequins sequoia serious serous serum serumal 
serums setous setout setouts setup setups sevruga sexual sfumato shaduf shadufs shakeup 
shamus shapeup shaugh shaughs shaul shauled shauls sheuch sheuchs sheugh sheughs shiatsu 
shiatzu shlub shlubs shlump shlumps shlumpy shmuck shmucks shogun shoguns shotgun should 
shout shouted shouter shouts shoyu shoyus shroud shrouds shrub shrubby shrubs shrug 
shrugs shrunk shuck shucked shucker shucks shudder shuffle shul shuln shuls shun 
shunned shunner shuns shunt shunted shunter shunts shush shushed shusher shushes shut 
shute shuted shutes shuteye shutoff shutout shuts shutter shuttle sickout siddur siddurs 
sieur sieurs siglum silenus siliqua silique silurid simious simular sinful sinuate sinuous 
sinus sinuses sirup siruped sirups sirupy sistrum situate situp situps situs situses 
skellum skilful skinful skookum skua skuas skulk skulked skulker skulks skull skulled 
skulls skunk skunked skunks skunky skysurf sleuth sleuths slipout slipup slipups slouch 
slouchy slough sloughs sloughy slu slub slubbed slubber slubs sludge sludged sludges 
sludgy slue slued slues sluff sluffed sluffs slug slugged slugger slugs sluice 
sluiced sluices sluicy slum slumber slumgum slumism slummed slummer slummy slump slumped 
slumps slums slung slunk slur slurb slurban slurbs slurp slurped slurps slurred 
slurry slurs slush slushed slushes slushy slut sluts slutty smashup smeddum smudge 
smudged smudges smudgy smug smugger smuggle smugly smush smushed smushes smut smutch 
smutchy smuts smutted smutty snafu snafued snafus snout snouted snouts snouty snub 
snubbed snubber snubby snubs snuck snuff snuffed snuffer snuffle snuffly snuffs snuffy 
snug snugged snugger snuggle snugly snugs sobful sodium sodiums soilure sojourn solanum 
soleus solidus soluble solubly solum solums solunar solus solute solutes songful sorghum 
sorus sou souari souaris soubise soucar soucars soudan soudans souffle sough soughed 
soughs sought souk soukous souks soul souled soulful souls sound sounded sounder 
soundly sounds soup soupcon souped soupier soups soupy sour source sourced sources 
soured sourer sourest sourish sourly sours soursop sous souse soused souses souslik 
soutane souter souters south southed souther souths soyuz soyuzes spatula specula speedup 
spelunk spicula spicule spinous spinout spinula spinule spirula splurge splurgy sporule spousal 
spouse spoused spouses spout spouted spouter spouts sprout sprouts spruce spruced sprucer 
spruces sprucy sprue sprues sprug sprugs sprung spu spud spudded spudder spuds 
spue spued spues spum spume spumed spumes spumier spumone spumoni spumous spumy 
spun spunk spunked spunkie spunks spunky spur spurge spurges spurn spurned spurner 
spurns spurred spurrer spurrey spurry spurs spurt spurted spurter spurtle spurts sputa 
sputnik sputter sputum squab squabby squabs squad squads squalid squall squalls squally 
squalor squama squamae square squared squarer squares squark squarks squash squashy squat 
squatly squats squatty squaw squawk squawks squaws squeak squeaks squeaky squeal squeals 
squeeze squeg squegs squelch squib squibs squid squids squiffy squill squilla squills 
squinch squinny squint squints squinty squire squired squires squirm squirms squirmy squirt 
squirts squish squishy squoosh squush stackup stadium standup stannum startup statue statued 
statues stature status statusy statute staunch sternum stewbum stibium stickum stickup stimuli 
stipule stirrup stound stounds stoup stoups stour stoure stoures stourie stours stoury 
stout stouten stouter stoutly stouts stratum stratus stroud strouds struck strudel strum 
struma strumae strumas strums strung strunt strunts strut struts stub stubbed stubble 
stubbly stubby stubs stucco stuccos stuck stud studded studdie student studied studier 
studies studio studios studly studs study stuff stuffed stuffer stuffs stuffy stuiver 
stull stulls stum stumble stummed stump stumped stumper stumps stumpy stums stun 
stung stunk stunned stunner stuns stunt stunted stunts stupa stupas stupe stupefy 
stupes stupid stupids stupor stupors sturdy sturt sturts stutter stylus su suable 
suably suasion suasive suasory suave suavely suaver suavest suavity sub suba subacid 
subadar subah subahs subalar subarea subarid subas subatom subb subbase subbass subbed 
subcell subclan subcode subcool subcult subdean subdeb subdebs subdual subduce subduct subdue 
subdued subduer subdues subecho subedit suber suberic suberin subers subfile subfix subfusc 
subgoal subgum subgums subhead subidea subitem subito subject subjoin sublate sublet sublets 
sublime subline sublot sublots submenu submiss submit submits subnet subnets suboral suborn 
suborns suboval subpar subpart subpena subplot subr subrace subrent subrule subs subsale 
subsea subsect subsere subset subsets subside subsidy subsist subsite subsoil subsume subtask 
subtaxa subteen subtend subtest subtext subtile subtle subtler subtly subtone subtype subunit 
suburb suburbs subvene subvert subway subways subzero subzone succah succahs succeed success 
succor succors succory succoth succour succuba succubi succumb succuss such suck sucked 
sucker suckers suckier suckle suckled suckler suckles sucks sucky sucrase sucre sucres 
sucrose suction sudaria sudary sudd sudden suddens sudds sudor sudoral sudors suds 
sudsed sudser sudsers sudses sudsier sudsy sue sued suede sueded suedes suer 
suers sues suet suets suety suffari suffer suffers suffice suffix suffuse sugar 
sugared sugarer sugars sugary suggest sugh sughed sughs suicide suint suints suit 
suite suited suiter suiters suites suitor suitors suits suk sukkah sukkahs sukkot 
sukkoth suks sulcal sulcate sulci sulcus suldan suldans sulfa sulfas sulfate sulfid 
sulfide sulfids sulfite sulfo sulfone sulfur sulfurs sulfury sulk sulked sulker sulkers 
sulkier sulkies sulkily sulks sulky sullage sullen sullied sullies sully sulpha sulphas 
sulphid sulphur sultan sultana sultans sultry sulu sulus sum sumac sumach sumachs 
sumacs sumless summ summa summae summand summary summas summate summed summer summers 
summery summit summits summon summons sumo sumoist sumos sump sumps sumpter sums 
sun sunback sunbath sunbeam sunbelt sunbird sunbow sunbows sunburn sundae sundaes sundeck 
sunder sunders sundew sundews sundial sundog sundogs sundown sundry sunfast sunfish sung 
sunglow sunk sunken sunket sunkets sunlamp sunland sunless sunlike sunlit sunn sunna 
sunnah sunnahs sunnas sunned sunnier sunnily sunns sunny sunray sunrays sunrise sunroof 
sunroom suns sunset sunsets sunspot sunsuit suntan suntans sunup sunups sunward sunwise 
sup supe super superb supered supers supes supine supines supp supped supper 
suppers supple suppled suppler supples supply support suppose supra supreme supremo sups 
suq suqs sura surah surahs sural suras surbase surcoat surd surds sure 
surely surer surest surety surf surface surfed surfeit surfer surfers surfier surfman 
surfmen surfs surfy surg surge surged surgeon surger surgers surgery surges surgy 
surimi surimis surlier surlily surly surmise surname surpass surplus surra surras surreal 
surrey surreys surtax surtout surveil survey surveys survive sushi sushis suslik susliks 
suspect suspend suspire suss sussed susses sustain sutler sutlers sutra sutras sutta 
suttas suttee suttees sutural suture sutured sutures swayful swoun swound swounds swouned 
swouns swum swung synfuel synura synurae syrup syruped syrups syrupy tableau tabouli 
tabour tabours tabu tabued tabular tabuli tabulis tabun tabuns tabus tactful tactual 
takeout takeup takeups talcous talcum talcums taluk taluka talukas taluks talus taluses 
tamandu tamarau tambour tambur tambura tamburs tankful tantrum tanuki tanukis tapetum tarbush 
tarsus tartufe tatouay tau taught taunt taunted taunter taunts tauon tauons taupe 
taupes taurine taus taut tautaug tauted tauten tautens tauter tautest tautly tautog 
tautogs tauts taxus teacup teacups tearful tectum tectums tedious tedium tediums teenful 
tegua teguas tegular tegumen teledu teledus telium tempura tendu tendus tenour tenours 
tenues tenuis tenuity tenuous tenure tenured tenures tenuti tenuto tenutos tequila terbium 
tergum testudo tetanus tetotum teuch teugh teughly textual texture thallus theurgy thorium 
thou thoued though thought thous through thru thrum thrummy thrums thruput thrush 
thrust thrusts thruway thud thudded thuds thug thuggee thugs thuja thujas thulia 
thulias thulium thumb thumbed thumbs thump thumped thumper thumps thunder thunk thunked 
thunks thurl thurls thus thusly thuya thuyas thymus thyrsus tilbury timarau timeous 
timeout tinamou tinful tinfuls tissual tissue tissued tissues tissuey tittup tittups titular 
tofu tofus tofutti togue togues toilful tolu toluate toluene toluic toluid toluide 
toluids toluol toluole toluols tolus toluyl toluyls tongue tongued tongues tonneau tonsure 
tonus tonuses topful topfull tophus toque toques toquet toquets torous torque torqued 
torquer torques torture torula torulae torulas torus tossup tossups toucan toucans touch 
touche touched toucher touches touchup touchy tough toughed toughen tougher toughie toughly 
toughs toughy toupee toupees tour touraco toured tourer tourers tourism tourist tourney 
tours tous touse toused touses tousle tousled tousles tout touted touter touters 
touts touzle touzled touzles traduce tragus trauma traumas trayful tribune tribute triduum 
trismus tritium triumph triune triunes trivium troilus trouble trough troughs trounce troupe 
trouped trouper troupes trouser trout trouts trouty tru truancy truant truants truc 
truce truced truces truck trucked trucker truckle trucks trudge trudged trudgen trudger 
trudges true trued truer trues truest truffe truffes truffle trug trugs truism 
truisms trull trulls truly trumeau trump trumped trumpet trumps trundle trunk trunked 
trunks trunnel truss trussed trusser trusses trust trusted trustee truster trustor trusts 
trusty truth truths tryout tryouts tsouris tsuba tsunami tsuris tuatara tuatera tub 
tuba tubae tubaist tubal tubas tubate tubb tubbed tubber tubbers tubbier tubby 
tube tubed tuber tubers tubes tubful tubfuls tubifex tubings tubist tubists tublike 
tubs tubular tubule tubules tubulin tuchun tuchuns tuck tucked tucker tuckers tucket 
tuckets tucks tufa tufas tuff tuffet tuffets tuffs tufoli tuft tufted tufter 
tufters tuftier tuftily tufts tufty tug tugboat tugg tugged tugger tuggers tughrik 
tugless tugrik tugriks tugs tui tuille tuilles tuis tuition tuladi tuladis tule 
tules tulip tulips tulle tulles tumble tumbled tumbler tumbles tumbrel tumbril tumefy 
tumesce tumid tumidly tummies tummler tummy tumor tumoral tumors tumour tumours tump 
tumped tumps tumular tumuli tumult tumults tumulus tun tuna tunable tunably tunas 
tundish tundra tundras tune tuned tuneful tuner tuners tunes tuneup tuneups tung 
tungs tunic tunica tunicae tunicle tunics tunn tunnage tunned tunnel tunnels tunnies 
tunny tuns tup tupelo tupelos tupik tupiks tupp tupped tups tuque tuques 
turaco turacos turacou turban turbans turbary turbeth turbid turbine turbit turbith turbits 
turbo turbos turbot turbots turd turdine turds tureen tureens turf turfed turfier 
turfman turfmen turfs turfski turfy turgent turgid turgite turgor turgors turion turions 
turista turk turkey turkeys turkois turks turmoil turn turned turner turners turnery 
turnip turnips turnkey turnoff turnon turnons turnout turns turnup turnups turpeth turps 
turret turrets turtle turtled turtler turtles turves tusche tusches tush tushed tushery 
tushes tushie tushies tushy tusk tusked tusker tuskers tusks tussah tussahs tussal 
tussar tussars tusseh tussehs tusser tussers tusses tussis tussive tussle tussled tussles 
tussock tussor tussore tussors tussuck tussur tussurs tut tutee tutees tutelar tutor 
tutored tutors tutoyed tutoyer tuts tutt tutted tutti tutties tuttis tutty tutu 
tutued tutus tux tuxedo tuxedos tuxes tuyer tuyere tuyeres tuyers typhous typhus 
tzuris uakari uakaris ubiety ubique udder udders udo udon udons udos ufology 
ugh ughs uglier uglies ugliest uglify uglily ugly ugsome uh uhlan uhlans 
ukase ukases uke ukelele ukes ukulele ulama ulamas ulan ulans ulcer ulcered 
ulcers ulema ulemas ulexite ullage ullaged ullages ulna ulnad ulnae ulnar ulnas 
ulpan ulpanim ulster ulsters ultima ultimas ultimo ultra ultras ulu ululant ululate 
ulus ulva ulvas um umami umamis umbel umbeled umbels umber umbered umbers 
umbles umbo umbonal umbones umbonic umbos umbra umbrae umbrage umbral umbras umiac 
umiack umiacks umiacs umiak umiaks umiaq umiaqs umlaut umlauts umm ump umped 
umpire umpired umpires umps umpteen un unable unacted unadded unadept unadult unag 
unaged unagile unai unaided unaimed unaired unais unakin unakite unalike unapt unaptly 
unarm unarmed unarms unary unasked unau unaus unawake unaware unawed unaxed unbaked 
unbale unbaled unbales unban unbans unbar unbars unbased unbated unbe unbear unbears 
unbelt unbelts unbend unbends unbent unbid unbind unbinds unblest unblock unbolt unbolts 
unboned unborn unbosom unbound unbowed unbox unboxed unboxes unbrace unbraid unbrake unbred 
unbroke unbuild unbuilt unbulky unburnt unbusy uncage uncaged uncages uncake uncaked uncakes 
uncanny uncap uncaps uncase uncased uncases uncast unceded unchain unchair unchary unchic 
unchoke unci uncia unciae uncial uncials uncinal uncini uncinus uncivil unclad unclamp 
unclasp uncle unclean unclear uncleft uncles unclip unclips uncloak unclog unclogs unclose 
uncloud unco uncock uncocks uncoded uncoil uncoils uncomic uncool uncork uncorks uncos 
uncouth uncover uncoy uncrate uncrazy uncross uncrown unction uncuff uncuffs uncurb uncurbs 
uncured uncurl uncurls uncus uncut uncute undated unde undead undee under underdo 
undergo undid undies undine undines undo undock undocks undoer undoers undoes undone 
undrape undraw undrawn undraws undress undrest undrew undried undrunk undue undular unduly 
undy undyed uneager unearth unease uneases uneasy uneaten unended unequal uneven unfaded 
unfair unfaith unfaked unfancy unfazed unfed unfelt unfence unfired unfit unfitly unfits 
unfix unfixed unfixes unfixt unfold unfolds unfond unfound unfree unfreed unfrees unfrock 
unfroze unfunny unfurl unfurls unfused unfussy ungated ungird ungirds ungirt unglove unglue 
unglued unglues ungodly ungot ungual unguard unguent ungues unguis ungula ungulae ungular 
unhair unhairs unhand unhands unhandy unhang unhangs unhappy unhasty unhat unhats unheard 
unhelm unhelms unhewn unhinge unhip unhired unhitch unholy unhood unhoods unhook unhooks 
unhoped unhorse unhouse unhuman unhung unhurt unhusk unhusks unibody unicorn unideal uniface 
unific unified unifier unifies uniform unify union unions unipod unipods unique uniquer 
uniques unisex unisize unison unisons unit unitage unitard unitary unite united uniter 
uniters unites unities unitive unitize units unity unjaded unjam unjams unjoint unjust 
unkempt unkend unkent unkept unkind unkink unkinks unknit unknits unknot unknots unknown 
unlace unlaced unlaces unlade unladed unladen unlades unlaid unlash unlatch unlay unlays 
unlead unleads unlearn unleash unled unless unlet unlevel unlike unliked unlined unlink 
unlinks unlit unlive unlived unlives unload unloads unlobed unlock unlocks unloose unloved 
unlucky unmacho unmade unmake unmaker unmakes unman unmanly unmans unmask unmasks unmated 
unmeant unmeet unmerry unmesh unmet unmew unmewed unmews unmined unmiter unmitre unmix 
unmixed unmixes unmixt unmold unmolds unmoor unmoors unmoral unmoved unmown unnail unnails 
unnamed unnerve unnoisy unnoted unoiled unopen unowned unpack unpacks unpaged unpaid unpaved 
unpeg unpegs unpen unpens unpent unpick unpicks unpile unpiled unpiles unpin unpins 
unplait unplug unplugs unposed unpure unquiet unquote unraked unrated unravel unrazed unread 
unready unreal unreel unreels unreeve unrent unrest unrests unrig unrigs unrimed unrip 
unripe unriper unrips unrisen unrobe unrobed unrobes unroll unrolls unroof unroofs unroot 
unroots unroped unrough unround unrove unroven unruled unruly uns unsafe unsaid unsated 
unsaved unsawed unsawn unsay unsays unscrew unseal unseals unseam unseams unseat unseats 
unseen unsell unsells unsent unset unsets unsew unsewed unsewn unsews unsex unsexed 
unsexes unsexy unsharp unshed unshell unshift unship unships unshod unshorn unshowy unshut 
unsight unsized unsl unslick unslung unsmart unsnag unsnags unsnap unsnaps unsnarl unsober 
unsold unsolid unsoncy unsonsy unsound unsowed unsown unspeak unspent unspilt unsplit unspoke 
unspool unspun unstack unstate unsteel unstep unsteps unstick unstop unstops unstrap unstuck 
unstung unsung unsunk unsure unswear unswept unswore unsworn untack untacks untaken untame 
untamed untaxed unteach unthink untidy untie untied unties until untimed untired unto 
untold untorn untrack untread untried untrim untrims untrod untrue untruer untruly untruss 
untruth untuck untucks untune untuned untunes untwine untwist unty unurged unused unusual 
unveil unveils unvexed unvext unvocal unvoice unwary unwaxed unweary unweave unwed unwell 
unwept unwet unwhite unwind unwinds unwise unwiser unwish unwit unwits unwon unwooed 
unworn unwound unwove unwoven unwrap unwraps unwrung unyoke unyoked unyokes unyoung unzip 
unzips unzoned up upas upases upbear upbears upbeat upbeats upbind upbinds upboil 
upboils upbore upborne upbound upbow upbows upbraid upbuild upbuilt upby upbye upcast 
upcasts upchuck upclimb upcoast upcoil upcoils upcourt upcurl upcurls upcurve updart updarts 
update updated updater updates updive updived updives updo updos updove updraft updried 
updries updry upend upended upends upfield upfl upflow upflows upflung upfold upfolds 
upfront upgaze upgazed upgazes upgird upgirds upgirt upgo upgrade upgrew upgrow upgrown 
upgrows upheap upheaps upheave upheld uphill uphills uphoard uphold upholds uphove uphroe 
uphroes upkeep upkeeps upland uplands upleap upleaps upleapt uplift uplifts uplight uplink 
uplinks uplit upload uploads upmost upo upon upp upped upper uppers uppile 
uppiled uppiles uppings uppish uppity upprop upprops upraise uprate uprated uprates upreach 
uprear uprears upright uprise uprisen upriser uprises upriver uproar uproars uproot uproots 
uprose uprouse uprush ups upscale upsend upsends upsent upset upsets upshift upshoot 
upshot upshots upside upsides upsilon upsize upsized upsizes upslope upsoar upsoars upstage 
upstair upstand upstare upstart upstate upstep upsteps upstir upstirs upstood upsurge upsw 
upsweep upswell upswept upswung uptake uptakes uptalk uptalks uptear uptears uptempo upthrew 
upthrow uptick upticks uptight uptilt uptilts uptime uptimes uptore uptorn uptoss uptown 
uptowns uptrend upturn upturns upwaft upwafts upward upwards upwell upwells upwind upwinds 
uracil uracils uraei uraemia uraemic uraeus uralite urania uranias uranic uranide uranism 
uranite uranium uranous uranyl uranyls urare urares urari uraris urase urases urate 
urates uratic urb urban urbane urbaner urbia urbias urbs urchin urchins urd 
urds urea ureal ureas urease ureases uredia uredial uredium uredo uredos ureic 
ureide ureides uremia uremias uremic ureter ureters urethan urethra uretic urg urge 
urged urgency urgent urger urgers urges urial urials uric uridine urinal urinals 
urinary urinate urine urines urinose urinous urn urnlike urns urodele urolith urology 
uropod uropods urp urped urps ursa ursae ursid ursids ursine urtext urtexts 
urus uruses us usable usably usage usages usance usances usaunce use useable 
useably used useful useless user users uses usher ushered ushers usnea usneas 
usque usques usual usually usuals usurer usurers usuries usurp usurped usurper usurps 
usury ut uta utas ute utensil uteri uterine uterus utes utile utilise 
utility utilize utmost utmosts utopia utopian utopias utopism utopist utricle uts utter 
uttered utterer utterly utters uvea uveal uveas uveitic uveitis uveous uvula uvulae 
uvular uvulars uvulas uxorial vacua vacuity vacuole vacuous vacuum vacuums vague vaguely 
vaguer vaguest vagus valgus valour valours valu valuate value valued valuer valuers 
values valuta valutas valvula valvule vapour vapours vapoury vaquero various varus varuses 
vascula vatful vatfuls vatu vatus vau vault vaulted vaulter vaults vaulty vaunt 
vaunted vaunter vauntie vaunts vaunty vaus veinule vellum vellums velour velours veloute 
velum velure velured velures vendue vendues venous venture venturi venue venues venular 
venule venules venus venuses verdure vermuth verruca versus vertu vertus vesture viaduct 
vicious victual vicugna vicuna vicunas viduity vigour vigours villous villus vincula vinous 
virgule virtu virtual virtue virtues virtus virus viruses viscous viscus visual visuals 
vodou vodoun vodouns vodous vodun voduns vogu vogue vogued voguer voguers vogues 
voguish voluble volubly volume volumed volumes volute voluted volutes volutin volvuli vomitus 
vouch vouched vouchee voucher vouches voudon voudons voudoun vouvray voyeur voyeurs vrouw 
vrouws vug vugg vuggier vuggs vuggy vugh vughs vugs vulgar vulgars vulgate 
vulgo vulgus vulpine vulture vulva vulvae vulval vulvar vulvas vulvate vum waeful 
waesuck wafture wailful wakeful walkout walkup walkups walnut walnuts walrus wamefou wameful 
wammus wampum wampums wampus wamus wamuses wangun wanguns warmup warmups washout washtub 
washup washups waucht wauchts waugh waught waughts wauk wauked wauks waul wauled 
wauls waur wetsuit whaup whaups whump whumped whumps whup whupped whups wickiup 
wickyup wideout wikiup wikiups wilful willful windup windups wipeout wiseguy wishful wistful 
without woeful woful wofully woodcut workout workup workups would wouldst wound wounded 
wounds wrought wrung wud wurst wursts wurzel wurzels wushu wuss wusses wussier 
wussies wussy wuther wuthers xenopus xerus xeruses xu xystus yakuza yamulka yamun 
yamuns yanqui yanquis yaud yauds yauld yaup yauped yauper yaupers yaupon yaupons 
yaups yautia yautias yeuk yeuked yeuks yeuky yoghurt yogurt yogurts you young 
younger youngs younker youpon youpons your yourn yours yous youse youth youthen 
youths yttrium yuan yuans yuca yucas yucca yuccas yucch yuch yuck yucked 
yuckier yucks yucky yuga yugas yuk yukk yukked yukkier yukky yuks yulan 
yulans yule yules yum yummier yummies yummy yup yupon yupons yuppie yuppies 
yuppify yuppy yups yurt yurta yurts yutz yutzes zealous zebu zebus zestful 
zeugma zeugmas zikurat zincous zoarium zoecium zonula zonulae zonular zonulas zonule zonules 
zouave zouaves zouk zouks zounds zuz zuzim zymurgy
);

my @C_words = qw(
abaca abacas abaci aback abacus abbacy abbotcy abduce abduced abduces abduct abducts 
abiotic abject aboulic abreact abroach abscess abscise abscond absence abulic ac acacia 
acacias academe academy acajou acajous acaleph acantha acanthi acapnia acari acarid acarids 
acarine acaroid acarus acaudal accede acceded acceder accedes accent accents accept accepts 
access accidia accidie acclaim accord accords accost accosts account accrete accrual accrue 
accrued accrues accurst accusal accuse accused accuser accuses ace aced acedia acedias 
acequia acerate acerb acerber acerbic acerola acerose acerous aces aceta acetal acetals 
acetate acetic acetify acetin acetins acetone acetose acetous acetum acetyl acetyls ach 
ache ached achene achenes aches achier achiest achieve achiote achiral acholia achoo 
achy acicula acid acidic acidify acidity acidly acids acidy aciform acinar acini 
acinic acinose acinous acinus ackee ackees aclinic acmatic acme acmes acmic acne 
acned acnes acnode acnodes acock acold acolyte aconite acorn acorned acorns acquest 
acquire acquit acquits acrasia acrasin acre acreage acred acres acrid acrider acridly 
acrobat acrogen acromia acronic acronym across acrotic acrylic act acta actable acted 
actin actinal actings actinia actinic actinon actins action actions active actives actor 
actorly actors actress acts actual actuary actuate acuate acuity aculei aculeus acumen 
acumens acute acutely acuter acutes acutest acyclic acyl acylate acyloin acyls addict 
addicts adduce adduced adducer adduces adduct adducts adipic adjunct adunc advance advect 
advects advice advices aecia aecial aecidia aecium aeonic aerobic affect affects affiche 
afflict agamic agapeic agaric agarics agency aggadic aglycon agnatic agonic agravic ahchoo 
aircrew airsick aitch aitches alack albinic albitic alcade alcades alcaic alcaics alcaide 
alcalde alcayde alcazar alchemy alchymy alcid alcids alcohol alcove alcoved alcoves alec 
alecs alembic alencon alkalic alkylic allelic allicin allylic almanac almuce almuces alnico 
alnicos aloetic alpaca alpacas ambsace amebic amerce amerced amercer amerces amesace amice 
amices amici amicus amidic aminic ammonic amnesic amnic amoebic amtrac amtrack amtracs 
amuck amucks amylic anaemic anarch anarchs anarchy ancho anchor anchors anchos anchovy 
anchusa ancient ancilla ancon anconal ancone ancones ancress anemic anergic angelic anglice 
animacy anionic anisic anlace anlaces anodic anomic anosmic anoxic antacid antic anticar 
antick anticks anticly antics anuric aortic apace apache apaches apercu apercus aphasic 
aphetic aphonic aphotic apical apicals apices apiculi apiece aplitic apneic apnoeic apocarp 
apocope apogeic apomict apraxic apricot aprotic aquatic arabic arabica arc arcade arcaded 
arcades arcadia arcana arcane arcanum arced arch archaea archaic archean arched archer 
archers archery arches archfoe archil archils archine archive archly archon archons archway 
arck arcked arco arcs arcsine arctic arctics arcuate arcus arcuses ardency areca 
arecas areic argotic arkosic armlock arnica arnicas arrack arracks arsenic article ascared 
ascarid ascaris ascend ascends ascent ascents asceses ascesis ascetic asci ascidia ascites 
ascitic ascot ascots ascribe ascus asdic asdics aseptic ashcake ashcan ashcans askance 
asocial aspect aspects aspic aspics astatic astrict atactic atavic ataxic ataxics atelic 
atomic atomics atonic atonics atopic atresic atretic attach attache attack attacks attic 
attics attract atypic auction aucuba aucubas augitic aulic auric auricle aurochs auspice 
autarch auxetic auxinic avarice aviatic avionic avocado avocet avocets avouch axenic axonic 
azoic azonic azotic babiche bacalao bacca baccae baccara baccate bacchic bacchii bach 
bached baches bacilli back backbit backed backer backers backfit backhoe backlit backlog 
backout backs backsaw backset backup backups bacon bacons bacula baculum balance balcony 
baldric banco bancos bannock barca barcas barchan bardic baric barrack barytic bascule 
basic basics basilic batch batched batcher batches bawcock bawdric beach beached beaches 
beachy beacon beacons bearcat becalm becalms became becap becaps because bechalk becharm 
beck becked becket beckets beckon beckons becks beclasp becloak beclog beclogs becloud 
beclown become becomes becrawl becrime becrowd becrust becurse becurst bedeck bedecks bedrock 
bedtick bedunce beech beechen beeches beechy befleck belaced belch belched belcher belches 
bemock bemocks bench benched bencher benches benefic benthic benzoic bescour beseech bewitch 
beylic beylics bibasic bibcock bicarb bicarbs bice bicep biceps bices bicker bickers 
bicolor bicorn bicorne bicorns bicron bicrons bicycle biface bifaces bifocal binocle binocs 
biochip biocide bionic bionics biontic biopic biopics biopsic bioptic biotech biotic biotics 
bipack bipacks birch birched birchen birches biscuit bisect bisects bitch bitched bitchen 
bitches bitchy bittock bivouac black blacked blacken blacker blackly blacks blanch bleach 
blench bloc block blocked blocker blocks blocky blocs blotch blotchy blucher bluecap 
bobcat bobcats bobeche bocce bocces bocci boccia boccias boccie boccies boccis boche 
boches bock bocks bodice bodices bonaci bonacis bonduc bonducs bonnock boocoo boocoos 
boraces boracic boric boronic borsch borscht boscage bosonic botanic botch botched botcher 
botches botchy bouchee boucle boucles bounce bounced bouncer bounces bouncy boxcar boxcars 
boychik boycott brac brace braced bracer bracero bracers braces brach braches brachet 
brachia brachs bracken bracket bract bracted bracts branch branchy breach breccia brecham 
brechan breech brick bricked brickle bricks bricky bricole brioche broach brocade broche 
brock brocket brocks brocoli bromic bronc bronchi broncho bronco broncos broncs brooch 
brucin brucine brucins brunch bubonic buccal buck bucked buckeen bucker buckers bucket 
buckets buckeye buckish buckle buckled buckler buckles bucko buckoes buckos buckra buckram 
buckras bucks bucksaw bucolic bulimic bullace bullock bunch bunched bunches bunchy bunco 
buncoed buncos burdock bustic bustics butch butcher butches buttock butyric buyback buzzcut 
bycatch cab cabal cabala cabalas cabals cabana cabanas cabaret cabb cabbage cabbagy 
cabbala cabbed cabbie cabbies cabby caber cabers cabezon cabildo cabin cabined cabinet 
cabins cabl cable cabled cabler cablers cables cablet cablets cabman cabmen cabob 
cabobs cabomba caboose cabs caca cacao cacaos cacas cach cache cached caches 
cachet cachets cachexy cachou cachous cacique cackle cackled cackler cackles cacodyl caconym 
cacti cactoid cactus cad cadaver caddice caddie caddied caddies caddis caddish caddy 
cade cadelle cadence cadency cadent cadenza cades cadet cadets cadg cadge cadged 
cadger cadgers cadges cadgy cadi cadis cadmic cadmium cadre cadres cads caducei 
caeca caecal caecum caeoma caeomas caesar caesars caesium caestus caesura cafe cafes 
caff caffein caffs caftan caftans cag cage caged cageful cager cagers cages 
cagey cagier cagiest cagily cagy cahier cahiers cahoot cahoots cahow cahows caid 
caids caiman caimans cain cains caique caiques caird cairds cairn cairned cairns 
cairny caisson caitiff cajaput cajeput cajole cajoled cajoler cajoles cajon cajones cajuput 
cak cake caked cakes cakey cakier cakiest caky calamar calami calamus calando 
calash calathi calcar calcars calces calcic calcify calcine calcite calcium calculi caldera 
caldron caleche calends calesa calesas calf calfs caliber calibre calices caliche calicle 
calico calicos calif califs calipee caliper caliph caliphs calix calk calked calker 
calkers calkin calkins calks call calla callan callans callant callas callboy called 
callee callees caller callers callet callets callose callous callow calls callus calm 
calmed calmer calmest calmly calms calo calomel caloric calorie calory calos calotte 
caloyer calpac calpack calpacs calpain calque calqued calques caltrap caltrop calumet calumny 
calv calvary calve calved calves calx calxes calyces calycle calypso calyx calyxes 
calzone cam camail camails camas camases camass camber cambers cambia cambial cambism 
cambist cambium cambric came camel camelia camelid camels cameo cameoed cameos camera 
camerae cameral cameras cames camion camions camisa camisas camise camises camisia camlet 
camlets cammie cammies camo camorra camos camp camped camper campers camphol camphor 
campi campier campily campion campo campong campos campout camps campus campy cams 
can canakin canal canaled canals canape canapes canard canards canary canasta cancan 
cancans cancel cancels cancer cancers cancha canchas candela candent candid candida candids 
candied candies candle candled candler candles candor candors candour candy cane caned 
canella caner caners canes canful canfuls cangue cangues canid canids canikin canine 
canines canker cankers cann canna cannas canned cannel cannels canner canners cannery 
cannie cannier cannily cannoli cannon cannons cannot cannula canny canoe canoed canoer 
canoers canoes canola canolas canon canonic canonry canons canopic canopy cans cansful 
canso cansos canst cant cantal cantala cantals cantata cantdog canted canteen canter 
canters canthal canthi canthus cantic cantina cantle cantles canto canton cantons cantor 
cantors cantos cantrap cantrip cants cantus canty canula canulae canular canulas canvas 
canvass canyon canyons canzona canzone canzoni cap capable capably cape caped capelan 
capelet capelin caper capered caperer capers capes capful capfuls caph caphs capias 
capita capital capitol capiz capizes capless caplet caplets caplin caplins capo capon 
capons caporal capos capote capotes capouch capp capped capper cappers capric caprice 
caprine capris caprock caps capsid capsids capsize capstan capsule captain captan captans 
caption captive captor captors capture capuche caput car carabao carabid carabin caracal 
carack caracks caracol caracul carafe carafes caramba caramel carapax carat carate carates 
carats caravan caravel caraway carb carbarn carbide carbine carbo carbon carbons carbora 
carbos carboy carboys carbs carcase carcass carcel carcels card carded carder carders 
cardia cardiac cardiae cardias cardio cardon cardons cardoon cards care cared careen 
careens career careers careful carer carers cares caress caret carets carex carfare 
carful carfuls cargo cargoes cargos carhop carhops caribe caribes caribou carices caried 
caries carina carinae carinal carinas carioca cariole carious caritas carjack cark carked 
carks carl carle carles carless carlin carline carlins carlish carload carls carman 
carmen carmine carn carnage carnal carnet carnets carney carneys carnie carnies carnify 
carns carny caroach carob carobs caroch caroche carol caroled caroler caroli carols 
carolus carom caromed caroms carotid carotin carouse carp carpal carpale carpals carped 
carpel carpels carper carpers carpet carpets carpi carpool carport carps carpus carr 
carrack carrel carrell carrels carried carrier carries carrion carroch carrom carroms carrot 
carrots carroty carrs carry carryon cars carse carses carsick cart cartage carte 
carted cartel cartels carter carters cartes carton cartons cartoon cartop carts carv 
carve carved carvel carvels carven carver carvers carves carwash cas casa casaba 
casabas casas casava casavas casbah casbahs cascade cascara case casease caseate cased 
casefy caseic casein caseins caseose caseous casern caserne caserns cases casette cash 
cashaw cashaws cashbox cashed cashes cashew cashews cashier cashoo cashoos casings casini 
casino casinos casita casitas cask casked casket caskets casks casky casque casqued 
casques cassaba cassata cassava cassena cassene cassia cassias cassina cassine cassino cassis 
cassock cast caste caster casters castes castle castled castles castoff castor castors 
casts casual casuals casuist casus cat catalo catalog catalos catalpa catarrh catawba 
catbird catboat catcall catch catcher catches catchup catchy catclaw cate catechu catena 
catenae catenas cater cateran catered caterer caters cates catface catfall catfish catgut 
catguts cathead cathect cathode cation cations catjang catkin catkins catl catlike catlin 
catlins catmint catnap catnaps catnip catnips cats catspaw catsuit catsup catsups catt 
cattail cattalo catted cattery cattie cattier catties cattily cattish cattle catty catwalk 
caucus caudad caudal caudate caudex caudle caudles caught caul cauld caulds caules 
cauline caulis caulk caulked caulker caulks cauls caus causal causals cause caused 
causer causers causes causey causeys caustic cautery caution cav cavalla cavally cavalry 
cave caveat caveats caved caveman cavemen caver cavern caverns cavers caves cavetti 
cavetto caviar caviare caviars cavie cavies cavil caviled caviler cavils cavings cavity 
cavort cavorts cavy caw cawed caws cay cayenne cayman caymans cays cayuse 
cayuses cazique ceas cease ceased ceases cebid cebids ceboid ceboids ceca cecal 
cecally cecity cecum ced cedar cedarn cedars cedary cede ceded ceder ceders 
cedes cedi cedilla cedis cedula cedulas cee cees ceiba ceibas ceil ceiled 
ceiler ceilers ceili ceilidh ceilis ceils cel celadon celeb celebs celery celesta 
celeste celiac celiacs cell cella cellae cellar cellars celled celli cellist cello 
cellos cells cellule celom celoms celosia celotex cels celt celts cembali cembalo 
cement cementa cements cenacle cenote cenotes cens cense censed censer censers censes 
censor censors censual censure census cent centai cental centals centare centas centaur 
centavo center centers centile centime centimo centner cento centos centra central centre 
centred centres centric centrum cents centu centum centums century ceorl ceorls cep 
cepe cepes cepheid ceps cer ceramal ceramic cerate cerated cerates ceratin cercal 
cerci cercis cercus cere cereal cereals cerebra cered ceres cereus ceria cerias 
ceric ceriph ceriphs cerise cerises cerite cerites cerium ceriums cermet cermets cero 
ceros cerotic cerous certain certes certify cerumen ceruse ceruses cerveza cervid cervine 
cervix cesium cesiums cess cessed cesses cession cesspit cesta cestas cesti cestode 
cestoi cestoid cestos cestus cesura cesurae cesuras cetane cetanes cete cetes ceviche 
chablis chabouk chabuk chabuks chachka chacma chacmas chad chadar chadars chador chadors 
chadri chads chaebol chaeta chaetae chaetal chaf chafe chafed chafer chafers chafes 
chaff chaffed chaffer chaffs chaffy chagrin chai chain chaine chained chaines chains 
chair chaired chairs chais chaise chaises chakra chakras chalah chalahs chalaza chalcid 
chaleh chalehs chalet chalets chalice chalk chalked chalks chalky challa challah challas 
challie challis challot chally chalone chalot chaloth chalupa chalutz cham chamade chamber 
chamfer chamisa chamise chamiso chammy chamois chamoix champ champac champak champed champer 
champs champy chams chance chanced chancel chancer chances chancre chancy chang change 
changed changer changes changs channel chanoyu chanson chant chanted chanter chantey chantor 
chantry chants chanty chao chaos chaoses chaotic chap chapati chape chapeau chapel 
chapels chapes chaplet chapman chapmen chapped chappie chaps chapt chapter char charade 
charas chard chards chare chared chares charge charged charger charges charier charily 
chariot charism charity chark charka charkas charked charkha charks charley charlie charm 
charmed charmer charms charnel charpai charpoy charqui charr charred charro charros charrs 
charry chars chart charted charter charts chary chas chase chased chaser chasers 
chases chasm chasmal chasmed chasmic chasms chasmy chasse chassed chasses chassis chaste 
chasten chaster chat chateau chats chatted chattel chatter chatty chaufer chaunt chaunts 
chaw chawed chawer chawers chaws chay chayote chays chazan chazans chazzan chazzen 
cheap cheapen cheaper cheapie cheaply cheapo cheapos cheaps cheat cheated cheater cheats 
chebec chebecs check checked checker checks checkup cheddar cheder cheders chedite cheek 
cheeked cheeks cheeky cheep cheeped cheeper cheeps cheer cheered cheerer cheerio cheerly 
cheero cheeros cheers cheery cheese cheesed cheeses cheesy cheetah chef chefdom chefed 
cheffed chefs chegoe chegoes chela chelae chelas chelate cheloid chemic chemics chemise 
chemism chemist chemo chemos cheque chequer cheques cherish cheroot cherry chert cherts 
cherty cherub cherubs chervil chess chesses chest chested chests chesty chetah chetahs 
cheth cheths chetrum chevied chevies cheviot chevre chevres chevret chevron chevy chew 
chewed chewer chewers chewier chewink chews chewy chez chi chia chianti chiao 
chias chiasm chiasma chiasmi chiasms chiaus chibouk chic chica chicane chicano chicas 
chicer chicest chichi chichis chick chickee chicken chicks chicle chicles chicly chico 
chicory chicos chics chid chidden chide chided chider chiders chides chief chiefer 
chiefly chiefs chiel chield chields chiels chiffon chigger chignon chigoe chigoes child 
childe childes childly chile chiles chili chiliad chilies chilis chill chilled chiller 
chilli chillis chills chillum chilly chim chimar chimars chimb chimbly chimbs chime 
chimed chimer chimera chimere chimers chimes chimla chimlas chimley chimney chimp chimps 
chin china chinas chinch chinchy chine chined chines chink chinked chinks chinky 
chinned chino chinone chinook chinos chins chints chintz chintzy chinwag chip chipped 
chipper chippie chippy chips chiral chirk chirked chirker chirks chirm chirmed chirms 
chiro chiros chirp chirped chirper chirps chirpy chirr chirre chirred chirren chirres 
chirrs chirrup chiru chirus chis chisel chisels chit chital chitin chitins chitlin 
chiton chitons chits chitter chitty chivari chive chives chivied chivies chivvy chivy 
chlamys chloral chloric chlorid chlorin choana choanae chock chocked chocks choice choicer 
choices choir choired choirs chok choke choked choker chokers chokes chokey chokier 
choky chola cholas cholate cholent choler cholera cholers choline cholla chollas cholo 
cholos chomp chomped chomper chomps chon chook chooks choose chooser chooses choosey 
choosy chop chopin chopine chopins chopped chopper choppy chops chor choragi choral 
chorale chorals chord chordal chorded chords chore chorea choreal choreas chored choregi 
choreic chores chorial choric chorine chorion chorizo choroid chorten chortle chorus chose 
chosen choses chott chotts chough choughs chouse choused chouser chouses choush chow 
chowder chowed chows chowse chowsed chowses chrism chrisma chrisms chrisom christy chroma 
chromas chrome chromed chromes chromic chromo chromos chromy chromyl chronic chronon chub 
chubby chubs chuck chucked chuckle chucks chucky chuddah chuddar chudder chufa chufas 
chuff chuffed chuffer chuffs chuffy chug chugged chugger chugs chukar chukars chukka 
chukkar chukkas chukker chum chummed chummy chump chumped chumps chums chunk chunked 
chunks chunky chunnel chunter chuppa chuppah chuppas church churchy churl churls churn 
churned churner churns churr churred churro churros churrs chut chute chuted chutes 
chutist chutnee chutney chutzpa chyle chyles chylous chyme chymes chymic chymics chymist 
chymous chytrid ciao cibol cibols ciboria ciboule cicada cicadae cicadas cicala cicalas 
cicale cicely cicero ciceros cichlid cicoree cider ciders cig cigar cigaret cigars 
cigs cilia ciliary ciliate cilice cilices cilium cimex cimices cinch cinched cinches 
cinder cinders cindery cine cineast cinema cinemas cineol cineole cineols cinerin cines 
cingula cinque cinques cion cions cipher ciphers ciphony cipolin circa circle circled 
circler circles circlet circuit circus circusy cire cires cirque cirques cirrate cirri 
cirrose cirrous cirrus cirsoid cis cisco ciscoes ciscos cissies cissoid cissy cist 
cisted cistern cistron cists cistus cit citable citadel citator cite cited citer 
citers cites cithara cither cithern cithers cithren citied cities citify citizen citola 
citolas citole citoles citral citrals citrate citric citrin citrine citrins citron citrons 
citrous citrus citrusy cittern city civet civets civic civics civie civies civil 
civilly civism civisms civvies civvy cl clabber clach clachan clachs clack clacked 
clacker clacks clad cladded clade clades cladism cladist cladode clads clag clagged 
clags claim claimed claimer claims clam clamant clamber clammed clammer clammy clamor 
clamors clamour clamp clamped clamper clamps clams clan clang clanged clanger clangor 
clangs clank clanked clanks clanky clans clap clapped clapper claps clapt claque 
claquer claques claret clarets claries clarify clarion clarity clarkia claro claroes claros 
clary clash clashed clasher clashes clasp clasped clasper clasps claspt class classed 
classer classes classic classis classon classy clast clastic clasts clatter claucht claught 
clausal clause clauses clavate clave claver clavers claves clavi clavier clavus claw 
clawed clawer clawers claws claxon claxons clay clayed clayey clayier clayish claypan 
clays clean cleaned cleaner cleanly cleans cleanse cleanup clear cleared clearer clearly 
clears cleat cleated cleats cleave cleaved cleaver cleaves cleek cleeked cleeks clef 
clefs cleft clefted clefts clement clench cleome cleomes clep clepe cleped clepes 
clept clergy cleric clerics clerid clerids clerisy clerk clerked clerkly clerks clever 
clevis clew clewed clews cliche cliched cliches click clicked clicker clicks client 
clients cliff cliffs cliffy clift clifts climate climax climb climbed climber climbs 
clime climes clinal clinch cline clines clinged clinger clings clingy clinic clinics 
clink clinked clinker clinks clip clipped clipper clips clipt clique cliqued cliques 
cliquey cliquy clitic clitics clivers clivia clivias cloaca cloacae cloacal cloacas cloak 
cloaked cloaks clobber cloche cloches clock clocked clocker clocks clod cloddy clods 
clog clogged clogger cloggy clogs clomb clomp clomped clomps clon clonal clone 
cloned cloner cloners clones clonic clonism clonk clonked clonks clons clonus cloot 
cloots clop clopped clops cloque cloques clos close closed closely closer closers 
closes closest closet closets closeup closure clot cloth clothe clothed clothes cloths 
clots clotted clotty cloture cloud clouded clouds cloudy clough cloughs clour cloured 
clours clout clouted clouter clouts clove cloven clover clovers clovery cloves clowder 
clown clowned clowns cloy cloyed cloys cloze clozes clu club clubbed clubber 
clubby clubman clubmen clubs cluck clucked clucks clue clued clues clumber clump 
clumped clumps clumpy clumsy clung clunk clunked clunker clunks clunky clupeid cluster 
clutch clutchy clutter clypeal clypei clypeus clyster cnida cnidae coach coached coacher 
coaches coact coacted coactor coacts coadmit coaeval coagent coagula coal coala coalas 
coalbin coalbox coaled coaler coalers coalier coalify coalpit coals coaly coam coannex 
coapt coapted coapts coarse coarsen coarser coast coastal coasted coaster coasts coat 
coated coatee coatees coater coaters coati coatis coats coax coaxal coaxed coaxer 
coaxers coaxes coaxial cob cobalt cobalts cobb cobber cobbers cobbier cobble cobbled 
cobbler cobbles cobbs cobby cobia cobias coble cobles cobnut cobnuts cobra cobras 
cobs cobweb cobwebs coca cocain cocaine cocains cocas coccal cocci coccic coccid 
coccids coccoid coccous coccus coccyx cochair cochin cochins cochlea cock cockade cocked 
cocker cockers cockeye cockier cockily cockish cockle cockled cockles cockney cockpit cocks 
cockshy cockup cockups cocky coco cocoa cocoas cocomat coconut cocoon cocoons cocos 
cocotte cocoyam cod coda codable codas codd codded codder codders coddle coddled 
coddler coddles code codec codecs coded codeia codeias codein codeina codeine codeins 
coden codens coder coders codes codex codfish codger codgers codices codicil codify 
codl codlin codlins codon codons codrive codrove cods coed coedit coedits coeds 
coeliac coelom coelome coeloms coempt coempts coenact coenure coenuri coequal coerce coerced 
coercer coerces coerect coesite coeval coevals coexert coexist coff coffee coffees coffer 
coffers coffin coffins coffle coffled coffles coffret coffs cofound coft cog cogency 
cogent cogg cogged cogito cogitos cognac cognacs cognate cognise cognize cogon cogons 
cogs cogway cogways cohabit cohead coheads coheir coheirs cohere cohered coherer coheres 
coho cohog cohogs cohort cohorts cohos cohosh cohost cohosts cohune cohunes coif 
coifed coiffe coiffed coiffes coifs coign coigne coigned coignes coigns coil coiled 
coiler coilers coils coin coinage coined coiner coiners coinfer coins cointer coir 
coirs coital coition coitus cojoin cojoins cojones cok coke coked cokes coky 
col cola colas colby colbys cold colder coldest coldish coldly colds cole 
colead coleads coled coles coleus colic colicin colicky colics colies colin colins 
colitic colitis collage collar collard collars collate collect colleen college collet collets 
collide collie collied collier collies collins colloid collop collops collude colly colobi 
colobus colog cologne cologs colon colone colonel colones coloni colonic colons colonus 
colony color colored colorer colors colossi colour colours cols colt colter colters 
coltish colts colugo colugos columel column columns colure colures coly colza colzas 
com coma comade comae comake comaker comakes comal comas comate comates comatic 
comatik comb combat combats combe combed comber combers combes combine combo combos 
combs combust come comedic comedo comedos comedy comely comer comers comes comet 
cometh cometic comets comfier comfit comfits comfort comfrey comfy comic comical comics 
comings comitia comity comix comma command commas commata commend comment commie commies 
commit commits commix commixt commode common commons commove commune commute commy comose 
comous comp compact company compare compart compas compass comped compeer compel compels 
compend compere compete compile complex complin complot comply compo compone compony comport 
compos compose compost compote comps compt compted compts compute comrade comsymp comte 
comtes con conatus concave conceal concede conceit concent concept concern concert conch 
concha conchae conchal conchas conches conchie concho conchos conchs conchy concise concoct 
concord concur concurs concuss condemn condign condo condoes condole condom condoms condone 
condor condors condos conduce conduct conduit condyle cone coned cones coney coneys 
confab confabs confect confer confers confess confide confine confirm confit confits conflux 
conform confuse confute conga congaed congas conge congeal congee congeed congees conger 
congers conges congest congii congius congo congoes congos congou congous coni conic 
conical conics conidia conies conifer coniine conin conine conines conins conium coniums 
conjoin conjure conk conked conker conkers conks conky conn connate connect conned 
conner conners connive connote conns conoid conoids conquer cons consent consign consist 
consol console consols consort consul consuls consult consume contact contain conte contemn 
contend content contes contest context conto contort contos contour contra contras control 
contuse conus convect convene convent convert convex convey conveys convict convoke convoy 
convoys cony coo cooch cooches coocoo cooed cooee cooeed cooees cooer cooers 
cooey cooeyed cooeys coof coofs cook cooked cooker cookers cookery cookey cookeys 
cookie cookies cookoff cookout cooks cooktop cooky cool coolant cooled cooler coolers 
coolest coolie coolies coolish coolly cools coolth coolths cooly coomb coombe coombes 
coombs coon cooncan coons coontie coop cooped cooper coopers coopery coops coopt 
coopted coopts coos coot cooter cooters cootie cooties coots cop copaiba copal 
copalm copalms copals copay copays cope copeck copecks coped copen copens copepod 
coper copers copes copied copier copiers copies copihue copilot copings copious coplot 
coplots copout copouts copp copped copper coppers coppery coppice coppra coppras copra 
coprah coprahs copras cops copse copses copter copters copula copulae copular copulas 
copy copyboy copycat copyist coquet coquets coquina coquito cor coracle coral corals 
coranto corban corbans corbeil corbel corbels corbie corbies corbina corby cord cordage 
cordate corded corder corders cordial cordite cordoba cordon cordons cords core cored 
coreign coremia corer corers cores corf corgi corgis coria corium cork corkage 
corked corker corkers corkier corks corky corm cormel cormels cormoid cormous corms 
corn corncob cornea corneal corneas corned cornel cornels corner corners cornet cornets 
cornfed cornice cornier cornify cornily cornrow corns cornu cornua cornual cornus cornute 
cornuto corny corody corolla corona coronae coronal coronas coronel coroner coronet corpora 
corps corpse corpses corpus corrade corral corrals correct corrida corrie corries corrode 
corrody corrupt cors corsac corsacs corsage corsair corse corses corset corsets corslet 
cortege cortex cortin cortina cortins coruler corvee corvees corves corvet corvets corvid 
corvids corvina corvine cory corymb corymbs coryza coryzal coryzas cos cosec cosecs 
coses coset cosets cosey coseys cosh coshed cosher coshers coshes cosie cosied 
cosier cosies cosiest cosign cosigns cosily cosine cosines cosmic cosmid cosmids cosmism 
cosmist cosmos coss cossack cosset cossets cost costa costae costal costar costard 
costars costate costed coster costers costive costly costrel costs costume cosy cot 
cotan cotans cote coteau coteaux coted coterie cotes cothurn cotidal cotinga cots 
cotta cottae cottage cottar cottars cottas cotter cotters cottier cotton cottons cottony 
cotype cotypes couch couched coucher couches coude cougar cougars cough coughed cougher 
coughs could couldst coulee coulees coulis couloir coulomb coulter council counsel count 
counted counter country counts county coup coupe couped coupes couple coupled coupler 
couples couplet coupon coupons coups courage courant courier courlan course coursed courser 
courses court courted courter courtly courts cousin cousins couteau couter couters couth 
couther couthie couths couture couvade cov covary cove coved coven covens cover 
covered coverer covers covert coverts coverup coves covet coveted coveter covets covey 
coveys covin covings covins cow cowage cowages coward cowards cowbane cowbell cowbind 
cowbird cowboy cowboys cowed cowedly cower cowered cowers cowfish cowflap cowflop cowgirl 
cowhage cowhand cowherb cowherd cowhide cowier cowiest cowl cowled cowlick cowls cowman 
cowmen cowpat cowpats cowpea cowpeas cowpie cowpies cowplop cowpoke cowpox cowrie cowries 
cowrite cowrote cowry cows cowshed cowskin cowslip cowy cox coxa coxae coxal 
coxalgy coxcomb coxed coxes coxitis coxless coy coydog coydogs coyed coyer coyest 
coyish coyly coyness coyote coyotes coypou coypous coypu coypus coys coz cozen 
cozened cozener cozens cozes cozey cozeys cozie cozied cozier cozies coziest cozily 
cozy cozzes craal craaled craals crab crabbed crabber crabby crabs crack cracked 
cracker crackle crackly cracks crackup cracky cradle cradled cradler cradles craft crafted 
crafter crafts crafty crag cragged craggy crags crake crakes cram crambe crambes 
crambo crambos crammed crammer cramp cramped crampit crampon cramps crampy crams cran 
cranch crane craned cranes crania cranial cranium crank cranked cranker crankle crankly 
cranks cranky crannog cranny crap crape craped crapes crapola crapped crapper crappie 
crappy craps crases crash crashed crasher crashes crasis crass crasser crassly crat 
cratch crate crated crater craters crates craton cratons craunch crav cravat cravats 
crave craved craven cravens craver cravers craves craw crawdad crawl crawled crawler 
crawls crawly craws crayon crayons craz craze crazed crazes crazier crazies crazily 
crazy creak creaked creaks creaky cream creamed creamer creams creamy crease creased 
creaser creases creasy create created creates creatin creator creche creches cred credal 
credent credit credits credo credos creds creed creedal creeds creek creeks creel 
creeled creels creep creeped creeper creepie creeps creepy creese creeses creesh cremate 
creme cremes cremini crenate crenel crenels creole creoles creosol crep crepe creped 
crepes crepey crepier crepon crepons crept crepy cresol cresols cress cresses cresset 
cressy crest crestal crested crests cresyl cresyls cretic cretics cretin cretins crevice 
crew crewcut crewed crewel crewels crewman crewmen crews crib cribbed cribber cribs 
crick cricked cricket crickey cricks cricoid cried crier criers cries crikey crime 
crimes crimine crimini criminy crimmer crimp crimped crimper crimple crimps crimpy crimson 
cringe cringed cringer cringes cringle crinite crinkle crinkly crinoid crinum crinums criollo 
cripe cripes cripple cris crises crisic crisis crisp crisped crispen crisper crisply 
crisps crispy crissa crissal crissum crista cristae crit critic critics crits critter 
crittur croak croaked croaker croaks croaky croc crocein crochet croci crocine crock 
crocked crocket crocks crocs crocus croft crofter crofts crojik crojiks crone crones 
cronies cronish crony crook crooked crooker crooks croon crooned crooner croons crop 
cropped cropper croppie crops croquet croquis crore crores crosier cross crosse crossed 
crosser crosses crossly crotch croton crotons crouch croup croupe croupes croups croupy 
crouse croute croutes crouton crow crowbar crowd crowded crowder crowdie crowds crowdy 
crowed crower crowers crown crowned crowner crownet crowns crows croze crozer crozers 
crozes crozier cru cruces crucial crucian crucify cruck crucks crud crudded cruddy 
crude crudely cruder crudes crudest crudity cruds cruel crueler cruelly cruelty cruet 
cruets cruise cruised cruiser cruises cruller crumb crumbed crumber crumble crumbly crumbs 
crumbum crumby crummie crummy crump crumped crumpet crumple crumply crumps crunch crunchy 
crunode cruor cruors crupper crura crural crus crusade crusado cruse cruses cruset 
crusets crush crushed crusher crushes crusily crust crustal crusted crusts crusty crutch 
crux cruxes cruzado crwth crwths cry crybaby cryogen cryonic crypt cryptal cryptic 
crypto cryptos crypts crystal ctenoid cu cuatro cuatros cub cubage cubages cubbies 
cubbish cubby cube cubeb cubebs cubed cuber cubers cubes cubic cubical cubicle 
cubicly cubics cubism cubisms cubist cubists cubit cubital cubiti cubits cubitus cuboid 
cuboids cubs cuckold cuckoo cuckoos cud cudbear cuddie cuddies cuddle cuddled cuddler 
cuddles cuddly cuddy cudgel cudgels cuds cudweed cue cued cues cuesta cuestas 
cuff cuffed cuffs cuif cuifs cuirass cuish cuishes cuisine cuisse cuisses cuittle 
cuke cukes culch culches culet culets culex culexes culices culicid cull cullay 
cullays culled culler cullers cullet cullets cullied cullies cullion cullis culls cully 
culm culmed culms culotte culpa culpae culprit cult cultch culti cultic cultish 
cultism cultist cults culture cultus culver culvers culvert cum cumarin cumber cumbers 
cumbia cumbias cumin cumins cummer cummers cummin cummins cumquat cumshaw cumuli cumulus 
cundum cundums cuneal cuneate cunn cunner cunners cunt cunts cup cupcake cupel 
cupeled cupeler cupels cupful cupfuls cupid cupids cuplike cupola cupolas cupp cuppa 
cuppas cupped cupper cuppers cuppier cuppy cupric cuprite cuprous cuprum cuprums cups 
cupsful cupula cupulae cupular cupule cupules cur curable curably curacao curacoa curacy 
curagh curaghs curara curaras curare curares curari curaris curate curated curates curator 
curb curbed curber curbers curbs curch curches curcuma curd curded curdier curdle 
curdled curdler curdles curds curdy cure cured curer curers cures curet curets 
curette curf curfew curfews curfs curia curiae curial curie curies curio curios 
curiosa curious curite curites curium curiums curl curled curler curlers curlew curlews 
curlier curlily curls curly curn curns curr currach curragh curran currans currant 
curred current currie curried currier curries currish currs curry curs curse cursed 
curser cursers curses cursive cursor cursors cursory curst curt curtail curtain curtal 
curtals curtate curter curtest curtesy curtly curtsey curtsy curule curv curve curved 
curves curvet curvets curvey curvier curvy cuscus cusec cusecs cushat cushats cushaw 
cushaws cushier cushily cushion cushy cusk cusks cusp cuspal cuspate cusped cuspid 
cuspids cuspis cusps cuss cussed cusser cussers cusses cusso cussos custard custody 
custom customs custos cut cutaway cutback cutbank cutch cutches cutdown cute cutely 
cuter cutes cutesie cutest cutesy cutey cuteys cuticle cutie cuties cutin cutins 
cutis cutises cutlas cutlass cutler cutlers cutlery cutlet cutlets cutline cutoff cutoffs 
cutout cutouts cutover cuts cutt cuttage cutter cutters cutties cuttle cuttled cuttles 
cutty cutup cutups cutwork cutworm cuvee cuvees cuvette cwm cwms cyan cyanate 
cyanic cyanid cyanide cyanids cyanin cyanine cyanins cyanite cyano cyans cyber cyborg 
cyborgs cycad cycads cycas cycases cycasin cycl cyclase cycle cycled cycler cyclers 
cyclery cycles cyclic cyclin cyclins cyclist cyclize cyclo cycloid cyclone cyclops cyclos 
cyder cyders cyeses cyesis cygnet cygnets cylices cylix cyma cymae cymar cymars 
cymas cymatia cymbal cymbals cyme cymene cymenes cymes cyml cymlin cymlins cymoid 
cymol cymols cymose cymous cynic cynical cynics cypher cyphers cypres cypress cyprian 
cyprus cypsela cyst cystein cystic cystine cystoid cysts cyton cytons cytosol czar 
czardas czardom czarina czarism czarist czars dace daces dacha dachas dacite dacites 
dacker dackers dacoit dacoits dacoity dacron dacrons dactyl dactyli dactyls daglock danc 
dance danced dancer dancers dances daric darics datcha datchas daturic daycare deacon 
deacons debacle debauch debouch decadal decade decades decaf decafs decagon decal decalog 
decals decamp decamps decanal decane decanes decant decants decapod decare decares decay 
decayed decayer decays decease deceit deceits deceive decency decent decern decerns deciare 
decibel decide decided decider decides decidua decile deciles decimal deck decked deckel 
deckels decker deckers deckle deckles decks declaim declare declass declaw declaws decline 
deco decoct decocts decode decoded decoder decodes decolor decor decors decorum decos 
decoy decoyed decoyer decoys decree decreed decreer decrees decrial decried decrier decries 
decrown decry decrypt decuman decuple decurve decury deduce deduced deduces deduct deducts 
deface defaced defacer defaces defect defects defence deficit deflect defocus deforce defrock 
defunct dehisce deic deice deiced deicer deicers deices deicide deictic deific deistic 
deject dejecta dejects delict delicts delphic deltaic deltic demic demonic demotic deontic 
depict depicts dermic derrick descant descend descent descry detach detect detects detick 
deticks detract deuc deuce deuced deuces device devices devoice dewclaw dezinc dezincs 
dharmic diacid diacids dialect diarchy dibasic dic dicamba dicast dicasts dice diced 
dicer dicers dices dicey dicier diciest dick dicked dickens dicker dickers dickey 
dickeys dickie dickier dickies dicks dicky dicliny dicot dicots dicotyl dicta dictate 
dictier diction dictum dictums dicty dicycly didact didacts dieback dimeric dineric diocese 
dioecy diploic dipodic diptyca diptych direct directs disc discant discard discase disced 
discept discern disci disco discoed discoid discord discos discs discus discuss disject 
disomic dissect distich ditch ditched ditcher ditches divorce doc docent docents docetic 
docile dock dockage docked docker dockers docket dockets docks docs doctor doctors 
dogcart dogface dolce dolci domic domical domicil dormice dorneck dornick dornock douce 
doucely douceur douche douched douches dovecot dracena drachm drachma drachms drastic dreck 
drecks drecky dreich drench druidic dryadic ducal ducally ducat ducats duce duces 
duchess duchies duchy duci duck ducked ducker duckers duckie duckier duckies duckpin 
ducks ducky duct ductal ducted ductile ducts ductule dulcet dulcets dulcify dunce 
dunces dunch dunches duncish dunitic durance duroc durocs dutch dyadic dyadics dyarchy 
dynamic dysuric each earache earlock ebonics ecarte ecartes ecbolic eccrine ecdyses ecdysis 
ecdyson ecesic ecesis ech echard echards eche eched echelle echelon eches echidna 
echini echinus echo echoed echoer echoers echoes echoey echoic echoism echos echt 
eclair eclairs eclat eclats eclipse eclogue ecocide ecology economy ecotage ecotone ecotour 
ecotype ecru ecrus ecstasy ectases ectasis ectatic ecthyma ectopia ectopic ectozoa ectypal 
ectype ectypes ecu ecus eczema eczemas edacity edaphic edenic edict edictal edicts 
edifice educ educate educe educed educes educt eductor educts efface effaced effacer 
effaces effect effects eggcup eggcups eidetic eidolic eirenic eject ejecta ejected ejector 
ejects ekistic elastic eldrich elect elected electee elector electro elects elegiac elenchi 
elflock elicit elicits embolic embrace emcee emceed emcees emetic emetics emic empiric 
emplace enact enacted enactor enacts enatic encage encaged encages encamp encamps encase 
encased encases encash enchain enchant enchase encina encinal encinas enclasp enclave enclose 
encode encoded encoder encodes encomia encore encored encores encrust encrypt encyst encysts 
endarch endemic enface enfaced enfaces enforce enhance enlace enlaced enlaces enolic enounce 
enrich enteric entice enticed enticer entices entopic enzymic eocene eosinic epact epacts 
eparch eparchs eparchy epeiric ephebic epic epical epicarp epicene epics epicure epigeic 
episcia epizoic epoch epochal epochs erect erected erecter erectly erector erects erethic 
ergodic ergotic erica ericas ericoid eristic erotic erotica erotics errancy erratic eruct 
eructed eructs escalop escape escaped escapee escaper escapes escar escarp escarps escars 
eschar eschars escheat eschew eschews escolar escort escorts escot escoted escots escrow 
escrows escuage escudo escudos essence etch etchant etched etcher etchers etches etheric 
ethic ethical ethics ethnic ethnics ethylic etic eucaine euchre euchred euchres euclase 
eucrite eugenic eunuch eunuchs eupneic eustacy evacuee evict evicted evictee evictor evicts 
evince evinced evinces exact exacta exactas exacted exacter exactly exactor exacts exarch 
exarchs exarchy exceed exceeds excel excels except excepts excerpt excess excide excided 
excides excimer exciple excise excised excises excite excited exciter excites exciton excitor 
exclaim exclave exclude excreta excrete excuse excused excuser excuses exec execs execute 
exilic exocarp exonic exosmic exotic exotica exotics expect expects exscind exsect exsects 
extinct extract eyecup eyecups fabric fabrics fac facade facades face faced facer 
facers faces facet facete faceted facets faceup facia faciae facial facials facias 
faciend facies facile facings fact factful faction factoid factor factors factory facts 
factual facture facula faculae facular faculty faecal faeces faience falcate falces falcon 
falcons fallacy fanatic fancied fancier fancies fancify fancily fancy fanfic fanfics faradic 
farc farce farced farcer farcers farces farceur farci farcie farcies farcy fasces 
fascia fasciae fascial fascias fascine fascism fascist fatback fatidic faucal faucals fauces 
faucet faucets faucial fecal feces fecial fecials feck feckly fecks fecula feculae 
fecund felsic felucca fenc fence fenced fencer fencers fences fennec fennecs ferric 
fescue fescues fetch fetched fetcher fetches fetich fetlock fiacre fiacres fiance fiancee 
fiances fiaschi fiasco fiascos fice fices fiche fiches fichu fichus ficin ficins 
fickle fickler fickly fico ficoes fictile fiction fictive ficus ficuses fierce fiercer 
filch filched filcher filches filmic finance finback finca fincas finch finches finical 
finicky fisc fiscal fiscals fiscs fistic fitch fitchee fitches fitchet fitchew fitchy 
fjordic flaccid flack flacked flacks flacon flacons flatcap flatcar fleche fleches fleck 
flecked flecks flecky fleece fleeced fleecer fleeces fleech fleecy flench fletch flic 
flick flicked flicker flicks flics flinch flitch floc flocced flocci floccus flock 
flocked flocks flocky flocs flounce flouncy fluency flueric fluidic fluoric flysch focal 
focally foci focus focused focuser focuses folacin folic forc force forced forceps 
forcer forcers forces formic formica fossick fracas fractal fracted fracti fractur fractus 
franc francs frantic freckle freckly french fresco frescos frock frocked frocks frolic 
frolics frounce fuchsia fuchsin fuci fucoid fucoids fucose fucoses fucous fucus fucuses 
fulcra fulcrum fumaric functor fundic fungic funicle furcate furcula furnace fuscous fustic 
fustics futharc futhorc futtock fyce fyces galenic gallic gallica galyac galyacs gametic 
gamic ganache garcon garcons garlic garlics gascon gascons gastric gauche gaucher gaucho 
gauchos geck gecked gecko geckoes geckos gecks gelcap gelcaps generic genetic genic 
genomic geodic geoduck georgic gestic gimmick glace glaceed glaces glacial glacier glacis 
glance glanced glancer glances glitch glitchy glochid glottic glucan glucans glucose glunch 
glycan glycans glycin glycine glycins glycol glycols glycyl glycyls glyphic glyptic gnathic 
gnocchi gnomic gnostic gonadic gonidic gorcock gotcha gotchas gothic gothics gouache grac 
grace graced graces gracile grackle graphic grecize grimace grinch grocer grocers grocery 
grouch grouchy grutch guaco guacos guaiac guaiacs guanaco guck gucks gulch gulches 
gunlock gweduc gweduck gweducs gynecia gynecic hacek haceks hachure hack hackbut hacked 
hackee hackees hacker hackers hackie hackies hackle hackled hackler hackles hackly hackman 
hackmen hackney hacks hacksaw haddock haemic hagadic haircap haircut halacha halakic halcyon 
hammock hance hances handcar haptic haricot hassock hatch hatched hatchel hatcher hatches 
hatchet hatrack haunch havoc havocs haycock hayrack hayrick hebetic heck heckle heckled 
heckler heckles hecks hectare hectic hector hectors hedonic heliac helical helices helicon 
hellcat hematic hemic hemlock hence hencoop henpeck hepatic hepcat hepcats herdic herdics 
heretic heroic heroics heuch heuchs hexadic hexylic hibachi hic hiccup hiccups hick 
hickey hickeys hickie hickies hickish hickory hicks hijack hijacks hillock hircine hitch 
hitched hitcher hitches hock hocked hocker hockers hockey hockeys hocks hocus hocused 
hocuses hoecake hogback hoick hoicked hoicks holmic homeric hommock honcho honchos hooch 
hooches hoochie hootch hopsack hospice hotcake hotch hotched hotches hubcap hubcaps huck 
huckle huckles hucks huic humic hummock hunch hunched hunches hutch hutched hutches 
hyaenic hydric hyenic hypnic hypoxic hyraces iambic iambics iatric ibices ic ice 
iceberg iceboat icebox icecap icecaps iced icefall iceless icelike iceman icemen ices 
ich ichnite ichor ichors ichs icicle icicled icicles icier iciest icily iciness 
icings ick icker ickers ickier ickiest ickily icky icon icones iconic icons 
icteric icterus ictic ictus ictuses icy identic idiocy idiotic idyllic ileac iliac 
illicit illitic illogic imidic impact impacts impeach inarch incage incaged incages incant 
incants incase incased incases incense incent incents incept incepts incest incests inch 
inched incher inchers inches incipit incisal incise incised incises incisor incite incited 
inciter incites incivil inclasp incline inclip inclips inclose include incog incogs income 
incomer incomes inconnu incony incross incrust incubi incubus incudal incudes incult incur 
incurs incurve incus incuse incused incuses indican indices indicia indict indicts induce 
induced inducer induces induct inducts inexact infancy infarct infect infects inflect inflict 
infract inject injects inlace inlaced inlaces inocula inscape insculp insect insects inspect 
intact invoice iodic ionic ionics ipecac ipecacs iracund irenic irenics iridic iritic 
ironic ischia ischial ischium isochor isopach isotach isthmic italic italics itch itched 
itches itchier itchily itchy jacal jacales jacals jacamar jacana jacanas jacinth jack 
jackal jackals jackass jackdaw jacked jacker jackers jacket jackets jackies jackleg jackpot 
jacks jacky jacobin jacobus jaconet jacuzzi jaditic jalapic jaunce jaunced jaunces jicama 
jicamas jock jockey jockeys jocko jockos jocks jocose jocular jocund jounce jounced 
jounces jouncy joyance juco jucos juic juice juiced juicer juicers juices juicier 
juicily juicy jumbuck junco juncoes juncos juridic justice kachina kalpac kalpacs kaonic 
karmic karstic katcina kebbock kebbuck keck kecked keckle keckled keckles kecks kench 
kenches kenotic keramic kerchoo ketch ketches ketchup ketonic ketotic keycard kick kickbox 
kicked kicker kickers kickier kickoff kicks kickup kickups kicky killick killock kimchee 
kimchi kimchis kinesic kinetic kingcup kirsch kitchen kitsch kitschy klatch klatsch klick 
klicks knack knacked knacker knacks kneecap knock knocked knocker knocks knuckle knuckly 
kolacky kopeck kopecks kuchen kuchens kvetch kvetchy kwacha kwachas kyack kyacks lac 
lace laced lacer lacers laces lacey laches lacier laciest lacily lacings lack 
lacked lacker lackers lackey lackeys lacks laconic lacquer lacquey lacs lactam lactams 
lactary lactase lactate lacteal lactean lactic lactone lactose lacuna lacunae lacunal lacunar 
lacunas lacune lacunes lacy laic laical laich laichs laicise laicism laicize laics 
lanc lance lanced lancer lancers lances lancet lancets larceny larch larchen larches 
lascar lascars latch latched latches latchet latency latices lattice launce launces launch 
lavrock leach leached leacher leaches leachy lech leched lecher lechers lechery leches 
lechwe lechwes lectern lectin lectins lection lector lectors lecture lecythi leech leeched 
leeches legacy lentic letch letched letches lettuce leucin leucine leucins leucite leucoma 
lexemic lexica lexical lexicon lice licence license licente lich lichee lichees lichen 
lichens liches lichi lichis licht lichted lichtly lichts licit licitly lick licked 
licker lickers licks lictor lictors lilac lilacs limacon limbeck limbic limnic linac 
linacs linecut lingcod linocut lipidic litchi litchis lithic litotic loach loaches loca 
local locale locales locally locals locate located locater locates locator loch lochan 
lochans lochia lochial lochs loci lock lockage lockbox locked locker lockers locket 
lockets lockjaw locknut lockout lockram locks lockset lockup lockups loco locoed locoes 
locoism locos locular locule loculed locules loculi loculus locum locums locus locust 
locusta locusts logic logical logics lorica loricae lotic louche lubric lucarne luce 
lucence lucency lucent lucern lucerne lucerns luces lucid lucidly lucifer lucite lucites 
luck lucked luckie luckier luckies luckily lucks lucky lucre lucres ludic luetic 
luetics lunacy lunatic lunch lunched luncher lunches lurch lurched lurcher lurches lycea 
lycee lycees lyceum lyceums lych lychee lychees lyches lychnis lycopod lycra lycras 
lyncean lynch lynched lyncher lynches lyric lyrical lyricon lyrics lytic mac macaber 
macabre macaco macacos macadam macaque macaw macaws macchia macchie mace maced macer 
macers maces mach mache maches machete machine macho machos machree machs machzor 
mack mackle mackled mackles macks macle macled macles macon macons macrame macro 
macron macrons macros macs macula maculae macular maculas macule maculed macules macumba 
madcap madcaps maffick mafic magic magical magics malacca malefic malic malice malices 
mammock manacle manche manches manchet maniac maniacs manic manics manioc manioca maniocs 
manpack mantic mantric maraca maracas marasca marc marcato marcel marcels march marched 
marchen marcher marches marcs mascara mascon mascons mascot mascots masonic mastic mastics 
match matched matcher matches matchup mattock mecca meccas medevac mediacy medic medical 
medick medicks medico medicos medics medivac meiotic melanic melic melodic menace menaced 
menacer menaces menisci mensch menschy merc mercer mercers mercery merces merch merches 
mercies mercs mercury mercy meropic mesarch mescal mescals mesclun mesic mesonic metical 
metopic metric metrics mezcal mezcals miasmic mic mica micas mice micell micella 
micelle micells mich miche miched miches mick mickey mickeys mickle mickler mickles 
micks micra micrify micro microbe microhm micron microns micros mics midcap midcult 
milch milchig mimetic mimic mimical mimicry mimics minc mince minced mincer mincers 
minces mincier mincy minicab minicam minicar minorca miocene miotic miotics miracle misact 
misacts miscall miscast miscite miscode miscoin miscook miscopy miscue miscued miscues miscut 
miscuts miskick mitotic mobcap mobcaps moc mocha mochas mochila mock mocked mocker 
mockers mockery mocks mockup mockups mocs modica modicum mollusc moloch molochs monacid 
monadic monarch monocle monocot monodic monoecy mooch mooched moocher mooches morceau morocco 
moronic morphic mortice mosaic mosaics motific motivic motoric mouch mouched mouches much 
muches muchly mucho mucid mucin mucins muck mucked mucker muckers muckier muckily 
muckle muckles mucks mucky mucluc muclucs mucoid mucoids mucor mucors mucosa mucosae 
mucosal mucosas mucose mucous mucro mucus mucuses mudcap mudcaps mudcat mudcats mudpack 
mudrock mulch mulched mulches mulct mulcted mulcts mullock munch munched muncher munches 
muntjac muonic murices musca muscae muscat muscats muscid muscids muscle muscled muscles 
muscly music musical musick musicks musics mutch mutches myalgic myc mycele myceles 
mycelia mycoses mycosis mycotic mycs myopic myotic myotics myrica myricas myrrhic mystic 
mystics mythic nacelle nachas naches nacho nachos nacre nacred nacres nance nances 
nancies nancy narc narcein narcism narcist narco narcoma narcos narcose narcs naric 
nascent nastic natch nautch neck necked necker neckers necks necktie necrose nectar 
nectars nectary neglect nematic neocon neocons nephric nepotic neritic neumic neustic niacin 
niacins niblick nicad nicads nice nicely nicer nicest nicety nich niche niched 
niches nick nicked nickel nickels nicker nickers nickle nickled nickles nicks nicoise 
nicol nicols nicotin nictate niece nieces niobic nitchie nitpick nitric nocent nock 
nocked nocks noctuid noctule nocturn nocuous nodical noetic nomadic nomarch nonacid noncash 
nonce nonces noncola noncom noncoms noncore nonfact nonsuch noplace nordic noritic nostoc 
nostocs notch notched notcher notches notice noticed noticer notices novice novices nuance 
nuanced nuances nubuck nubucks nucelli nucha nuchae nuchal nuchals nucleal nuclear nuclei 
nuclein nucleon nucleus nuclide nudnick numeric nuncio nuncios nuncle nuncles nutcase nutpick 
oarlock oatcake obconic object objects obscene obscure obtect oca ocarina ocas occiput 
occlude occult occults occupy occur occurs ocean oceanic oceans ocellar ocelli ocellus 
oceloid ocelot ocelots ocher ochered ochers ochery ochone ochr ochre ochrea ochreae 
ochred ochres ochroid ochrous ochry ocicat ocicats ocker ockers ocrea ocreae ocreate 
octad octadic octads octagon octal octan octane octanes octanol octans octant octants 
octaval octave octaves octavo octavos octet octets octette octopi octopod octopus octroi 
octrois octuple octuply octyl octyls ocular oculars oculi oculist oculus odic offcast 
offcut offcuts offence office officer offices oghamic ohmic oilcamp oilcan oilcans oilcup 
oilcups oleic olicook omicron omnific once oncet oneiric ontic oocyst oocysts oocyte 
oocytes oolitic oologic oomiac oomiack oomiacs ootheca opacify opacity ophitic opsonic optic 
optical optics orach orache oraches oracle oracles orc orca orcas orcein orceins 
orchard orchid orchids orchil orchils orchis orcin orcinol orcins orcs orectic organic 
orgiac orgic orifice orphic orrice orrices oscine oscines oscula oscular oscule oscules 
osculum osmatic osmic osmics osmotic ossicle ossific ostraca ostrich otalgic otic otitic 
otocyst ouch ouched ouches ounce ounces outact outacts outback outcall outcast outchid 
outcity outcome outcook outcrop outcrow outcry outecho outface outkick outpace outrace outrock 
overact overcoy overcut ovicide oviduct ovisac ovisacs ovonic ovonics oxalic oxcart oxcarts 
oxidic oxyacid ozonic pac paca pacas pace paced pacer pacers paces pacey 
pacha pachas pachisi pachuco pacier paciest pacific pacify pack package packed packer 
packers packet packets packly packman packmen packs packwax pacs pact paction pacts 
pacy paddock padlock painch palace palaced palaces panacea panache pancake panchax pandect 
panic panicky panicle panics panicum panocha panoche papacy paprica parcel parcels parch 
parched parches paretic parodic parotic parsec parsecs pascal pascals paschal pataca patacas 
patch patched patcher patches patchy patency paucity paunch paunchy payback peac peace 
peaced peaces peach peached peacher peaches peachy peacoat peacock peascod pec pecan 
pecans peccant peccary peccavi pech pechan pechans peched pechs peck pecked pecker 
peckers peckier peckish pecks pecky pecs pectase pectate pecten pectens pectic pectin 
pectins pectize peculia pedicab pedicel pedicle pedocal pelagic pelican pelitic peloric pelvic 
pelvics pemican penance pence pencel pencels pencil pencils penicil penoche penuche penuchi 
peptic peptics peracid percale percent percept perch perched percher perches percoid percuss 
perfect petcock phallic phasic phatic phobic phobics phocine phonic phonics photic photics 
phrenic phylic physic physics pianic pibroch pic pica picacho picador pical picante 
picara picaras picaro picaros picas piccata piccolo pice piceous pick pickax pickaxe 
picked pickeer picker pickers picket pickets pickier pickle pickled pickles pickoff picks 
pickup pickups picky picnic picnics picolin picot picoted picotee picots picquet picrate 
picric picrite pics picture picul piculs piddock piec piece pieced piecer piecers 
pieces pierce pierced piercer pierces pincer pincers pinch pinched pincher pinches pinnace 
pinocle pionic piracy piratic piscary piscina piscine pisco piscos pitch pitched pitcher 
pitches pitchy plac placard placate place placebo placed placer placers places placet 
placets placid plack placket placks placoid plaice plaices planch planche plasmic plastic 
playact pleach plectra plench pleonic pliancy plica plicae plical plicate pluck plucked 
plucker plucks plucky plumbic poach poached poacher poaches poachy pochard pock pocked 
pocket pockets pockier pockily pocks pocky poco pocosen pocosin pocoson poditic poetic 
poetics polecat polemic police policed policer polices policy politic pollack pollock polycot 
pomace pomaces ponc ponce ponced ponces poncho ponchos pooch pooched pooches popcorn 
porch porches porcine porcini porcino porrect portico postdoc potamic potence potency potiche 
potlach potluck pouch pouched pouches pouchy pounce pounced pouncer pounces practic prance 
pranced prancer prances preach preachy preact preacts precast precava precede precent precept 
precess precipe precis precise precode precook precool precoup precure precut precuts predict 
preface prefect prelacy prelect prepack prepuce prerace prerock priapic pric price priced 
pricer pricers prices pricey pricier pricily prick pricked pricker pricket prickle prickly 
pricks pricky pricy primacy prince princes princox privacy procarp proceed process proctor 
procure produce product project prosaic prosect protect prussic psalmic pschent psoatic psocid 
psocids psych psyche psyched psyches psychic psycho psychos psychs ptotic pubic public 
publics puccoon puce puces puck pucka pucker puckers puckery puckish pucks pudency 
pudic pumice pumiced pumicer pumices punch punched puncher punches punchy puranic putsch 
pyaemic pyemic pyic pyknic pyknics pyloric pyretic pyrexic pyric pyridic pyritic pyrrhic 
quack quacked quacks quacky quadric quaich quaichs quantic quartic quench quiche quiches 
quick quicken quicker quickie quickly quicks quince quinces quinic quintic quitch rabic 
rac raccoon race raced raceme racemed racemes racemic racer racers races raceway 
rachet rachets rachial rachis racial racier raciest racily racings racism racisms racist 
racists rack racked racker rackers racket rackets rackety rackful rackle racks racon 
racons racoon racoons racquet racy radical radicel radices radicle railcar rance rances 
ranch ranched rancher ranches rancho ranchos rancid rancor rancors rancour ransack rascal 
rascals ratch ratches ratchet raucity raucous raunch raunchy reach reached reacher reaches 
react reacted reactor reacts rebec rebeck rebecks rebecs rec recall recalls recane 
recaned recanes recant recants recap recaps recarry recast recasts recce recces recede 
receded recedes receipt receive recency recent recept recepts recess rechart recheat recheck 
rechew rechews rechose recipe recipes recit recital recite recited reciter recites recits 
reck recked reckon reckons recks reclad reclads reclaim reclame reclasp reclean recline 
recluse recoal recoals recoat recoats recock recocks recode recoded recodes recoil recoils 
recoin recoins recolor recomb recombs recon recons recook recooks recopy record records 
recork recorks recount recoup recoupe recoups recover recrate recross recrown recruit recs 
recta rectal recti rectify recto rector rectors rectory rectos rectrix rectum rectums 
rectus recur recurs recurve recusal recuse recused recuses recut recuts recycle redact 
redacts redcap redcaps redcoat redneck redock redocks reduce reduced reducer reduces reecho 
reechy reeject reelect reenact reerect reface refaced refaces refect refects refence reflect 
refocus refract regency reincur reject rejects rejoice relace relaced relaces relic relics 
relict relicts relock relocks reluct relucts rematch reoccur repack repacks repatch replace 
replica reprice rerack reracks rescale rescind rescore rescue rescued rescuer rescues resect 
resects respace respect restack restock retack retacks retch retched retches reteach reticle 
retouch retrace retrack retract revoice rhachis rheumic rhodic rhombic rhonchi rhotic ric 
rice riced ricer ricers rices rich richen richens richer riches richest richly 
ricin ricins ricinus rick ricked rickets rickety rickey rickeys ricks ricksha ricotta 
ricrac ricracs rictal rictus rimrock ripcord roach roached roaches robotic roc rochet 
rochets rock rockaby rocked rocker rockers rockery rocket rockets rockier rockoon rocks 
rocky rococo rococos rocs roebuck rollick romance rootcap rosacea roscoe roscoes rotch 
rotche rotches rouche rouches rowlock rubace rubaces rubidic rubric rubrics ruch ruche 
ruched ruches ruck rucked ruckle ruckled ruckles rucks ruckus ruction ruddock runback 
runic rustic rustics sac sacaton sacbut sacbuts saccade saccate saccule sacculi sachem 
sachems sachet sachets sack sackbut sacked sacker sackers sackful sacks saclike sacque 
sacques sacr sacra sacral sacrals sacred sacrist sacrum sacrums sacs saice saices 
salchow salic salicin sambuca samech samechs sancta sanctum sanicle sapphic sarcasm sarcina 
sarcoid sarcoma sarcous satanic satchel satiric satyric sauc sauce sauced saucer saucers 
sauces sauch sauchs saucier saucily saucy sawbuck scab scabbed scabble scabby scabies 
scabs scad scads scag scags scal scalade scalado scalage scalar scalare scalars 
scald scalded scaldic scalds scale scaled scalene scaleni scaler scalers scales scaleup 
scalier scall scallop scalls scalp scalped scalpel scalper scalps scaly scam scammed 
scammer scamp scamped scamper scampi scamps scams scan scandal scandia scandic scanned 
scanner scans scant scanted scanter scantly scants scanty scap scape scaped scapes 
scapose scapula scar scarab scarabs scarce scarcer scare scared scarer scarers scares 
scarey scarf scarfed scarfer scarfs scarier scarify scarily scarlet scarp scarped scarper 
scarph scarphs scarps scarred scarry scars scart scarted scarts scarves scary scat 
scathe scathed scathes scats scatt scatted scatter scatts scatty scaup scauper scaups 
scaur scaurs scena scenas scend scended scends scene scenery scenes scenic scenics 
scent scented scents scepter sceptic sceptre schappe schav schavs schema schemas scheme 
schemed schemer schemes scherzi scherzo schism schisms schist schists schizo schizos schizy 
schizzy schlep schlepp schleps schlock schlub schlubs schlump schmalz schmear schmeer schmo 
schmoe schmoes schmoos schmos schmuck schnaps schnook schnoz schnozz scholar scholia school 
schools schorl schorls schrik schriks schrod schrods schtick schtik schtiks schuit schuits 
schul schuln schuls schuss schwa schwas sciatic science scilla scillas scion scions 
scirrhi scissor sciurid sclaff sclaffs sclera sclerae scleral scleras scoff scoffed scoffer 
scoffs scold scolded scolder scolds scolex scollop sconce sconced sconces scone scones 
scooch scoop scooped scooper scoops scoot scootch scooted scooter scoots scop scope 
scoped scopes scops scopula scor scorch score scored scorer scorers scores scoria 
scoriae scorify scorn scorned scorner scorns scot scotch scoter scoters scotia scotias 
scotoma scots scottie scour scoured scourer scourge scours scouse scouses scout scouted 
scouter scouth scouths scouts scow scowder scowed scowl scowled scowler scowls scows 
scrag scraggy scrags scraich scraigh scram scrams scrap scrape scraped scraper scrapes 
scrapie scrappy scraps scratch scrawl scrawls scrawly scrawny screak screaks screaky scream 
screams scree screech screed screeds screen screens screes screw screwed screwer screws 
screwup screwy scribal scribe scribed scriber scribes scried scries scrieve scrim scrimp 
scrimps scrimpy scrims scrip scrips script scripts scrive scrived scrives scrod scrods 
scroggy scroll scrolls scrooch scrooge scroop scroops scrota scrotal scrotum scrouge scrub 
scrubby scrubs scruff scruffs scruffy scrum scrums scrunch scruple scry scuba scubaed 
scubas scud scudded scudi scudo scuds scuff scuffed scuffer scuffle scuffs sculch 
sculk sculked sculker sculks scull sculled sculler sculls sculp sculped sculpin sculps 
sculpt sculpts scultch scum scumbag scumble scummed scummer scummy scums scunner scup 
scupper scups scurf scurfs scurfy scurril scurry scurvy scut scuta scutage scutate 
scutch scute scutes scuts scutter scuttle scutum scuzz scuzzes scuzzy scyphi scyphus 
scythe scythed scythes seacock seance seances search seasick sebacic sebasic sec secant 
secants secco seccos secede seceded seceder secedes secern secerns seclude seconal second 
seconde secondi secondo seconds secpar secpars secrecy secret secrete secrets secs sect 
sectary sectile section sector sectors sects secular secund secure secured securer secures 
seduce seduced seducer seduces seiche seiches seismic select selects selenic sematic sememic 
seneca senecas senecio sepic septic septics serac seracs sericin service setback seviche 
sferics shack shacked shackle shacko shackos shacks shellac sheuch sheuchs shicker shicksa 
shlock shlocks shlocky shmuck shmucks shock shocked shocker shocks shoepac shtick shticks 
shticky shuck shucked shucker shucks shylock sialic sibylic sic sicc siccan sicced 
sice sices sick sickbay sickbed sicked sickee sickees sicken sickens sicker sickest 
sickie sickies sickish sickle sickled sickles sickly sicko sickos sickout sicks sics 
sidecar silence silica silicas silicic silicle silicon silvics since sincere sirocco sitcom 
sitcoms skaldic skeptic sketch sketchy skycap skycaps skyjack slack slacked slacken slacker 
slackly slacks slatch slic slice sliced slicer slicers slices slick slicked slicken 
slicker slickly slicks slouch slouchy sluice sluiced sluices sluicy smack smacked smacker 
smacks smectic smirch smock smocked smocks smooch smoochy smutch smutchy snack snacked 
snacker snacks snatch snatchy sneck snecks snick snicked snicker snicks snitch snowcap 
snowcat snuck soca socage socager socages socas soccage soccer soccers social socials 
society sock socked socket sockets sockeye sockman sockmen socko socks socle socles 
socman socmen sodic solace solaced solacer solaces solicit somatic somitic sonance sonic 
sonics sorbic sorcery soritic soroche soucar soucars soupcon source sourced sources sowcar 
sowcars spac space spaced spacer spacers spaces spacey spacial spacier spackle spacy 
spancel spastic spathic spec specced special specie species specify speck specked speckle 
specks specs specter spectra spectre specula speech spence spencer spences spermic sphenic 
spheric spic spica spicae spicas spicate spice spiced spicer spicers spicery spices 
spicey spicier spicily spick spicks spics spicula spicule spicy spinach splenic splice 
spliced splicer splices splotch spruce spruced sprucer spruces sprucy squelch squinch stack 
stacked stacker stacks stackup stacte stactes stance stances stanch stannic starch starchy 
static statice statics staunch stearic stelic stench stenchy stencil steric sthenic stich 
stichic stichs stick sticked sticker stickit stickle sticks stickum stickup sticky stitch 
stock stocked stocker stocks stocky stoic stoical stoics stomach stretch strick stricks 
strict strobic struck stucco stuccos stuck styptic subacid subcell subclan subcode subcool 
subcult subduce subduct subecho suberic subfusc subject subrace subsect succah succahs succeed 
success succor succors succory succoth succour succuba succubi succumb succuss such suck 
sucked sucker suckers suckier suckle suckled suckler suckles sucks sucky sucrase sucre 
sucres sucrose suction suffice suicide sulcal sulcate sulci sulcus sumac sumach sumachs 
sumacs sunback sundeck surcoat surface suspect swacked swatch switch syce sycee sycees 
syces syconia sycoses sycosis sylphic sync syncarp synced synch synched synchro synchs 
syncom syncoms syncope syncs syndic syndics synodic tabetic tace taces tacet tach 
tache taches tachism tachist tachs tachyon tacit tacitly tack tacked tacker tackers 
tacket tackets tackey tackier tackify tackily tackle tackled tackler tackles tacks tacky 
tacnode taco tacos tacrine tact tactful tactic tactics tactile taction tacts tactual 
talc talced talcked talcky talcose talcous talcs talcum talcums tambac tambacs tannic 
tanrec tanrecs tantric tapioca tarmac tarmacs taroc tarocs taxemic taxicab taxitic teacake 
teacart teach teacher teaches teacup teacups tech teched techie techier techies techily 
technic techno technos techs techy tecta tectal tectite tectrix tectum tectums telco 
telcos telecom telic telomic tenace tenaces tenancy tench tenches tenrec tenrecs terbic 
terce tercel tercels terces tercet tercets terebic terrace testacy tetanic tetched tetchy 
teuch thack thacked thacks thallic thatch thatchy theca thecae thecal thecate thence 
theriac thermic thetic thick thicken thicker thicket thickly thicks thiolic thionic thoric 
thrice thwack thwacks thymic tic tical ticals ticc ticced tick ticked ticker 
tickers ticket tickets tickle tickled tickler tickles ticks tics tictac tictacs tictoc 
tictocs tieback tierce tierced tiercel tierces tincal tincals tinct tincted tincts tipcart 
tipcat tipcats titanic titmice tobacco toccata toccate tocher tochers tocsin tocsins toecap 
toecaps toluic tombac tomback tombacs tomcat tomcats tomcod tomcods tonemic tonetic tonic 
tonics topcoat topic topical topics topkick torc torch torched torches torchon torchy 
torcs toric torics totemic toucan toucans touch touche touched toucher touches touchup 
touchy touraco towsack toxemic toxic toxical toxics trac trace traced tracer tracers 
tracery traces trachea trachle track tracked tracker tracks tract tractor tracts traduce 
traffic tragic tragics traject tramcar trance tranced trances tranche treacle treacly trench 
triac triacid triacs triadic tric trice triced tricep triceps trices trick tricked 
tricker trickie trickle trickly tricks tricksy tricky triclad tricorn tricot tricots tripack 
trisect trismic trocar trocars trochal trochar troche trochee troches trochil trock trocked 
trocks trophic tropic tropics trounce truancy truc truce truced truces truck trucked 
trucker truckle trucks tryptic tuchun tuchuns tuck tucked tucker tuckers tucket tuckets 
tucks tumesce tunic tunica tunicae tunicle tunics turaco turacos turacou tusche tusches 
tussock tussuck twice twitch twitchy tycoon tycoons typic typical tyronic ulcer ulcered 
ulcers umbonic umiac umiack umiacks umiacs unacted unblock unbrace uncage uncaged uncages 
uncake uncaked uncakes uncanny uncap uncaps uncase uncased uncases uncast unceded unchain 
unchair unchary unchic unchoke unci uncia unciae uncial uncials uncinal uncini uncinus 
uncivil unclad unclamp unclasp uncle unclean unclear uncleft uncles unclip unclips uncloak 
unclog unclogs unclose uncloud unco uncock uncocks uncoded uncoil uncoils uncomic uncool 
uncork uncorks uncos uncouth uncover uncoy uncrate uncrazy uncross uncrown unction uncuff 
uncuffs uncurb uncurbs uncured uncurl uncurls uncus uncut uncute undock undocks unfancy 
unfence unfrock unhitch unicorn uniface unific unlace unlaced unlaces unlatch unlock unlocks 
unlucky unmacho unpack unpacks unpick unpicks unscrew unslick unsoncy unstack unstick unstuck 
untack untacks unteach untrack untuck untucks unvocal unvoice upcast upcasts upchuck upclimb 
upcoast upcoil upcoils upcourt upcurl upcurls upcurve upreach upscale uptick upticks uracil 
uracils uraemic uranic uratic urchin urchins ureic uremic uretic urgency uric usance 
usances usaunce utricle uveitic vac vacancy vacant vacate vacated vacates vaccina vaccine 
vacs vacua vacuity vacuole vacuous vacuum vacuums valance valence valency valeric vanadic 
varices vascula vatic vatical vector vectors vehicle velcro velcros veloce venatic vendace 
verdict veridic verruca vesica vesicae vesical vesicle vetch vetches viaduct viatic viatica 
vic vicar vicarly vicars vice viced viceroy vices vichies vichy vicinal vicious 
vicomte victim victims victor victors victory victual vicugna vicuna vicunas vidicon vinca 
vincas vincula vinic vinylic viremic viscera viscid viscoid viscose viscous viscus vitric 
vitrics vivace vivaces vivific vocab vocable vocably vocabs vocal vocalic vocally vocals 
voces vocoder voic voice voiced voicer voicers voices volcano voltaic vomica vomicae 
vouch vouched vouchee voucher vouches wack wacke wacker wackes wackest wackier wackily 
wacko wackos wacks wacky waesuck warlock watch watched watcher watches waucht wauchts 
wavicle webcam webcams webcast wecht wechts wedlock welch welched welcher welches welcome 
wench wenched wencher wenches wetback whack whacked whacker whacko whackos whacks whacky 
whence which whicker wicca wiccan wiccans wiccas wich wiches wick wickape wicked 
wicker wickers wicket wickets wickiup wicks wickyup wicopy wilco wildcat winc wince 
winced wincer wincers winces wincey winceys winch winched wincher winches winnock witch 
witched witches witchy woodcut wrack wracked wracks wreck wrecked wrecker wrecks wrench 
wretch wrick wricked wricks wryneck wych wyches xanthic xebec xebecs xenic xerarch 
xeric xerotic yacht yachted yachter yachts yack yacked yacks yapock yapocks yashmac 
yclad ycleped yclept yecch yecchs yech yechs yechy yince yock yocked yocks 
yogic yoicks yonic yttric yuca yucas yucca yuccas yucch yuch yuck yucked 
yuckier yucks yucky zacaton zaddick zebec zebeck zebecks zebecs zebraic zecchin zechin 
zechins zilch zilches zinc zincate zinced zincic zincify zincite zincked zincky zincoid 
zincous zincs zincy ziplock zircon zircons zlotych zocalo zocalos zodiac zodiacs zoecia 
zoecium zoic zooecia zydeco zydecos zygotic zymotic      
);

my @M_words = qw(
abamp abamps abdomen abeam ableism abloom abmho abmhos abohm abohms aboma abomas 
abomasa abomasi abysm abysmal abysms academe academy acclaim acetum aciform acmatic acme 
acmes acmic acromia acronym acumen acumens adamant adeem adeemed adeems adenoma adman 
admass admen admiral admire admired admirer admires admit admits admix admixed admixes 
admixt adwoman adwomen adytum aecium affirm affirms aflame aftmost agama agamas agamete 
agamic agamid agamids agamous ageism ageisms agemate agendum agism agisms agleam agma 
agmas agnomen ahem ahimsa ahimsas aidman aidmen ailment aim aimed aimer aimers 
aimful aimless aims airmail airman airmen airtime akimbo alameda alamo alamode alamos 
alarm alarmed alarms alarum alarums album albumen albumin albums alchemy alchymy alembic 
algum algums aliform aliment alimony allium alliums allonym alma almah almahs almanac 
almas alme almeh almehs almemar almes almner almners almond almonds almondy almoner 
almonry almost alms almsman almsmen almuce almuces almud almude almudes almuds almug 
almugs alodium alum alumin alumina alumine alumins alumna alumnae alumni alumnus alums 
alyssum am ama amadou amadous amah amahs amain amalgam amanita amarna amarone 
amas amass amassed amasser amasses amateur amative amatol amatols amatory amaz amaze 
amazed amazes amazon amazons ambage ambages ambari ambaris ambary ambeer ambeers amber 
ambers ambery ambient ambit ambits ambl amble ambled ambler amblers ambles ambo 
amboina ambones ambos amboyna ambries ambroid ambry ambsace ambush ameba amebae ameban 
amebas amebean amebic ameboid ameer ameers amen amend amended amender amends amenity 
amens ament amentia aments amerce amerced amercer amerces amesace ami amia amiable 
amiably amias amice amices amici amicus amid amidase amide amides amidic amidin 
amidine amidins amido amidol amidols amidone amids amidst amie amies amiga amigas 
amigo amigos amin amine amines aminic aminity amino amins amir amirate amirs 
amis amiss amities amity ammeter ammine ammines ammino ammo ammonal ammonia ammonic 
ammono ammos amnesia amnesic amnesty amnia amnic amnio amnion amnions amnios amniote 
amoeba amoebae amoeban amoebas amoebic amok amoks amole amoles among amongst amoral 
amorini amorino amorist amoroso amorous amort amosite amotion amount amounts amour amours 
amp amped ampere amperes amphora ample ampler amplest amplify amply ampoule amps 
ampul ampule ampules ampulla ampuls amputee amreeta amrita amritas amtrac amtrack amtracs 
amu amuck amucks amulet amulets amus amuse amused amuser amusers amuses amusia 
amusias amusive amyl amylase amylene amylic amyloid amylose amyls amylum amylums anadem 
anadems anaemia anaemic anagram anatomy anemia anemias anemic anemone angioma anima animacy 
animal animals animas animate animato anime animes animi animis animism animist animus 
anomaly anomic anomie anomies anomy anonym anonyms anosmia anosmic anthem anthems antijam 
antiman antonym antrum antrums anymore anytime aplomb aplombs apogamy apomict apothem arame 
arames aramid aramids arcanum arm armada armadas armband armed armer armers armet 
armets armful armfuls armhole armies armiger armilla armings armless armlet armlets armlike 
armload armlock armoire armor armored armorer armors armory armour armours armoury armpit 
armpits armrest arms armsful armure armures army aroma aromas arum arums asarum 
asarums ashamed ashman ashmen ashram ashrams asrama asramas assume assumed assumer assumes 
asthma asthmas aswarm asylum asylums ataman atamans atavism atemoya atheism atma atman 
atmans atmas atom atomic atomics atomies atomise atomism atomist atomize atoms atomy 
atrium atriums attempt augment aurum aurums ausform autism autisms automan automat automen 
autonym autumn autumns awesome awmous axeman axemen axiom axioms axman axmen axoneme 
azimuth baalim baalism baculum badman badmen bagman bagmen bagworm balm balmier balmily 
balms balmy balsam balsams bam bambini bambino bamboo bamboos bamm bammed bams 
bantam bantams baptism barium bariums barm barmaid barman barmen barmie barmier barms 
barmy barroom baseman basemen basmati bathmat batman batmen batsman batsmen bayamo bayamos 
bayman baymen bazooms beadman beadmen beam beamed beamier beamily beamish beams beamy 
becalm becalms became becharm become becomes becrime bedamn bedamns bedeman bedemen bedim 
bedims bedlam bedlamp bedlams bedmate bedroom bedtime bedumb bedumbs begloom begrim begrime 
begrims begum begums beldam beldame beldams bellman bellmen bema bemadam bemas bemata 
bemean bemeans bemire bemired bemires bemist bemists bemix bemixed bemixes bemixt bemoan 
bemoans bemock bemocks bemuse bemused bemuses bename benamed benames benempt benomyl benumb 
benumbs berhyme berime berimed berimes berm berme bermed bermes berms berseem beseem 
beseems beshame beslime besmear besmile besmoke besmut besmuts besom besoms beswarm bethump 
betime betimes bevomit beworm beworms biform bigamy bigtime bima bimah bimahs bimas 
bimbo bimboes bimbos bimetal bimodal bimorph biofilm bioherm biomass biome biomes bionomy 
birdman birdmen bireme biremes bismuth bitmap bitmaps bitumen blam blame blamed blamer 
blamers blames blams blellum blemish blimey blimp blimps blimy bloom bloomed bloomer 
blooms bloomy blossom bluegum blum blume blumed blumes boatman boatmen bogyism bogyman 
bogymen bohemia bohrium bomb bombard bombast bombax bombe bombed bomber bombers bombes 
bomblet bombs bombyx bondman bondmen boojum boojums bookman bookmen boom boombox boomed 
boomer boomers boomier boomkin boomlet booms boomy boredom bosom bosomed bosoms bosomy 
bossdom bossism bottom bottoms bowman bowmen brahma brahmas bramble brambly bream breamed 
breams brecham bregma brim brimful brimmed brimmer brims bromal bromals bromate brome 
bromes bromic bromid bromide bromids bromin bromine bromins bromism bromize bromo bromos 
broom broomed brooms broomy brumal brumby brume brumes brumous brutism bruxism buckram 
budworm bulimia bulimic bum bumble bumbled bumbler bumbles bumboat bumelia bumf bumfs 
bumkin bumkins bumm bummalo bummed bummer bummers bummest bump bumped bumper bumpers 
bumph bumphs bumpier bumpily bumpkin bumps bumpy bums bunkum bunkums bushman bushmen 
busman busmen buxom buxomer buxomly byname bynames cabman cabmen cabomba caconym cadmic 
cadmium caecum caeoma caeomas caesium caiman caimans calamar calami calamus calcium calm 
calmed calmer calmest calmly calms calomel calumet calumny cam camail camails camas 
camases camass camber cambers cambia cambial cambism cambist cambium cambric came camel 
camelia camelid camels cameo cameoed cameos camera camerae cameral cameras cames camion 
camions camisa camisas camise camises camisia camlet camlets cammie cammies camo camorra 
camos camp camped camper campers camphol camphor campi campier campily campion campo 
campong campos campout camps campus campy cams caramba caramel carman carmen carmine 
carom caromed caroms carrom carroms catmint caveman cavemen cayman caymans cecum celom 
celoms cembali cembalo cement cementa cements centime centimo centrum centum centums ceramal 
ceramic cerium ceriums cermet cermets cerumen cesium cesiums chacma chacmas cham chamade 
chamber chamfer chamisa chamise chamiso chammy chamois chamoix champ champac champak champed 
champer champs champy chams chapman chapmen charism charm charmed charmer charms chasm 
chasmal chasmed chasmic chasms chasmy chefdom chemic chemics chemise chemism chemist chemo 
chemos chetrum chiasm chiasma chiasmi chiasms chillum chim chimar chimars chimb chimbly 
chimbs chime chimed chimer chimera chimere chimers chimes chimla chimlas chimley chimney 
chimp chimps chirm chirmed chirms chlamys chomp chomped chomper chomps chrism chrisma 
chrisms chrisom chroma chromas chrome chromed chromes chromic chromo chromos chromy chromyl 
chum chummed chummy chump chumped chumps chums chyme chymes chymic chymics chymist 
chymous cilium cimex cimices cinema cinemas civism civisms cladism claim claimed claimer 
claims clam clamant clamber clammed clammer clammy clamor clamors clamour clamp clamped 
clamper clamps clams clement cleome cleomes climate climax climb climbed climber climbs 
clime climes clomb clomp clomped clomps clonism clubman clubmen clumber clump clumped 
clumps clumpy clumsy coadmit coam cocomat cocoyam coelom coelome coeloms coempt coempts 
columel column columns com coma comade comae comake comaker comakes comal comas 
comate comates comatic comatik comb combat combats combe combed comber combers combes 
combine combo combos combs combust come comedic comedo comedos comedy comely comer 
comers comes comet cometh cometic comets comfier comfit comfits comfort comfrey comfy 
comic comical comics comings comitia comity comix comma command commas commata commend 
comment commie commies commit commits commix commixt commode common commons commove commune 
commute commy comose comous comp compact company compare compart compas compass comped 
compeer compel compels compend compere compete compile complex complin complot comply compo 
compone compony comport compos compose compost compote comps compt compted compts compute 
comrade comsymp comte comtes condemn condom condoms confirm conform conium coniums consume 
contemn coomb coombe coombes coombs copalm copalms coremia corium corm cormel cormels 
cormoid cormous corms corymb corymbs cosmic cosmid cosmids cosmism cosmist cosmos costume 
coulomb cowman cowmen coxcomb cram crambe crambes crambo crambos crammed crammer cramp 
cramped crampit crampon cramps crampy crams cranium cream creamed creamer creams creamy 
cremate creme cremes cremini crewman crewmen crime crimes crimine crimini criminy crimmer 
crimp crimped crimper crimple crimps crimpy crimson crinum crinums crissum crumb crumbed 
crumber crumble crumbly crumbs crumbum crumby crummie crummy crump crumped crumpet crumple 
crumply crumps cubism cubisms culm culmed culms cultism cum cumarin cumber cumbers 
cumbia cumbias cumin cumins cummer cummers cummin cummins cumquat cumshaw cumuli cumulus 
cundum cundums cuprum cuprums curcuma curium curiums custom customs cutworm cwm cwms 
cyma cymae cymar cymars cymas cymatia cymbal cymbals cyme cymene cymenes cymes 
cyml cymlin cymlins cymoid cymol cymols cymose cymous czardom czarism dadaism dadgum 
daemon daemons daimen daimio daimios daimon daimons daimyo daimyos dam damage damaged 
damager damages daman damans damar damars damask damasks dame dames damiana damm 
dammar dammars dammed dammer dammers dammit damn damned damner damners damnify damns 
damosel damozel damp damped dampen dampens damper dampers dampest dampish damply damps 
dams damsel damsels damson damsons datum datums daymare dayroom daysman daysmen daytime 
deadman deadmen decamp decamps decimal declaim decorum decuman deem deemed deems defame 
defamed defamer defames defoam defoams deform deforms degame degames degami degamis degerm 
degerms degum degums deiform deism deisms delime delimed delimes delimit demagog demand 
demands demark demarks demast demasts deme demean demeans dement dements demerge demerit 
demes demesne demeton demic demies demigod demirep demise demised demises demit demits 
demo demob demobs demode demoded demoed demon demonic demons demos demoses demote 
demoted demotes demotic demount demur demure demurer demurs demy denim denimed denims 
deperm deperms deplume derm derma dermal dermas dermic dermis dermoid derms deskman 
deskmen desman desmans desmid desmids desmoid deworm deworms dharma dharmas dharmic diadem 
diadems diagram diamide diamin diamine diamins diamond diastem diatom diatoms dicamba dictum 
dictums digamma digamy dilemma dim dime dimer dimeric dimers dimes dimeter dimity 
dimly dimm dimmed dimmer dimmers dimmest dimness dimorph dimout dimouts dimple dimpled 
dimples dimply dims dimwit dimwits dinkum dinkums diorama diploma diram dirams dirdum 
dirdums dirham dirhams disarm disarms dishelm dislimn dismal dismals dismast dismay dismays 
disme dismes dismiss disomic distome dodgem dodgems dodoism dogdom dogdoms dogedom dogma 
dogmas dogmata dolma dolman dolmans dolmas dolmen dolmens dom domain domaine domains 
domal dome domed domes domic domical domicil domine domines dominie domino dominos 
doms doom doomed doomful doomier doomily dooms doomy doorman doormat doormen dorm 
dormant dormer dormers dormice dormie dormin dormins dorms dormy dorsum doum douma 
doumas doums drachm drachma drachms dram drama dramady dramas dramedy drammed drams 
drayman draymen dream dreamed dreamer dreams dreamt dreamy dromon dromond dromons drum 
drumble drumlin drumly drummed drummer drums dualism dubnium dukedom duma dumas dumb 
dumbed dumber dumbest dumbly dumbo dumbos dumbs dumdum dumdums dumka dumky dummied 
dummies dummy dump dumped dumper dumpers dumpier dumpily dumpish dumps dumpy dunam 
dunams duomi duomo duomos duramen durmast durum durums dustman dustmen duumvir dynamic 
dynamo dynamos eardrum earldom earmark earmuff earworm echoism economy ecthyma eczema eczemas 
edema edemas edemata eelworm egoism egoisms egotism element elemi elemis elitism elm 
elmier elmiest elms elmy eluvium elytrum em email emailed emails emanant emanate 
embalm embalms embank embanks embar embargo embark embarks embars embassy embay embayed 
embays embed embeds ember embers emblaze emblem emblems embody emboli embolic embolus 
emboly embosk embosks embosom emboss embow embowed embowel embower embows embrace embroil 
embrown embrue embrued embrues embrute embryo embryon embryos emcee emceed emcees emdash 
eme emeer emeers emend emended emender emends emerald emerge emerged emerges emeries 
emerita emeriti emerod emerods emeroid emersed emery emes emeses emesis emetic emetics 
emetin emetine emetins emeu emeus emeute emeutes emic emigre emigres eminent emir 
emirate emirs emit emits emitted emitter emmer emmers emmet emmets emmy emmys 
emodin emodins emot emote emoted emoter emoters emotes emotion emotive empale empaled 
empaler empales empanel empathy emperor empery empire empires empiric emplace emplane employ 
employe employs emporia empower empress emprise emprize emptied emptier empties emptily emptins 
empty empyema ems emu emulate emulous emus emyd emyde emydes emyds enamel 
enamels enamine enamor enamors enamour encamp encamps encomia endemic endgame endmost enema 
enemas enemata enemies enemy enflame enframe engram engrams enigma enigmas enmesh enmity 
enorm entomb entombs envenom enwomb enwombs enzym enzyme enzymes enzymic enzyms eonism 
eonisms epiderm epigram epimer epimere epimers episome epitome eponym eponyms eponymy erbium 
erbiums eremite eremuri ermine ermined ermines erotism erratum esteem esteems estrum estrums 
etamin etamine etamins etatism ethmoid etyma etymon etymons eudemon exam examen examens 
examine example exams excimer exclaim exempla exempt exempts exhume exhumed exhumer exhumes 
exoderm exogamy exonym exonyms exosmic exotism extrema extreme exuvium eyebeam eyesome faddism 
fam fame famed fames family famine famines famish famous famuli famulus fandom 
fandoms fantasm fantom fantoms fanum fanums farm farmed farmer farmers farms fascism 
fathom fathoms fauvism favism favisms fem female females feme femes feminie femme 
femmes femora femoral fems femur femurs ferbam ferbams fermata fermate ferment fermi 
fermion fermis fermium ferrum ferrums fibroma fideism fiefdom figment filemot film filmdom 
filmed filmer filmers filmi filmic filmier filmily filmis films filmset filmy filum 
fimble fimbles fimbria finmark firearm fireman firemen firm firman firmans firmed firmer 
firmers firmest firmly firms fitment flagman flagmen flam flambe flambee flambes flame 
flamed flamen flamens flamer flamers flames flamier flammed flams flamy fleam fleams 
flehmen flemish flimsy flotsam flum flume flumed flumes flummox flump flumped flumps 
flyman flymen foam foamed foamer foamers foamier foamily foams foamy foeman foemen 
fogyism folium foliums folkmot foment foments fomite fomites footman footmen foram foramen 
forams forearm foreman foremen form formal formals formant format formate formats forme 
formed formee former formers formes formful formic formica formol formols forms formula 
formyl formyls forum forums fraenum fram frame framed framer framers frames freedom 
freeman freemen fremd frenum frenums frogman frogmen from fromage frump frumps frumpy 
frustum fulcrum fulham fulhams fullam fullams fulmar fulmars fulmine fulsome fum fumaric 
fumble fumbled fumbler fumbles fume fumed fumer fumers fumes fumet fumets fumette 
fumier fumiest fumuli fumulus fumy furmety furmity fusuma gagman gagmen gallium galumph 
gam gama gamas gamay gamays gamb gamba gambade gambado gambas gambe gambes 
gambia gambias gambier gambir gambirs gambit gambits gamble gambled gambler gambles gamboge 
gambol gambols gambrel gambs game gamed gamelan gamely gamer gamers games gamest 
gametal gamete gametes gametic gamey gamic gamier gamiest gamily gamin gamine gamines 
gamings gamins gamm gamma gammas gammed gammer gammers gammier gammon gammons gammy 
gamp gamps gams gamut gamuts gamy garment gasman gasmen gateman gatemen gaum 
gaumed gaums gazump gazumps geekdom gem geminal gemlike gemm gemma gemmae gemmate 
gemmed gemmier gemmily gemmule gemmy gemot gemote gemotes gemots gems gemsbok genom 
genome genomes genomic genoms germ german germane germans germen germens germier germina 
germs germy geum geums gimbal gimbals gimel gimels gimlet gimlets gimmal gimmals 
gimme gimmes gimmick gimmie gimmies gimp gimped gimpier gimps gimpy gingham gisarme 
gismo gismos gizmo gizmos glam glamor glamors glamour glams gleam gleamed gleamer 
gleams gleamy gleeman gleemen glim glime glimed glimes glimmer glimpse glims glioma 
gliomas gloam gloams glom glomera glommed gloms glomus gloom gloomed glooms gloomy 
glum glume glumes glumly glummer glumpy glums gnome gnomes gnomic gnomish gnomist 
gnomon gnomons goddam goddamn goddams golem golems gombeen gombo gombos gomer gomeral 
gomerel gomeril gomers gomuti gomutis gonium goodman goodmen goombah goombay gorm gormand 
gormed gorms gourami gourmet goyim graham grahams gram grama gramary gramas gramma 
grammar grammas gramme grammes gramp grampa grampas gramps grampus grams grandam grandma 
granum gremial gremlin gremmie gremmy grim grimace grime grimed grimes grimier grimily 
grimly grimmer grimy gripman gripmen grogram grommet groom groomed groomer grooms grum 
grumble grumbly grume grumes grummer grummet grumose grumous grump grumped grumphy grumps 
grumpy guimpe guimpes gum gumball gumbo gumboil gumboot gumbos gumdrop gumless gumlike 
gumline gumm gumma gummas gummata gummed gummer gummers gummier gummite gummose gummous 
gummy gums gumshoe gumtree gumweed gumwood gunman gunmen gunroom gym gymnast gyms 
gypsum gypsums hackman hackmen hadarim haem haemal haemic haemin haemins haemoid haems 
hafnium hahnium haimish hakeem hakeems hakim hakims halidom halm halma halmas halms 
ham hamada hamadas hamal hamals hamate hamates hamaul hamauls hambone hamburg hame 
hames hamlet hamlets hamm hammada hammal hammals hammam hammams hammed hammer hammers 
hammier hammily hammock hammy hamper hampers hams hamster hamular hamuli hamulus hamza 
hamzah hamzahs hamzas hangman hangmen hansom hansoms hanuman hareem hareems harem harems 
harm harmed harmer harmers harmful harmin harmine harmins harmony harms harumph hassium 
haulm haulms haulmy haymow haymows hazanim hazmat hazmats headman headmen heaume heaumes 
hegemon hegumen heimish heirdom helium heliums helm helmed helmet helmets helms hem 
hemagog hemal hematal hematic hematin heme hemes hemic hemin hemins hemiola hemline 
hemlock hemm hemmed hemmer hemmers hemoid hemp hempen hempie hempier hemps hempy 
hems herdman herdmen herm herma hermae hermai hermit hermits herms heroism hetman 
hetmans hiemal hilum him himatia hims himself hitman hitmen hm hmm hoboism 
hogmane hokum hokums holism holisms holm holmic holmium holms hom homage homaged 
homager homages hombre hombres homburg home homeboy homed homely homer homered homeric 
homers homes homey homeys homie homier homies homiest homily homines hominid hominy 
hommock hommos homo homolog homonym homos homosex homy hoodlum hormone hum human 
humane humaner humanly humans humate humates humble humbled humbler humbles humbly humbug 
humbugs humdrum humeral humeri humerus humic humid humidex humidly humidor humm hummed 
hummer hummers hummock hummus humor humoral humored humors humour humours hump humped 
humper humpers humph humphed humphs humpier humps humpy hums humus humuses humvee 
humvees hutment hymen hymenal hymenia hymens hymn hymnal hymnals hymnary hymned hymnist 
hymnody hymns hyponym iamb iambi iambic iambics iambs iambus ibidem iceman icemen 
idem idiom idioms idolism ihram ihrams ileum ilium illume illumed illumes imag 
image imaged imager imagers imagery images imagine imagism imagist imago imagoes imagos 
imam imamate imams imaret imarets imaum imaums imbalm imbalms imbark imbarks imbed 
imbeds imbibe imbibed imbiber imbibes imblaze imbody imbosom imbower imbrown imbrue imbrued 
imbrues imbrute imbu imbue imbued imbues imid imide imides imidic imido imids 
imine imines imino imitate immane immense immerge immerse immesh immies immix immixed 
immixes immoral immune immunes immure immured immures immy imp impact impacts impaint 
impair impairs impala impalas impale impaled impaler impales impanel impark imparks impart 
imparts impasse impaste impasto impavid impawn impawns impeach impearl imped impede impeded 
impeder impedes impel impels impend impends imperia imperil impetus imphee imphees impi 
impiety impinge impings impious impis impish implant implead impled implied implies implode 
implore imply impone imponed impones import imports impose imposed imposer imposes impost 
imposts impound impower impregn impresa imprese impress imprest imprint improv improve improvs 
imps impugn impugns impulse impure impurer impute imputed imputer imputes inarm inarmed 
inarms income incomer incomes indamin indium indiums infamy infirm infirms inflame inform 
informs inhuman inhume inhumed inhumer inhumes inmate inmates inmesh inmost inseam inseams 
interim intima intimae intimal intimas intime intomb intombs iodism iodisms ionium ioniums 
ionomer ipomoea iridium irksome ironman ironmen ischium ism isms isoform isogamy isogram 
isomer isomers isonomy isozyme isthmi isthmic isthmus item itemed itemise itemize items 
iterum jacamar jam jamb jambe jambeau jambed jambes jambs jamlike jamm jammed 
jammer jammers jammier jammies jammy jams jarldom jasmin jasmine jasmins jazzman jazzmen 
jejunum jemadar jemidar jemmied jemmies jemmy jetsam jetsams jetsom jetsoms jibboom jicama 
jicamas jiminy jimjams jimmie jimmied jimmies jimminy jimmy jimp jimper jimpest jimply 
jimpy jism jisms jobname jomon joram jorams jorum jorums jugulum jugum jugums 
jujuism jumbal jumbals jumble jumbled jumbler jumbles jumbo jumbos jumbuck jump jumped 
jumper jumpers jumpier jumpily jumpoff jumps jumpy junkman junkmen juryman jurymen kalam 
kalams kalimba kalium kaliums kalmia kalmias kamala kamalas kame kames kami kamik 
kamiks kampong kamseen kamsin kamsins karma karmas karmic kashmir kelim kelims kemp 
kemps kempt keramic kermes kermess kermis kerygma khamsin khoum khoums kilim kilims 
kimchee kimchi kimchis kimono kimonos kinema kinemas kingdom kinsman kinsmen kirkman kirkmen 
kirmess kismat kismats kismet kismets klezmer komatik kombu kombus korma kormas koumis 
koumiss koumys koumyss kremlin krimmer kumiss kummel kummels kumquat kumys kumyses labarum 
labium labrum labrums lactam lactams ladanum laicism lam lama lamas lamb lambada 
lambast lambda lambdas lambed lambent lamber lambers lambert lambie lambier lambies lambkin 
lambs lamby lame lamed lamedh lamedhs lameds lamella lamely lament laments lamer 
lames lamest lamia lamiae lamias lamina laminae laminal laminar laminas laminin lamm 
lammed lamp lampad lampads lampas lamped lampers lampion lampoon lamprey lamps lams 
lamster landman landmen larum larums lawman lawmen layman laymen leadman leadmen leftism 
legman legmen legroom legume legumes legumin lehayim leman lemans lemm lemma lemmas 
lemmata lemon lemons lemony lempira lemur lemures lemurs lensman lensmen leucoma leukoma 
lexeme lexemes lexemic liftman liftmen lim lima limacon liman limans limas limb 
limba limbas limbate limbeck limbed limber limbers limbi limbic limbier limbo limbos 
limbs limbus limby lime limeade limed limen limens limes limey limeys limier 
limiest limina liminal limit limited limiter limites limits limmer limmers limn limned 
limner limners limnic limns limo limos limp limpa limpas limped limper limpers 
limpest limpet limpets limpid limpkin limply limps limpsey limpsy limuli limulus limy 
lineman linemen lingam lingams linkman linkmen linum linums lipoma lipomas lissom lissome 
lithium litmus llama llamas loam loamed loamier loams loamy lobworm lockram locoism 
locum locums logjam logjams lomein lomeins loment lomenta loments lookism loom loomed 
looms lordoma lorimer louma loumas lugworm lum luma lumas lumbago lumbar lumbars 
lumber lumbers lumen lumenal lumens lumina luminal lummox lump lumped lumpen lumpens 
lumper lumpers lumpier lumpily lumpish lumps lumpy lums lustrum luteum lyceum lyceums 
lymph lymphs lyrism lyrisms ma maar maars mabe mabes mac macaber macabre 
macaco macacos macadam macaque macaw macaws macchia macchie mace maced macer macers 
maces mach mache maches machete machine macho machos machree machs machzor mack 
mackle mackled mackles macks macle macled macles macon macons macrame macro macron 
macrons macros macs macula maculae macular maculas macule maculed macules macumba mad 
madam madame madames madams madcap madcaps madd madded madden maddens madder madders 
maddest maddish made madeira madly madman madmen madness madonna madras madrasa madre 
madres madrona madrone madrono mads madtom madtoms maduro maduros madwort madzoon mae 
maenad maenads maes maestri maestro maffia maffias maffick mafia mafias mafic mafiosi 
mafioso maftir maftirs mag magalog mage magenta mages maggot maggots maggoty magi 
magian magians magic magical magics magilp magilps maglev maglevs magma magmas magmata 
magnate magnet magneto magnets magnify magnum magnums magot magots magpie magpies mags 
maguey magueys magus mahatma mahjong mahoe mahoes mahonia mahout mahouts mahuang mahzor 
mahzors maid maiden maidens maidish maids maigre maihem maihems mail mailbag mailbox 
maile mailed mailer mailers mailes maill maillot maills mailman mailmen mails maim 
maimed maimer maimers maims main mainly mains maintop mair mairs maist maists 
maize maizes majagua majesty major majored majorly majors mak makable makar makars 
make maker makers makes makeup makeups makings mako makos makuta malacca malady 
malaise malanga malar malaria malarky malars malate malates male maleate malefic males 
malfed malgre malic malice malices malign maligns maline malines malison malkin malkins 
mall mallard malled mallee mallees mallei mallet mallets malleus mallow mallows malls 
malm malmier malms malmsey malmy malodor maloti malt maltase malted malteds maltha 
malthas maltier maltol maltols maltose malts malty mama mamas mamba mambas mambo 
mamboed mamboes mambos mamey mameyes mameys mamie mamies mamluk mamluks mamma mammae 
mammal mammals mammary mammas mammate mammati mammee mammees mammer mammers mammet mammets 
mammey mammeys mammie mammies mammock mammon mammons mammoth mammy mamzer mamzers man 
mana manacle manage managed manager manages manakin manana mananas manas manat manatee 
manats manche manches manchet mandala mandate mandola mandrel mandril mane maned manege 
maneges manes manful manga mangaby mangas mange mangel mangels manger mangers manges 
mangey mangier mangily mangle mangled mangler mangles mango mangoes mangold mangos mangy 
manhole manhood manhunt mania maniac maniacs manias manic manics manihot manikin manila 
manilas manilla manille manioc manioca maniocs maniple manito manitos manitou manitu manitus 
mankind manless manlier manlike manlily manly manmade mann manna mannan mannans mannas 
manned manner manners mannish mannite mannose mano manor manors manos manpack manque 
manrope mans mansard manse manses mansion manta mantas manteau mantel mantels mantes 
mantic mantid mantids mantis mantle mantled mantles mantlet mantra mantram mantrap mantras 
mantric mantua mantuas manual manuals manuary manumit manure manured manurer manures manus 
manward manwise many map maple maples maplike mapp mapped mapper mappers maps 
maqui maquila maquis mar mara marabou maraca maracas maranta maras marasca maraud 
marauds marble marbled marbler marbles marbly marc marcato marcel marcels march marched 
marchen marcher marches marcs mare maremma maremme marengo mares margay margays marge 
margent marges margin margins maria marimba marina marinas marine mariner marines marish 
marital mark marka markas marked marker markers market markets markhor markka markkaa 
markkas marks markup markups marl marled marlier marlin marline marlins marlite marls 
marly marmite marmot marmots maroon maroons marplot marque marquee marques marquis marr 
marram marrams marrano marred marrer marrers married marrier marries marron marrons marrow 
marrows marrowy marry mars marsala marse marses marsh marshal marshes marshy mart 
marted marten martens martial martian martin martini martins martlet marts martyr martyrs 
martyry marvel marvels marvy mas masa masala masalas masas mascara mascon mascons 
mascot mascots maser masers mash mashed masher mashers mashes mashie mashies mashy 
masjid masjids mask masked maskeg maskegs masker maskers masks mason masoned masonic 
masonry masons masque masquer masques mass massa massage massas masse massed masses 
masseur massier massif massifs massive massy mast mastaba masted master masters mastery 
mastic mastics mastiff mastix mastoid masts mat matador match matched matcher matches 
matchup mate mated matelot mater maters mates matey mateys math maths matier 
matiest matilda matin matinal matinee matings matins matless matrass matres matrix matron 
matrons mats matsah matsahs matt matte matted matter matters mattery mattes mattin 
mattins mattock mattoid matts mature matured maturer matures matza matzah matzahs matzas 
matzo matzoh matzohs matzoon matzos matzot matzoth maud maudlin mauds mauger maugre 
maul mauled mauler maulers mauls maumet maumets maun maund maunder maunds maundy 
maut mauts mauve mauves maven mavens mavie mavies mavin mavins mavis mavises 
maw mawed mawkish mawn maws max maxed maxes maxi maxilla maxim maxima 
maximal maximin maxims maximum maxis maxixe maxixes maxwell may maya mayan mayas 
maybe maybes maybird maybush mayday maydays mayed mayest mayfly mayhap mayhem mayhems 
mayings mayo mayor mayoral mayors mayos maypole maypop maypops mays mayst mayvin 
mayvins mayweed maz mazard mazards maze mazed mazedly mazer mazers mazes mazier 
maziest mazily mazuma mazumas mazurka mazy mazzard mbira mbiras me mead meadow 
meadows meadowy meads meager meagre meal mealie mealier mealies meals mealy mean 
meander meaner meaners meanest meanie meanies meanly means meant meany measle measled 
measles measly measure meat meatal meated meatier meatily meatman meatmen meats meatus 
meaty mecca meccas med medaka medakas medal medaled medals meddle meddled meddler 
meddles medevac medfly media mediacy mediad mediae medial medials median medians mediant 
medias mediate medic medical medick medicks medico medicos medics medigap medii medina 
medinas medium mediums medius medivac medlar medlars medley medleys meds medulla medusa 
medusae medusal medusan medusas meed meeds meek meeker meekest meekly meerkat meet 
meeter meeters meetly meets meg mega megabar megabit megahit megapod megara megaron 
megass megasse megaton megilla megilp megilph megilps megohm megohms megrim megrims megs 
mehndi mehndis meikle meinie meinies meiny meioses meiosis meiotic meister mel melamed 
melange melanic melanin meld melded melder melders melds melee melees melena melenas 
melic melilot melisma mell melled mellow mellows mells melodia melodic melody meloid 
meloids melon melons mels melt meltage melted melter melters melton meltons melts 
melty mem member members meme memento memes memo memoir memoirs memory memos 
mems men menace menaced menacer menaces menad menads menage menages menazon mend 
mended mender menders mendigo mends menfolk menhir menhirs menial menials meninx menisci 
meno menorah mens mensa mensae mensal mensas mensch menschy mense mensed menses 
mensh menshen menshes menta mental mentee mentees menthol mention mentor mentors mentum 
menu menudo menudos menus meou meoued meous meow meowed meows merc mercer 
mercers mercery merces merch merches mercies mercs mercury mercy merde merdes mere 
merely merer meres merest merg merge merged mergee mergees merger mergers merges 
merino merinos merises merisis merit merited merits merk merks merl merle merles 
merlin merlins merlon merlons merlot merlots merls mermaid merman mermen meropia meropic 
merrier merrily merry mesa mesally mesarch mesas mescal mescals mesclun meseems mesh 
meshed meshes meshier meshuga meshy mesial mesian mesic mesne mesnes meson mesonic 
mesons mesquit mess message messan messans messed messes messiah messier messily messman 
messmen messy mestee mestees mesteso mestino mestiza mestizo met meta metage metages 
metal metaled metals metamer metatag metate metates metazoa mete meted meteor meteors 
metepa metepas meter metered meters metes meth methane method methods methoxy meths 
methyl methyls metical metier metiers metis metisse metol metols metonym metopae metope 
metopes metopic metopon metr metre metred metres metric metrics metrify metrist metro 
metros mettle mettled mettles metump metumps mew mewed mewl mewled mewler mewlers 
mewls mews mezcal mezcals meze mezes mezquit mezuza mezuzah mezuzas mezuzot mezzo 
mezzos mho mhos mi miaou miaoued miaous miaow miaowed miaows miasm miasma 
miasmal miasmas miasmic miasms miaul miauled miauls mib mibs mic mica micas 
mice micell micella micelle micells mich miche miched miches mick mickey mickeys 
mickle mickler mickles micks micra micrify micro microbe microhm micron microns micros 
mics mid midair midairs midcap midcult midday middays midden middens middies middle 
middled middler middles middy midge midges midget midgets midgut midguts midi midiron 
midis midland midleg midlegs midlife midline midlist midmost midnoon midrash midrib midribs 
midriff mids midship midsize midsole midst midsts midterm midtown midway midways midweek 
midwife midyear mien miens miff miffed miffier miffs miffy mig migg miggle 
miggles miggs might mights mighty mignon mignons migrant migrate migs mihrab mihrabs 
mik mikado mikados mike miked mikes mikra mikron mikrons mikvah mikvahs mikveh 
mikvehs mikvos mikvot mikvoth mil miladi miladis milady milage milages milch milchig 
mild milded milden mildens milder mildest mildew mildews mildewy mildly milds mile 
mileage miler milers miles milfoil milia miliary milieu milieus milieux militia milium 
milk milked milker milkers milkier milkily milkman milkmen milks milksop milky mill 
millage milldam mille milled miller millers milles millet millets millier millime milline 
million millrun mills milneb milnebs milo milord milords milos milpa milpas milreis 
mils milt milted milter milters miltier milts milty mim mimbar mimbars mime 
mimed mimeo mimeoed mimeos mimer mimers mimes mimeses mimesis mimetic mimic mimical 
mimicry mimics mimosa mimosas min mina minable minae minaret minas minc mince 
minced mincer mincers minces mincier mincy mind minded minder minders mindful minds 
mindset mine mined miner mineral miners mines mingier mingle mingled mingler mingles 
mingy mini minibar minibus minicab minicam minicar minify minikin minilab minim minima 
minimal minimax minims minimum minings minion minions minis minish miniski minium miniums 
minivan miniver mink minke minkes minks minnies minnow minnows minny minor minorca 
minored minors minster mint mintage minted minter minters mintier mints minty minuend 
minuet minuets minus minuses minute minuted minuter minutes minutia minx minxes minxish 
minyan minyans miocene mioses miosis miotic miotics mips mir miracle mirador mirage 
mirages mire mired mires mirex mirexes miri mirier miriest mirin mirins mirk 
mirker mirkest mirkier mirkily mirks mirky mirror mirrors mirs mirth mirths miry 
mirza mirzas mis misact misacts misadd misadds misaim misaims misally misate misaver 
misbias misbill misbind miscall miscast miscite miscode miscoin miscook miscopy miscue miscued 
miscues miscut miscuts misdate misdeal misdeed misdeem misdial misdid misdo misdoer misdoes 
misdone misdraw misdrew mise misease miseat miseats misedit miser miserly misers misery 
mises misfed misfeed misfile misfire misfit misfits misform misgave misgive misgrew misgrow 
mishap mishaps mishear mishit mishits misjoin miskal miskals miskeep miskept miskick misknew 
misknow mislaid mislain mislay mislays mislead misled mislie mislies mislike mislit mislive 
mismade mismake mismark mismate mismeet mismet mismove misname miso misos mispage mispart 
mispen mispens misplan misplay mispled misrate misread misrely misrule miss missaid missal 
missals missay missays misseat missed missel missels missend missent misses misset missets 
misshod missies missile mission missis missive missort missout misstep misstop missuit missus 
missy mist mistake mistbow misted mistend mister misterm misters misteuk mistier mistily 
mistime mistook mistral mists mistune misty mistype misuse misused misuser misuses misword 
miswrit misyoke mite miter mitered miterer miters mites mither mithers mitier mitiest 
mitis mitises mitogen mitoses mitosis mitotic mitr mitral mitre mitred mitres mitsvah 
mitt mitten mittens mitts mity mitzvah mix mixable mixed mixedly mixer mixers 
mixes mixible mixt mixture mixup mixups mizen mizens mizuna mizunas mizzen mizzens 
mizzle mizzled mizzles mizzly mm mo moa moan moaned moaner moaners moanful 
moans moas moat moated moats mob mobb mobbed mobber mobbers mobbish mobbism 
mobcap mobcaps mobile mobiles mobled mobs mobster moc mocha mochas mochila mock 
mocked mocker mockers mockery mocks mockup mockups mocs mod modal modally modals 
mode model modeled modeler models modem modemed modems modern moderne moderns modes 
modest modesty modi modica modicum modify modioli modish modiste mods modular module 
modules moduli modulo modulus modus mofette mog mogg mogged moggie moggies moggy 
moghul moghuls mogs mogul moguled moguls mohair mohairs mohalim mohawk mohawks mohel 
mohelim mohels mohur mohurs moidore moiety moil moiled moiler moilers moils moira 
moirai moire moires moist moisten moister moistly mojarra mojo mojoes mojos moke 
mokes mol mola molal molar molars molas mold molded molder molders moldier 
molds moldy mole moles molest molests molies moline moll mollah mollahs mollie 
mollies mollify molls mollusc mollusk molly moloch molochs mols molt molted molten 
molter molters molto molts moly mom mome moment momenta momento moments momes 
momi momism momisms momma mommas mommies mommy moms momser momsers momus momuses 
momzer momzers mon monacid monad monadal monades monadic monads monarch monarda monas 
monaxon monde mondes mondo mondos moneran money moneyed moneyer moneys monger mongers 
mongo mongoe mongoes mongol mongols mongos mongrel mongst monie monied monies moniker 
monish monism monisms monist monists monitor monk monkery monkey monkeys monkish monks 
mono monocle monocot monodic monody monoecy monofil monolog monomer monopod monos mons 
monsoon monster montage montane monte montero montes month monthly months monuron mony 
moo mooch mooched moocher mooches mood moodier moodily moods moody mooed mool 
moola moolah moolahs moolas mooley mooleys mools moon moonbow mooned mooner mooners 
mooneye moonier moonily moonish moonlet moonlit moons moonset moony moor moorage moored 
moorhen moorier moorish moors moory moos moose moot mooted mooter mooters moots 
mop mope moped mopeds moper mopers mopery mopes mopey mopier mopiest mopish 
mopoke mopokes mopp mopped mopper moppers moppet moppets mops mopy mor mora 
morae moraine moral morale morales morally morals moras morass morassy moray morays 
morbid morceau mordant mordent more moreen moreens morel morelle morello morels mores 
morgan morgans morgen morgens morgue morgues morion morions morn morns morocco moron 
moronic morons morose morph morphed morphia morphic morphin morpho morphos morphs morrion 
morris morro morros morrow morrows mors morse morsel morsels mort mortal mortals 
mortar mortars mortary mortice mortify mortise morts morula morulae morular morulas mos 
mosaic mosaics mosey moseyed moseys mosh moshav moshed mosher moshers moshes mosk 
mosks mosque mosques moss mossed mosser mossers mosses mossier mosso mossy most 
moste mostest mostly mosts mot mote motel motels motes motet motets motey 
moth mother mothers mothery mothier moths mothy motif motific motifs motile motiles 
motion motions motive motived motives motivic motley motleys motlier motmot motmots motor 
motored motoric motors mots mott motte mottes mottle mottled mottler mottles motto 
mottoes mottos motts mouch mouched mouches moue moues mouflon mouille moujik moujiks 
moulage mould moulded moulder moulds mouldy moulin moulins moult moulted moulter moults 
mound mounded mounds mount mounted mounter mounts mourn mourned mourner mourns mous 
mousaka mouse moused mouser mousers mouses mousey mousier mousily mousse moussed mousses 
mousy mouth mouthed mouther mouths mouthy mouton moutons mov movable movably move 
moved mover movers moves movie movies moviola mow mowed mower mowers mowings 
mown mows moxa moxas moxie moxies mozetta mozette mozo mozos mu much 
muches muchly mucho mucid mucin mucins muck mucked mucker muckers muckier muckily 
muckle muckles mucks mucky mucluc muclucs mucoid mucoids mucor mucors mucosa mucosae 
mucosal mucosas mucose mucous mucro mucus mucuses mud mudbug mudbugs mudcap mudcaps 
mudcat mudcats mudd mudded mudder mudders muddied muddier muddies muddily muddle muddled 
muddler muddles muddly muddy mudfish mudflap mudflat mudflow mudhen mudhens mudhole mudlark 
mudpack mudra mudras mudrock mudroom muds mudsill mueddin muesli mueslis muezzin muff 
muffed muffin muffins muffle muffled muffler muffles muffs mufti muftis mug mugful 
mugfuls mugg muggar muggars mugged muggee muggees mugger muggers muggier muggily muggins 
muggs muggur muggurs muggy mughal mughals mugs mugwort mugwump muhlies muhly mujik 
mujiks mukluk mukluks muktuk muktuks mul mulatto mulch mulched mulches mulct mulcted 
mulcts mule muled mules muleta muletas muley muleys mulish mull mulla mullah 
mullahs mullas mulled mullein mullen mullens muller mullers mullet mullets mulley mulleys 
mullion mullite mullock mulls multure mum mumble mumbled mumbler mumbles mumbly mumm 
mummed mummer mummers mummery mummied mummies mummify mumms mummy mump mumped mumper 
mumpers mumps mums mumu mumus mun munch munched muncher munches mundane mungo 
mungoes mungos muni munis munnion muns munster munt muntin muntins muntjac muntjak 
muon muonic muonium muons mur mura mural muraled murals muras murder murders 
mure mured murein mureins mures murex murexes muriate murices murid murids murine 
murines murk murker murkest murkier murkily murkly murks murky murmur murmurs murphy 
murr murra murrain murras murre murres murrey murreys murrha murrhas murries murrine 
murrs murry murther mus musca muscae muscat muscats muscid muscids muscle muscled 
muscles muscly muse mused museful muser musers muses musette museum museums mush 
mushed musher mushers mushes mushier mushily mushy music musical musick musicks musics 
musings musjid musjids musk muskeg muskegs musket muskets muskie muskier muskies muskily 
muskit muskits muskox muskrat musks musky muslin muslins muspike muss mussed mussel 
mussels musses mussier mussily mussy must mustang mustard musted mustee mustees muster 
musters musth musths mustier mustily musts musty mut mutable mutably mutagen mutant 
mutants mutase mutases mutate mutated mutates mutch mutches mute muted mutedly mutely 
muter mutes mutest mutine mutined mutines mutiny mutism mutisms muton mutons muts 
mutt mutter mutters mutton muttons muttony mutts mutual mutuals mutuel mutuels mutular 
mutule mutules muumuu muumuus muzhik muzhiks muzjik muzjiks muzzier muzzily muzzle muzzled 
muzzler muzzles muzzy my myalgia myalgic myases myasis myc mycele myceles mycelia 
mycoses mycosis mycotic mycs myelin myeline myelins myeloid myeloma myiases myiasis mylar 
mylars myna mynah mynahs mynas mynheer myoid myology myoma myomas myomata myope 
myopes myopia myopias myopic myopies myopy myoses myosin myosins myosis myosote myotic 
myotics myotome myriad myriads myrica myricas myrrh myrrhic myrrhs myrtle myrtles myself 
mysid mysids mysost mysosts mystery mystic mystics mystify myth mythic mythier mythoi 
mythos myths mythy myxoid myxoma myxomas nam namable name named namely namer 
namers names nametag nanism nanisms napalm napalms narcism narcoma natrium neem neems 
nelumbo nema nemas nematic nemeses nemesis neum neume neumes neumic neums neuroma 
newmown newsman newsmen nim nimbi nimble nimbler nimbly nimbus nimiety nimious nimm 
nimmed nimrod nimrods nims niobium nizam nizams noisome nom noma nomad nomadic 
nomads nomarch nomas nombles nombril nome nomen nomes nomina nominal nominee nomism 
nomisms nomoi nomos noms noncom noncoms nonfarm nongame nonheme nonhome nonman nonmeat 
nonmen norm normal normals normed norms nostrum notum noumena nudism nudisms numb 
numbat numbats numbed number numbers numbest numbles numbly numbs numen numeral numeric 
numina nummary nutmeat nutmeg nutmegs nymph nympha nymphae nymphal nymphet nympho nymphos 
nymphs oakmoss oakum oakums oarsman oarsmen oatmeal obelism obiism obiisms oddment odeum 
odeums odium odiums oedema oedemas oenomel oestrum offramp ogam ogams ogham oghamic 
oghams ogreism ogrism ogrisms ohm ohmage ohmages ohmic ohms oidium oilcamp oilman 
oilmen oinomel oleum oleums om omasa omasum omber ombers ombre ombres omega 
omegas omelet omelets omen omened omens omenta omental omentum omer omers omicron 
omikron ominous omit omits omitted omitter omnibus omnific omphali oms onanism onetime 
onium oogamy oomiac oomiack oomiacs oomiak oomiaks oompah oompahs oomph oomphs oosperm 
opium opiums opossum optima optimal optime optimes optimum oralism organum orgasm orgasms 
origami ormer ormers ormolu ormolus orphism osculum osmatic osmic osmics osmious osmium 
osmiums osmol osmolal osmolar osmole osmoles osmols osmose osmosed osmoses osmosis osmotic 
osmous osmund osmunda osmunds osteoma ostium ostmark ostomy ottoman outbeam outcome outjump 
outman outmans outmode outmost outmove outswam outswim outswum overarm overman overmen overmix 
oviform ovum oxim oxime oximes oxims oxymora oxysome pablum pablums pabulum packman 
packmen pajama pajamas pallium palm palmar palmary palmate palmed palmer palmers palmful 
palmier palmist palms palmtop palmy palmyra pam pampa pampas pampean pamper pampero 
pampers pams panama panamas pangram panicum pantoum papadam papadom papadum papism papisms 
paramo paramos paronym passim pastime patamar payment paynim paynims pelmet pelmets pembina 
pemican pemphix penman penmen penname peonism peplum peplums perform perfume perfumy perm 
permed permian permit permits perms permute phantom phasmid phellem phenom phenoms phlegm 
phlegms phlegmy phloem phloems phoneme phylum pianism pietism pigment pigmies pigmy pikeman 
pikemen pileum pilgrim pima pimas pimento pimp pimped pimple pimpled pimples pimply 
pimps pinetum pinworm pismire pitman pitmans pitmen plasm plasma plasmas plasmic plasmid 
plasmin plasmon plasms plenism plenum plenums plimsol plowman plowmen plum plumage plumate 
plumb plumbed plumber plumbic plumbs plumbum plume plumed plumes plumier plummer plummet 
plummy plumose plump plumped plumpen plumper plumply plumps plums plumule plumy pneuma 
pneumas podium podiums poem poems pogrom pogroms polemic polymer polyoma pom pomace 
pomaces pomade pomaded pomades pomatum pome pomelo pomelos pomes pomfret pommee pommel 
pommels pommie pommies pommy pomo pomos pomp pompano pompom pompoms pompon pompons 
pompous pomps poms popedom porism porisms possum possums postman postmen potamic potman 
potmen praam praams pram prams preamp preamps prearm prearms preboom preemie preempt 
preform pregame prelim prelims premade preman premeal premed premeds premeet premen premie 
premier premies premise premiss premium premix premixt premold premolt premune prename presume 
preterm pretrim prewarm prim prima primacy primage primal primary primas primate prime 
primed primely primer primero primers primes primi primine primly primmed primmer primo 
primos primp primped primps prims primsie primula primus prism prisms problem proem 
proems program prom promine promise promo promoed promos promote prompt prompts proms 
propman propmen prosoma protium proximo psalm psalmed psalmic psalms psammon ptomain pugmark 
pullman puma pumas pumelo pumelos pumice pumiced pumicer pumices pummel pummelo pummels 
pump pumped pumper pumpers pumpkin pumps purism purisms putamen pyaemia pyaemic pyemia 
pyemias pyemic pygmean pygmies pygmoid pygmy pyjama pyjamas pyramid qualm qualms qualmy 
quamash quantum quomodo quondam quorum quorums raceme racemed racemes racemic racism racisms 
radium radiums radome radomes ragman ragmen ragtime raiment ram ramada ramadas ramal 
ramate rambla ramblas ramble rambled rambler rambles ramee ramees ramekin ramen ramenta 
ramet ramets rami ramie ramies ramify ramilie ramjet ramjets ramm rammed rammer 
rammers rammier rammish rammy ramona ramonas ramose ramous ramp rampage rampant rampart 
ramped rampike rampion rampole ramps ramrod ramrods rams ramson ramsons ramtil ramtils 
ramus random randoms ransom ransoms readmit realism realm realms ream reamed reamer 
reamers reams rearm rearmed rearms rebloom reclaim reclame recomb recombs rectum rectums 
redeem redeems redream reedman reedmen reemit reemits refilm refilms reform reforms reframe 
regime regimen regimes regma regmata regnum regroom rehem rehems reimage relume relumed 
relumes rem remade remail remails remain remains remake remaker remakes reman remand 
remands remans remap remaps remark remarks remarry rematch remate remated remates remedy 
remeet remeets remelt remelts remend remends remerge remet remex remiges remind reminds 
remint remints remise remised remises remiss remit remits remix remixed remixes remixt 
remnant remodel remold remolds remora remoras remorid remorse remote remoter remotes remount 
removal remove removed remover removes rems remuda remudas rename renamed renames replumb 
repump repumps requiem resmelt restamp resume resumed resumer resumes reteam reteams retem 
retems retime retimed retimes retrim retrims revamp revamps rewarm rewarms rhabdom rhamnus 
rheme rhemes rhenium rheum rheumic rheums rheumy rhizoma rhizome rhodium rhomb rhombi 
rhombic rhombs rhombus rhumb rhumba rhumbas rhumbs rhym rhyme rhymed rhymer rhymers 
rhymes rhythm rhythms rim rime rimed rimer rimers rimes rimfire rimier rimiest 
rimland rimless rimm rimmed rimmer rimmers rimose rimous rimple rimpled rimples rimrock 
rims rimshot rimy roam roamed roamer roamers roams rodman rodmen rodsman rodsmen 
rollmop rom romaine romaji romajis roman romance romano romanos romans romaunt romeo 
romeos romp romped romper rompers rompish romps roms room roomed roomer roomers 
roomful roomie roomier roomies roomily rooms roomy rostrum rum rumaki rumakis rumba 
rumbaed rumbas rumble rumbled rumbler rumbles rumbly rumen rumens rumina ruminal rummage 
rummer rummers rummest rummier rummies rummy rumor rumored rumors rumour rumours rump 
rumple rumpled rumples rumply rumps rumpus rums sachem sachems sacrum sacrums sadism 
sadisms sagaman sagamen sagum saimin saimins salaam salaams salami salamis salmi salmis 
salmon salmons samadhi samara samaras samba sambaed sambal sambals sambar sambars sambas 
sambhar sambhur sambo sambos sambuca sambuke sambur samburs same samech samechs samek 
samekh samekhs sameks samiel samiels samisen samite samites samlet samlets samosa samosas 
samovar samoyed samp sampan sampans sample sampled sampler samples samps samsara samshu 
samshus samurai sanctum sandman sandmen santimi santims santimu sarcasm sarcoma sarment sashimi 
satem satsuma sawmill scam scammed scammer scamp scamped scamper scampi scamps scams 
schema schemas scheme schemed schemer schemes schism schisms schlump schmalz schmear schmeer 
schmo schmoe schmoes schmoos schmos schmuck scotoma scram scrams scream screams scrim 
scrimp scrimps scrimpy scrims scrotum scrum scrums scum scumbag scumble scummed scummer 
scummy scums scutum seam seaman seamark seamed seamen seamer seamers seamier seams 
seamy sebum sebums sedarim sedum sedums seedman seedmen seem seemed seemer seemers 
seemly seems segment seism seismal seismic seisms seldom selfdom sematic seme sememe 
sememes sememic semen semens semes semi semidry semifit semilog semimat semina seminal 
seminar semipro semiraw semis semises semple sempre sensum sentimo septime septum septums 
serfdom seriema sermon sermons serum serumal serums sesame sesames sexism sexisms sfumato 
shahdom shalom shaloms sham shaman shamans shamas shamble shame shamed shames shammas 
shammed shammer shammes shammos shammy shamois shamos shamoy shamoys shampoo shams shamus 
shawm shawms shazam shim shimmed shimmer shimmy shims shipman shipmen shittim shlump 
shlumps shlumpy shmaltz shmear shmears shmo shmoes shmooze shmuck shmucks sholom sholoms 
shopman shopmen showman showmen shrimp shrimps shrimpy siamang siamese sidearm sideman sidemen 
siemens siglum sigma sigmas sigmate sigmoid sim sima simar simars simas simian 
simians similar simile similes simioid simious simitar simlin simlins simmer simmers simnel 
simnels simony simoom simooms simoon simoons simp simper simpers simple simpler simples 
simplex simply simps sims simular sistrum sitcom sitcoms sixmo sixmos sjambok skellum 
skelm skelms skim skimmed skimmer skimo skimos skimp skimped skimps skimpy skims 
skookum skyman skymen slalom slaloms slam slammed slammer slams slim slime slimed 
slimes slimier slimily slimly slimmed slimmer slimpsy slims slimsy slimy slum slumber 
slumgum slumism slummed slummer slummy slump slumped slumps slums smack smacked smacker 
smacks small smaller smalls smalt smalti smalto smaltos smalts smaragd smarm smarms 
smarmy smart smarted smarten smarter smartie smartly smarts smarty smash smashed smasher 
smashes smashup smatter smaze smazes smear smeared smearer smears smeary smectic smeddum 
smeek smeeked smeeks smegma smegmas smell smelled smeller smells smelly smelt smelted 
smelter smelts smerk smerked smerks smew smews smidge smidgen smidges smidgin smil 
smilax smile smiled smiler smilers smiles smiley smileys smirch smirk smirked smirker 
smirks smirky smit smite smiter smiters smites smith smiths smithy smitten smock 
smocked smocks smog smoggy smogs smok smoke smoked smoker smokers smokes smokey 
smokier smokily smoky smolder smolt smolts smooch smoochy smoosh smooth smooths smoothy 
smote smother smudge smudged smudges smudgy smug smugger smuggle smugly smush smushed 
smushes smut smutch smutchy smuts smutted smutty snowman snowmen sockman sockmen socman 
socmen sodium sodiums sodom sodoms sodomy sokeman sokemen solanum solemn solum solums 
som soma soman somans somas somata somatic somber sombre some someday somehow 
someone someway somital somite somites somitic somoni soms sophism sorghum soymilk spam 
spambot spammed spammer spams spasm spasmed spasms sperm spermic sperms spirem spireme 
spirems spum spume spumed spumes spumier spumone spumoni spumous spumy sputum squama 
squamae squirm squirms squirmy stadium stamen stamens stamina stammel stammer stamp stamped 
stamper stamps stannum stardom stasima statism steam steamed steamer steams steamy stem 
stemma stemmas stemmed stemmer stemmy stems stemson sternum stewbum stibium stickum stigma 
stigmal stigmas stime stimes stimied stimies stimuli stimy stoma stomach stomal stomas 
stomata stomate stomp stomped stomper stomps storm stormed storms stormy stratum stream 
streams streamy stroma stromal strum struma strumae strumas strums stum stumble stummed 
stump stumped stumper stumps stumpy stums stymie stymied stymies stymy subatom subgum 
subgums subitem sublime submenu submiss submit submits subsume succumb sum sumac sumach 
sumachs sumacs sumless summ summa summae summand summary summas summate summed summer 
summers summery summit summits summon summons sumo sumoist sumos sump sumps sumpter 
sums sunbeam sunlamp sunroom supreme supremo surfman surfmen surimi surimis surmise surname 
swagman swagmen swam swami swamies swamis swamp swamped swamper swamps swampy swamy 
swarm swarmed swarmer swarms swim swimmer swimmy swims swum symbion symbiot symbol 
symbols symptom syncom syncoms syngamy synonym syntagm system systems tachism tagmeme talcum 
talcums tam tamable tamal tamale tamales tamals tamandu tamarao tamarau tamari tamarin 
tamaris tamasha tambac tambacs tambak tambaks tambala tambour tambur tambura tamburs tame 
tamed tamein tameins tamely tamer tamers tames tamest tamis tamises tammie tammies 
tammy tamp tampala tampan tampans tamped tamper tampers tampion tampon tampons tamps 
tams tandem tandems tangram tantrum tapetum taproom tarama taramas tarmac tarmacs tatami 
tatamis taxeme taxemes taxemic taximan taximen taxman taxmen team teamed teams tearoom 
teatime tectum tectums tedium tediums teem teemed teemer teemers teems tegmen tegmina 
tegumen telamon telecom teleman telemen telium telome telomes telomic temblor temp temped 
tempeh tempehs temper tempera tempers tempest tempi templar temple templed temples templet 
tempo tempos temps tempt tempted tempter tempts tempura teraohm terbium tergum term 
termed termer termers termini termite termly termor termors terms tetotum thairm thairms 
thalami tharm tharms theism theisms them theme themed themes theorem therm thermae 
thermal therme thermel thermes thermic thermit thermos therms thiamin thimble thiram thirams 
thorium thrombi thrum thrummy thrums thulium thumb thumbed thumbs thump thumped thumper 
thumps thyme thymes thymey thymi thymic thymier thymine thymol thymols thymus thymy 
tim timarau timbal timbale timbals timber timbers timbery timbral timbre timbrel timbres 
time timed timely timeous timeout timer timers times timid timider timidly timings 
timolol timothy timpana timpani timpano tinamou tinman tinmen titman titmen titmice tmeses 
tmesis tokamak tokomak tollman tollmen tom toman tomans tomato tomb tombac tomback 
tombacs tombak tombaks tombal tombed tombola tombolo tomboy tomboys tombs tomcat tomcats 
tomcod tomcods tome tomenta tomes tomfool tomm tommed tommies tommy tompion toms 
tomtit tomtits tonearm toneme tonemes tonemic tongman tongmen toom topmast topmost toponym 
torment totem totemic totems tourism towmond towmont toxemia toxemic tram tramcar tramel 
tramell tramels trammed trammel tramp tramped tramper trample tramps trampy trams tramway 
trangam transom trauma traumas tremble trembly tremolo tremor tremors triduum triform trigram 
trim trimer trimers trimly trimmed trimmer trims trireme triseme trismic trismus trisome 
trisomy tritium tritoma triumph trivium trommel tromp trompe tromped trompes tromps tropism 
truism truisms trumeau trump trumped trumpet trumps tryma trymata tsardom tsarism tsimmes 
tsunami tumble tumbled tumbler tumbles tumbrel tumbril tumefy tumesce tumid tumidly tummies 
tummler tummy tumor tumoral tumors tumour tumours tump tumped tumps tumular tumuli 
tumult tumults tumulus turfman turfmen turmoil twasome twosome tymbal tymbals tympan tympana 
tympani tympano tympans tympany tzardom tzarism tzimmes ugsome ulama ulamas ulema ulemas 
ulpanim ultima ultimas ultimo um umami umamis umbel umbeled umbels umber umbered 
umbers umbles umbo umbonal umbones umbonic umbos umbra umbrae umbrage umbral umbras 
umiac umiack umiacks umiacs umiak umiaks umiaq umiaqs umlaut umlauts umm ump 
umped umpire umpired umpires umps umpteen unaimed unarm unarmed unarms unbosom unclamp 
uncomic unhelm unhelms unhuman uniform unjam unjams unkempt unmacho unmade unmake unmaker 
unmakes unman unmanly unmans unmask unmasks unmated unmeant unmeet unmerry unmesh unmet 
unmew unmewed unmews unmined unmiter unmitre unmix unmixed unmixes unmixt unmold unmolds 
unmoor unmoors unmoral unmoved unmown unnamed unrimed unseam unseams unsmart untame untamed 
untimed untrim untrims upclimb upmost uptempo uptime uptimes uraemia uraemic uranism uranium 
uredium uremia uremias uremic utmost utmosts utopism vacuum vacuums vagrom vamoose vamose 
vamosed vamoses vamp vamped vamper vampers vampier vampire vampish vamps vampy vanman 
vanmen varment varmint varoom varooms velamen vellum vellums velum venom venomed venomer 
venoms verism verismo verisms vermeil vermes vermian vermin vermis vermuth vicomte victim 
victims vim vimen vimina viminal vims viremia viremic vitamer vitamin volume volumed 
volumes vomer vomers vomica vomicae vomit vomited vomiter vomito vomitos vomits vomitus 
vroom vroomed vrooms vum wadmaal wadmal wadmals wadmel wadmels wadmol wadmoll wadmols 
wagsome wakame wakames wamble wambled wambles wambly wame wamefou wameful wames wammus 
wampish wampum wampums wampus wamus wamuses warm warmed warmer warmers warmest warmish 
warmly warms warmth warmths warmup warmups wartime waxworm webcam webcams webworm welcome 
wham whammed whammo whammy whamo whams whelm whelmed whelms whilom whim whimper 
whims whimsey whimsy wholism whom whomp whomped whomps whomso whump whumped whumps 
wifedom wigwam wigwams wimble wimbled wimbles wimmin wimp wimped wimpier wimpish wimple 
wimpled wimples wimps wimpy wingman wingmen winsome wireman wiremen wisdom wisdoms woesome 
wolfram woman womaned womanly womans womb wombat wombats wombed wombier wombs womby 
women womera womeras wommera womyn woodman woodmen woolman woolmen woomera workman workmen 
worm wormed wormer wormers wormier wormil wormils wormish worms wormy xylem xylems 
yam yamalka yamen yamens yammer yammers yams yamulka yamun yamuns yardarm yardman 
yardmen yashmac yashmak yasmak yasmaks yeggman yeggmen yeoman yeomen ylem ylems yohimbe 
yom yomim yttrium yum yummier yummies yummy zamarra zamarro zamia zamias zemstva 
zemstvo zeugma zeugmas ziram zirams zoarium zoecium zombi zombie zombies zombify zombis 
zoom zoomed zooms zootomy zuzim zygoma zygomas zymase zymases zyme zymes zymogen 
zymosan zymoses zymosis zymotic zymurgy
);

my @F_words = qw(
abaft abfarad acetify acidify aciform adrift aerify afar afars afeard afeared aff 
affable affably affair affaire affairs affect affects affiant affiche affinal affine affined 
affines affirm affirms affix affixal affixed affixer affixes afflict afflux afford affords 
affray affrays affront afghan afghani afghans afield afire aflame afloat afoot afore 
afoul afraid afreet afreets afresh afrit afrits aft after afters aftmost aftosa 
aftosas agrafe agrafes agraffe aidful aimful airfare airflow airfoil airlift alef alefs 
alewife alfa alfaki alfakis alfalfa alfaqui alfas alforja alfredo alif aliform alifs 
aloft aloof aloofly amplify antefix antifat antiflu antifog antifur aquifer archfoe arf 
arfs argufy armful armfuls armsful artful ashfall ausform awful awfully backfit baff 
baffed baffies baffle baffled baffler baffles baffs baffy bagful bagfuls bagsful bailiff 
baleful baneful barefit barf barfed barfly barfs bashful basify batfish batfowl beatify 
bedfast bedwarf beef beefalo beefed beefier beefily beefs beefy befall befalls befell 
befit befits beflag beflags beflea befleas befleck befog befogs befool befools before 
befoul befouls befret befrets begulf begulfs behalf behoof belfry belief beliefs benefic 
benefit bereft biface bifaces biff biffed biffies biffin biffins biffs biffy bifid 
bifidly bifilar biflex bifocal bifold biform bigfeet bigfoot biofilm biofuel blaff blaffs 
blowfly blowoff bluefin bluff bluffed bluffer bluffly bluffs boatful boff boffed boffin 
boffins boffo boffola boffos boffs boiloff bonfire bookful botfly bouffe bouffes bowfin 
bowfins bowlful boxfish boxful boxfuls brief briefed briefer briefly briefs brimful brutify 
buff buffalo buffed buffer buffers buffest buffet buffets buffi buffier buffo buffoon 
buffos buffs buffy bumf bumfs buyoff buyoffs cafe cafes caff caffein caffs 
caftan caftans cageful caitiff calcify calf calfs calif califs canful canfuls cansful 
capful capfuls carafe carafes careful carfare carful carfuls carnify casefy castoff catface 
catfall catfish certify chaf chafe chafed chafer chafers chafes chaff chaffed chaffer 
chaffs chaffy chamfer chaufer chef chefdom chefed cheffed chefs chief chiefer chiefly 
chiefs chiffon chufa chufas chuff chuffed chuffer chuffs chuffy citify clarify clef 
clefs cleft clefted clefts cliff cliffs cliffy clift clifts coalify codfish codify 
coff coffee coffees coffer coffers coffin coffins coffle coffled coffles coffret coffs 
cofound coft coif coifed coiffe coiffed coiffes coifs coinfer comfier comfit comfits 
comfort comfrey comfy confab confabs confect confer confers confess confide confine confirm 
confit confits conflux conform confuse confute conifer coof coofs cookoff corf cornfed 
cornify cowfish cowflap cowflop craft crafted crafter crafts crafty croft crofter crofts 
crucify cuff cuffed cuffs cuif cuifs cupful cupfuls cupsful curf curfew curfews 
curfs cutoff cutoffs daff daffed daffier daffily daffs daffy daft dafter daftest 
daftly damnify dandify dareful dayfly deaf deafen deafens deafer deafest deafish deafly 
debrief decaf decafs deerfly def deface defaced defacer defaces defame defamed defamer 
defames defang defangs defat defats default defeat defeats defect defects defence defend 
defends defense defer defers deffer deffest defi defiant deficit defied defier defiers 
defies defile defiled defiler defiles define defined definer defines defis deflate deflea 
defleas deflect defoam defoams defocus defog defogs deforce deform deforms defrag defrags 
defraud defray defrays defrock defrost deft defter deftest deftly defuel defuels defunct 
defund defunds defuse defused defuser defuses defuze defuzed defuzes defy deific deified 
deifier deifies deiform deify delf delfs delft delfts densify dewfall dieoff dieoffs 
dif diff differ differs diffs diffuse difs dignify direful dishful distaff doff 
doffed doffer doffers doffs dogface dogfish doleful doofus doomful draff draffs draffy 
draft drafted draftee drafter drafts drafty drift drifted drifter drifts drifty duff 
duffel duffels duffer duffers duffle duffles duffs dufus dufuses dulcify dustoff dutiful 
dwarf dwarfed dwarfer dwarfs earflap earful earfuls earmuff easeful edifice edified edifier 
edifies edify ef eff effable efface effaced effacer effaces effect effects effendi 
effete effigy efflux effort efforts effs effulge effuse effused effuses efs eft 
efts eftsoon elf elfin elfins elfish elflike elflock endleaf enface enfaced enfaces 
enfeoff enfever enflame enfold enfolds enforce enframe engraft engulf engulfs enserf enserfs 
enuf eyefold eyeful eyefuls eyelift fa fab fabber fabbest fabl fable fabled 
fabler fablers fables fabliau fabric fabrics fabs fabular fac facade facades face 
faced facer facers faces facet facete faceted facets faceup facia faciae facial 
facials facias faciend facies facile facings fact factful faction factoid factor factors 
factory facts factual facture facula faculae facular faculty fad fadable faddier faddish 
faddism faddist faddy fade faded fadedly fadein fadeins fadeout fader faders fades 
fadg fadge fadged fadges fadings fadlike fado fados fads faecal faeces faena 
faenas faerie faeries faery fag fagg fagged faggier faggot faggots faggoty faggy 
fagin fagins fagot fagoted fagoter fagots fags faience fail failed faille failles 
fails failure fain fainer fainest faint fainted fainter faintly faints fair faired 
fairer fairest fairies fairish fairly fairs fairway fairy faith faithed faiths faitour 
fajita fajitas fak fake faked fakeer fakeers faker fakers fakery fakes fakey 
fakir fakirs falafel falbala falcate falces falcon falcons fall fallacy fallal fallals 
fallen faller fallers falloff fallout fallow fallows falls false falsely falser falsest 
falsie falsies falsify falsity falter falters falx fam fame famed fames family 
famine famines famish famous famuli famulus fan fanatic fancied fancier fancies fancify 
fancily fancy fandom fandoms fane fanega fanegas fanes fanfare fanfic fanfics fanfold 
fang fanga fangas fanged fangs fanion fanions fanjet fanjets fanlike fann fanned 
fanner fanners fannies fanny fano fanon fanons fanos fans fantail fantasm fantast 
fantasy fantod fantods fantom fantoms fanum fanums fanwise fanwort fanzine faqir faqirs 
faquir faquirs far farad faraday faradic farads faraway farc farce farced farcer 
farcers farces farceur farci farcie farcies farcy fard farded fardel fardels fards 
fare farebox fared farer farers fares farfal farfals farfel farfels farina farinas 
farinha farl farle farles farls farm farmed farmer farmers farms farness faro 
faros farrago farrier farrow farrows farside fart farted farther fartlek farts fas 
fasces fascia fasciae fascial fascias fascine fascism fascist fash fashed fashes fashion 
fast fasted fasten fastens faster fastest fasts fat fatal fatally fatback fatbird 
fate fated fateful fates fathead father fathers fathom fathoms fatidic fatigue fatl 
fatless fatlike fatly fatness fats fatso fatsoes fatsos fatt fatted fatten fattens 
fatter fattest fattier fatties fattily fattish fatty fatuity fatuous fatwa fatwas fatwood 
faucal faucals fauces faucet faucets faucial faugh fauld faulds fault faulted faults 
faulty faun fauna faunae faunal faunas fauns fauve fauves fauvism fauvist faux 
fava favas fave favela favelas favella faves favism favisms favor favored favorer 
favors favour favours favus favuses fawn fawned fawner fawners fawnier fawns fawny 
fax faxed faxes fay fayed fays faz faze fazed fazenda fazes fe 
feal fealty fear feared fearer fearers fearful fears feas fease feased feases 
feast feasted feaster feasts feat feater featest feather featly feats feature feaz 
feaze feazed feazes febrile fecal feces fecial fecials feck feckly fecks fecula 
feculae fecund fed fedayee federal fedex fedexed fedexes fedora fedoras feds fee 
feeb feeble feebler feebly feebs feed feedbag feedbox feeder feeders feedlot feeds 
feel feeler feelers feeless feels fees feet feez feeze feezed feezes feh 
fehs feign feigned feigner feigns feijoa feijoas feint feinted feints feirie feist 
feists feisty felafel felid felids feline felines fell fella fellah fellahs fellas 
fellate felled feller fellers fellest fellies felloe felloes fellow fellows fells felly 
felon felonry felons felony felsic felsite felspar felt felted felts felucca felwort 
fem female females feme femes feminie femme femmes femora femoral fems femur 
femurs fen fenagle fenc fence fenced fencer fencers fences fend fended fender 
fenders fends fenland fennec fennecs fennel fennels fennier fenny fens fenuron feod 
feodary feods feoff feoffed feoffee feoffer feoffor feoffs fer feral ferals ferbam 
ferbams fere feres feria feriae ferial ferias ferine ferity ferlie ferlies ferly 
fermata fermate ferment fermi fermion fermis fermium fern fernery fernier ferns ferny 
ferrate ferrel ferrels ferret ferrets ferrety ferric ferried ferries ferrite ferrous ferrule 
ferrum ferrums ferry fertile ferula ferulae ferulas ferule feruled ferules fervent fervid 
fervor fervors fervour fes fescue fescues fess fesse fessed fesses fest festal 
fester festers festive festoon fests fet feta fetal fetas fetch fetched fetcher 
fetches fete feted fetes fetial fetials fetich fetid fetidly fetish fetlock fetor 
fetors fets fett fetted fetter fetters fettle fettled fettles fetus fetuses feu 
feuar feuars feud feudal feudary feuded feudist feuds feued feus fever fevered 
fevers few fewer fewest fewness fey feyer feyest feyly feyness fez fezes 
fezzed fezzes fezzy fiacre fiacres fiance fiancee fiances fiar fiars fiaschi fiasco 
fiascos fiat fiats fib fibb fibbed fibber fibbers fiber fibered fibers fibre 
fibres fibril fibrils fibrin fibrins fibroid fibroin fibroma fibrous fibs fibster fibula 
fibulae fibular fibulas fice fices fiche fiches fichu fichus ficin ficins fickle 
fickler fickly fico ficoes fictile fiction fictive ficus ficuses fid fiddle fiddled 
fiddler fiddles fiddly fideism fideist fidg fidge fidged fidges fidget fidgets fidgety 
fido fidos fids fie fief fiefdom fiefs field fielded fielder fields fiend 
fiends fierce fiercer fierier fierily fiery fiesta fiestas fif fife fifed fifer 
fifers fifes fifteen fifth fifthly fifths fifties fifty fig figg figged fight 
fighter fights figment figs figural figure figured figurer figures figwort fil fila 
filar filaree filaria filbert filch filched filcher filches file filed filemot filer 
filers files filet fileted filets filial filiate filibeg filings fill fille filled 
filler fillers filles fillet fillets fillies fillip fillips fillo fillos fills filly 
film filmdom filmed filmer filmers filmi filmic filmier filmily filmis films filmset 
filmy filo filos filose fils filter filters filth filths filthy filum fimble 
fimbles fimbria fin finable finagle final finale finales finalis finally finals finance 
finback finca fincas finch finches find finder finders finds fine fined finely 
finer finery fines finesse finest finfish finfoot finger fingers finial finials finical 
finicky finikin finings finis finises finish finite finites finito fink finked finks 
finless finlike finmark finn finned finnier finny fino finos fins fiord fiords 
fipple fipples fique fiques fir fire firearm firebox firebug fired firedog firefly 
firelit fireman firemen firepan firepot firer firers fires firings firkin firkins firm 
firman firmans firmed firmer firmers firmest firmly firms firn firns firrier firry 
firs first firstly firsts firth firths fisc fiscal fiscals fiscs fish fished 
fisher fishers fishery fishes fisheye fishgig fishier fishily fishnet fishway fishy fissate 
fissile fission fissure fist fisted fistful fistic fists fistula fit fitch fitchee 
fitches fitchet fitchew fitchy fitful fitly fitment fitness fits fitt fitted fitter 
fitters fittest five fiver fivers fives fix fixable fixate fixated fixates fixatif 
fixed fixedly fixer fixers fixes fixings fixit fixity fixt fixture fixure fixures 
fiz fizgig fizgigs fizz fizzed fizzer fizzers fizzes fizzier fizzle fizzled fizzles 
fizzy fjeld fjelds fjord fjordic fjords fl flab flabby flabs flaccid flack 
flacked flacks flacon flacons flag flagged flagger flaggy flagman flagmen flagon flagons 
flags flail flailed flails flair flairs flak flake flaked flaker flakers flakes 
flakey flakier flakily flaky flam flambe flambee flambes flame flamed flamen flamens 
flamer flamers flames flamier flammed flams flamy flan flanes flaneur flange flanged 
flanger flanges flank flanked flanken flanker flanks flannel flans flap flapped flapper 
flappy flaps flar flare flared flares flareup flash flashed flasher flashes flashy 
flask flasket flasks flat flatbed flatcap flatcar flatlet flatly flats flatted flatten 
flatter flattop flatus flaunt flaunts flaunty flauta flautas flavin flavine flavins flavone 
flavor flavors flavory flavour flaw flawed flawier flaws flawy flax flaxen flaxes 
flaxier flaxy flay flayed flayer flayers flays flea fleabag fleam fleams fleapit 
fleas fleche fleches fleck flecked flecks flecky fled fledge fledged fledges fledgy 
flee fleece fleeced fleecer fleeces fleech fleecy fleer fleered fleers flees fleet 
fleeted fleeter fleetly fleets flehmen flemish flench flense flensed flenser flenses flesh 
fleshed flesher fleshes fleshly fleshy fletch fleuron fleury flew flews flex flexed 
flexes flexile flexion flexor flexors flexure fley fleyed fleys flic flick flicked 
flicker flicks flics flied flier fliers flies fliest flight flights flighty flimsy 
flinch flinder flinger flings flint flinted flints flinty flip flipped flipper flippy 
flips flir flirs flirt flirted flirter flirts flirty flit flitch flite flited 
flites flits flitted flitter flivver float floated floatel floater floats floaty floc 
flocced flocci floccus flock flocked flocks flocky flocs floe floes flog flogged 
flogger flogs flokati flong flongs flood flooded flooder floods flooey flooie floor 
floored floorer floors floosie floosy floozie floozy flop flopped flopper floppy flops 
flora florae floral florals floras floret florets florid florin florins florist floruit 
floss flossed flosser flosses flossie flossy flota flotage flotas flotsam flounce flouncy 
flour floured flours floury flout flouted flouter flouts flow flowage flowed flower 
flowers flowery flown flows flu flub flubbed flubber flubdub flubs flue flued 
fluency fluent flueric flues fluff fluffed fluffer fluffs fluffy fluid fluidal fluidic 
fluidly fluids fluish fluk fluke fluked flukes flukey flukier flukily fluky flum 
flume flumed flumes flummox flump flumped flumps flung flunk flunked flunker flunkey 
flunkie flunks flunky fluor fluoric fluorid fluorin fluors flurry flus flush flushed 
flusher flushes fluster flut flute fluted fluter fluters flutes flutey flutier flutist 
flutter fluty fluvial flux fluxed fluxes fluxion fluyt fluyts fly flyable flyaway 
flybelt flyblew flyblow flyboat flyboy flyboys flyby flybys flyer flyers flyings flyleaf 
flyless flyman flymen flyoff flyoffs flyover flypast flysch flyt flyte flyted flytes 
flytier flytrap flyway flyways foal foaled foals foam foamed foamer foamers foamier 
foamily foams foamy fob fobb fobbed fobs focal focally foci focus focused 
focuser focuses fodder fodders fodgel foe foehn foehns foeman foemen foes foetal 
foetid foetor foetors foetus fog fogbow fogbows fogdog fogdogs fogey fogeys fogg 
foggage fogged fogger foggers foggier foggily foggy foghorn fogie fogies fogless fogs 
fogy fogyish fogyism foh fohn fohns foible foibles foil foiled foils foin 
foined foins foison foisons foist foisted foists folacin folate folates fold folded 
folder folders foldout folds foldup foldups foley foleys folia foliage foliar foliate 
folic folio folioed folios foliose folious folium foliums folk folkie folkier folkies 
folkish folkmot folks folksy folkway folky folles follies follis follow follows folly 
foment foments fomite fomites fon fond fondant fonded fonder fondest fondle fondled 
fondler fondles fondly fonds fondu fondue fondued fondues fondus fons font fontal 
fontina fonts food foodie foodies foods fool fooled foolery foolish fools foot 
footage footbag footboy footed footer footers footie footier footies footle footled footler 
footles footman footmen footpad foots footsie footsy footway footy foozle foozled foozler 
foozles fop fopp fopped foppery foppish fops for fora forage foraged forager 
forages foram foramen forams foray forayed forayer forays forb forbad forbade forbare 
forbear forbid forbids forbode forbore forbs forby forbye forc force forced forceps 
forcer forcers forces ford forded fordid fordo fordoes fordone fords fore forearm 
forebay foreby forebye foredid foredo forego foregut foreign foreleg foreman foremen forepaw 
foreran forerun fores foresaw foresee forest forests foretop forever forfeit forfend forg 
forgat forgave forge forged forger forgers forgery forges forget forgets forgive forgo 
forgoer forgoes forgone forgot forint forints fork forked forker forkers forkful forkier 
forks forky forlorn form formal formals formant format formate formats forme formed 
formee former formers formes formful formic formica formol formols forms formula formyl 
formyls fornent fornix forrit forsake forsook fort forte fortes forth forties fortify 
fortis forts fortune forty forum forums forward forwent forwhy forworn foss fossa 
fossae fossas fossate fosse fosses fossick fossil fossils foster fosters fou fouette 
fought foul foulard fouled fouler foulest foully fouls found founded founder foundry 
founds fount founts four fourgon fours fourth fourths fovea foveae foveal foveas 
foveate foveola foveole fowl fowled fowler fowlers fowlpox fowls fox foxed foxes 
foxfire foxfish foxhole foxhunt foxier foxiest foxily foxings foxlike foxskin foxtail foxtrot 
foxy foy foyer foyers foys fozier foziest fozy fracas fractal fracted fracti 
fractur fractus frae fraena fraenum frag fragged fragile frags frail frailer frailly 
frails frailty fraise fraises fraktur fram frame framed framer framers frames franc 
francs frank franked franker frankly franks frantic frap frappe frapped frappes fraps 
frass frasses frat frater fraters frats fraud frauds fraught fray frayed frays 
frazil frazils frazzle freak freaked freaks freaky freckle freckly free freebee freebie 
freed freedom freely freeman freemen freer freers frees freesia freest freeway freeze 
freezer freezes freight fremd frena french frenula frenum frenums frenzy frere freres 
fresco frescos fresh freshed freshen fresher freshes freshet freshly fresnel fret fretful 
frets fretsaw fretted fretter fretty friable friar friarly friars friary fribble fridge 
fridges fried friend friends frier friers fries frieze friezes frig frigate friges 
frigged fright frights frigid frigs frijol frijole frill frilled friller frills frilly 
fringe fringed fringes fringy frisbee frise frisee frisees frises friseur frisk frisked 
frisker frisket frisks frisky frisson frit frites frith friths frits fritt fritted 
fritter fritts fritz fritzes frivol frivols friz frized frizer frizers frizes frizz 
frizzed frizzer frizzes frizzle frizzly frizzy fro frock frocked frocks froe froes 
frog frogeye frogged froggy froglet frogman frogmen frogs frolic frolics from fromage 
frond fronded fronds frons front frontal fronted fronter frontes fronton fronts frore 
frosh frost frosted frosts frosty froth frothed frother froths frothy frounce frouzy 
frow froward frown frowned frowner frowns frows frowst frowsts frowsty frowsy frowzy 
froze frozen frug frugal frugged frugs fruit fruited fruiter fruits fruity frump 
frumps frumpy frusta frustum fry fryable fryer fryers frypan frypans fub fubar 
fubb fubbed fubs fubsier fubsy fuchsia fuchsin fuci fucoid fucoids fucose fucoses 
fucous fucus fucuses fud fuddies fuddle fuddled fuddles fuddy fudg fudge fudged 
fudges fuds fuehrer fuel fueled fueler fuelers fuelled fueller fuels fug fugal 
fugally fugato fugatos fugg fugged fuggier fuggily fuggy fugio fugios fugl fugle 
fugled fugles fugs fugu fugue fugued fugues fuguist fugus fuhrer fuhrers fuji 
fujis fulcra fulcrum fulfil fulfill fulfils fulgent fulgid fulham fulhams full fullam 
fullams fulled fuller fullers fullery fullest fulls fully fulmar fulmars fulmine fulness 
fulsome fulvous fum fumaric fumble fumbled fumbler fumbles fume fumed fumer fumers 
fumes fumet fumets fumette fumier fumiest fumuli fumulus fumy fun functor fund 
funded funder funders fundi fundic funds fundus funeral funest funfair funfest fungal 
fungals fungi fungic fungo fungoes fungoid fungous fungus funicle funk funked funker 
funkers funkia funkias funkier funkily funks funky funn funned funnel funnels funner 
funnest funnier funnies funnily funny funplex funs fur furan furane furanes furans 
furbish furcate furcula furfur furies furioso furious furl furled furler furlers furless 
furlong furls furmety furmity furnace furnish furor furore furores furors furr furred 
furrier furrily furrow furrows furrowy furry furs further furtive fury furze furzes 
furzier furzy fus fusain fusains fusaria fuscous fuse fused fusee fusees fusel 
fusels fuses fusible fusibly fusil fusile fusilli fusils fusion fusions fuss fussed 
fusser fussers fusses fussier fussily fusspot fussy fustian fustic fustics fustier fustily 
fusty fusuma futharc futhark futhorc futhork futile futon futons futtock futural future 
futures futz futzed futzes fuz fuze fuzed fuzee fuzees fuzes fuzil fuzils 
fuzz fuzzed fuzzes fuzzier fuzzily fuzzy fyce fyces fyke fykes fylfot fylfots 
fynbos fytte fyttes gabfest gadfly gaff gaffe gaffed gaffer gaffers gaffes gaffs 
gainful gallfly ganef ganefs ganof ganofs garfish gasify gauffer gift gifted giftee 
giftees gifts giraffe gleeful gliff gliffs glorify glowfly gofer gofers goffer goffers 
golf golfed golfer golfers golfs gonef gonefs gonif goniff goniffs gonifs gonof 
gonofs goof goofed goofier goofily goofs goofy graft grafted grafter grafts gratify 
grief griefs griff griffe griffes griffin griffon griffs grift grifted grifter grifts 
gruff gruffed gruffer gruffly gruffs gruffy guff guffaw guffaws guffs gulf gulfed 
gulfier gulfs gulfy gunfire haaf haafs haffet haffets haffit haffits hafiz hafizes 
hafnium haft haftara hafted hafter hafters hafts hagfish half halfway handful handoff 
harmful hateful hatful hatfuls hatsful hayfork hayloft headful heedful heft hefted hefter 
hefters heftier heftily hefts hefty heifer heifers helpful hereof herself himself hisself 
hogfish hoof hoofed hoofer hoofers hoofs hopeful horrify hotfoot howf howff howffs 
howfs huff huffed huffier huffily huffish huffs huffy hurtful hushful huswife icefall 
if iff iffier iffiest iffy ifs ignify indraft infall infalls infamy infancy 
infant infanta infante infants infarct infare infares infauna infect infects infeoff infer 
inferno infers infest infests infidel infield infight infill infirm infirms infix infixed 
infixes inflame inflate inflect inflict inflow inflows influx info infold infolds inform 
informs infos infra infract infuse infused infuser infuses ingraft ingulf ingulfs insofar 
introfy ireful isoform itself jarful jarfuls jarsful jefe jefes jellify jestful jetfoil 
jewfish jiff jiffies jiffs jiffy jollify joyful jugful jugfuls jugsful jumpoff justify 
kaf kaffir kaffirs kafir kafirs kafs kaftan kaftans kaif kaifs kalif kalifs 
keef keefs kef kefir kefirs kefs kenaf kenafs kerf kerfed kerfs khaf 
khafs khalif khalifa khalifs kickoff kief kiefs kif kifs kinfolk kistful kloof 
kloofs knif knife knifed knifer knifers knifes kraft krafts kufi kufis lapful 
lapfuls lawful layoff layoffs leadoff leaf leafage leafed leafier leaflet leafs leafy 
left lefter leftest lefties leftish leftism leftist lefts lefty lief liefer liefest 
liefly life lifeful lifer lifers lifeway lift lifted lifter lifters liftman liftmen 
liftoff lifts lignify liquefy liquify lithify loaf loafed loafer loafers loafs lobefin 
loft lofted lofter lofters loftier loftily lofts lofty loof loofa loofah loofahs 
loofas loofs lowlife lucifer luff luffa luffas luffed luffs lungful lustful lutfisk 
maffia maffias maffick mafia mafias mafic mafiosi mafioso maftir maftirs magnify malefic 
malfed manful massif massifs mastiff mayfly medfly menfolk metrify micrify midlife midriff 
midwife miff miffed miffier miffs miffy milfoil mindful minify misfed misfeed misfile 
misfire misfit misfits misform moanful modify mofette mollify monofil mortify motif motific 
motifs mouflon mudfish mudflap mudflat mudflow muff muffed muffin muffins muffle muffled 
muffler muffles muffs mufti muftis mugful mugfuls mummify museful myself mystify naff 
naffed naffs naif naifs nakfa nakfas nazify needful neif neifs nidify niffer 
niffers niftier nifties niftily nifty nigrify nitrify nonfact nonfan nonfans nonfarm nonfat 
nonfood nonfuel nonlife nonself notify nullify oaf oafish oafs oarfish odorful of 
ofay ofays off offal offals offbeat offcast offcut offcuts offed offence offend 
offends offense offer offered offerer offeror offers offhand office officer offices offings 
offish offkey offline offload offramp offs offset offsets offside oft often oftener 
ofter oftest oldwife olefin olefine olefins omnific onefold oneself opacify orfray orfrays 
orifice ossific ossify ourself outface outfall outfast outfawn outfeel outfelt outfind outfire 
outfish outfit outfits outflew outflow outfly outfool outfoot outfox overfar overfat overfed 
overfit overfly oviform oxford oxfords pacific pacify pageful pailful painful palfrey palmful 
panfish panfry panful panfuls parfait payoff payoffs peafowl pelf pelfs perfect perfidy 
perform perfume perfumy perfuse petrify pfennig pfft pfui piaffe piaffed piaffer piaffes 
pickoff piefort piffle piffled piffles pigfish pilaf pilaff pilaffs pilafs pilfer pilfers 
pinfish pinfold pipeful pitfall pitiful plafond playful playoff pomfret pontiff poof poofs 
pooftah poofter poofy postfix potful potfuls pouf poufed pouff pouffe pouffed pouffes 
pouffs pouffy poufs poutful prefab prefabs preface prefade prefect prefer prefers prefile 
prefire prefix preform prefund prelife presift prof profane profess proffer profile profit 
profits profs profuse proof proofed proofer proofs puff puffed puffer puffers puffery 
puffier puffily puffin puffins puffs puffy pupfish purfle purfled purfler purfles purify 
pushful putoff putoffs putrefy quaff quaffed quaffer quaffs qualify quiff quiffs rackful 
raff raffia raffias raffish raffle raffled raffler raffles raffs raft rafted rafter 
rafters rafts rakeoff ramify rarefy rarify ratafee ratafia ratfink ratfish ratify reaffix 
rebuff rebuffs rectify redefy redfin redfins redfish redraft reedify reef reefed reefer 
reefers reefier reefs reefy ref reface refaced refaces refall refalls refect refects 
refed refeed refeeds refeel refeels refel refell refels refelt refence refer referee 
refers reff reffed refight refile refiled refiles refill refills refilm refilms refind 
refinds refine refined refiner refines refire refired refires refit refits refix refixed 
refixes reflag reflags reflate reflect reflet reflets reflew reflex reflies refloat reflood 
reflow reflown reflows reflux refly refocus refold refolds reforge reform reforms refound 
refract refrain reframe refresh refried refries refront refroze refry refs reft refuel 
refuels refuge refuged refugee refuges refugia refund refunds refusal refuse refused refuser 
refuses refutal refute refuted refuter refutes regraft reif reified reifier reifies reifs 
reify relief reliefs reoffer reproof reroof reroofs resift resifts restaff restful restuff 
reunify rif rife rifely rifer rifest riff riffed riffle riffled riffler riffles 
riffs rifl rifle rifled rifler riflers riflery rifles riflip riflips rifs rift 
rifted rifts rimfire ripoff ripoffs rolf rolfed rolfer rolfers rolfs roof roofed 
roofer roofers roofie roofies roofs rooftop roomful rotifer ruboff ruboffs rueful ruff 
ruffe ruffed ruffes ruffian ruffle ruffled ruffler ruffles ruffly ruffs rufiyaa rufous 
runoff runoffs russify ruthful sackful safari safaris safe safely safer safes safest 
safety saffron safrol safrole safrols salify salsify sandfly satisfy sawfish sawfly scarf 
scarfed scarfer scarfs scarify sclaff sclaffs scoff scoffed scoffer scoffs scorify scruff 
scruffs scruffy scuff scuffed scuffer scuffle scuffs scurf scurfs scurfy seafood seafowl 
sealift seif seifs self selfdom selfed selfish selfs selloff semifit sendoff serf 
serfage serfdom serfish serfs serif serifed serifs setoff setoffs sferics sfumato shadfly 
shadoof shaduf shadufs shaft shafted shafts sharif sharifs sheaf sheafed sheafs shelf 
shereef sherif sheriff sherifs shift shifted shifter shifts shifty shofar shofars shoofly 
showoff shrift shrifts shroff shroffs shuffle shutoff sifaka sifakas sift sifted sifter 
sifters sifts signify sinful sixfold skiff skiffle skiffs skilful skinful skysurf sluff 
sluffed sluffs snaffle snafu snafued snafus snarf snarfed snarfs sniff sniffed sniffer 
sniffle sniffly sniffs sniffy snifter snuff snuffed snuffer snuffle snuffly snuffs snuffy 
sobful sofa sofabed sofar sofars sofas soffit soffits soft softa softas soften 
softens softer softest softie softies softish softly softs softy solfege songful souffle 
soulful specify spiff spiffed spiffs spiffy spinoff spliff spliffs spoof spoofed spoofer 
spoofs spoofy sportif squiffy staff staffed staffer staffs stiff stiffed stiffen stiffer 
stiffie stiffly stiffs stifle stifled stifler stifles stopoff strafe strafed strafer strafes 
strife strifes stuff stuffed stuffer stuffs stuffy stupefy subfile subfix subfusc suffari 
suffer suffers suffice suffix suffuse sulfa sulfas sulfate sulfid sulfide sulfids sulfite 
sulfo sulfone sulfur sulfurs sulfury sunfast sunfish sunroof surf surface surfed surfeit 
surfer surfers surfier surfman surfmen surfs surfy swarf swarfs swayful swift swifter 
swiftly swifts synfuel tackify tactful taffeta taffia taffias taffies taffy tafia tafias 
tailfan tailfin takeoff tankful tariff tariffs tartufe tearful teenful teff teffs teflon 
teflons telefax telfer telfers telford tenfold tepefy terefah terrify testify theft thefts 
thereof thief thrift thrifts thrifty thyself tiff tiffany tiffed tiffin tiffins tiffs 
tinfoil tinful tinfuls tipoff tipoffs titfer titfers toff toffee toffees toffies toffs 
toffy toft tofts tofu tofus tofutti toilful tomfool topful topfull torrefy torrify 
traffic trayful tref trefah trefoil trifid trifle trifled trifler trifles trifold triform 
troffer truffe truffes truffle tubful tubfuls tubifex tufa tufas tuff tuffet tuffets 
tuffs tufoli tuft tufted tufter tufters tuftier tuftily tufts tufty tumefy tuneful 
turf turfed turfier turfman turfmen turfs turfski turfy turnoff twelfth twofer twofers 
twofold typify ufology uglify uncleft uncuff uncuffs unfaded unfair unfaith unfaked unfancy 
unfazed unfed unfelt unfence unfired unfit unfitly unfits unfix unfixed unfixes unfixt 
unfold unfolds unfond unfound unfree unfreed unfrees unfrock unfroze unfunny unfurl unfurls 
unfused unfussy uniface unific unified unifier unifies uniform unify unroof unroofs unsafe 
unshift updraft upfield upfl upflow upflows upflung upfold upfolds upfront uplift uplifts 
upshift upwaft upwafts useful vatful vatfuls verbify verify versify vilify vinify vitrify 
vivific vivify waeful wafer wafered wafers wafery waff waffed waffie waffies waffle 
waffled waffler waffles waffly waffs waft waftage wafted wafter wafters wafts wafture 
waif waifed waifish waifs wailful wakeful wamefou wameful warfare waveoff webfed webfeet 
webfoot weft wefts welfare werwolf wharf wharfed wharfs whereof whiff whiffed whiffer 
whiffet whiffle whiffs whoof whoofed whoofs wif wife wifed wifedom wifely wifes 
wifey wifeys wiftier wifty wilful willful wishful wistful witloof woeful woful wofully 
wolf wolfed wolfer wolfers wolfish wolfram wolfs woof woofed woofer woofers woofs 
yaff yaffed yaffs yuppify zaffar zaffars zaffer zaffers zaffir zaffirs zaffre zaffres 
zaftig zarf zarfs zestful zincify zinkify zoftig zombify     
);

my @Y_words = qw(
abaya abayas abbacy abbey abbeys abbotcy abeyant abhenry ability ably aby abye 
abyes abys abysm abysmal abysms abyss abyssal abysses academy acetify acetyl acetyls 
achy acidify acidity acidly acidy acolyte acridly acronym acrylic actorly actuary acuity 
acutely acyclic acyl acylate acyloin acyls addedly adenyl adenyls adeptly adultly adyta 
adytum aerify aerily aery affably affray affrays agedly agency agentry agilely agility 
agley agly aglycon agony agouty ahoy airily airplay airway airways airy alanyl 
alanyls alary alcayde alchemy alchymy alertly alienly alimony aliya aliyah aliyahs aliyas 
aliyos aliyot alkoxy alky alkyd alkyds alkyl alkylic alkyls alkyne alkynes allay 
allayed allayer allays allergy alley alleys allonym alloy alloyed alloys ally allyl 
allylic allyls almondy almonry aloofly alphyl alphyls already alway always alyssum amatory 
ambary ambery amboyna ambry amenity amiably aminity amity amnesty amplify amply amyl 
amylase amylene amylic amyloid amylose amyls amylum amylums anagogy anality anally analogy 
analyse analyst analyte analyze anarchy anatomy anchovy anergy angary angerly angrily angry 
anility animacy annoy annoyed annoyer annoys annuity anodyne anolyte anomaly anomy anonym 
anonyms anorexy anticly antigay antonym antsy anxiety any anybody anyhow anymore anyon 
anyone anyons anytime anyway anyways anywise apathy apery apetaly aphylly apiary apishly 
aplenty apogamy apology apply apteryx aptly apyrase archery archly archway ardency areally 
areaway argosy argufy argyle argyles argyll argylls ariary aridity aridly armory armoury 
army aroynt aroynts array arrayal arrayed arrayer arrays arrowy arroyo arroyos artery 
artily artsy arty aryl aryls ashtray ashy asphyxy assay assayed assayer assays 
astheny astony astray astylar asyla asylum asylums atalaya ataraxy ataxy atemoya athodyd 
atomy atony atopy atrophy attaboy atypic audibly augury auntly aunty aurally autarky 
autonym autopsy aviary avidity avidly away aweary awfully awny awry axially ay 
ayah ayahs aye ayes ayin ayins ays azygos azygous baby babyish babysat 
babysit baddy badly baffy baggily baggy bailey baileys bairnly bakery balcony baldly 
baldy balkily balky ballsy bally balmily balmy baloney banally bandy banty banyan 
banyans barely barfly barky barley barleys barmy barney barneys barny barony barye 
baryes baryon baryons baryta barytas baryte barytes barytic baryton basally basely bashlyk 
basify bassly bassy batboy batboys bathyal battery batty baulky bawdily bawdry bawdy 
bawty bay bayamo bayamos bayard bayards bayed bayman baymen bayonet bayou bayous 
bays baywood beachy beadily beady beaky beamily beamy beanery beastly beatify beauty 
bedirty beechy beefily beefy beery beeyard beggary beigy belady belay belayed belayer 
belays belfry bellboy belly beltway bely benday bendays bendy bendys benny benomyl 
benzoyl benzyl benzyls berhyme berry beryl beryls betony betray betrays bevy beweary 
beworry bewray bewrays bey beylic beylics beylik beyliks beyond beyonds beys bheesty 
bialy bialys bibbery bicycle biddy biffy bifidly bigamy bigeye bigeyes biggety biggity 
biggy bigly bigotry bikeway bilayer bilby bilgy biliary billowy billy binary bindery 
biogeny biology bionomy biopsy biotype biparty biryani bitchy bitsy bitty bivinyl blabby 
blackly blandly blankly blarney blasty bleakly bleary blebby blenny blighty blimey blimy 
blindly blocky bloody blooey bloomy blotchy blotty blousy blowby blowbys blowfly blowsy 
blowy blowzy bluejay bluely bluesy bluey blueys bluffly bluntly blurry blype blypes 
bobbery bobby bobstay bodily body bogey bogeyed bogeys boggy bogusly bogy bogyism 
bogyman bogymen boldly boloney bolshy bombyx boney boneyer bonnily bonny bony booby 
boody boogey boogeys boogy boomy bootery booty boozily boozy borty bosky bosomy 
bossily bossy botany botchy botfly bothy bouncy bounty bousy bowery bowyer bowyers 
boxily boxy boy boyar boyard boyards boyars boychik boycott boyhood boyish boyla 
boylas boyo boyos boys braggy brainy braky brambly branchy brandy branny brashly 
brashy brassy bratty bravely bravery brawly brawny braxy bray brayed brayer brayers 
brays bready breathy breezy brevity brewery briary bribery bricky briefly briery briny 
briony briskly bristly brittly broadly brolly bronzy broody broomy brosy brothy browny 
brulyie brumby brushy brutely brutify bryony bubbly bubby buckeye buddy buffy bugeye 
bugeyes buggery buggy buirdly bulgy bulkily bulky bully bumpily bumpy bunchy bunny 
bunya bunyas buoy buoyage buoyant buoyed buoys buppy burbly burley burleys burlily 
burly burry bursary bury busboy busboys busby bushily bushy busily busty busy 
butlery buttery buttony butty butyl butyls butyral butyric butyrin butyryl buxomly buy 
buyable buyback buyer buyers buyoff buyoffs buyout buyouts buys by bycatch bye 
byelaw byelaws byes bygone bygones bylaw bylaws byline bylined byliner bylines byname 
bynames bypass bypast bypath bypaths byplay byplays byre byres byrl byrled byrls 
byrnie byrnies byroad byroads bys byssal byssi byssus bytalk bytalks byte bytes 
byway byways byword bywords bywork byworks byzant byzants cabbagy cabby cachexy cacodyl 
caconym caddy cadency cadgy cagey cagily cagy cairny cakey caky calcify callboy 
calmly calory caloyer calumny calvary calyces calycle calypso calyx calyxes campily campy 
canary candy cannery cannily canny canonry canopy canty canyon canyons capably caraway 
carboy carboys carney carneys carnify carny carroty carry carryon casefy casky catchy 
cattery cattily catty causey causeys cautery cavally cavalry cavity cavy cay cayenne 
cayman caymans cays cayuse cayuses cecally cecity cedary celery century certify chaffy 
chalky chally chammy champy chancy chanoyu chantey chantry chanty charily charity charley 
charpoy charry chary chasmy chatty chay chayote chays cheaply cheeky cheerly cheery 
cheesy cherry cherty chesty chevy chewy chicly chicory chiefly childly chilly chimbly 
chimley chimney chinchy chinky chintzy chippy chirpy chitty chivvy chivy chlamys chokey 
choky choosey choosy choppy christy chromy chromyl chubby chucky chuffy chummy chunky 
churchy chutney chyle chyles chylous chyme chymes chymic chymics chymist chymous chytrid 
cicely ciliary cindery ciphony circusy cissy citify citrusy city civilly civvy clammy 
clanky clarify clarity clary classy clay clayed clayey clayier clayish claypan clays 
cleanly clearly clergy clerisy clerkly cliffy clingy cliquey cliquy cloddy cloggy closely 
clotty cloudy clovery cloy cloyed cloys clubby clumpy clumsy clunky clutchy clypeal 
clypei clypeus clyster coalify coaly cobby coccyx cockeye cockily cockney cockshy cocky 
cocoyam codify cogency cogway cogways coky colby colbys coldly colicky colly colony 
coly comedy comely comfrey comfy comity commy company comply compony comsymp conchy 
condyle coney coneys conky convey conveys convoy convoys cony cooey cooeyed cooeys 
cookery cookey cookeys cooky coolly cooly coopery copay copays coppery copy copyboy 
copycat copyist corby corky cornify cornily corny corody corrody cory corymb corymbs 
coryza coryzal coryzas cosey coseys cosily costly cosy cottony cotype cotypes country 
county courtly covary covey coveys cowboy cowboys cowedly cowry cowy coxalgy coy 
coydog coydogs coyed coyer coyest coyish coyly coyness coyote coyotes coypou coypous 
coypu coypus coys cozey cozeys cozily cozy crabby crackly cracky crafty craggy 
crampy crankly cranky cranny crappy crassly crawly crayon crayons crazily crazy creaky 
creamy creasy creepy crepey crepy cressy cresyl cresyls crickey crikey criminy crimpy 
crinkly crisply crispy croaky crony crossly croupy crowdy crucify cruddy crudely crudity 
cruelly cruelty crumbly crumby crummy crumply crunchy crusily crusty cry crybaby cryogen 
cryonic crypt cryptal cryptic crypto cryptos crypts crystal cubby cubicly cuddly cuddy 
cullay cullays cully cuppy curably curacy curdy curlily curly curry cursory curtesy 
curtly curtsey curtsy curvey curvy cushily cushy custody cutaway cutely cutesy cutey 
cuteys cutlery cutty cyan cyanate cyanic cyanid cyanide cyanids cyanin cyanine cyanins 
cyanite cyano cyans cyber cyborg cyborgs cycad cycads cycas cycases cycasin cycl 
cyclase cycle cycled cycler cyclers cyclery cycles cyclic cyclin cyclins cyclist cyclize 
cyclo cycloid cyclone cyclops cyclos cyder cyders cyeses cyesis cygnet cygnets cylices 
cylix cyma cymae cymar cymars cymas cymatia cymbal cymbals cyme cymene cymenes 
cymes cyml cymlin cymlins cymoid cymol cymols cymose cymous cynic cynical cynics 
cypher cyphers cypres cypress cyprian cyprus cypsela cyst cystein cystic cystine cystoid 
cysts cyton cytons cytosol dacoity dactyl dactyli dactyls daddy daffily daffy daftly 
daily daimyo daimyos dainty dairy daisy dakoity dally damnify damply dandify dandily 
dandy dangly dankly daresay darkey darkeys darkly darky dashy dasyure datary datedly 
daubery daubry dauby davy day daybed daybeds daybook daycare dayfly dayglow daylily 
daylit daylong daymare dayroom days dayside daysman daysmen daystar daytime daywork dazedly 
deadeye deadly deafly deanery dearly deary deathly deathy debye debyes decay decayed 
decayer decays decency decoy decoyed decoyer decoys decry decrypt decury deedy deejay 
deejays deeply deerfly defray defrays deftly defy deify deity delay delayed delayer 
delays delly demy denary densely densify density deny deoxy deploy deploys deputy 
deray derays derby derry descry desoxy destiny destroy devilry dewily dewy dexy 
dey deys dhooly dialyse dialyze diarchy diary dicey dickey dickeys dicky dicliny 
dicotyl dicty dicycly diddley diddly didy dietary digamy dignify dignity dikey dilly 
dimity dimly dimply dingey dingeys dinghy dingily dingy dinkey dinkeys dinkly dinky 
dioecy dipody dippy diptyca diptych direly dirtily dirty dishy dismay dismays disobey 
display disyoke dithery ditsy dittany ditty ditzy divvy dizzily dizzy djinny dobby 
doby doddery dodgery dodgy dogey dogeys doggery doggy dogy doily dolly donkey 
donkeys donsy doody dooly doomily doomy doorway doozy dopey dopily dopy dorky 
dormy dorty dory dottily dotty doty doubly doucely doughty doughy dourly dovekey 
dowdily dowdy dowery downy dowry doxy doyen doyenne doyens doyley doyleys doylies 
doyly dozily dozy drably draffy drafty draggy dramady dramedy drapery drapey drawly 
dray drayage drayed drayman draymen drays dreamy dreary drecky dreggy dressy dribbly 
drifty drily drippy drizzly drolly drooly droopy dropsy droshky drosky drossy drouthy 
drowsy druggy drumly dry dryable dryad dryades dryadic dryads dryer dryers dryest 
dryish dryland drylot drylots dryly dryness drys drywall drywell duality dually dubiety 
ducally duchy ducky duddy dulcify dully duly dumbly dumky dummy dumpily dumpy 
dungy duopoly dupery durably duskily dusky dustily dusty duty duvetyn dweeby dy 
dyable dyad dyadic dyadics dyads dyarchy dybbuk dybbuks dye dyeable dyed dyeings 
dyer dyers dyes dyeweed dyewood dyings dyk dyke dyked dykes dykey dynamic 
dynamo dynamos dynast dynasts dynasty dyne dynein dyneins dynel dynels dynes dynode 
dynodes dyspnea dysuria dysuric dyvour dyvours eagerly early earthly earthy easily easy 
eatery ebony ecdyses ecdysis ecdyson echoey ecology economy ecotype ecstasy ecthyma ectypal 
ectype ectypes edacity eddy edgily edgy edify eely eerily eery effigy eggy 
eighty elderly elegy elmy elusory elysian elytra elytron elytrum embassy embay embayed 
embays embody emboly embryo embryon embryos emery emmy emmys empathy empery employ 
employe employs emptily empty empyema emyd emyde emydes emyds encrypt encyst encysts 
endplay endways enemy energy enjoy enjoyed enjoyer enjoys enmity ennuye ennuyee enology 
enquiry ensky enskyed entity entropy entry envoy envoys envy enzym enzyme enzymes 
enzymic enzyms eparchy epiboly epigyny epitaxy eponym eponyms eponymy epoxy epoxyed equably 
equally equerry equity erectly erosely errancy eryngo eryngos espy essay essayed essayer 
essays estray estrays estuary ethinyl ethoxy ethoxyl ethyl ethylic ethyls ethyne ethynes 
ethynyl etyma etymon etymons eulogy eupepsy euphony euroky euryoky eustacy eustasy eutaxy 
evenly every evilly exabyte exactly exarchy exequy exogamy exonym exonyms expiry ey 
eyas eyases eyass eyasses eye eyeable eyeball eyebar eyebars eyebeam eyebolt eyebrow 
eyecup eyecups eyed eyefold eyeful eyefuls eyehole eyehook eyelash eyeless eyelet eyelets 
eyelid eyelids eyelift eyelike eyen eyer eyers eyes eyeshot eyesome eyesore eyespot 
eyewash eyewear eyewink eyne eyra eyras eyre eyres eyrie eyries eyrir eyry 
factory faculty faddy fadedly faery faggoty faggy faintly fairly fairway fairy fakery 
fakey fallacy falsely falsify falsity family fancify fancily fancy fanny fantasy faraday 
faraway farcy fatally fatly fattily fatty fatuity faulty fawny fay fayed fays 
fealty featly feckly fedayee feebly feisty felly felonry felony fenny feodary ferity 
ferly fernery ferny ferrety ferry fetidly feudary fey feyer feyest feyly feyness 
fezzy fickly fiddly fidgety fierily fiery fifthly fifty filly filmily filmy filthy 
finally finely finery finicky finny firefly firmly firry firstly fishery fisheye fishily 
fishway fishy fitchy fitly fixedly fixity fizzy flabby flaggy flakey flakily flaky 
flamy flappy flashy flatly flaunty flavory flawy flaxy flay flayed flayer flayers 
flays flecky fledgy fleecy fleetly fleshly fleshy fleury fley fleyed fleys flighty 
flimsy flinty flippy flirty floaty flocky flooey floosy floozy floppy flossy flouncy 
floury flowery fluency fluffy fluidly flukey flukily fluky flunkey flunky flurry flutey 
fluty fluyt fluyts fly flyable flyaway flybelt flyblew flyblow flyboat flyboy flyboys 
flyby flybys flyer flyers flyings flyleaf flyless flyman flymen flyoff flyoffs flyover 
flypast flysch flyt flyte flyted flytes flytier flytrap flyway flyways foamily foamy 
focally fogey fogeys foggily foggy fogy fogyish fogyism foley foleys folksy folkway 
folky folly fondly foolery footboy footsy footway footy foppery foray forayed forayer 
forays forby forbye forebay foreby forebye forgery forky formyl formyls fortify forty 
forwhy foully foundry foxily foxy foy foyer foyers foys fozy frailly frailty 
frankly fray frayed frays freaky freckly freely freeway frenzy freshly fretty friarly 
friary frilly fringy frisky frizzly frizzy frogeye froggy frosty frothy frouzy frowsty 
frowsy frowzy fruity frumpy fry fryable fryer fryers frypan frypans fubsy fuddy 
fugally fuggily fuggy fullery fully fumy funkily funky funnily funny furmety furmity 
furrily furrowy furry fury furzy fusibly fussily fussy fustily fusty fuzzily fuzzy 
fyce fyces fyke fykes fylfot fylfots fynbos fytte fyttes gabby gaby gadfly 
gadgety gaiety gaily gainly gainsay galaxy gallery galley galleys gallfly gally galyac 
galyacs galyak galyaks gamay gamays gamely gamey gamily gammy gamy gangly gangway 
gantry gappy gapy garbagy gargety garvey garveys gaseity gasify gassily gassy gateway 
gaudery gaudily gaudy gauntly gauntry gauzily gauzy gawkily gawky gawsy gay gayal 
gayals gaydar gaydars gayer gayest gayety gayly gayness gays geeky gelidly gemmily 
gemmy gently gentry geodesy geology germy getaway gey geyser geysers gharry ghastly 
ghostly ghosty ghyll ghylls giddily giddy giddyap giddyup giggly gilly gimpy gingely 
gingery ginny gipsy girly gladly glady glairy glary glassy glazily glazy gleamy 
gleety glegly gley gleyed gleys glibly glinty glitchy glitzy globby gloomy gloppy 
glorify glory glossy glowfly gluey gluily glumly glumpy glycan glycans glycin glycine 
glycins glycol glycols glycyl glycyls glyph glyphic glyphs glyptic gnarly gnatty gobony 
goby godlily godly goggly goldeye golly goodby goodbye goodbys goodly goody gooey 
goofily goofy googly gooky goombay gooney gooneys goony goopy goosey goosy gorily 
gorsy gory gossipy goutily gouty gowany goy goyim goyish goys grabby grainy 
gramary granary grandly granny grapery grapey grapy grassy gratify gravely gravity gravy 
gray grayed grayer grayest grayish graylag grayly grayout grays greasy greatly greedy 
greenly greeny gremmy grey greyed greyer greyest greyhen greyish greylag greyly greys 
grimily grimly grimy gripey grippy gripy grisly gristly gritty grizzly grocery grody 
groggy groovy grossly groszy grotty grouchy grouty growly growthy groyne groynes grubby 
gruffly gruffy grumbly grumphy grumpy grungy gruyere gryphon guanay guanays guayule guilty 
gulfy gulley gulleys gully gulpy gummy gunky gunnery gunny gunplay guppy gurney 
gurneys gurry gushily gushy gussy gustily gusty gutsily gutsy guttery gutty guy 
guyed guyline guyot guyots guys gyb gybe gybed gybes gym gymnast gyms 
gynecia gynecic gyoza gyozas gyp gyplure gypp gypped gypper gyppers gyps gypsied 
gypsies gypster gypsum gypsums gypsy gyr gyral gyrally gyrase gyrases gyrate gyrated 
gyrates gyrator gyre gyred gyrene gyrenes gyres gyri gyro gyron gyrons gyros 
gyrose gyrus gyttja gyttjas gyv gyve gyved gyves hackly hackney hairy halcyon 
halfway hallway halyard hammily hammy handily handy hanky haply happily happy hardily 
hardly hardy harmony harpy harry harshly hastily hasty haughty haulmy hautboy hawkey 
hawkeys hay haycock hayed hayer hayers hayey hayfork hayings haylage hayloft haymow 
haymows hayrack hayrick hayride hays hayseed hayward haywire hazelly hazily hazy headily 
headway heady healthy heapy hearsay hearty heathy heavily heavy hedgy heftily hefty 
hellery helotry hempy henley henleys hennery henry henrys herby hereby heresy heronry 
herry hexyl hexylic hexyls hey heyday heydays heydey heydeys hickey hickeys hickory 
highboy highly highway hilly hinky hinny hiply hippy hissy history hoagy hoarily 
hoary hobby hockey hockeys hodaddy hokey hokily holey holiday holily holly holy 
holyday homeboy homely homey homeys homily hominy homonym homy honesty honey honeyed 
honeys honkey honkeys honky hoody hooey hooeys hookey hookeys hooky hooly hooray 
hoorays hooty hoppy horary hornily horny horrify horsey horsily horsy hosey hoseyed 
hoseys hosiery hostly hotly hourly howdy hoy hoya hoyas hoyden hoydens hoyle 
hoyles hoys hryvna hryvnas hryvnia hubbly hubby huffily huffy hugely hulky humanly 
humbly humidly humpy hungry hunkey hunkeys hunky hurley hurleys hurly hurray hurrays 
hurry hushaby huskily husky hussy hy hyaena hyaenas hyaenic hyalin hyaline hyalins 
hyalite hyaloid hybrid hybrids hybris hydatid hydra hydrae hydrant hydras hydrase hydrate 
hydria hydriae hydric hydrid hydride hydrids hydro hydroid hydrops hydros hydrous hydroxy 
hyena hyenas hyenic hyenine hyenoid hyetal hygeist hygiene hyla hylas hymen hymenal 
hymenia hymens hymn hymnal hymnals hymnary hymned hymnist hymnody hymns hyoid hyoidal 
hyoids hyp hype hyped hyper hyperon hypers hypes hypha hyphae hyphal hyphen 
hyphens hypnic hypnoid hypo hypoed hypogea hyponea hyponym hypos hypoxia hypoxic hyps 
hyraces hyrax hyraxes hyson hysons hyssop hyssops hyte icily ickily icky icy 
ideally idiocy idly idyl idylist idyll idyllic idylls idyls iffy ignify ignobly 
illy imagery imbody immy impiety imply inanely inanity inaptly inby inbye incony 
indoxyl ineptly inertly infamy infancy injury inky inlay inlayer inlays inly innerly 
inquiry introfy irately irony isogamy isogeny isogony isohyet isonomy isotopy isotype isozyme 
itchily itchy ivory ivy ivylike jacky jadedly jaggary jaggery jaggy jaloppy jalopy 
jammy jangly janty japery jargony jarvey jarveys jaspery jaunty jay jaybird jaygee 
jaygees jays jayvee jayvees jaywalk jazzily jazzy jeepney jellify jelly jemmy jenny 
jerkily jerky jerry jersey jerseys jetty jetway jetways jewelry jiffy jiggly jiggy 
jiminy jimminy jimmy jimply jimpy jingly jitney jitneys jittery jivey jivy jobbery 
jockey jockeys joey joeys johnny joinery jointly jokey jokily joky jollify jollily 
jollity jolly joltily jolty jotty jouncy journey jowly joy joyance joyed joyful 
joyless joyous joypop joypops joyride joyrode joys juicily juicy jumpily jumpy jungly 
junky jurally jury juryman jurymen justify justly jutty kabaya kabayas katydid kaury 
kay kayak kayaked kayaker kayaks kayles kayo kayoed kayoes kayos kays keenly 
kelly kelpy kerry kersey kerseys kerygma key keycard keyed keyhole keyless keynote 
keypad keypads keypal keypals keys keyset keysets keyster keyway keyways keyword kicky 
kiddy kidney kidneys killjoy kilty kindly kingly kinkily kinky kissy kitschy kitty 
kludgey kludgy klutzy knarry knavery knobbly knobby knolly knotty knubby knuckly knurly 
kolacky kolhozy kolkozy kooky kopiyka koruny koumys koumyss kouprey krypton kumys kumyses 
kvetchy kyack kyacks kyak kyaks kyanise kyanite kyanize kyar kyars kyat kyats 
kybosh kye kyes kylikes kylix kyrie kyries kyte kytes kyth kythe kythed 
kythes lacey lacily lackey lackeys lacquey lactary lacy lady ladybug ladyish ladykin 
lairdly laithly laity laky lamby lamely lamprey lanely laneway langley laniary lankily 
lankly lanky lanyard larceny lardy largely larky larynx lastly lately latency lathery 
lathy laundry lawny lawyer lawyers laxity laxly lay layaway layed layer layered 
layers layette layin layins layman laymen layoff layoffs layout layouts layover lays 
layup layups lazily lazy lazyish leachy leady leafy leakily leaky leally lealty 
leanly leary leavy lechery lecythi ledgy leerily leery leeway leeways lefty legacy 
legally leggy legibly lehayim lekythi lemony lengthy lenity leprosy levelly levity levy 
lewdly ley leys lezzy liberty library lichtly licitly liefly lifeway lightly lignify 
likely lily limby limey limeys limply limpsey limpsy limy lindy lineny liney 
lingy linkboy linky linsey linseys linty liny lippy liquefy liquify litany lithely 
lithify littery liturgy lively livery lividly livyer livyers loamy loathly lobby lobbyer 
locally loftily lofty loggy logily logway logways logy lollopy lolly lonely longly 
looby looey looeys looney looneys loonily loony loopily loopy loosely loppy lordly 
lorry lory lossy lottery loudly loungy loury lousily lousy lovably lovely loverly 
lowboy lowboys lowery lowlily lowly loyal loyaler loyally loyalty lucency lucidly luckily 
lucky lullaby lumpily lumpy lunacy lungyi lungyis luny luridly lushly lustily lusty 
luxury ly lyard lyart lyase lyases lycea lycee lycees lyceum lyceums lych 
lychee lychees lyches lychnis lycopod lycra lycras lyddite lye lyes lyingly lyings 
lymph lymphs lyncean lynch lynched lyncher lynches lynx lynxes lyrate lyrated lyre 
lyres lyric lyrical lyricon lyrics lyrism lyrisms lyrist lyrists lys lysate lysates 
lyse lysed lyses lysin lysine lysines lysins lysis lysogen lyssa lyssas lytic 
lytta lyttae lyttas madly maggoty magnify maguey magueys mainly majesty majorly malady 
malarky malmsey malmy malty mamey mameyes mameys mammary mammey mammeys mammy mangaby 
mangey mangily mangy manlily manly manuary many marbly margay margays marly marrowy 
marry marshy martyr martyrs martyry marvy mashy masonry massy mastery matey mateys 
mattery maundy may maya mayan mayas maybe maybes maybird maybush mayday maydays 
mayed mayest mayfly mayhap mayhem mayhems mayings mayo mayor mayoral mayors mayos 
maypole maypop maypops mays mayst mayvin mayvins mayweed mazedly mazily mazy meadowy 
mealy meanly meany measly meatily meaty medfly mediacy medley medleys meekly meetly 
meiny melody melty memory menschy mercery mercury mercy merely merrily merry mesally 
meshy messily messy methoxy methyl methyls metonym metrify mickey mickeys micrify midday 
middays middy midway midways midyear miffy mighty milady mildewy mildly miliary milkily 
milky milty mimicry mincy mingy minify minny minty minyan minyans mirkily mirky 
miry misally miscopy miserly misery mislay mislays misplay misrely missay missays missy 
mistily misty mistype misyoke mity mixedly mizzly mockery modally modesty modify moggy 
moiety moistly moldy mollify molly moly mommy money moneyed moneyer moneys monkery 
monkey monkeys monody monoecy monthly mony moodily moody mooley mooleys mooneye moonily 
moony moory mopery mopey mopy morally morassy moray morays mortary mortify mosey 
moseyed moseys mossy mostly motey mothery mothy motley motleys mouldy mousey mousily 
mousy mouthy movably muchly muckily mucky muddily muddly muddy muggily muggy muhly 
muley muleys mulley mulleys mumbly mummery mummify mummy murkily murkly murky murphy 
murrey murreys murry muscly mushily mushy muskily musky mussily mussy mustily musty 
mutably mutedly mutely mutiny muttony muzzily muzzy my myalgia myalgic myases myasis 
myc mycele myceles mycelia mycoses mycosis mycotic mycs myelin myeline myelins myeloid 
myeloma myiases myiasis mylar mylars myna mynah mynahs mynas mynheer myoid myology 
myoma myomas myomata myope myopes myopia myopias myopic myopies myopy myoses myosin 
myosins myosis myosote myotic myotics myotome myriad myriads myrica myricas myrrh myrrhic 
myrrhs myrtle myrtles myself mysid mysids mysost mysosts mystery mystic mystics mystify 
myth mythic mythier mythoi mythos myths mythy myxoid myxoma myxomas naggy naively 
naivety nakedly namely nancy nanny napery nappy narky nary nasally nastily nasty 
nattily natty naughty navally navvy navy nay nays naysaid naysay naysays nazify 
nearby nearly neatly nebuly nectary neddy needily needy nelly neology neoteny neotype 
nerdy nervily nervy nettly netty newly newsboy newsy nicely nicety nidify niftily 
nifty niggly nightly nighty nigrify nimbly nimiety ninety ninny ninthly nippily nippy 
nitery nitrify nitty nixy nobbily nobby nobly nobody nodally noddy noily noisily 
noisy nonbody nongay nongays nonjury nonoily nonplay nonyl nonyls nooky noonday nosegay 
nosey nosily nosy notably notary notedly notify novelly novelty noway noways noyade 
noyades nubbly nubby nudely nudity nuggety nullify nullity numbly nummary nunnery nursery 
nutsy nuttily nutty nyala nyalas nylghai nylghau nylon nylons nymph nympha nymphae 
nymphal nymphet nympho nymphos nymphs oaky obesely obesity obey obeyed obeyer obeyers 
obeys obloquy obsequy occupy ochery ochry octuply octyl octyls oddity oddly odyl 
odyle odyles odyls odyssey ofay ofays offkey oilily oilway oilways oily okay 
okayed okays oldy olivary ology onery oniony onlay onlays only onyx onyxes 
oocyst oocysts oocyte oocytes oogamy oogeny oology oophyte oozily oozy opacify opacity 
openly orality orally orangey orangy oratory orby orderly orfray orfrays organdy orgy 
ornery orogeny orology orphrey orrery oryx oryxes osprey ospreys ossify ossuary ostiary 
ostomy otalgy otocyst otology ouguiya outbuy outbuys outby outbye outcity outcry outfly 
outlay outlays outpity outplay outpray outsay outsays outstay outyell outyelp ovality ovally 
ovary ovately overbuy overcoy overdry overdye overfly overjoy overlay overly overpay overply 
overtly ovulary oxeye oxeyes oxy oxyacid oxygen oxygens oxymora oxyphil oxysalt oxysome 
oxytone oy oyer oyers oyes oyesses oyez oyezes oyster oysters pacey pacify 
packly pacy paddy pageboy painty paisley palely palfrey pally palmary palmy palmyra 
palsy paltry paly pandy panfry panicky panoply pansy pantry panty papacy papally 
papaya papayan papayas papery pappy papyral papyri papyrus pardy parity parkway parlay 
parlays parley parleys parody paronym parroty parry parsley partly partway party partyer 
passkey pastry pasty patchy patency pathway patly patsy patty paty paucity paughty 
paunchy pawkily pawky pay payable payably payback payday paydays payed payee payees 
payer payers payload payment paynim paynims payoff payoffs payola payolas payor payors 
payout payouts payroll pays peachy peaky pearly peartly peaty peavey peaveys peavy 
pebbly peccary pecky pedlary pedlery peery peltry penally penalty penny pentyl pentyls 
penury peony peppery peppily peppy perdy perfidy perfumy perjury perkily perky peroxy 
perry pertly peskily pesky pessary pesty petrify pettily petty peyote peyotes peyotl 
peyotls peytral peytrel pharynx phenoxy phenyl phenyls phlegmy phoney phoneys phonily phony 
phooey phoresy phratry phrensy phyla phylae phylar phyle phylic phyllo phyllos phylon 
phylum physed physeds physes physic physics physis phytane phytin phytins phytoid phytol 
phytols phyton phytons picky piddly piety piggery piggy pigmy pigsney pigsty pillory 
pillowy pily pimply pinery piney pinkey pinkeye pinkeys pinkly pinky pinny piny 
pinyin pinyon pinyons piosity piously pipy piracy piraya pirayas piscary pitaya pitayas 
pitchy pithily pithy pity pixy pixyish pizazzy plaguey plaguy plainly plashy platy 
platypi platys play playa playact playas playboy playday played player players playful 
playlet playoff playpen plays plenary plenty pliably pliancy plisky ploidy plotty plowboy 
ploy ployed ploys plucky plummy plumply plumy plunky plushly plushy ply plyer 
plyers plywood poachy poboy poboys pockily pocky podgily podgy poesy poetry pogey 
pogeys pogy pointy pokey pokeys pokily poky poleyn poleyns policy polity poly 
polycot polyene polygon polymer polynya polynyi polyol polyols polyoma polyp polyped polypi 
polypod polyps polypus polys pommy pony poofy poorly popery popeyed poppy popsy 
porgy porky porny portly portray poshly postboy posy potboy potboys potency potsy 
pottery potty pouchy pouffy poultry pouty poverty powdery poxy poyou poyous pray 
prayed prayer prayers prays preachy prebuy prebuys predry prelacy prepay prepays preppy 
pretty pretype prexy prey preyed preyer preyers preys pricey pricily prickly pricky 
pricy primacy primary primely primly priorly priory prissy privacy privily privity privy 
probity prodigy progeny pronely propyl propyla propyls prosily prosody prosy protyl protyle 
protyls proudly proxy prudery pry pryer pryers prythee psaltry psych psyche psyched 
psyches psychic psycho psychos psychs psylla psyllas psyllid psyops psywar psywars pteryla 
ptooey ptyalin puberty puckery puddly pudency pudgily pudgy puffery puffily puffy puggry 
puggy pulley pulleys pulpily pulpy punchy punily punkey punkeys punky punny punty 
puny puppy purely purify purity purply pursily pursy purty purvey purveys pushily 
pushy pusley pusleys pussley pussly pussy putrefy putty pya pyaemia pyaemic pyas 
pye pyemia pyemias pyemic pyes pygidia pygmean pygmies pygmoid pygmy pyic pyin 
pyins pyjama pyjamas pyknic pyknics pylon pylons pylori pyloric pylorus pyoid pyoses 
pyosis pyralid pyramid pyran pyrans pyre pyrene pyrenes pyres pyretic pyrex pyrexes 
pyrexia pyrexic pyric pyridic pyrite pyrites pyritic pyro pyrogen pyrola pyrolas pyrone 
pyrones pyrope pyropes pyros pyrosis pyrrhic pyrrol pyrrole pyrrols python pythons pyuria 
pyurias pyx pyxes pyxides pyxidia pyxie pyxies pyxis quacky quaggy quakily quaky 
qualify quality qualmy quarry quavery quay quayage quays qubyte qubytes queasy queazy 
queenly queerly query quey queys quickly quietly quinary quinsy quippy quirky quivery 
qwerty qwertys rabbity rabidly raceway racily rackety racy raggedy raggy railway rainily 
rainy raisiny rally rallye rallyes ramify rammy randy rangy rankly rapidly raptly 
rarefy rarely rarify rarity rashly raspy ratably ratany ratify rattly ratty raucity 
raunchy ravelly rawly ray raya rayah rayahs rayas rayed rayless raylike rayon 
rayons rays readily ready reality really realty reapply rebody rebury rebuy rebuys 
recarry recency recopy rectify rectory recycle redbay redbays redefy redeny redeye redeyes 
redly redry redye redyed redyes reechy reedify reedily reedy reefy reeky reenjoy 
reentry refly refry regally regency reify rekey rekeyed rekeys relay relayed relays 
rely remarry remedy repay repays replay replays replevy reply resay resays resiny 
respray restudy restyle retally retiary retry rety retype retyped retypes reunify revelry 
revery reynard rhatany rheumy rhym rhyme rhymed rhymer rhymers rhymes rhyta rhythm 
rhythms rhyton rhytons riantly ribbony ribby richly rickety rickey rickeys ridgy ridley 
ridleys rifely riflery rightly righty rigidly riley rimy rindy ripely ripply risibly 
riskily risky ritzily ritzy rivalry riyal riyals roadway robbery robotry rockaby rockery 
rocky roguery roily rollway ronyon ronyons rookery rooky roomily roomy rooty ropery 
ropeway ropey ropily ropy rosary rosebay rosery rosily rosiny rosy rotary roughly 
roughy roundly roupily roupy rowdily rowdy royal royally royals royalty royster rubbery 
rubbly rubby ruby ruddily ruddy rudely rudery rudesby ruffly rufiyaa rugby ruly 
rumbly rummy rumply runaway runny runty runway runways rurally rushy russety russify 
rustily rusty ruttily rutty rya ryas rye ryes ryk ryke ryked rykes 
rynd rynds ryokan ryokans ryot ryots sabayon sadly safely safety sagely saggy 
sagy saintly saiyid saiyids salably salary salify sallowy sally salsify saltily salty 
samoyed sandfly sandy sanely sanity sappily sappy sarky sashay sashays sassaby sassily 
sassy satay satays satiety satiny satisfy satrapy satyr satyric satyrid satyrs saucily 
saucy saughy saury saveloy savory savoury savoy savoys savvily savvy sawfly sawney 
sawneys sawyer sawyers saxony say sayable sayed sayeds sayer sayers sayest sayid 
sayids sayings says sayst sayyid sayyids scabby scaly scantly scanty scarey scarify 
scarily scarry scary scatty scenery schizy schizzy scorify scraggy scrappy scrawly scrawny 
screaky screwy scrimpy scroggy scrubby scruffy scry scummy scurfy scurry scurvy scuzzy 
scyphi scyphus scythe scythed scythes sealery seamy seaway seaways secrecy sectary sedgy 
seedily seedy seely seemly seepy selsyn selsyns semidry senary senryu sensory sentry 
sepoy sepoys serry seventy sexily sexy shabby shadfly shadily shadowy shady shaggy 
shakily shaky shaley shaly shammy shamoy shamoys shandy shanny shantey shanty shapely 
sharny sharply sharpy shay shays sheeney sheeny sheerly shelly shelty shelvy sherry 
shifty shily shimmy shindy shindys shingly shinily shinney shinny shiny shipway shirty 
shitty shivery shlocky shlumpy shoaly shoddy shoofly shopboy shortly shorty showery showily 
showy shoyu shoyus shrieky shrilly shrimpy shrubby shticky shuteye shy shyer shyers 
shyest shylock shyly shyness shyster sibyl sibylic sibyls sickbay sickly sideway sightly 
signify signory silkily silky sillily silly silty silvery simony simply sinewy singly 
sinsyne sirupy sissy sixthly sixty sizably sizy skanky skerry sketchy skiddy skidway 
skiey skimpy skinny skivvy skunky sky skybox skycap skycaps skydive skydove skyed 
skyey skyhook skyjack skylark skylike skyline skylit skyman skymen skyphoi skyphos skysail 
skysurf skywalk skyward skyway skyways slackly slaggy slangy slantly slanty slatey slaty 
slavery slavey slaveys slay slayed slayer slayers slays sleazy sleekly sleeky sleepy 
sleety slickly slily slimily slimly slimpsy slimsy slimy slinky slippy slipway slitty 
slobby sloppy sloshy slouchy sloughy slowly sloyd sloyds sludgy sluicy slummy slurry 
slushy slutty sly slyer slyest slyly slyness slype slypes smarmy smartly smarty 
smeary smelly smiley smileys smirky smithy smoggy smokey smokily smoky smoochy smoothy 
smudgy smugly smutchy smutty snaggy snakey snakily snaky snappy snarky snarly snatchy 
snazzy sneaky sneery sneezy snidely sniffly sniffy snippy snobby snoopy snooty snoozy 
snotty snouty snowily snowy snubby snuffly snuffy snugly snye snyes soapily soapy 
soberly society sockeye soddy sodomy softly softy soggily soggy solely solidly solubly 
someday someway sonly sonny sonsy sooey soothly sootily sooty sophy soppy sorcery 
sorely sorrily sorry soundly soupy sourly soy soya soyas soybean soymilk soys 
soyuz soyuzes spacey spacy spangly sparely sparkly sparky sparry spay spayed spays 
specify speedy spendy sphery sphynx spicery spicey spicily spicy spidery spiffy spikey 
spikily spiky spindly spinney spinny spiny spiry spivvy splashy splay splayed splays 
spleeny splurgy spongy spoofy spooky spooney spoony sporty spotty sprawly spray sprayed 
sprayer sprays spriggy springy sprucy spry spryer spryest spryly spumy spunky spurrey 
spurry spy squabby squally squashy squatly squatty squeaky squiffy squinny squinty squirmy 
squishy stably stagey staggy stagily stagy staidly stalely stalky standby starchy starkly 
starry startsy stately statusy stay stayed stayer stayers stays steady steamy steely 
steeply stemmy stenchy stenoky sternly stewy stey sticky stiffly stilly stimy stingy 
stinky stithy stocky stodgy stogey stogeys stogy stoney stonily stony storey storeys 
stormy story stoury stoutly strappy strawy stray strayed strayer strays streaky streamy 
stringy stripy stroppy stroy stroyed stroyer stroys stubbly stubby studly study stuffy 
stumpy stupefy sturdy sty stye styed styes stygian styl stylar stylate style 
styled styler stylers styles stylet stylets styli stylise stylish stylist stylite stylize 
styloid stylus stymie stymied stymies stymy stypsis styptic styrax styrene suably suasory 
suavely suavity subsidy subtly subtype subway subways succory sucky sudary sudsy suety 
sugary sulfury sulkily sulky sully sultry summary summery sundry sunnily sunny sunray 
sunrays supply surely surety surfy surgery surgy surlily surly surrey surreys survey 
surveys swabby swampy swamy swanky swanny swarthy swarty sway swayed swayer swayers 
swayful sways sweaty sweeney sweeny sweepy sweetly sweltry swiftly swimmy swingby swingy 
swinney swirly swishy swithly swoony swoopy sybo syboes syce sycee sycees syces 
syconia sycoses sycosis syenite syke sykes syli sylis syllabi sylph sylphic sylphid 
sylphs sylphy sylva sylvae sylvan sylvans sylvas sylvin sylvine sylvins sylvite symbion 
symbiot symbol symbols symptom syn synagog synanon synapse sync syncarp synced synch 
synched synchro synchs syncom syncoms syncope syncs syndet syndets syndic syndics syne 
synergy synesis synfuel syngamy syngas synod synodal synodic synods synonym synovia syntagm 
syntax synth synths syntony synura synurae syph sypher syphers syphon syphons syphs 
syren syrens syrette syringa syringe syrinx syrphid syrup syruped syrups syrupy sysop 
sysops system systems systole syzygal syzygy tabby tachyon tacitly tackey tackify tackily 
tacky taffy talcky talky tallboy tallowy tally tallyho tamely tammy tangly tangy 
tannery tannoy tannoys tansy tantivy tanyard tardily tardy tardyon tarry tartily tartly 
tarty tastily tasty tatouay tattily tatty tautly tawdry tawney tawneys tawnily tawny 
taxably taxiway taxy teapoy teapoys tearily teary techily techy teddy teensy teentsy 
teeny telly tellys tenably tenancy tensely tensity tenthly tenty tenuity tepefy tepidly 
tepoy tepoys termly ternary terrify terry tersely testacy testify testily testy tetany 
tetchy tetryl tetryls teughly thatchy thegnly theory therapy thereby theurgy thewy they 
thickly thinly thionyl thirdly thirsty thirty thistly thorny thready thrifty throaty thrummy 
thruway thusly thuya thuyas thy thyme thymes thymey thymi thymic thymier thymine 
thymol thymols thymus thymy thyroid thyrse thyrses thyrsi thyrsus thyself tidally tiddly 
tideway tidily tidy tiffany tightly tilbury timbery timely timidly timothy tindery tingly 
tinily tinkly tinnily tinny tintype tiny tippy tipsily tipsy tiredly tissuey titty 
tivy tizzy toady toasty toby today todays toddy tody toffy toggery tokay 
tokays tollway toluyl toluyls tolyl tolyls tomboy tomboys tommy tonally toney tony 
toothy tootsy topiary toponym torchy torrefy torrify tory totally tottery touchy toughly 
toughy tourney towaway towery towny towy toy toyed toyer toyers toyish toyless 
toylike toyo toyon toyons toyos toys toyshop tracery tragedy trampy tramway tranny 
trashy trawley tray trayful trays treacly treaty trebly trembly trendy tressy trey 
treys trickly tricksy tricky trigly trilby trilogy trimly trinary trinity triply tripody 
trippy trisomy tritely trolley trolly trophy trotyl trotyls trouty troy troys truancy 
truly trusty try tryma trymata tryout tryouts trypsin tryptic trysail tryst tryste 
trysted tryster trystes trysts tubby tuftily tufty tumefy tumidly tummy tunably tunny 
turbary turfy turkey turkeys turnery turnkey tushery tushy tutoyed tutoyer tutty tuyer 
tuyere tuyeres tuyers twangy twanky tweaky tweedy tweeny twenty twiddly twiggy twinkly 
twiny twirly twisty twitchy twyer twyers ty tycoon tycoons tye tyee tyees 
tyer tyers tyes tyin tyiyn tyke tykes tylosin tymbal tymbals tympan tympana 
tympani tympano tympans tympany tyn tyne tyned tynes typ typable typal type 
typebar typed types typeset typey typhoid typhon typhons typhoon typhose typhous typhus 
typic typical typier typiest typify typist typists typo typos typp typps typy 
tyr tyranny tyrant tyrants tyre tyred tyres tyro tyronic tyros tyth tythe 
tythed tythes ubiety ufology uglify uglily ugly unaptly unary unbulky unbusy uncanny 
unchary uncoy uncrazy unduly undy undyed uneasy unfancy unfitly unfunny unfussy ungodly 
unhandy unhappy unhasty unholy unibody unify unitary unity unlay unlays unlucky unmanly 
unmerry unnoisy unready unruly unsay unsays unsexy unshowy unsoncy unsonsy untidy untruly 
unty unwary unweary unyoke unyoked unyokes unyoung upby upbye updry uppity uranyl 
uranyls urgency urinary urology usably useably usually usury utility utterly vacancy vacuity 
vagally vagary vaguely vainly valency validly valkyr valkyrs valley valleys vampy vandyke 
vanity vapidly vapory vapoury variety varsity vary vastity vastly vasty vaulty vaunty 
vealy veejay veejays veery veiny velvety venally venery verbify verify verily verity 
versify very vestry vexedly viably vicarly viceroy vichy victory viduity viewy vilayet 
vilely vilify vinery vinify viny vinyl vinylic vinyls virally virelay visibly vitally 
vitrify vivary vividly vivify vixenly vocably vocally volery volley volleys volubly votary 
vouvray voyage voyaged voyager voyages voyeur voyeurs vuggy vy vyingly wabbly wackily 
wacky waddly waddy wady wafery waffly waggery waggly walkway wallaby walleye wally 
waly wambly waney wanly wany warily warmly warty wary washday washy waspily 
waspy wastery wastry watery wavery wavey waveys wavily wavy waxily waxy way 
waybill waylaid waylay waylays wayless ways wayside wayward wayworn weakly wealthy wearily 
weary weasely webby wedgy weedily weedy weekday weekly weensy weeny weepy weevily 
weighty weirdly weirdy welly wenny wetly whacky whammy wheezy whelky whereby wherry 
whey wheyey wheyish wheys whimsey whimsy whiney whinny whiny whippy whipray whirly 
whirry whiskey whisky whitely whitey whiteys whity whizzy wholly why whydah whydahs 
whys wickyup wicopy widdy widely wieldy wifely wifey wifeys wifty wiggery wiggly 
wiggy wildly wilily willowy willy wily wimpy wincey winceys windily windowy windway 
windy winery winey wingy wintery wintry winy wireway wirily wiry wiseguy wisely 
wispily wispy witchy withy witney witneys wittily witty wobbly wofully womanly womby 
womyn wonky woodsy woody woolly wooly woozily woozy wordily wordy workday worldly 
wormy worry worthy wrathy wreathy wriggly wrinkly wristy wrongly wry wryer wryest 
wryly wryneck wryness wussy wych wyches wye wyes wyl wyle wyled wyles 
wyn wynd wynds wynn wynns wyns wyt wyte wyted wytes wyvern wyverns 
xylan xylans xylem xylems xylene xylenes xylidin xylitol xyloid xylol xylols xylose 
xyloses xylyl xylyls xyst xyster xysters xysti xystoi xystos xysts xystus ya 
yabber yabbers yabbie yabbies yabby yacht yachted yachter yachts yack yacked yacks 
yaff yaffed yaffs yag yager yagers yagi yagis yags yah yahoo yahoos 
yaird yairds yak yakk yakked yakker yakkers yaks yakuza yald yam yamalka 
yamen yamens yammer yammers yams yamulka yamun yamuns yang yangs yank yanked 
yanks yanqui yanquis yantra yantras yap yapock yapocks yapok yapoks yapon yapons 
yapp yapped yapper yappers yaps yar yard yardage yardarm yarded yarder yarders 
yardman yardmen yards yare yarely yarer yarest yarn yarned yarner yarners yarns 
yarrow yarrows yashmac yashmak yasmak yasmaks yatagan yatter yatters yaud yauds yauld 
yaup yauped yauper yaupers yaupon yaupons yaups yautia yautias yaw yawed yawey 
yawl yawled yawls yawn yawned yawner yawners yawns yawp yawped yawper yawpers 
yawps yaws yay yays yclad ycleped yclept ye yea yeah yeahs yeal 
yean yeaned yeans year yearend yearly yearn yearned yearner yearns years yeas 
yeast yeasted yeasts yeasty yecch yecchs yech yechs yechy yeelin yeelins yegg 
yeggman yeggmen yeggs yeh yeld yelk yelks yell yelled yeller yellers yellow 
yellows yellowy yells yelp yelped yelper yelpers yelps yen yenn yenned yens 
yenta yentas yente yentes yeoman yeomen yep yeps yerba yerbas yerk yerked 
yerks yes yeses yeshiva yess yessed yesses yester yestern yet yeti yetis 
yett yetts yeuk yeuked yeuks yeuky yew yews yid yids yield yielded 
yielder yields yikes yill yills yin yince yins yip yipe yipes yipp 
yipped yippee yippie yippies yips yird yirds yirr yirred yirrs yirth yirths 
ylem ylems yo yob yobbo yobboes yobbos yobs yock yocked yocks yod 
yodel yodeled yodeler yodels yodh yodhs yodl yodle yodled yodler yodlers yodles 
yods yoga yogas yogee yogees yogh yoghs yoghurt yogi yogic yogin yogini 
yoginis yogins yogis yogurt yogurts yohimbe yoicks yok yoke yoked yokel yokels 
yokes yoks yolk yolked yolkier yolks yolky yom yomim yon yond yonder 
yoni yonic yonis yonker yonkers yore yores you young younger youngs younker 
youpon youpons your yourn yours yous youse youth youthen youths yow yowe 
yowed yowes yowie yowies yowl yowled yowler yowlers yowls yows yperite yttria 
yttrias yttric yttrium yuan yuans yuca yucas yucca yuccas yucch yuch yuck 
yucked yuckier yucks yucky yuga yugas yuk yukk yukked yukkier yukky yuks 
yulan yulans yule yules yum yummier yummies yummy yup yupon yupons yuppie 
yuppies yuppify yuppy yups yurt yurta yurts yutz yutzes ywis zanily zany 
zanyish zappy zayin zayins zedoary zephyr zephyrs zestily zesty zincify zincky zincy 
zingy zinkify zinky zippy zloty zlotych zlotys zombify zonally zonary zooey zoogeny 
zoology zootomy zooty zoysia zoysias zydeco zydecos zygoid zygoma zygomas zygose zygoses 
zygosis zygote zygotes zygotic zymase zymases zyme zymes zymogen zymosan zymoses zymosis 
zymotic zymurgy zyzzyva
);

my @W_words = qw(
abwatt abwatts adown adwoman adwomen aglow aircrew airflow airglow airshow airward airwave 
airway airways airwise ajowan ajowans alewife allow allowed allows alow alway always 
anew answer answers antiwar anyhow anyway anyways anywise archway areaway arrow arrowed 
arrows arrowy artwork askew asswage aswarm aswirl aswoon athwart atwain atween avow 
avowal avowals avowed avower avowers avows aw awa await awaited awaiter awaits 
awak awake awaked awaken awakens awakes award awarded awardee awarder awards aware 
awash away awe aweary awed awee aweigh aweless awes awesome awful awfully 
awhile awhirl awkward awl awless awls awlwort awmous awn awned awnings awnless 
awns awny awoke awoken awol awols awry backsaw bagwig bagwigs bagworm baklawa 
bandsaw barlow barlows barrow barrows barware bashaw bashaws batfowl batw bawbee bawbees 
bawcock bawd bawdier bawdies bawdily bawdric bawdry bawds bawdy bawl bawled bawler 
bawlers bawls bawsunt bawtie bawties bawty baywood beclown becrawl becrowd bedew bedewed 
bedews bedgown bedward bedwarf beeswax behowl behowls bejewel bellow bellows below belows 
beltway beshrew besnow besnows bestow bestows bestrew bestrow beswarm between betwixt bewail 
bewails beware bewared bewares beweary beweep beweeps bewept bewig bewigs bewitch beworm 
beworms beworry bewrap bewraps bewrapt bewray bewrays bigwig bigwigs bikeway billow billows 
billowy blaw blawed blawn blaws blew blow blowby blowbys blowed blower blowers 
blowfly blowgun blowier blowjob blown blowoff blowout blows blowsed blowsy blowup blowups 
blowy blowzed blowzy bogwood borrow borrows bow bowed bowel boweled bowels bower 
bowered bowers bowery bowfin bowfins bowhead bowings bowknot bowl bowlder bowled bowleg 
bowlegs bowler bowlers bowless bowlful bowlike bowline bowls bowman bowmen bowpot bowpots 
bows bowse bowsed bowses bowshot bowwow bowwows bowyer bowyers boxwood bradawl braw 
brawer brawest brawl brawled brawler brawlie brawls brawly brawn brawns brawny braws 
brew brewage brewed brewer brewers brewery brewis brewpub brews brewski brow browed 
brown browned browner brownie browns browny brows browse browsed browser browses bucksaw 
budworm bulwark burrow burrows burweed bushwa bushwah bushwas buzzwig bwana bwanas byelaw 
byelaws bylaw bylaws byway byways byword bywords bywork byworks cahow cahows callow 
caraway carwash cashaw cashaws cashew cashews catawba catclaw catspaw catwalk caw cawed 
caws chaw chawed chawer chawers chaws chew chewed chewer chewers chewier chewink 
chews chewy chinwag chow chowder chowed chows chowse chowsed chowses claw clawed 
clawer clawers claws clew clewed clews clowder clown clowned clowns cobweb cobwebs 
cogway cogways cornrow cow cowage cowages coward cowards cowbane cowbell cowbind cowbird 
cowboy cowboys cowed cowedly cower cowered cowers cowfish cowflap cowflop cowgirl cowhage 
cowhand cowherb cowherd cowhide cowier cowiest cowl cowled cowlick cowls cowman cowmen 
cowpat cowpats cowpea cowpeas cowpie cowpies cowplop cowpoke cowpox cowrie cowries cowrite 
cowrote cowry cows cowshed cowskin cowslip cowy craw crawdad crawl crawled crawler 
crawls crawly craws crew crewcut crewed crewel crewels crewman crewmen crews crow 
crowbar crowd crowded crowder crowdie crowds crowdy crowed crower crowers crown crowned 
crowner crownet crowns crows crwth crwths cudweed cumshaw curfew curfews curlew curlews 
cushaw cushaws cutaway cutdown cutwork cutworm cwm cwms dagwood daw dawdle dawdled 
dawdler dawdles dawed dawen dawk dawks dawn dawned dawns daws dawt dawted 
dawtie dawties dawts dayglow daywork declaw declaws decrown deewan deewans dew dewan 
dewans dewar dewars dewater dewax dewaxed dewaxes dewclaw dewdrop dewed dewfall dewier 
dewiest dewily dewlap dewlaps dewless dewool dewools deworm deworms dews dewy dhow 
dhows dimwit dimwits disavow disown disowns diwan diwans dogwood doorway doowop doowops 
dorhawk dow dowable dowager dowdier dowdies dowdily dowdy dowed dowel doweled dowels 
dower dowered dowers dowery dowie down downbow downed downer downers downier downs 
downy dowries dowry dows dowse dowsed dowser dowsers dowses draw drawbar drawee 
drawees drawer drawers drawl drawled drawler drawls drawly drawn draws drew drown 
drownd drownds drowned drowner drowns drowse drowsed drowses drowsy drywall drywell dwarf 
dwarfed dwarfer dwarfs dwarves dweeb dweebs dweeby dwell dwelled dweller dwells dwelt 
dwin dwindle dwine dwined dwines dyeweed dyewood earwax earwig earwigs earworm eelworm 
eiswein ekpwele elbow elbowed elbows embow embowed embowel embower embows embrown empower 
endow endowed endower endows endways endwise enow enows entwine entwist enwheel enwind 
enwinds enwomb enwombs enwound enwrap enwraps erenow eschew eschews escrow escrows etwee 
etwees ewe ewer ewers ewes eyebrow eyewash eyewear eyewink fairway fallow fallows 
fanwise fanwort faraway farrow farrows fatwa fatwas fatwood fawn fawned fawner fawners 
fawnier fawns fawny fellow fellows felwort few fewer fewest fewness figwort fishway 
fitchew flaw flawed flawier flaws flawy flew flews flow flowage flowed flower 
flowers flowery flown flows flyaway flyblew flyblow flyway flyways fogbow fogbows folkway 
follow follows footway forepaw foresaw forward forwent forwhy forworn fowl fowled fowler 
fowlers fowlpox fowls freeway fretsaw frow froward frown frowned frowner frowns frows 
frowst frowsts frowsty frowsy frowzy furrow furrows furrowy gadwall gallows gangway gateway 
gawk gawked gawker gawkers gawkier gawkies gawkily gawkish gawks gawky gawp gawped 
gawper gawpers gawps gawsie gawsy geegaw geegaws getaway gewgaw gewgaws glow glowed 
glower glowers glowfly glows gnaw gnawed gnawer gnawers gnawn gnaws godown godowns 
godwit godwits goshawk gowan gowaned gowans gowany gowd gowds gowk gowks gown 
gowned gowns grew grow grower growers growl growled growler growls growly grown 
grownup grows growth growths growthy guffaw guffaws gumweed gumwood gunwale gweduc gweduck 
gweducs gwine hacksaw halfway hallow hallows hallway handsaw haniwa harrow harrows haw 
hawala hawalas hawed hawk hawked hawker hawkers hawkey hawkeys hawkie hawkies hawkish 
hawks haws hawse hawser hawsers hawses haymow haymows hayward haywire headway heehaw 
heehaws hew hewable hewed hewer hewers hewn hews highway hoedown hogwash hogweed 
hollow hollows hoosgow how howbeit howdah howdahs howdie howdied howdies howdy howe 
howes however howf howff howffs howfs howk howked howks howl howled howler 
howlers howlet howlets howls hows huswife hwan imbower imbrown impawn impawns impower 
indow indowed indows indrawn indwell indwelt inflow inflows ingrown inkwell inkwood inswept 
intown intwine intwist inwall inwalls inward inwards inweave inwind inwinds inwound inwove 
inwoven inwrap inwraps iwis jackdaw jaw jawan jawans jawbone jawed jawless jawlike 
jawline jaws jaywalk jetway jetways jew jewed jewel jeweled jeweler jewelry jewels 
jewfish jews jigsaw jigsawn jigsaws jow jowar jowars jowed jowl jowled jowlier 
jowls jowly jows kewpie kewpies keyway keyways keyword kiwi kiwis knawe knawel 
knawels knawes knew know knower knowers known knowns knows kotow kotowed kotower 
kotows kowtow kowtows krewe krewes kwacha kwachas kwanza kwanzas laneway lapw lauwine 
law lawbook lawed lawful lawine lawines lawings lawless lawlike lawman lawmen lawn 
lawns lawny laws lawsuit lawyer lawyers layaway lechwe lechwes leeward leeway leeways 
legwork letdown lewd lewder lewdest lewdly lewis lewises lifeway lobworm lockjaw logway 
logways logwood longbow low lowball lowborn lowboy lowboys lowbred lowbrow lowdown lowe 
lowed lower lowered lowers lowery lowes lowest lowings lowish lowland lowlier lowlife 
lowlily lowly lown lowness lows lowse lugworm lwei lweis macaw macaws madwort 
mallow mallows manward manwise marrow marrows marrowy maw mawed mawkish mawn maws 
maxwell mayweed meadow meadows meadowy mellow mellows meow meowed meows mew mewed 
mewl mewled mewler mewlers mewls mews miaow miaowed miaows midtown midway midways 
midweek midwife mildew mildews mildewy minnow minnows misdraw misdrew misgrew misgrow misknew 
misknow mistbow misword miswrit mohawk mohawks moonbow morrow morrows mow mowed mower 
mowers mowings mown mows mudflow mugwort mugwump narrow narrows narwal narwals narwhal 
naw nawab nawabs nephew nephews network new newbie newbies newborn newel newels 
newer newest newie newies newish newly newmown newness news newsboy newsie newsier 
newsies newsman newsmen newsy newt newton newtons newts ngwee nitwit nitwits nohow 
nonnews nonwage nonwar nonwars nonwool nonword nonwork now noway noways nowhere nowise 
nowness nows nowt nowts nutwood oilway oilways oldwife onward onwards outbawl outcrow 
outdraw outdrew outfawn outflew outflow outglow outgnaw outgrew outgrow outhowl outlaw outlaws 
outrow outrows outsaw outswam outswim outswum outwait outwalk outwar outward outwars outwash 
outwear outweep outwent outwept outwile outwill outwind outwish outwit outwith outwits outwore 
outwork outworn outwrit overawe overnew oversaw oversew overwet ow owe owed owes 
owl owlet owlets owlish owllike owls own ownable owned owner owners owns 
owse owsen oxbow oxbows packwax papaw papaws parkway partway pathway paw pawed 
pawer pawers pawkier pawkily pawky pawl pawls pawn pawnage pawned pawnee pawnees 
pawner pawners pawnor pawnors pawns pawpaw pawpaws paws paxwax peafowl peewee peewees 
peewit peewits periwig pesewa pesewas pew pewee pewees pewit pewits pews pewter 
pewters phew pigweed pilaw pilaws pillow pillows pillowy pinwale pinweed pinwork pinworm 
pitsaw pitsaws plew plews plow plowboy plowed plower plowers plowman plowmen plows 
plywood postwar pow powder powders powdery power powered powers pows powter powters 
powwow powwows prawn prawned prawner prawns predawn prelaw preshow preview prewar prewarm 
prewarn prewash prewire prework preworn prewrap prow prowar prower prowess prowest prowl 
prowled prowler prowls prows pshaw pshawed pshaws psywar psywars purview putdown qwerty 
qwertys raceway ragweed ragwort railway rainbow raw rawer rawest rawhide rawin rawins 
rawish rawly rawness raws reavow reavows reawake reawoke rechew rechews recrown redowa 
redowas redraw redrawn redraws redrew redw redware redwood reendow reflew reflow reflown 
reflows reglow reglows regrew regrow regrown regrows renew renewal renewed renewer renews 
renown renowns replow replows repower resaw resawed resawn resaws resew resewed resewn 
resews reshow reshown reshows resow resowed resown resows retwist review reviews rewake 
rewaked rewaken rewakes rewan reward rewards rewarm rewarms rewash rewax rewaxed rewaxes 
rewear rewears reweave rewed reweds reweigh reweld rewelds rewet rewets rewiden rewin 
rewind rewinds rewins rewire rewired rewires rewoke rewoken rewon reword rewords rewore 
rework reworks reworn rewound rewove rewoven rewrap rewraps rewrapt rewrite rewrote ribwort 
rikshaw ringtaw ripsaw ripsawn ripsaws roadway rollway ropeway row rowable rowan rowans 
rowboat rowdier rowdies rowdily rowdy rowed rowel roweled rowels rowen rowens rower 
rowers rowings rowlock rows rowth rowths rubdown runaway rundown runway runways sahiwal 
salchow sallow sallows sallowy sapwood saw sawbill sawbuck sawdust sawed sawer sawers 
sawfish sawfly sawlike sawlog sawlogs sawmill sawn sawney sawneys saws sawyer sawyers 
schwa schwas scow scowder scowed scowl scowled scowler scowls scows scrawl scrawls 
scrawly scrawny screw screwed screwer screws screwup screwy seafowl seawall seawan seawans 
seawant seaward seaware seaway seaways seaweed seesaw seesaws semiraw serow serows sew 
sewable sewage sewages sewan sewans sewar sewars sewed sewer sewered sewers sewings 
sewn sews shadow shadows shadowy shallow shaw shawed shawl shawled shawls shawm 
shawms shawn shaws shew shewed shewer shewers shewn shews shipway show showbiz 
showed shower showers showery showier showily showman showmen shown showoff shows showy 
shrew shrewd shrewed shrews shwa shwas sideway sinew sinewed sinews sinewy skew 
skewed skewer skewers skews skidway skiwear skywalk skyward skyway skyways slaw slaws 
slew slewed slews slipway slow slowed slower slowest slowish slowly slows smew 
smews snaw snawed snaws snow snowcap snowcat snowed snowier snowily snowman snowmen 
snows snowy somehow someway sorrow sorrows sow sowable sowans sowar sowars sowcar 
sowcars sowed sowens sower sowers sown sows sparrow spawn spawned spawner spawns 
spew spewed spewer spewers spews sprawl sprawls sprawly squaw squawk squawks squaws 
staw stew steward stewbum stewed stewpan stews stewy stow stowage stowed stowp 
stowps stows straw strawed straws strawy strew strewed strewer strewn strews strow 
strowed strown strows subway subways sunbow sunbows sundew sundews sundown sunglow sunward 
sunwise sw swab swabbed swabber swabbie swabby swabs swacked swaddle swag swage 
swaged swager swagers swages swagged swagger swaggie swagman swagmen swags swail swails 
swain swains swale swales swallow swam swami swamies swamis swamp swamped swamper 
swamps swampy swamy swan swang swank swanked swanker swanks swanky swanned swanny 
swanpan swans swap swapped swapper swaps swaraj sward swarded swards sware swarf 
swarfs swarm swarmed swarmer swarms swart swarth swarths swarthy swarty swash swashed 
swasher swashes swat swatch swath swathe swathed swather swathes swaths swats swatted 
swatter sway swayed swayer swayers swayful sways swear swearer swears sweat sweated 
sweater sweats sweaty swede swedes sweeney sweeny sweep sweeper sweeps sweepy sweer 
sweet sweeten sweeter sweetie sweetly sweets swell swelled sweller swells swelter sweltry 
swept swerve swerved swerver swerves sweven swevens swidden swift swifter swiftly swifts 
swig swigged swigger swigs swill swilled swiller swills swim swimmer swimmy swims 
swindle swine swingby swinge swinged swinger swinges swingle swings swingy swinish swink 
swinked swinks swinney swip swipe swiped swipes swiple swiples swipple swirl swirled 
swirls swirly swish swished swisher swishes swishy swiss swisses switch swith swithe 
swither swithly swiv swive swived swivel swivels swives swivet swivets swizzle swob 
swobbed swobber swobs swollen swoon swooned swooner swoons swoony swoop swooped swooper 
swoops swoopy swoosh swop swopped swops sword swords swore sworn swot swots 
swotted swotter swoun swound swounds swouned swouns swum swung tallow tallows tallowy 
tarweed taw tawdry tawed tawer tawers tawie tawney tawneys tawnier tawnies tawnily 
tawny tawpie tawpies taws tawse tawsed tawses taxiway taxwise teabowl teaware tew 
tewed tews thalweg thaw thawed thawer thawers thaws thew thewier thews thewy 
thraw thrawed thrawn thraws threw throw thrower thrown throws thruway thwack thwacks 
thwart thwarts tideway tinware tinwork tollway topwork tow towable towage towages toward 
towards towaway towboat towed towel toweled towels tower towered towers towery towhead 
towhee towhees towie towies towline towmond towmont town townee townees townie townies 
townish townlet towns towny towpath towrope tows towsack towy tramway trawl trawled 
trawler trawley trawls trews trishaw trow trowed trowel trowels trows trowth trowths 
twa twaddle twae twaes twain twains twang twanged twanger twangle twangs twangy 
twanky twas twasome twat twats twattle tweak tweaked tweaks tweaky twee tweed 
tweedle tweeds tweedy tween tweener tweens tweeny tweet tweeted tweeter tweets tweeze 
tweezed tweezer tweezes twelfth twelve twelves twenty twerp twerps twibil twibill twibils 
twice twiddle twiddly twier twiers twig twigged twiggen twiggy twigs twilit twill 
twilled twills twin twine twined twiner twiners twines twinge twinged twinges twinier 
twinjet twinkie twinkle twinkly twinned twins twinset twiny twirl twirled twirler twirls 
twirly twirp twirps twist twisted twister twists twisty twit twitch twitchy twits 
twitted twitter twixt two twofer twofers twofold twoonie twos twosome twyer twyers 
unawake unaware unawed unbowed uncrown undraw undrawn undraws undrew unhewn unknown unmew 
unmewed unmews unmown unowned unsawed unsawn unscrew unsew unsewed unsewn unsews unshowy 
unsowed unsown unswear unswept unswore unsworn untwine untwist unwary unwaxed unweary unweave 
unwed unwell unwept unwet unwhite unwind unwinds unwise unwiser unwish unwit unwits 
unwon unwooed unworn unwound unwove unwoven unwrap unwraps unwrung upbow upbows upflow 
upflows upgrew upgrow upgrown upgrows upsw upsweep upswell upswept upswung upthrew upthrow 
uptown uptowns upwaft upwafts upward upwards upwell upwells upwind upwinds vanward vaw 
vaward vawards vawntie vaws view viewed viewer viewers viewier views viewy vow 
vowed vowel vowels vower vowers vowless vows vrouw vrouws vrow vrows w 
wab wabble wabbled wabbler wabbles wabbly wabs wack wacke wacker wackes wackest 
wackier wackily wacko wackos wacks wacky wad wadable wadd wadded wadder wadders 
waddie waddied waddies waddle waddled waddler waddles waddly waddy wade waded wader 
waders wades wadi wadies wadis wadmaal wadmal wadmals wadmel wadmels wadmol wadmoll 
wadmols wads wadset wadsets wady wae waeful waeness waes waesuck wafer wafered 
wafers wafery waff waffed waffie waffies waffle waffled waffler waffles waffly waffs 
waft waftage wafted wafter wafters wafts wafture wag wage waged wager wagered 
wagerer wagers wages wagg wagged wagger waggers waggery waggish waggle waggled waggles 
waggly waggon waggons wagon wagoned wagoner wagons wags wagsome wagtail wahine wahines 
wahoo wahoos waif waifed waifish waifs wail wailed wailer wailers wailful wails 
wain wains wair waired wairs waist waisted waister waists wait waited waiter 
waiters waitron waits waiv waive waived waiver waivers waives wak wakame wakames 
wakanda wake waked wakeful waken wakened wakener wakens waker wakers wakes wakiki 
wakikis wal wale waled waler walers wales walies walk walked walker walkers 
walkout walks walkup walkups walkway wall walla wallaby wallah wallahs wallas walled 
wallet wallets walleye wallie wallies wallop wallops wallow wallows walls wally walnut 
walnuts walrus waltz waltzed waltzer waltzes waly wamble wambled wambles wambly wame 
wamefou wameful wames wammus wampish wampum wampums wampus wamus wamuses wan wand 
wander wanders wandle wands wane waned wanes waney wangan wangans wangle wangled 
wangler wangles wangun wanguns wanier waniest wanigan wanion wanions wank wanked wanker 
wankers wanks wanly wann wannabe wanned wanner wanness wannest wans want wantage 
wanted wanter wanters wanton wantons wants wany wap wapiti wapitis wapp wapped 
waps war warble warbled warbler warbles ward warded warden wardens warder warders 
wards ware wared wares warfare warhead warier wariest warily warison wark warked 
warks warless warlike warlock warlord warm warmed warmer warmers warmest warmish warmly 
warms warmth warmths warmup warmups warn warned warner warners warns warp warpage 
warpath warped warper warpers warps warr warrant warred warren warrens warrior wars 
warsaw warsaws warship warsle warsled warsler warsles warstle wart warted warthog wartier 
wartime warts warty warwork warworn wary was wasabi wasabis wash washday washed 
washer washers washes washier washout washrag washtub washup washups washy wasp waspier 
waspily waspish wasps waspy wassail wast wastage waste wasted waster wasters wastery 
wastes wastrel wastrie wastry wasts wat watap watape watapes wataps watch watched 
watcher watches water watered waterer waters watery wats watt wattage wattape watter 
wattest wattle wattled wattles watts waucht wauchts waugh waught waughts wauk wauked 
wauks waul wauled wauls waur wav wave waved wavelet waveoff waver wavered 
waverer wavers wavery waves wavey waveys wavicle wavier wavies waviest wavily wavy 
waw wawl wawled wawls waws wax waxable waxbill waxed waxen waxer waxers 
waxes waxier waxiest waxily waxings waxlike waxw waxweed waxwork waxworm waxy way 
waybill waylaid waylay waylays wayless ways wayside wayward wayworn wazoo wazoos we 
weak weaken weakens weaker weakest weakish weakly weakon weakons weal weald wealds 
weals wealth wealths wealthy wean weaned weaner weaners weans weapon weapons wear 
wearer wearers wearied wearier wearies wearily wearish wears weary weasand weasel weasels 
weasely weason weasons weather weav weave weaved weaver weavers weaves weazand web 
webb webbed webbier webby webcam webcams webcast weber webers webfed webfeet webfoot 
webless weblike weblog weblogs webpage webs website webster webwork webworm wecht wechts 
wed wedd wedded wedder wedders wedel wedeled wedeln wedelns wedels wedg wedge 
wedged wedges wedgie wedgier wedgies wedgy wedlock weds wee weed weeded weeder 
weeders weedier weedily weeds weedy week weekday weekend weekly weeks weel ween 
weened weenie weenier weenies weens weensy weeny weep weeper weepers weepie weepier 
weepies weeps weepy weer wees weest weet weeted weets weever weevers weevil 
weevils weevily weewee weeweed weewees weft wefts weigela weigh weighed weigher weighs 
weight weights weighty weiner weiners weir weird weirded weirder weirdie weirdly weirdo 
weirdos weirds weirdy weirs weka wekas welch welched welcher welches welcome weld 
welded welder welders weldor weldors welds welfare welkin welkins well welled wellie 
wellies wells welly welsh welshed welsher welshes welt welted welter welters welts 
wen wench wenched wencher wenches wend wended wendigo wends wennier wennish wenny 
wens went wept were wergeld wergelt wergild wert werwolf weskit weskits wessand 
west wester western westers wests wet wetback wether wethers wetland wetly wetness 
wets wetsuit wett wetted wetter wetters wettest wettish wetware wha whack whacked 
whacker whacko whackos whacks whacky whal whale whaled whaler whalers whales wham 
whammed whammo whammy whamo whams whang whanged whangee whangs whap whapped whapper 
whaps wharf wharfed wharfs wharve wharves what whatnot whats whatsis whatsit whaup 
whaups wheal wheals wheat wheaten wheats whee wheedle wheel wheeled wheeler wheelie 
wheels wheen wheens wheep wheeped wheeple wheeps wheeze wheezed wheezer wheezes wheezy 
whelk whelks whelky whelm whelmed whelms whelp whelped whelps when whenas whence 
whens where whereas whereat whereby wherein whereof whereon wheres whereto wherry wherve 
wherves whet whether whets whetted whetter whew whews whey wheyey wheyish wheys 
which whicker whid whidah whidahs whidded whids whiff whiffed whiffer whiffet whiffle 
whiffs whig whigs whil while whiled whiles whilom whilst whim whimper whims 
whimsey whimsy whin whine whined whiner whiners whines whiney whinge whinged whinger 
whinges whinier whinny whins whiny whip whipped whipper whippet whippy whipray whips 
whipsaw whipt whir whirl whirled whirler whirls whirly whirr whirred whirrs whirry 
whirs whish whished whishes whisht whishts whisk whisked whisker whiskey whisks whisky 
whisper whist whisted whistle whists whit white whited whitely whiten whitens whiter 
whites whitest whitey whiteys whither whitier whities whitish whitlow whits whitter whittle 
whity whiz whizz whizzed whizzer whizzes whizzy who whoa whoever whole wholes 
wholism wholly whom whomp whomped whomps whomso whoof whoofed whoofs whoop whooped 
whoopee whooper whoopie whoopla whoops whoosh whoosis whop whopped whopper whops whor 
whore whored whores whorish whorl whorled whorls whort whortle whorts whose whosis 
whoso whump whumped whumps whup whupped whups why whydah whydahs whys wicca 
wiccan wiccans wiccas wich wiches wick wickape wicked wicker wickers wicket wickets 
wickiup wicks wickyup wicopy widder widders widdie widdies widdle widdled widdles widdy 
wide widely widen widened widener widens wideout wider wides widest widgeon widget 
widgets widish widow widowed widower widows width widths wield wielded wielder wields 
wieldy wiener wieners wienie wienies wif wife wifed wifedom wifely wifes wifey 
wifeys wiftier wifty wig wigan wigans wigeon wigeons wigg wigged wiggery wiggier 
wiggle wiggled wiggler wiggles wiggly wiggy wight wights wigless wiglet wiglets wiglike 
wigs wigwag wigwags wigwam wigwams wikiup wikiups wil wilco wild wildcat wilded 
wilder wilders wildest wildish wildly wilds wile wiled wiles wilful wilier wiliest 
wilily will willed willer willers willet willets willful willie willied willies willow 
willows willowy wills willy wilt wilted wilts wily wimble wimbled wimbles wimmin 
wimp wimped wimpier wimpish wimple wimpled wimples wimps wimpy win winc wince 
winced wincer wincers winces wincey winceys winch winched wincher winches wind windage 
windbag winded winder winders windier windigo windily windle windled windles window windows 
windowy windrow winds windup windups windway windy wine wined winery wines winesap 
winesop winey wing wingbow winged winger wingers wingier winglet wingman wingmen wings 
wingtip wingy winier winiest winish wink winked winker winkers winkle winkled winkles 
winks winless winn winned winner winners winnock winnow winnows wino winoes winos 
wins winsome winter winters wintery wintle wintled wintles wintry winy winze winzes 
wip wipe wiped wipeout wiper wipers wipes wir wirable wire wired wireman 
wiremen wirer wirers wires wiretap wireway wirier wiriest wirily wirings wirra wiry 
wis wisdom wisdoms wise wiseass wised wiseguy wisely wisent wisents wiser wises 
wisest wish wisha wished wisher wishers wishes wishful wisp wisped wispier wispily 
wispish wisps wispy wiss wissed wisses wist wisted wistful wists wit witan 
witans witch witched witches witchy wite wited wites with withal withe withed 
wither withers withes withier withies within withins without withy witl witless witloof 
witness witney witneys wits witt witted wittier wittily wittol wittols witty wiv 
wive wived wiver wivern wiverns wivers wives wiz wizard wizards wizen wizened 
wizens wizes wizzen wizzens wizzes wo woad woaded woads woadwax woald woalds 
wobble wobbled wobbler wobbles wobbly wodge wodges woe woeful woeness woes woesome 
woful wofully wog woggish wogs wok woke woken woks wold wolds wolf 
wolfed wolfer wolfers wolfish wolfram wolfs wolver wolvers wolves woman womaned womanly 
womans womb wombat wombats wombed wombier wombs womby women womera womeras wommera 
womyn won wonder wonders wonk wonkier wonks wonky wonn wonned wonner wonners 
wons wont wonted wonton wontons wonts woo wood woodbin woodbox woodcut wooded 
wooden woodhen woodie woodier woodies woodlot woodman woodmen woods woodsia woodsy woodwax 
woody wooed wooer wooers woof woofed woofer woofers woofs wool wooled woolen 
woolens wooler woolers woolhat woolie woolier woolies woolled woollen woolly woolman woolmen 
wools wooly woomera woops woopsed woopses woorali woorari woos woosh wooshed wooshes 
woozier woozily woozy wop wops word wordage worded wordier wordily words wordy 
wore work workbag workbox workday worked worker workers workman workmen workout works 
workup workups world worldly worlds worm wormed wormer wormers wormier wormil wormils 
wormish worms wormy worn worried worrier worries worrit worrits worry worse worsen 
worsens worser worses worset worsets worship worst worsted worsts wort worth worthed 
worths worthy worts wos wost wot wots wott wotted would wouldst wound 
wounded wounds wove woven wovens wow wowed wows wowser wowsers wr wrack 
wracked wracks wraith wraiths wrang wrangle wrangs wrap wrapped wrapper wraps wrapt 
wrasse wrasses wrassle wrastle wrath wrathed wraths wrathy wreak wreaked wreaker wreaks 
wreath wreathe wreaths wreathy wreck wrecked wrecker wrecks wren wrench wrens wrest 
wrested wrester wrestle wrests wretch wrick wricked wricks wried wrier wries wriest 
wriggle wriggly wright wrights wringed wringer wrings wrinkle wrinkly wrist wrists wristy 
writ write writer writers writes writhe writhed writhen writher writhes writs written 
wrong wronged wronger wrongly wrongs wrote wroth wrought wrung wry wryer wryest 
wryly wryneck wryness wud wurst wursts wurzel wurzels wushu wuss wusses wussier 
wussies wussy wuther wuthers wych wyches wye wyes wyl wyle wyled wyles 
wyn wynd wynds wynn wynns wyns wyt wyte wyted wytes wyvern wyverns 
yarrow yarrows yaw yawed yawey yawl yawled yawls yawn yawned yawner yawners 
yawns yawp yawped yawper yawpers yawps yaws yellow yellows yellowy yew yews 
yow yowe yowed yowes yowie yowies yowl yowled yowler yowlers yowls yows 
ywis zowie
);

my @G_words = qw(
aah aargh aarrgh aarrghh abas abat abid abigail ablings abod abought abridge 
abus aby ac ach acreage acrogen act actings adage adages adagial adagio 
adagios add addl adjudge ador adz aegis aegises aerogel aerugo aerugos afghan 
afghani afghans ag aga again against agama agamas agamete agamic agamid agamids 
agamous agapae agapai agape agapeic agapes agar agaric agarics agarose agars agas 
agate agates agatize agatoid agave agaves agaze age aged agedly agee ageings 
ageism ageisms ageist ageists ageless agelong agemate agency agenda agendas agendum agene 
agenes agenize agent agented agentry agents ager agers ages aggada aggadah aggadas 
aggadic aggadot agger aggers aggie aggies aggrade aggress aggro aggros agha aghas 
aghast agile agilely agility agin agings aginner agio agios agism agisms agist 
agisted agists agita agitas agitate agitato aglare agleam aglee aglet aglets agley 
aglow agly aglycon agma agmas agnail agnails agnate agnates agnatic agnize agnized 
agnizes agnomen agnosia ago agog agon agonal agone agones agonic agonies agonise 
agonist agonize agons agony agora agorae agoras agorot agoroth agouti agoutis agouty 
agrafe agrafes agraffe agrapha agravic agree agreed agrees agria agrias aground ags 
ague agues aguish ah aid aiglet aiglets aigret aigrets ail aim air 
airbag airbags airglow airings airt ajuga ajugas alang alegar alegars alga algae 
algal algas algebra algid algin algins algoid algor algors algum algums alight 
alights align aligned aligner aligns alin allege alleged alleger alleges allegro allergy 
allonge ally almug almugs along alright amalgam amaz ambage ambages ambl amiga 
amigas amigo amigos among amongst amp amus anagoge anagogy anagram analgia analog 
analogs analogy anel anergia anergic anergy anga angakok angaria angary angas angel 
angeled angelic angels angelus anger angered angerly angers angina anginal anginas angioma 
angl angle angled angler anglers angles anglice anglo anglos angora angoras angrier 
angrily angry angst angsts anguine anguish angular anhinga ankl anlage anlagen anlages 
ant ante antibug antifog antigay antigen antigun antilog antings antisag ap apagoge 
apanage aphagia apogamy apogeal apogean apogee apogees apogeic apolog apologs apology arc 
arch arck argal argala argalas argali argalis argals argent argents argil argils 
argl argle argled argles argol argols argon argons argosy argot argotic argots 
argu argue argued arguer arguers argues argufy argus arguses argyle argyles argyll 
argylls aright aris arm armiger armings arraign arrange arugola arugula ash ask 
askings assagai assegai assign assigns assuage asswage ataghan atingle aton auberge aud 
audings augend augends auger augers aught aughts augite augites augitic augment augur 
augural augured augurer augurs augury august auto avenge avenged avenger avenges average 
avgas avgases avow aw awak awe aweigh awn awnings ax azygos azygous 
baa baby bach back backlog badg badge badged badger badgers badges baff 
bag bagass bagasse bagel bagels bagful bagfuls bagg baggage bagged bagger baggers 
baggie baggier baggies baggily baggy baglike bagman bagmen bagnio bagnios bagpipe bags 
bagsful baguet baguets bagwig bagwigs bagworm bail bait bak bakings bal bald 
balk ball bamm ban band bandage bandog bandogs bang banged banger bangers 
bangkok bangle bangles bangs bank bann banteng bar barb bard barege bareges 
barf barg bargain barge barged bargee bargees barges bark barn barong barongs 
barr barrage bas bash bask bast bat batgirl bath batt batw bawl 
bay be bead beagle beagles beam bean beanbag bear bearhug beat beck 
beclog beclogs bedbug bedbugs bedd bedgown bedight bedrug bedrugs beef beep beflag 
beflags befog befogs beg begall begalls began begat begaze begazed begazes beget 
begets begg beggar beggars beggary begged begin begins begird begirds begirt beglad 
beglads begloom begone begonia begorah begorra begot begrim begrime begrims begroan begs 
beguile beguine begulf begulfs begum begums begun beige beiges beigne beignes beignet 
beigy beings belga belgas bell belong belongs belt beluga belugas bely bend 
benign berg bergere bergs berm besiege best bett bewig bewigs bhang bhangra 
bhangs bias bibb bid bidd biff big bigamy bigeye bigeyes bigfeet bigfoot 
bigg bigger biggest biggety biggie biggies biggin biggins biggish biggity biggy bighead 
bighorn bight bighted bights bigly bigness bigos bigoses bigot bigoted bigotry bigots 
bigs bigtime bigwig bigwigs bik bilg bilge bilged bilges bilgier bilgy bilk 
bill billbug biltong bind bing binge binged binger bingers binges bingo bingoes 
bingos binn biog biogas biogen biogens biogeny biogs biology bird birddog birl 
birr bisnaga bit bitt biznaga blad blam blar blaw blaz blight blights 
blighty blog blogger blogs blow blowgun blu bludge bludged bludger bludges blue 
bluegum bluings blum blunge blunged blunger blunges bo boat bobb bod bodega 
bodegas bodings body boff bog bogan bogans bogart bogarts bogbean bogey bogeyed 
bogeys bogg bogged boggier boggish boggle boggled boggler boggles boggy bogie bogies 
bogle bogles bogs bogus bogusly bogwood bogy bogyism bogyman bogymen boil boings 
boll bologna bolt bomb bon bond bondage bong bonged bongo bongoes bongos 
bongs bonk boo boob booger boogers boogey boogeys boogie boogied boogies boogy 
book boom boot bootleg booz bopp bor borage borages borings bork borough 
boscage boskage boss bough boughed boughs bought bougie bougies bourg bourgs bous 
bow bowings bowl bowleg bowlegs bows box boxings br brac brag bragged 
bragger braggy brags brak brav bray braz bregma brew brewage brib bridge 
bridged bridges brig brigade brigand bright brights brigs brin bringer brings brogan 
brogans brogue brogues brok brokage brought brugh brughs brung brut brux bubinga 
buck budd budg budge budged budger budgers budges budget budgets budgie budgies 
buff bug bugaboo bugbane bugbear bugeye bugeyes bugg bugged bugger buggers buggery 
buggier buggies buggy bugl bugle bugled bugler buglers bugles bugloss bugout bugouts 
bugs bugseed bugsha bugshas bulg bulge bulged bulger bulgers bulges bulghur bulgier 
bulgur bulgurs bulgy bulk bulkage bull bulldog bumm bump bung bunged bungee 
bungees bungle bungled bungler bungles bungs bunk bunt buoy buoyage burg burgage 
burgee burgees burgeon burger burgers burgess burgh burghal burgher burghs burglar burgle 
burgled burgles burgoo burgoos burgout burgs burk burl burn burp burr bury 
bus busgirl bush bushpig busings busk buss bust busy butl butt buy 
buzz buzzwig bygone bygones byrl cabb cabbage cabbagy cabl cach cadg cadge 
cadged cadger cadgers cadges cadgy cag cage caged cageful cager cagers cages 
cagey cagier cagiest cagily cagy cak calk call calm calv camp campong 
can cangue cangues cann cant cantdog capp car card cargo cargoes cargos 
cark carl carnage carp cart cartage carv cas cash casings cask cast 
catalog catgut catguts catjang catl catt caught caus cav cavings caw ceas 
ced ceil cell cens cer cess chaf chagrin chang change changed changer 
changes changs char charge charged charger charges chas chaw chef chegoe chegoes 
chew chid chigger chignon chigoe chigoes chim chin chinwag chok chor choragi 
choregi chough choughs chow chug chugged chugger chugs chut cig cigar cigaret 
cigars cigs cingula cit cl clag clagged clags clang clanged clanger clangor 
clangs claught claw clay clep clergy clew clinged clinger clings clingy clog 
clogged clogger cloggy clogs clon clos clough cloughs cloy clu clue clung 
coagent coagula coal coam coat coax cock cod codd codger codgers codl 
coff cog cogency cogent cogg cogged cogito cogitos cognac cognacs cognate cognise 
cognize cogon cogons cogs cogway cogways cohog cohogs coif coign coigne coigned 
coignes coigns coil coin coinage cok collage college colog cologne cologs colugo 
colugos com comb comings comp con condign conga congaed congas conge congeal 
congee congeed congees conger congers conges congest congii congius congo congoes congos 
congou congous conk conn consign coo cook cool coop cop copings copp 
copy cor cord cordage coreign corgi corgis cork corkage corn corsage cortege 
cosh cosign cosigns cost cosy cot cotinga cottage cougar cougars cough coughed 
cougher coughs coup courage cov covings cow cowage cowages cowgirl cowhage cowl 
cox coxalgy coy coydog coydogs cozy crag cragged craggy crags cran crannog 
crap crat crav craz crep crew cringe cringed cringer cringes cringle crow 
cry cryogen cu cub cubage cubages cudgel cudgels cue cuff cull culm 
cunn cupp cur curagh curaghs curb curd curl curr curragh curs curv 
cuss cutt cuttage cyborg cyborgs cycl cygnet cygnets cyml d dabb dadgum 
dado daff dag dagga daggas dagger daggers daggle daggled daggles daglock dago 
dagoba dagobas dagoes dagos dags dagwood damage damaged damager damages damm damn 
damp danc dang danged danger dangers dangle dangled dangler dangles dangly dangs 
dapp dar darings dark darl darn dart dash dat daub daut daw 
dawn dawt dayglow daylong daz deal dean deav debag debags debug debugs 
decagon decalog deck deed deem defang defangs defog defogs defrag defrags defy 
degage degame degames degami degamis degas degases degauss degerm degerms deglaze degrade 
degree degreed degrees degum degums degust degusts deic deign deigned deigns dek 
deke dele delight deluge deluged deluges delv demagog demerge demigod demo dengue 
dengues denn dent deny deraign derange design designs desugar deterge deuc dew 
diagram dial dialog dialogs dibb dic dick die diet dig digamma digamy 
digest digests digg digged digger diggers dight dighted dights digit digital digits 
diglot diglots dignify dignity digoxin digraph digress digs dik dimm din ding 
dingbat dinge dinged dinger dingers dinges dingey dingeys dinghy dingier dingies dingily 
dingle dingles dingo dingoes dings dingus dingy dink dinn dint dipp dirge 
dirges dirk dirl dirtbag disc disgust dish dishrag disk diss div diverge 
divulge do doat dock dockage dodg dodge dodged dodgem dodgems dodger dodgers 
dodgery dodges dodgier dodgy doff dog dogbane dogcart dogdom dogdoms doge dogear 
dogears dogedom doges dogey dogeys dogface dogfish dogg dogged dogger doggers doggery 
doggie doggier doggies doggish doggo doggone doggrel doggy dogie dogies dogleg doglegs 
doglike dogma dogmas dogmata dognap dognaps dogs dogsled dogtrot dogvane dogwood dogy 
doings dol doll dom dong donga dongas dongle dongles dongola dongs donn 
doom dop dopings dorbug dorbugs dos dosage dosages doss dot dotage dotages 
dott dough doughs dought doughty doughy dous dow dowager down dows doz 
drag dragee dragees dragged dragger draggle draggy dragnet dragon dragons dragoon drags 
drap draught draw dray drayage dredge dredged dredger dredges dree dreg dreggy 
dregs dreigh driegh driv drogue drogues dron drongo drongos drought drov drudge 
drudged drudger drudges drug drugged drugget druggie druggy drugs dry dubb duck 
duct dud dudgeon duel duet dug dugong dugongs dugout dugouts dugs duk 
dull dumb dump dung dunged dungeon dungier dungs dungy dunk dunn dunnage 
dunt duolog duologs dup dupp dur durn dusk dust dustrag dwin dy 
dye dyeings dyings dyk eager eagerer eagerly eagers eagl eagle eagled eagles 
eaglet eaglets eagre eagres eanl ear earings earn earplug earr earwig earwigs 
eas east eat eatings ebb ech echo eclogue ecology ecotage eddy edg 
edge edged edger edgers edges edgier edgiest edgily edgings edgy edit educ 
effigy effulge egad egads egal egalite eger egers egest egesta egested egests 
egg eggar eggars eggcup eggcups egged egger eggers egghead eggless eggnog eggnogs 
eggs eggy egis egises ego egoism egoisms egoist egoists egoless egos egotism 
egotist egress egret egrets eight eighth eighths eights eightvo eighty ek elat 
elegant elegiac elegies elegise elegist elegit elegits elegize elegy elid eloign eloigns 
elop elud elut embargo emerge emerged emerges emigre emigres emot encage encaged 
encages end endgame endings endlong endogen endu energid energy eng engage engaged 
engager engages engild engilds engine engined engines engird engirds engirt english englut 
engluts engorge engraft engrail engrain engram engrams engrave engross engs engulf engulfs 
enigma enigmas enlarge enology enough enoughs enrage enraged enrages ensign ensigns ensu 
enur envy epergne epigeal epigean epigeic epigene epigon epigone epigoni epigons epigram 
epigyny epilog epilogs eras erelong erg ergate ergates ergo ergodic ergot ergotic 
ergots ergs eringo eringos erlk erod err erugo erugos eryngo eryngos escuage 
espy etagere etch eugenia eugenic eugenol euglena eulogia eulogy evad evangel even 
evit evok ex exegete exergue exigent exil exit exogamy exogen exogens expunge 
exud ey eye fabl fac facings fad fadg fadge fadged fadges fadings 
fag fagg fagged faggier faggot faggots faggoty faggy fagin fagins fagot fagoted 
fagoter fagots fags fail fair fak fall fam fanega fanegas fang fanga 
fangas fanged fangs fann far farc fard farm farrago fart fash fast 
fat fatigue fatl fatt faugh fawn fax fay faz fear feas feaz 
fee feed feedbag feel feez feign feigned feigner feigns fell felt fenagle 
fenc fend fess fet fett feu feud fibb fidg fidge fidged fidges 
fidget fidgets fidgety fif fig figg figged fight fighter fights figment figs 
figural figure figured figurer figures figwort fil filibeg filings fill film fin 
finagle find finger fingers finings fink finn fir firebug firedog firings firm 
fish fishgig fist fitt fix fixings fizgig fizgigs fizz fl flag flagged 
flagger flaggy flagman flagmen flagon flagons flags flak flam flange flanged flanger 
flanges flar flaw flay fleabag fledge fledged fledges fledgy flee flex fley 
flight flights flighty flinger flings flit flog flogged flogger flogs flong flongs 
flotage flow flowage fluk flum flung flut flux fly flyings flyt foal 
foam fobb fodgel fog fogbow fogbows fogdog fogdogs fogey fogeys fogg foggage 
fogged fogger foggers foggier foggily foggy foghorn fogie fogies fogless fogs fogy 
fogyish fogyism foil foin fold foliage fond fool foot footage footbag fopp 
forage foraged forager forages forc ford forego foregut foreign foreleg forg forgat 
forgave forge forged forger forgers forgery forges forget forgets forgive forgo forgoer 
forgoes forgone forgot fork form fought foul fourgon fowl fox foxings frag 
fragged fragile frags fram fraught fray free freight fridge fridges frig frigate 
friges frigged fright frights frigid frigs fringe fringed fringes fringy friz frog 
frogeye frogged froggy froglet frogman frogmen frogs fromage frug frugal frugged frugs 
fry fubb fudg fudge fudged fudges fuel fug fugal fugally fugato fugatos 
fugg fugged fuggier fuggily fuggy fugio fugios fugl fugle fugled fugles fugs 
fugu fugue fugued fugues fuguist fugus fulgent fulgid full fum fund fungal 
fungals fungi fungic fungo fungoes fungoid fungous fungus funk funn furl furlong 
furr fus fuss futz fuz fuzz gab gabb gabbard gabbart gabbed gabber 
gabbers gabbier gabble gabbled gabbler gabbles gabbro gabbros gabby gabelle gabfest gabies 
gabion gabions gabl gable gabled gables gaboon gaboons gabs gaby gad gadd 
gadded gadder gadders gaddi gaddis gadfly gadget gadgets gadgety gadi gadid gadids 
gadis gadje gadjo gadoid gadoids gadroon gads gadwall gae gaed gaen gaes 
gaff gaffe gaffed gaffer gaffers gaffes gaffs gag gaga gagaku gagakus gage 
gaged gager gagers gages gagg gagged gagger gaggers gaggle gaggled gaggles gagman 
gagmen gags gagster gahnite gaiety gaijin gaily gain gained gainer gainers gainful 
gainly gains gainsay gainst gait gaited gaiter gaiters gaits gal gala galabia 
galago galagos galah galahs galanga galas galatea galax galaxes galaxy gale galea 
galeae galeas galeate galena galenas galenic galere galeres gales galette galilee galiot 
galiots galipot gall gallant gallate galled gallein galleon gallery gallet galleta gallets 
galley galleys gallfly gallic gallica gallied gallies galliot gallium gallnut gallon gallons 
galloon galloot gallop gallops gallous gallows galls gallus gally galoot galoots galop 
galoped galops galore galores galosh galoshe gals galumph galyac galyacs galyak galyaks 
gam gama gamas gamay gamays gamb gamba gambade gambado gambas gambe gambes 
gambia gambias gambier gambir gambirs gambit gambits gamble gambled gambler gambles gamboge 
gambol gambols gambrel gambs game gamed gamelan gamely gamer gamers games gamest 
gametal gamete gametes gametic gamey gamic gamier gamiest gamily gamin gamine gamines 
gamings gamins gamm gamma gammas gammed gammer gammers gammier gammon gammons gammy 
gamp gamps gams gamut gamuts gamy gan ganache gander ganders gane ganef 
ganefs ganev ganevs gang ganged ganger gangers ganglia gangly gangrel gangs gangsta 
gangue gangues gangway ganja ganjah ganjahs ganjas gannet gannets ganof ganofs ganoid 
ganoids gantlet gantry gaol gaoled gaoler gaolers gaols gap gape gaped gaper 
gapers gapes gapless gaposis gapp gapped gappier gappy gaps gapy gar garage 
garaged garages garb garbage garbagy garbed garble garbled garbler garbles garboil garbs 
garcon garcons garda gardai gardant garden gardens garfish garget gargets gargety gargle 
gargled gargler gargles garigue garish garland garlic garlics garment garner garners garnet 
garnets garni garnish garote garoted garotes garotte garpike garr garred garret garrets 
garron garrons garrote gars garter garters garth garths garvey garveys gas gasbag 
gasbags gascon gascons gaseity gaseous gases gash gashed gasher gashes gashest gasify 
gask gasket gaskets gaskin gaskins gasless gaslit gasman gasmen gasohol gasp gasped 
gasper gaspers gasps gass gassed gasser gassers gasses gassier gassily gassy gast 
gasted gaster gasters gastral gastrea gastric gastrin gasts gat gate gateau gateaus 
gateaux gated gateman gatemen gater gaters gates gateway gather gathers gatings gator 
gators gats gauche gaucher gaucho gauchos gaud gaudery gaudier gaudies gaudily gauds 
gaudy gauffer gaug gauge gauged gauger gaugers gauges gault gaults gaum gaumed 
gaums gaun gaunt gaunter gauntly gauntry gaur gaurs gauss gausses gauze gauzes 
gauzier gauzily gauzy gavage gavages gave gavel gaveled gavels gavial gavials gavot 
gavots gavotte gawk gawked gawker gawkers gawkier gawkies gawkily gawkish gawks gawky 
gawp gawped gawper gawpers gawps gawsie gawsy gay gayal gayals gaydar gaydars 
gayer gayest gayety gayly gayness gays gaz gazabo gazabos gazania gazar gazars 
gaze gazebo gazebos gazed gazelle gazer gazers gazes gazette gazoo gazoos gazump 
gazumps gear gearbox geared gears geck gecked gecko geckoes geckos gecks ged 
geds gee geed geegaw geegaws geek geekdom geeked geekier geeks geeky gees 
geese geest geests geez geezer geezers geisha geishas gel gelable gelada geladas 
gelant gelants gelate gelated gelates gelati gelatin gelatis gelato gelatos gelcap gelcaps 
geld gelded gelder gelders gelds gelee gelees gelid gelidly gell gellant gelled 
gels gelt gelts gem geminal gemlike gemm gemma gemmae gemmate gemmed gemmier 
gemmily gemmule gemmy gemot gemote gemotes gemots gems gemsbok gen gender genders 
gene genera general generic genes geneses genesis genet genetic genets genette geneva 
genevas genial genic genie genies genii genip genipap genips genital genitor genius 
genoa genoas genoise genom genome genomes genomic genoms genre genres genro genros 
gens genseng gent genteel gentes gentian gentil gentile gentle gentled gentler gentles 
gently gentoo gentoos gentry gents genu genua genuine genus genuses geode geodes 
geodesy geodic geoduck geoid geoidal geoids geology georgic gerah gerahs gerbera gerbil 
gerbils gerent gerents gerenuk germ german germane germans germen germens germier germina 
germs germy gerund gerunds gesso gessoed gessoes gest gestalt gestapo gestate geste 
gestes gestic gests gesture get geta getable getas getaway gets gett getter 
getters getup getups geum geums gewgaw gewgaws gey geyser geysers gharial gharri 
gharris gharry ghast ghastly ghat ghats ghaut ghauts ghazi ghazies ghazis ghee 
ghees gherao gherkin ghetto ghettos ghi ghibli ghiblis ghillie ghis ghost ghosted 
ghostly ghosts ghosty ghoul ghoulie ghouls ghyll ghylls giant giants giaour giaours 
giardia gib gibb gibbed gibber gibbers gibbet gibbets gibbon gibbons gibbose gibbous 
gibe gibed giber gibers gibes giblet giblets gibs gibson gibsons gid giddap 
giddied giddier giddies giddily giddy giddyap giddyup gids gie gied gien gies 
gift gifted giftee giftees gifts gig giga gigabit gigas gigaton gigg gigged 
giggle giggled giggler giggles giggly gighe giglet giglets giglot giglots gigolo gigolos 
gigot gigots gigs gigue gigues gilbert gild gilded gilder gilders gilds gill 
gilled giller gillers gillie gillied gillies gillnet gills gilly gilt gilts gimbal 
gimbals gimel gimels gimlet gimlets gimmal gimmals gimme gimmes gimmick gimmie gimmies 
gimp gimped gimpier gimps gimpy gin gingal gingall gingals gingeli gingely ginger 
gingers gingery gingham gingili gingiva gingko gingkos gink ginkgo ginkgos ginks ginn 
ginned ginner ginners ginnier ginny gins ginseng ginzo ginzoes gip gipon gipons 
gipp gipped gipper gippers gips gipsied gipsies gipsy giraffe girasol gird girded 
girder girders girdle girdled girdler girdles girds girl girlie girlier girlies girlish 
girls girly girn girned girns giro girolle giron girons giros girosol girsh 
girshes girt girted girth girthed girths girts gisarme gismo gismos gist gists 
git gitano gitanos gite gites gits gitt gitted gittern gittin giv give 
given givens giver givers gives gizmo gizmos gizzard gjetost glace glaceed glaces 
glacial glacier glacis glad gladded gladden gladder glade glades gladier gladly glads 
glady glaiket glaikit glair glaire glaired glaires glairs glairy glaive glaived glaives 
glam glamor glamors glamour glams glance glanced glancer glances gland glandes glands 
glans glar glare glared glares glarier glary glass glassed glasses glassie glassy 
glaz glaze glazed glazer glazers glazes glazier glazily glazy gleam gleamed gleamer 
gleams gleamy glean gleaned gleaner gleans gleba glebae glebe glebes gled glede 
gledes gleds glee gleed gleeds gleeful gleek gleeked gleeks gleeman gleemen glees 
gleet gleeted gleets gleety gleg glegly glen glenoid glens gley gleyed gleys 
glia gliadin glial glias glib glibber glibly glid glide glided glider gliders 
glides gliff gliffs glim glime glimed glimes glimmer glimpse glims glint glinted 
glints glinty glioma gliomas glisten glister glitch glitchy glitter glitz glitzed glitzes 
glitzy gloam gloams gloat gloated gloater gloats glob global globate globby globe 
globed globes globin globins globoid globose globous globs globule glochid glogg gloggs 
glom glomera glommed gloms glomus glonoin gloom gloomed glooms gloomy glop glopped 
gloppy glops gloria glorias gloried glories glorify glory gloss glossa glossae glossal 
glossas glossed glosser glosses glossy glost glosts glottal glottic glottis glout glouted 
glouts glov glove gloved glover glovers gloves glow glowed glower glowers glowfly 
glows gloz gloze glozed glozes glu glucan glucans glucose glue glued gluepot 
gluer gluers glues gluey glug glugged glugs gluier gluiest gluily glum glume 
glumes glumly glummer glumpy glums glunch gluon gluons glut glute gluteal glutei 
gluten glutens glutes gluteus gluts glutted glutton glycan glycans glycin glycine glycins 
glycol glycols glycyl glycyls glyph glyphic glyphs glyptic gnar gnarl gnarled gnarls 
gnarly gnarr gnarred gnarrs gnars gnash gnashed gnashes gnat gnathal gnathic gnats 
gnatty gnaw gnawed gnawer gnawers gnawn gnaws gneiss gnocchi gnome gnomes gnomic 
gnomish gnomist gnomon gnomons gnoses gnosis gnostic gnu gnus go goa goad 
goaded goads goal goaled goalie goalies goals goanna goannas goas goat goatee 
goateed goatees goatish goats gob goban gobang gobangs gobans gobb gobbed gobbet 
gobbets gobble gobbled gobbler gobbles gobies gobioid goblet goblets goblin goblins gobo 
goboes gobonee gobony gobos gobs goby god godd goddam goddamn goddams godded 
goddess godet godetia godets godhead godhood godl godless godlier godlike godlily godly 
godown godowns godroon gods godsend godship godson godsons godwit godwits goer goers 
goes gofer gofers goffer goffers goggle goggled goggler goggles goggly goglet goglets 
gogo gogos goings goiter goiters goitre goitres gold goldarn goldbug golden golder 
goldest goldeye golds goldurn golem golems golf golfed golfer golfers golfs goliard 
goliath golly golosh goloshe gombeen gombo gombos gomer gomeral gomerel gomeril gomers 
gomuti gomutis gonad gonadal gonadic gonads gondola gone gonef gonefs goner goners 
gong gonged gongs gonia gonidia gonidic gonif goniff goniffs gonifs gonion gonium 
gonof gonofs gonoph gonophs gonzo goo goober goobers good goodby goodbye goodbys 
goodie goodies goodish goodly goodman goodmen goods goody gooey goof goofed goofier 
goofily goofs goofy googly googol googols gooier gooiest gook gooks gooky goombah 
goombay goon gooney gooneys goonie goonier goonies goons goony goop goopier goops 
goopy gooral goorals goos goose goosed gooses goosey goosier goosy gopher gophers 
gopik gor goral gorals gorcock gordita gore gored gores gorg gorge gorged 
gorger gorgers gorges gorget gorgets gorgon gorgons gorhen gorhens gorier goriest gorilla 
gorily gorm gormand gormed gorms gorp gorps gorse gorses gorsier gorsy gory 
gos gosh goshawk gosl gospel gospels gosport gossan gossans gossip gossips gossipy 
gossoon got gotcha gotchas goth gothic gothics gothite goths gotten gouache goug 
gouge gouged gouger gougers gouges goulash gourami gourd gourde gourdes gourds gourmet 
gout goutier goutily gouts gouty govern governs gowan gowaned gowans gowany gowd 
gowds gowk gowks gown gowned gowns gox goxes goy goyim goyish goys 
graal graals grab grabbed grabber grabble grabby graben grabens grabs grac grace 
graced graces gracile grackle grad gradate grade graded grader graders grades gradin 
gradine gradins grads gradual gradus graft grafted grafter grafts graham grahams grail 
grails grain grained grainer grains grainy gram grama gramary gramas gramma grammar 
grammas gramme grammes gramp grampa grampas gramps grampus grams gran grana granary 
grand grandad grandam grandee grander grandly grandma grandpa grands grange granger granges 
granita granite grannie granny granola grans grant granted grantee granter grantor grants 
granule granum grape grapery grapes grapey graph graphed graphic graphs grapier graplin 
grapnel grappa grappas grapple grapy grasp grasped grasper grasps grass grassed grasses 
grassy grat grate grated grater graters grates gratify gratin gratine gratins gratis 
graupel grav grave graved gravel gravels gravely graven graver gravers graves gravest 
gravid gravida gravies gravity gravlax gravure gravy gray grayed grayer grayest grayish 
graylag grayly grayout grays graz graze grazed grazer grazers grazes grazier grease 
greased greaser greases greasy great greaten greater greatly greats greave greaved greaves 
grebe grebes grecize gree greed greeds greedy greek green greened greener greenie 
greenly greens greenth greeny grees greet greeted greeter greets grego gregos greige 
greiges greisen gremial gremlin gremmie gremmy grenade grew grey greyed greyer greyest 
greyhen greyish greylag greyly greys gribble grid gridded gridder griddle gride grided 
grides grids grief griefs grieve grieved griever grieves griff griffe griffes griffin 
griffon griffs grift grifted grifter grifts grig grigri grigris grigs grill grille 
grilled griller grilles grills grilse grilses grim grimace grime grimed grimes grimier 
grimily grimly grimmer grimy grin grinch grind grinded grinder grinds gringa gringas 
gringo gringos grinned grinner grins griot griots grip gripe griped griper gripers 
gripes gripey gripier gripman gripmen grippe gripped gripper grippes gripple grippy grips 
gript gripy griskin grisly grison grisons grist grister gristle gristly grists grit 
grith griths grits gritted gritter gritty grivet grivets grizzle grizzly groan groaned 
groaner groans groat groats grocer grocers grocery grodier grody grog groggy grogram 
grogs groin groined groins grok grokked groks grommet groom groomed groomer grooms 
groove grooved groover grooves groovy grop grope groped groper gropers gropes gross 
grossed grosser grosses grossly grosz grosze groszy grot grots grotto grottos grotty 
grouch grouchy ground grounds group grouped grouper groupie groups grouse groused grouser 
grouses grout grouted grouter grouts grouty grove groved grovel grovels groves grow 
grower growers growl growled growler growls growly grown grownup grows growth growths 
growthy groyne groynes grub grubbed grubber grubby grubs grudge grudged grudger grudges 
grue gruel grueled grueler gruels grues gruff gruffed gruffer gruffly gruffs gruffy 
grugru grugrus grum grumble grumbly grume grumes grummer grummet grumose grumous grump 
grumped grumphy grumps grumpy grunge grunger grunges grungy grunion grunt grunted grunter 
gruntle grunts grushie grutch grutten gruyere gryphon guaco guacos guaiac guaiacs guan 
guanaco guanase guanay guanays guanin guanine guanins guano guanos guans guar guarana 
guarani guard guarded guarder guards guars guava guavas guayule guck gucks gude 
gudes gudgeon guenon guenons guerdon guess guessed guesser guesses guest guested guests 
guff guffaw guffaws guffs guggle guggled guggles guglet guglets guid guide guided 
guider guiders guides guidon guidons guids guil guild guilder guilds guile guiled 
guiles guilt guilts guilty guimpe guimpes guinea guineas guipure guiro guiros guis 
guisard guise guised guises guitar guitars gul gulag gulags gular gulch gulches 
gulden guldens gules gulf gulfed gulfier gulfs gulfy gull gulled gullet gullets 
gulley gulleys gullied gullies gulls gully gulp gulped gulper gulpers gulpier gulps 
gulpy guls gum gumball gumbo gumboil gumboot gumbos gumdrop gumless gumlike gumline 
gumm gumma gummas gummata gummed gummer gummers gummier gummite gummose gummous gummy 
gums gumshoe gumtree gumweed gumwood gun gunboat gundog gundogs gunfire gunite gunites 
gunk gunkier gunks gunky gunless gunlock gunman gunmen gunn gunned gunnel gunnels 
gunnen gunner gunners gunnery gunnies gunny gunplay gunroom guns gunsel gunsels gunship 
gunshot gunwale guppies guppy gurg gurge gurged gurges gurgle gurgled gurgles gurglet 
gurnard gurnet gurnets gurney gurneys gurries gurry gursh gurshes guru gurus gush 
gushed gusher gushers gushes gushier gushily gushy gusset gussets gussie gussied gussies 
gussy gust gusted gustier gustily gusto gustoes gusts gusty gut gutless gutlike 
guts gutsier gutsily gutsy gutt gutta guttae guttate gutted gutter gutters guttery 
guttier guttle guttled guttler guttles gutty guv guvs guy guyed guyline guyot 
guyots guys guzzle guzzled guzzler guzzles gweduc gweduck gweducs gwine gyb gybe 
gybed gybes gym gymnast gyms gynecia gynecic gyoza gyozas gyp gyplure gypp 
gypped gypper gyppers gyps gypsied gypsies gypster gypsum gypsums gypsy gyr gyral 
gyrally gyrase gyrases gyrate gyrated gyrates gyrator gyre gyred gyrene gyrenes gyres 
gyri gyro gyron gyrons gyros gyrose gyrus gyttja gyttjas gyv gyve gyved 
gyves hack had hae haft hag hagadic hagborn hagbush hagbut hagbuts hagdon 
hagdons hagfish hagg haggada haggard hagged haggis haggish haggle haggled haggler haggles 
hagride hagrode hags hail hal halo halogen halt halv hamburg hamm hand 
handbag handgun hang hangar hangars hangdog hanged hanger hangers hangman hangmen hangout 
hangs hangtag hangul hangup hangups hank hant happ har hark harm harp 
hash hasp hast hat hatt haugh haughs haughty haul haulage hav haw 
hawk hay hayings haylage haz hazings head heal heap hear heat heav 
hedg hedge hedged hedger hedgers hedges hedgier hedgy heed heel heez heft 
hegari hegaris hegemon hegira hegiras hegumen heigh height heighth heights heil heir 
hell helm help helv hemagog hemm henge henges hent herbage herd herr 
heugh heughs hew hex hexagon hid hidalgo hidings hie higgle higgled higgler 
higgles high highboy higher highest highly highs hight highted highth highths hightop 
hights highway hik hild hill hilt hindgut hing hinge hinged hinger hingers 
hinges hint hipp hir hiss hist hitt hiv hoagie hoagies hoagy hoax 
hobb hobo hock hoe hog hogan hogans hogback hogfish hogg hogged hogger 
hoggers hogget hoggets hoggish hoggs hoglike hogmane hognose hognut hognuts hogs hogtie 
hogtied hogties hogwash hogweed hois hok hol hold holk hom homage homaged 
homager homages homburg homolog hon hong hongi hongied hongies hongs honk hood 
hoof hook hoop hoosgow hoot hop hopp hord horn hors hos host 
hostage hotdog hotdogs hott hous howk howl huff hug huge hugely hugeous 
huger hugest hugg hugged hugger huggers hugs hulk hull humbug humbugs humm 
hump hung hunger hungers hungry hunt hurl hurt hush husk hutt hy 
hygeist hygiene hymn hyp hypo hypogea ic iceberg icings idl igg igged 
iggs igloo igloos iglu iglus ignatia igneous ignify ignite ignited igniter ignites 
ignitor ignoble ignobly ignore ignored ignorer ignores iguana iguanas iguanid illegal illogic 
imag image imaged imager imagers imagery images imagine imagism imagist imago imagoes 
imagos imbu immerge imp impinge impings impregn impugn impugns inbe incage incaged 
incages inch incog incogs indigen indign indigo indigos indu indulge infight ingate 
ingates ingenue ingest ingesta ingests ingle ingles ingo ingot ingoted ingots ingraft 
ingrain ingrate ingress ingroup ingrown ingulf ingulfs ink inkl inly inn innage 
innages innings insight insigne intagli integer inur inveigh ionogen ir iris irk 
iron isagoge isl isogamy isogeny isogon isogone isogons isogony isogram isogriv isolog 
isologs issu itch item jabb jack jackleg jad jaeger jaegers jag jager 
jagers jagg jaggary jagged jagger jaggers jaggery jaggier jaggies jaggs jaggy jagless 
jagra jagras jags jaguar jaguars jail jamb jamm jangle jangled jangler jangles 
jangly jap jargon jargons jargony jargoon jarr jauk jaup jaw jaygee jaygees 
jazz jee jeep jeer jell jerk jess jest jetlag jetlags jett jew 
jib jibb jig jigaboo jigg jigged jigger jiggers jiggier jiggish jiggle jiggled 
jiggles jiggly jiggy jiglike jigs jigsaw jigsawn jigsaws jilt jingal jingall jingals 
jingko jingle jingled jingler jingles jingly jingo jingoes jink jinx jiv jobb 
jog jogg jogged jogger joggers joggle joggled joggler joggles jogs join jok 
jolt josh jott jouk jow joy judg judge judged judger judgers judges 
jug juga jugal jugate jugful jugfuls jugg jugged juggle juggled juggler juggles 
jughead jugs jugsful jugula jugular jugulum jugum jugums juic juk jump jungle 
jungled jungles jungly junk jury just jutt k kagu kagus kalong kalongs 
kampong kart kayo keck kedg kedge kedged kedges keek keel keelage keen 
keep keg kegeler kegg kegged kegger keggers kegl kegler keglers kegs kelp 
kenn kepp kerb kerf kern kerogen kerygma key kiang kiangs kiaugh kiaughs 
kick kidd kill kiln kilt king kingcup kingdom kinged kinglet kingly kingpin 
kings kink kipp kirn kiss kit kitbag kitbags kith kitl kitt kleagle 
klong klongs kludge kludged kludges kludgey kludgy klug kluge kluged kluges knee 
knif knight knights know konk kugel kugels kurgan kurgans kyth l laager 
laagers lac lacings lack lad ladings ladl ladybug lag lagan lagans lagend 
lagends lager lagered lagers lagg laggard lagged lagger laggers lagoon lagoons lags 
laguna lagunas lagune lagunes laigh laighs lair lak lakings lall lam lamb 
lamm lamp lanc land lang langley langrel langue langues languet languid languor 
langur langurs lanugo lanugos laogai laogais lapdog lapdogs lapp laps lapw lard 
large largely larger larges largess largest largish largo largos lark las lasagna 
lasagne lash last lath latigo latigos laud laugh laughed laugher laughs lav 
lavage lavages law lawings lay laz lazy lead leaf leafage league leagued 
leaguer leagues leak leakage lean leap leas leav lech ledge ledger ledgers 
ledges ledgier ledgy leer leg legacy legal legally legals legate legated legatee 
legates legato legator legatos legend legends leger legers leges legg legged leggier 
leggin leggins leggy leghorn legible legibly legion legions legist legists legit legits 
legless leglike legman legmen legong legongs legroom legs legume legumes legumin legwork 
lekk lemm lend length lengths lengthy lens lentigo lett levy liang liangs 
lick lidd liege lieges lift ligan ligand ligands ligans ligase ligases ligate 
ligated ligates liger ligers light lighted lighten lighter lightly lights lignan lignans 
lignify lignin lignins lignite ligroin ligula ligulae ligular ligulas ligule ligules ligure 
ligures lik likings lilt lim limb limn limp lin linage linages lineage 
linga lingam lingams lingas lingcod linger lingers lingier lingo lingoes lings lingua 
linguae lingual lingula lingy linings link linkage linsang lint lipp lisp list 
liturgy liv livings load loaf loam loan lobb lock lockage loco lodg 
lodge lodged lodger lodgers lodges loft log logan logania logans logbook loge 
loges logg loggats logged logger loggers loggets loggia loggias loggie loggier loggish 
loggy logia logic logical logics logier logiest logily login logins logion logions 
logjam logjams logo logoi logon logons logos logroll logs logway logways logwood 
logy loid loll long longan longans longbow longe longed longer longers longes 
longest longies longish longly longs loo look loom loop loos loot lop 
lopp lord lorgnon los losings lott lough loughs lounge lounged lounger lounges 
loungy loup lour lous lout lov lovage lovages lovebug low lowings lox 
lozenge lub luck luff lug luge luged luger lugers luges lugg luggage 
lugged lugger luggers luggie luggies lugs lugsail lugworm lull lumbago lump lung 
lungan lungans lunge lunged lungee lungees lunger lungers lunges lungful lungi lungis 
lungs lungyi lungyis lunt lur lurk lush lust lut lutings ly lyingly 
lyings lys lysogen mac madd mag magalog mage magenta mages maggot maggots 
maggoty magi magian magians magic magical magics magilp magilps maglev maglevs magma 
magmas magmata magnate magnet magneto magnets magnify magnum magnums magot magots magpie 
magpies mags maguey magueys magus mahjong mahuang maigre mail mailbag maim majagua 
mak makings malanga malgre malign maligns mall malt manage managed manager manages 
manege maneges manga mangaby mangas mange mangel mangels manger mangers manges mangey 
mangier mangily mangle mangled mangler mangles mango mangoes mangold mangos mangy mann 
mapp marengo margay margays marge margent marges margin margins mark marl marr 
mart mash mask maskeg maskegs mass massage mast mat matings matt mauger 
maugre maul maw max may mayings maz meager meagre mean medigap meet 
meg mega megabar megabit megahit megapod megara megaron megass megasse megaton megilla 
megilp megilph megilps megohm megohms megrim megrims megs melange meld mell melt 
meltage menage menages mend mendigo mens meou meow merg merge merged mergee 
mergees merger mergers merges mesh meshuga mess message met metage metages metatag 
metr mew mewl mich midge midges midget midgets midgut midguts midleg midlegs 
miff mig migg miggle miggles miggs might mights mighty mignon mignons migrant 
migrate migs mik milage milages milchig mild mileage milk mill millage milt 
mim min minc mind mingier mingle mingled mingler mingles mingy minings mint 
mintage mir mirage mirages misgave misgive misgrew misgrow mispage miss mist mitogen 
mitr mix moan moat mobb mock mog mogg mogged moggie moggies moggy 
moghul moghuls mogs mogul moguled moguls moil mold molt monger mongers mongo 
mongoe mongoes mongol mongols mongos mongrel mongst monolog montage moo moon moor 
moorage moot mop mopp morgan morgans morgen morgens morgue morgues morn mosh 
moss moulage mous mov mow mowings muck mudbug mudbugs mudd muff mug 
mugful mugfuls mugg muggar muggars mugged muggee muggees mugger muggers muggier muggily 
muggins muggs muggur muggurs muggy mughal mughals mugs mugwort mugwump mul mull 
mumm mump mungo mungoes mungos munt mur mus mush musings muskeg muskegs 
muss must mustang mut mutagen myalgia myalgic myology nabb naff nag nagana 
naganas nagg nagged nagger naggers naggier naggy nags nail nam nametag napp 
nargile nark naught naughts naughty near neck need neg negate negated negater 
negates negaton negator neglect neglige negroid negroni negs negus neguses neigh neighed 
neighs neogene neology nerv nest nett ngwee nibb nich nick nid nidget 
nidgets nigella niggard nigger niggers niggle niggled niggler niggles niggly nigh nighed 
nigher nighest nighs night nightie nightly nights nighty nigrify nilgai nilgais nilgau 
nilgaus nilghai nilghau nill nimm nipp nix nock nodd nog nogg nogged 
noggin noggins noggs nogs nois nonage nonages nonagon nondrug nonego nonegos nongame 
nongay nongays nonwage noodge noodged noodges noogie noogies noon noos nos nosebag 
nosegay nosh nosings not noth nougat nougats nought noughts nudg nudge nudged 
nudger nudgers nudges nugget nuggets nuggety nuk null numb nurl nurs nutgall 
nutmeg nutmegs nutt nylghai nylghau oar obey oblige obliged obligee obliger obliges 
obligor oblong oblongs ochr octagon off offings ogam ogams ogdoad ogdoads ogee 
ogees ogham oghamic oghams ogival ogive ogives ogl ogle ogled ogler oglers 
ogles ogre ogreish ogreism ogres ogress ogrish ogrism ogrisms oh ohmage ohmages 
oil oink okay olingo olingos ologies ologist ology omega omegas omen onager 
onagers onagri ongo onstage oogamy oogeny oogonia ooh oologic oology oolong oolongs 
ooz op open opin oppugn oppugns opt orang orange oranges orangey orangs 
orangy orat orb oregano organ organa organdy organic organon organs organum organza 
orgasm orgasms orgeat orgeats orgiac orgiast orgic orgies orgone orgones orgy origami 
origan origans origin origins orogeny orology otalgia otalgic otalgy otology ouch ought 
oughted oughts ouguiya ourang ourangs oust out outage outages outbeg outbegs outbrag 
outdrag outgain outgas outgave outgaze outgive outglow outgnaw outgo outgoes outgone outgrew 
outgrin outgrow outgun outguns outgush outings outr outrage outrang outrig outrigs outrung 
outs outsang outsung over overage overbig overdog ow own oxygen oxygens p 
pac pack package padd padnag padnags pag pagan pagans page pageant pageboy 
paged pageful pager pagers pages paginal pagings pagod pagoda pagodas pagods pagurid 
paik pain pair pal palings pall palm palp pang panga pangas panged 
pangen pangene pangens pangram pangs pann pant par paragon parang parangs parerga 
parg parge parged parges parget pargets pargo pargos parings park parl parr 
pars part pash pass passage past patagia patt paughty paus pav pavings 
paw pawn pawnage pay peac peag peage peages peags peak peal pech 
peck pedagog pee peek peel peen peep peer peerage peev peg pegbox 
pegg pegged pegless peglike pegs pein peis pelage pelages pelagic pelt penang 
penangs pend pengo pengos penguin penn peonage pepp pergola perigee perigon periwig 
perk perm pett pfennig phage phages phas phlegm phlegms phlegmy phon photog 
photogs pi pick pidgin pidgins pie piec pierogi pig pigboat pigeon pigeons 
pigfish pigg pigged piggery piggie piggier piggies piggin piggins piggish piggy piglet 
piglets piglike pigment pigmies pigmy pignoli pignora pignus pignut pignuts pigout pigouts 
pigpen pigpens pigs pigskin pigsney pigsty pigtail pigweed pik pil pilgrim pilings 
pill pillage pimp pin pinang pinangs ping pinged pinger pingers pingo pingoes 
pingos pings pinguid pink pinn pip pipage pipages pipeage pipings pipp piqu 
piragua pirog pirogen piroghi pirogi pirogue pish pishoge piss pith pitt pity 
plac plagal plage plages plague plagued plaguer plagues plaguey plaguy plan plat 
play pledge pledged pledgee pledger pledges pledget pledgor plight plights plough ploughs 
plow ploy plug plugged plugger plugola plugs plum plumage plunge plunged plunger 
plunges ply pock podagra podd podgier podgily podgy pogey pogeys pogies pogonia 
pogonip pogrom pogroms pogy pois pok pol poll polygon ponc pond pong 
ponged pongee pongees pongid pongids pongs pony poo pooh pool poop popgun 
popguns popp por porgies porgy pork port portage pos post postage postbag 
potage potages pott pottage pour pout pox prang pranged prangs prat pray 
preaged pree pregame prepreg presage presong prey pric prid prig prigged prigs 
prim primage pris priz prob probang prodigy prodrug prog progeny progged progger 
program progs progun proleg prolegs prolog prologs prolong prong pronged prongs pros 
protege prov prun prurigo pry pudd pudgier pudgily pudgy puff pug pugaree 
pugg pugged puggier puggish puggree puggry puggy pugh pugmark pugree pugrees pugs 
puk pul pulings pull pulp puls pump pung pungent pungle pungled pungles 
pungs punn punt pupp purg purge purged purger purgers purges purl purr 
purs push putlog putlogs putt putz pygidia pygmean pygmies pygmoid pygmy pyrogen 
quag quagga quaggas quaggy quags quahaug quahog quahogs quaigh quaighs quak quango 
quangos quayage queu quir quohog quohogs quot r rac racings rack radd 
raft rag raga ragas ragbag ragbags rage raged ragee ragees rages ragg 
ragged raggedy raggee raggees raggies raggle raggles raggs raggy ragi ragis raglan 
raglans ragman ragmen ragout ragouts rags ragtag ragtags ragtime ragtop ragtops ragweed 
ragwort raid rail rain rais rak ramm ramp rampage rang range ranged 
ranger rangers ranges rangier rangy rank rant rap rapp rar ras rasp 
rat ratbag ratbags ratings ratt rav ravage ravaged ravager ravages ravings rax 
ray raz razz read reagent reagin reagins realgar realign ream reap rear 
reargue reav rebegan rebegin rebegun reck red redbug redbugs redd redleg redlegs 
redo redw reed reef reek reel reev reff refight reflag reflags reforge 
refuge refuged refugee refuges refugia reg regain regains regal regale regaled regaler 
regales regalia regally regard regards regatta regauge regave regear regears regency regent 
regents reges reggae reggaes regild regilds regilt regime regimen regimes regina reginae 
reginal reginas region regions regius regive regiven regives reglaze reglet reglets regloss 
reglow reglows reglue reglued reglues regma regmata regna regnal regnant regnum regorge 
regosol regrade regraft regrant regrate regreen regreet regress regret regrets regrew regrind 
regroom regroup regrow regrown regrows regs regular reguli regulus rehang rehangs rehinge 
rehung reign reigned reigns reimage rein reiv rejig rejigs rejudge relight rely 
remerge remiges rend renege reneged reneger reneges renig renigs rent repeg repegs 
repp repugn repugns rerig rerigs resight resign resigns rest restage resurge retag 
retags rett rety reus revenge revv reweigh rhym ribb ric rick rid 
ridd ridg ridge ridged ridgel ridgels ridges ridgier ridgil ridgils ridgy ridings 
riff rifl rift rig rigg rigged rigger riggers right righted righter rightly 
righto rights righty rigid rigidly rigor rigors rigour rigours rigs ril rill 
rim rimm ring ringed ringent ringer ringers ringgit ringlet rings ringtaw rinn 
rins riot rip ripp ris risings risk riv rivage rivages roam roar 
rob robb rock rodd roger rogered rogers rogu rogue rogued roguery rogues 
roguish roil rolf roll romp rontgen roof rook room roos root rootage 
rop ros rotgut rotguts rott roug rouge rouged rouges rough roughed roughen 
rougher roughly roughs roughy roup rous rout rov rovings row rowings ru 
rubb rubigo rubigos ruby ruch ruck ruff rug ruga rugae rugal rugate 
rugbies rugby rugg rugged rugger ruggers ruglike rugola rugolas rugosa rugosas rugose 
rugous rugs ruin rul rulings rummage rung rungs runn rush rust rutt 
ryk s sabb sabe sabr sack sacr sag saga sagaman sagamen sagas 
sagbut sagbuts sage sagely sager sages sagest sagg saggar saggard saggars sagged 
sagger saggers saggier saggy sagier sagiest sago sagos sags saguaro sagum sagy 
saiga saigas sail sain salt salv salvage san sand sandbag sandhog sang 
sanga sangar sangars sangas sanger sangers sangh sanghs sangria sapl sapp sapsago 
sarge sarges sargo sargos sarong sarongs sash sass sat satang satangs sauc 
sauger saugers saugh saughs saughy sausage sav savage savaged savager savages savings 
saw sawlog sawlogs say sayings scag scags scal scalage scap scar scop 
scor scourge scow scrag scraggy scrags scraigh scroggy scrooge scrouge scry scumbag 
scutage seabag seabags seadog seadogs seagirt seagull seal seam sear seat sedge 
sedges sedgier sedgy see seed seeings seek seel seem seep seepage seg 
segetal seggar seggars segment segni segno segnos sego segos segs segue segued 
segues sein seis seiz self sell selvage semilog send senega senegas sengi 
sens septage ser serfage serg serge serged serger sergers serges seringa serpigo 
serv sett sevruga sew sewage sewages sewings sex shad shag shagged shaggy 
shags shak sham shap shar shaugh shaughs shav shaw shebang shegetz sheugh 
sheughs shew shin shindig shingle shingly shoe shog shogged shogi shogis shogs 
shogun shoguns shoo shor shotgun shov show shrug shrugs shut shy siamang 
sibl sicc sick sid sidings sidl sieg siege sieged sieges siev sift 
siganid sigh sighed sigher sighers sighs sight sighted sighter sightly sights sigil 
sigils sigla sigloi siglos siglum sigma sigmas sigmate sigmoid sign signa signage 
signal signals signed signee signees signer signers signet signets signify signior signor 
signora signore signori signors signory signs silage silages silk silo silt sing 
singe singed singer singers singes single singled singles singlet singly sings sink 
sinkage sinn sip sipp sir sit sitt siz sizings skag skags skat 
skee skeg skegs skeigh skew ski skiings skit skiv skreegh skreigh sky 
sl slag slagged slaggy slags slak slang slanged slangs slangy slat slav 
slay sledge sledged sledges sleigh sleighs sleight slew slic slid slight slights 
slim slinger slings slip slog slogan slogans slogged slogger slogs slop slough 
sloughs sloughy slow slu sludge sludged sludges sludgy slug slugged slugger slugs 
slumgum slung smaragd smegma smegmas smidge smidgen smidges smidgin smil smit smog 
smoggy smogs smok smudge smudged smudges smudgy smug smugger smuggle smugly snag 
snagged snaggy snags snak snar snaw snigger sniggle sniglet snip snog snogged 
snogs snor snow snug snugged snugger snuggle snugly snugs soak soakage soap 
soar sobb socage socager socages soccage sock sodd sogged soggier soggily soggy 
soigne soignee soil soilage sol solfege solgel solo solv song songful songs 
soot sopp sor sorb sorgho sorghos sorghum sorgo sorgos sorings sorn sort 
sough soughed soughs sought soup sour sous sow spac spad spae spang 
spangle spangly spar sparge sparged sparger sparges spay spew spic spiegel spigot 
spigots spik spil spinage spir spit splodge splurge splurgy spok sponge sponged 
sponger sponges spongin spongy spor spr sprag sprags sprang sprangs sprig spriggy 
spright sprigs springe springs springy sprug sprugs sprung spu spum spurge spurges 
spy squeg squegs st stag stage staged stager stagers stages stagey stagged 
stagger staggie staggy stagier stagily stags stagy staig staigs stak stal stalag 
stalags stan stang stanged stangs star stat stav stay stengah stew stigma 
stigmal stigmas stinger stingo stingos stings stingy stodge stodged stodges stodgy stogey 
stogeys stogie stogies stogy stok ston stooge stooged stooges stop stopgap stor 
storage stow stowage str strang strange strigil strings stringy strong strung stung 
sty stygian styl su subb subgoal subgum subgums subr suck suds sued 
sugar sugared sugarer sugars sugary suggest sugh sughed sughs suit sulk sullage 
summ sundog sundogs sung sunglow sunn supp surf surg surge surged surgeon 
surger surgers surgery surges surgy suss sw swag swage swaged swager swagers 
swages swagged swagger swaggie swagman swagmen swags swang sway swig swigged swigger 
swigs swingby swinge swinged swinger swinges swingle swings swingy swip swiv swung 
synagog sync synergy syngamy syngas syntagm syringa syringe syzygal syzygy t tabb 
tabl tabu tack tag tagg taggant tagged tagger taggers taglike tagline tagmeme 
tagrag tagrags tags taiga taigas tail tak takings talc talk tallage tam 
tamp tanager tang tanga tanged tangelo tangent tangier tangle tangled tangler tangles 
tangly tango tangoed tangos tangram tangs tangy tank tankage tann tannage tap 
tapp tar targe targes target targets tarr tart task tast tatt taught 
taut tautaug tautog tautogs taw taws tax taxi taxy team tear teargas 
teas tedd tee teem teenage teg tegg teggs tegmen tegmina tegs tegua 
teguas tegular tegumen telega telegas tell temp tend tenge tens tent tentage 
terga tergal tergite tergum term test teugh teughly tew th thalweg thanage 
thaw thegn thegnly thegns them thenage theolog theurgy thigh thighed thighs things 
thol thong thonged thongs thou though thought throng throngs through thug thuggee 
thugs ticc tick tid tidings tidy tie tier tiff tiger tigers tight 
tighten tighter tightly tights tiglon tiglons tigon tigons tigress tigrish til tilings 
till tillage tilt tim timings tin ting tinge tinged tinges tingle tingled 
tingler tingles tingly tings tinn tint tipp tir tirl tith titl toe 
tog toga togae togaed togas togate togated togg togged toggery toggle toggled 
toggler toggles togs togue togues toil toit tok tol toll tollage tomb 
tomm ton tong tonga tongas tonged tonger tongers tongman tongmen tongs tongue 
tongued tongues tonight tonnage tool toot top topp toss tot tott tough 
toughed toughen tougher toughie toughly toughs toughy tour tous tout tow towage 
towages toy trac trad tragedy tragi tragic tragics tragus trangam tree trepang 
triage triaged triages tric trig trigged trigger trigly trigo trigon trigons trigos 
trigram trigs trilogy trin trog trogon trogons trogs trok trough troughs trow 
tru truc trudge trudged trudgen trudger trudges true trug trugs try tsk 
tub tubb tubings tuck tuft tug tugboat tugg tugged tugger tuggers tughrik 
tugless tugrik tugriks tugs tump tun tung tungs tunn tunnage tupp turf 
turgent turgid turgite turgor turgors turn tush tusk tutt twang twanged twanger 
twangle twangs twangy twig twigged twiggen twiggy twigs twin twinge twinged twinges 
ty tyn typ tyr tyth tzigane ufology ugh ughs uglier uglies ugliest 
uglify uglily ugly ugsome ullage ullaged ullages umbrage ump unag unaged unagile 
unbe uncage uncaged uncages unclog unclogs undergo undo undy uneager ungated ungird 
ungirds ungirt unglove unglue unglued unglues ungodly ungot ungual unguard unguent ungues 
unguis ungula ungulae ungular unhang unhangs unhinge unhung unit unitage unpaged unpeg 
unpegs unplug unplugs unrig unrigs unrough unsight unsl unslung unsnag unsnags unstung 
unsung unty unurged unwrung unyoung upfl upflung upgaze upgazed upgazes upgird upgirds 
upgirt upgo upgrade upgrew upgrow upgrown upgrows uplight upp uppings upright upstage 
upsurge upsw upswung uptight urg urge urged urgency urgent urger urgers urges 
urology urp us usage usages vagal vagally vagary vagi vagile vagina vaginae 
vaginal vaginas vagrant vagrom vague vaguely vaguer vaguest vagus vail valgoid valgus 
valu valv vamp vang vangs vann vantage vary vatt veal veer veg 
vegan vegans veges vegetal vegete vegg vegged veggie veggies vegie vegies veil 
vein veliger vend veng venge venged venges vent ventage verg verge verged 
verger vergers verges verglas vers vertigo vest vestige veto vett vex vial 
vic vicugna view vig viga vigas vigia vigias vigil vigils vigor vigors 
vigour vigours vigs vik vikings village vin vinegar vintage virago viragos virga 
virgas virgate virgin virgins virgule vis visa visage visaged visages vise vogie 
vogu vogue vogued voguer voguers vogues voguish voic void vol voltage vorlage 
vot vow voyage voyaged voyager voyages vug vugg vuggier vuggs vuggy vugh 
vughs vugs vulgar vulgars vulgate vulgo vulgus vy vyingly w wad wadd 
waff waft waftage wag wage waged wager wagered wagerer wagers wages wagg 
wagged wagger waggers waggery waggish waggle waggled waggles waggly waggon waggons wagon 
wagoned wagoner wagons wags wagsome wagtail waif wail wair wait waiv wak 
wal walk wall wan wangan wangans wangle wangled wangler wangles wangun wanguns 
wanigan wank wann want wantage wapp war ward wark warm warn warp 
warpage warr warthog wash washrag wast wastage wattage waugh waught waughts wauk 
waul wav wawl wax waxings waxw wean wear weav webb weblog weblogs 
webpage wedd wedg wedge wedged wedges wedgie wedgier wedgies wedgy weed ween 
weep weet weigela weigh weighed weigher weighs weight weights weighty weld well 
welt wend wendigo wergeld wergelt wergild west wett whal whang whanged whangee 
whangs whig whigs whil whin whinge whinged whinger whinges whit whor wick 
widgeon widget widgets wif wig wigan wigans wigeon wigeons wigg wigged wiggery 
wiggier wiggle wiggled wiggler wiggles wiggly wiggy wight wights wigless wiglet wiglets 
wiglike wigs wigwag wigwags wigwam wigwams wil wild will wilt wimp win 
winc wind windage windbag windigo wing wingbow winged winger wingers wingier winglet 
wingman wingmen wings wingtip wingy wink winn wip wir wirings wis wiseguy 
wish wisp wiss wist wit with witl witt wiv wodge wodges wog 
woggish wogs wolf wonn wont woo wood woof word wordage work workbag 
worm wott wow wr wrang wrangle wrangs wriggle wriggly wright wrights wringed 
wringer wrings writ wrong wronged wronger wrongly wrongs wrought wrung wry wyl 
wyt yack yaff yag yager yagers yagi yagis yags yakk yang yangs 
yank yapp yard yardage yarn yatagan yaup yaw yawl yawn yawp yeal 
yean yegg yeggman yeggmen yeggs yell yelp yenn yerk yess yeuk yipp 
yirr yock yodl yoga yogas yogee yogees yogh yoghs yoghurt yogi yogic 
yogin yogini yoginis yogins yogis yogurt yogurts yok young younger youngs yow 
yowl yuck yuga yugas yukk z zaftig zag zagg zagged zags zapp 
zero zest zeugma zeugmas zig zigg zigged zigs zigzag zigzags zinc zing 
zingani zingano zingara zingare zingari zingaro zinged zinger zingers zingier zings zingy 
zipp zoftig zon zonk zoogeny zooglea zoology zoom zoon zygoid zygoma zygomas 
zygose zygoses zygosis zygote zygotes zygotic zymogen zymurgy     
);

my @P_words = qw(
abamp abamps abrupt acaleph acapnia accept accepts adapt adapted adapter adaptor adapts 
adept adepter adeptly adepts adipic adipose adipous adopt adopted adoptee adopter adopts 
agapae agapai agape agapeic agapes agrapha airdrop airpark airplay airport airpost airship 
aleph alephs aliped alipeds alp alpaca alpacas alpha alphas alphorn alphyl alphyls 
alpine alpines alps amp amped ampere amperes amphora ample ampler amplest amplify 
amply ampoule amps ampul ampule ampules ampulla ampuls amputee anapest anaphor anopia 
anopias anopsia antipot ap apace apache apaches apagoge apanage aparejo apart apathy 
apatite ape apeak aped apeek apelike aper apercu apercus aperies apers apery 
apes apetaly apex apexes aphagia aphasia aphasic aphelia apheses aphesis aphetic aphid 
aphides aphids aphis aphonia aphonic aphotic aphtha aphthae aphylly apian apiary apical 
apicals apices apiculi apiece apish apishly aplasia aplenty aplite aplites aplitic aplomb 
aplombs apnea apneal apneas apneic apnoea apnoeal apnoeas apnoeic apo apocarp apocope 
apod apodal apodous apods apogamy apogeal apogean apogee apogees apogeic apollo apollos 
apolog apologs apology apolune apomict aporia aporias aport apos apostil apostle apothem 
app appal appall appalls appals apparat apparel appeal appeals appear appears appease 
appel appels append appends applaud apple apples applet applets applied applier applies 
apply appoint appose apposed apposer apposes apprise apprize approve apps appulse apraxia 
apraxic apres apricot apron aproned aprons apropos aprotic apse apses apsidal apsides 
apsis apt apter apteral apteria apteryx aptest aptly aptness apyrase arepa arepas 
armpit armpits arpen arpens arpent arpents aruspex asepses asepsis aseptic asleep aslope 
asp aspect aspects aspen aspens asper aspers asperse asphalt asphyxy aspic aspics 
aspire aspired aspirer aspires aspirin aspis aspises aspish asps atap ataps atop 
atopic atopies atopy atrip atrophy atropin attempt atypic auspex auspice autopen autopsy 
baaskap backup backups bagpipe bap baps baptise baptism baptist baptize barhop barhops 
barkeep bebop bebops becap becaps beclasp bedlamp bedpan bedpans bedpost bedrape beep 
beeped beeper beepers beeps beleap beleaps beleapt bellhop benempt bepaint bespake bespeak 
bespoke bethump beweep beweeps bewept bewrap bewraps bewrapt bicep biceps bimorph biochip 
biopic biopics biopsic biopsy bioptic biotope biotype bipack bipacks biparty biped bipedal 
bipeds biplane bipod bipods bipolar bishop bishops bitmap bitmaps bleep bleeped bleeper 
bleeps blimp blimps blip blipped blips bloop blooped blooper bloops blowup blowups 
bluecap blype blypes bop bopeep bopeeps bopp bopped bopper boppers bops bowpot 
bowpots breakup brewpub brushup buildup bullpen bump bumped bumper bumpers bumph bumphs 
bumpier bumpily bumpkin bumps bumpy bupkes bupkus buppie buppies buppy burlap burlaps 
burp burped burps bushpig bypass bypast bypath bypaths byplay byplays cajaput cajeput 
cajuput calipee caliper caliph caliphs calpac calpack calpacs calpain caltrap caltrop calypso 
camp camped camper campers camphol camphor campi campier campily campion campo campong 
campos campout camps campus campy canape canapes canopic canopy cantrap cantrip cap 
capable capably cape caped capelan capelet capelin caper capered caperer capers capes 
capful capfuls caph caphs capias capita capital capitol capiz capizes capless caplet 
caplets caplin caplins capo capon capons caporal capos capote capotes capouch capp 
capped capper cappers capric caprice caprine capris caprock caps capsid capsids capsize 
capstan capsule captain captan captans caption captive captor captors capture capuche caput 
carapax carhop carhops carp carpal carpale carpals carped carpel carpels carper carpers 
carpet carpets carpi carpool carport carps carpus cartop catalpa catchup catnap catnaps 
catnip catnips catspaw catsup catsups cep cepe cepes cepheid ceps ceriph ceriphs 
cesspit chalupa champ champac champak champed champer champs champy chap chapati chape 
chapeau chapel chapels chapes chaplet chapman chapmen chapped chappie chaps chapt chapter 
charpai charpoy cheap cheapen cheaper cheapie cheaply cheapo cheapos cheaps checkup cheep 
cheeped cheeper cheeps chimp chimps chip chipped chipper chippie chippy chips chirp 
chirped chirper chirps chirpy chirrup chomp chomped chomper chomps chop chopin chopine 
chopins chopped chopper choppy chops chump chumped chumps chuppa chuppah chuppas chutzpa 
cipher ciphers ciphony cipolin clamp clamped clamper clamps clap clapped clapper claps 
clapt clasp clasped clasper clasps claspt claypan cleanup clep clepe cleped clepes 
clept clip clipped clipper clips clipt clomp clomped clomps clop clopped clops 
closeup clump clumped clumps clumpy clupeid clypeal clypei clypeus coalpit coapt coapted 
coapts cockpit cockup cockups coempt coempts collop collops comp compact company compare 
compart compas compass comped compeer compel compels compend compere compete compile complex 
complin complot comply compo compone compony comport compos compose compost compote comps 
compt compted compts compute comsymp concept cooktop coop cooped cooper coopers coopery 
coops coopt coopted coopts cop copaiba copal copalm copalms copals copay copays 
cope copeck copecks coped copen copens copepod coper copers copes copied copier 
copiers copies copihue copilot copings copious coplot coplots copout copouts copp copped 
copper coppers coppery coppice coppra coppras copra coprah coprahs copras cops copse 
copses copter copters copula copulae copular copulas copy copyboy copycat copyist corpora 
corps corpse corpses corpus corrupt cotype cotypes coup coupe couped coupes couple 
coupled coupler couples couplet coupon coupons coups coverup cowflap cowflop cowpat cowpats 
cowpea cowpeas cowpie cowpies cowplop cowpoke cowpox cowslip coypou coypous coypu coypus 
crackup cramp cramped crampit crampon cramps crampy crap crape craped crapes crapola 
crapped crapper crappie crappy craps creep creeped creeper creepie creeps creepy crep 
crepe creped crepes crepey crepier crepon crepons crept crepy crimp crimped crimper 
crimple crimps crimpy cripe cripes cripple crisp crisped crispen crisper crisply crisps 
crispy crop cropped cropper croppie crops croup croupe croupes croups croupy crump 
crumped crumpet crumple crumply crumps crupper crypt cryptal cryptic crypto cryptos crypts 
culpa culpae culprit cup cupcake cupel cupeled cupeler cupels cupful cupfuls cupid 
cupids cuplike cupola cupolas cupp cuppa cuppas cupped cupper cuppers cuppier cuppy 
cupric cuprite cuprous cuprum cuprums cups cupsful cupula cupulae cupular cupule cupules 
cusp cuspal cuspate cusped cuspid cuspids cuspis cusps cutup cutups cyclops cypher 
cyphers cypres cypress cyprian cyprus cypsela dalapon damp damped dampen dampens damper 
dampers dampest dampish damply damps dap daphne daphnes daphnia dapp dapped dapper 
dapple dappled dapples daps dapsone dashpot dauphin deadpan decamp decamps decapod decrypt 
decuple deep deepen deepens deeper deepest deeply deeps delphic demirep depaint depart 
departs depend depends deperm deperms depict depicts deplane deplete deplore deploy deploys 
deplume depone deponed depones deport deports deposal depose deposed deposer deposes deposit 
depot depots deprave depress deprive depside depth depths depute deputed deputes deputy 
desktop despair despise despite despoil despond despot despots develop dewdrop dewlap dewlaps 
diaper diapers diapir diapirs diapsid digraph dimorph dimple dimpled dimples dimply diopter 
dioptre dip diphase diplex diploe diploes diploic diploid diploma diplont dipnet dipnets 
dipnoan dipodic dipody dipolar dipole dipoles dipp dipped dipper dippers dippier dippy 
dips dipsas dipshit dipso dipsos dipt diptera diptyca diptych discept dishpan dispart 
dispel dispels dispend display disport dispose dispute disrupt dognap dognaps dollop dollops 
dolphin doowop doowops dop dopa dopant dopants dopas dope doped doper dopers 
dopes dopey dopier dopiest dopily dopings dopy dorp dorper dorpers dorps drap 
drape draped draper drapers drapery drapes drapey drip dripped dripper drippy drips 
dript droop drooped droops droopy drop droplet dropout dropped dropper drops dropsy 
dropt drupe drupes duckpin dump dumped dumper dumpers dumpier dumpily dumpish dumps 
dumpy duopoly dup dupable dupe duped duper dupers dupery dupes duple duplex 
dupp dupped dups dustpan dustup dustups dyspnea eardrop earflap earlap earlaps earplug 
eclipse ecotype ectopia ectopic ectypal ectype ectypes edaphic eelpout eggcup eggcups ekpwele 
elapid elapids elapine elapse elapsed elapses ellipse elop elope eloped eloper elopers 
elopes empale empaled empaler empales empanel empathy emperor empery empire empires empiric 
emplace emplane employ employe employs emporia empower empress emprise emprize emptied emptier 
empties emptily emptins empty empyema encamp encamps enclasp encrypt endopod endplay enplane 
enrapt entopic entrap entraps entropy envelop enwrap enwraps epact epacts eparch eparchs 
eparchy epaulet epazote epee epeeist epees epeiric epergne epha ephah ephahs ephas 
ephebe ephebes ephebi ephebic epheboi ephebos ephebus ephedra ephod ephods ephor ephoral 
ephori ephors epiboly epic epical epicarp epicene epics epicure epiderm epidote epigeal 
epigean epigeic epigene epigon epigone epigoni epigons epigram epigyny epilate epilog epilogs 
epimer epimere epimers epinaoi epinaos episcia episode episome epistle epitaph epitaxy epithet 
epitome epitope epizoa epizoic epizoon epoch epochal epochs epode epodes eponym eponyms 
eponymy epopee epopees epos eposes epoxide epoxied epoxies epoxy epoxyed epsilon equip 
equips erepsin erupt erupted erupts escalop escape escaped escapee escaper escapes escarp 
escarps espanol esparto espial espials espied espies espouse esprit esprits espy estop 
estops etape etapes eupepsy euphony euphroe euploid eupnea eupneas eupneic eupnoea euripi 
euripus example exapted except excepts excerpt exciple exempla exempt exempts exocarp expand 
expands expanse expat expats expect expects expel expels expend expends expense expert 
experts expiate expire expired expirer expires expiry explain explant explode exploit explore 
expo export exports expos exposal expose exposed exposer exposes exposit expound express 
expulse expunge eyecup eyecups eyespot faceup felspar fillip fillips fipple fipples firepan 
firepot flap flapped flapper flappy flaps flareup flatcap flattop fleapit flip flipped 
flipper flippy flips flop flopped flopper floppy flops flump flumped flumps flypast 
flytrap foldup foldups footpad fop fopp fopped foppery foppish fops forceps forepaw 
foretop fowlpox frap frappe frapped frappes fraps frump frumps frumpy frypan frypans 
funplex fusspot galipot gallop gallops galop galoped galops galumph gamp gamps gap 
gape gaped gaper gapers gapes gapless gaposis gapp gapped gappier gappy gaps 
gapy garpike gasp gasped gasper gaspers gasps gawp gawped gawper gawpers gawps 
gazump gazumps gelcap gelcaps genip genipap genips gestapo getup getups giddap giddyap 
giddyup gimp gimped gimpier gimps gimpy gip gipon gipons gipp gipped gipper 
gippers gips gipsied gipsies gipsy glimpse glop glopped gloppy glops gluepot glumpy 
glyph glyphic glyphs glyptic godship gonoph gonophs goop goopier goops goopy gopher 
gophers gopik gorp gorps gospel gospels gosport gossip gossips gossipy gramp grampa 
grampas gramps grampus grandpa grape grapery grapes grapey graph graphed graphic graphs 
grapier graplin grapnel grappa grappas grapple grapy grasp grasped grasper grasps graupel 
grip gripe griped griper gripers gripes gripey gripier gripman gripmen grippe gripped 
gripper grippes gripple grippy grips gript gripy grop grope groped groper gropers 
gropes group grouped grouper groupie groups grownup grump grumped grumphy grumps grumpy 
gryphon guimpe guimpes guipure gulp gulped gulper gulpers gulpier gulps gulpy gumdrop 
gunplay gunship guppies guppy gyp gyplure gypp gypped gypper gyppers gyps gypsied 
gypsies gypster gypsum gypsums gypsy haircap hairpin hamper hampers hanaper hangup hangups 
hap hapax hapaxes hapkido hapless haplite haploid haplont haply happ happed happen 
happens happier happily happy haps hapten haptene haptens haptic hardpan hardtop harelip 
harp harped harper harpers harpies harpin harpins harpist harpoon harps harpy harumph 
hasp hasped hasps hatpin hatpins headpin heap heaped heaper heapers heaps heapy 
heeltap helipad help helped helper helpers helpful helps hemp hempen hempie hempier 
hemps hempy hencoop henpeck hep heparin hepatic hepcat hepcats hepper heppest heptad 
heptads heptane heptose herpes hexapla hexapod hiccup hiccups hightop hilltop hip hipbone 
hipless hiplike hipline hiply hipness hipp hipped hipper hippest hippie hippier hippies 
hippish hippo hippos hippy hips hipshot hipster hirple hirpled hirples hispid holdup 
holdups holp holpen hookup hookups hoop hooped hooper hoopers hoopla hooplas hoopoe 
hoopoes hoopoo hoopoos hoops hop hope hoped hopeful hoper hopers hopes hophead 
hoplite hopp hopped hopper hoppers hoppier hopple hoppled hopples hoppy hops hopsack 
hoptoad hospice hotspot hotspur hubcap hubcaps huipil huipils hump humped humper humpers 
humph humphed humphs humpier humps humpy hup huppah huppahs hutzpa hutzpah hutzpas 
hydrops hyp hype hyped hyper hyperon hypers hypes hypha hyphae hyphal hyphen 
hyphens hypnic hypnoid hypo hypoed hypogea hyponea hyponym hypos hypoxia hypoxic hyps 
hyssop hyssops icecap icecaps imp impact impacts impaint impair impairs impala impalas 
impale impaled impaler impales impanel impark imparks impart imparts impasse impaste impasto 
impavid impawn impawns impeach impearl imped impede impeded impeder impedes impel impels 
impend impends imperia imperil impetus imphee imphees impi impiety impinge impings impious 
impis impish implant implead impled implied implies implode implore imply impone imponed 
impones import imports impose imposed imposer imposes impost imposts impound impower impregn 
impresa imprese impress imprest imprint improv improve improvs imps impugn impugns impulse 
impure impurer impute imputed imputer imputes inapt inaptly incept incepts incipit inclasp 
inclip inclips inept ineptly ingroup inkpot inkpots inphase inpour inpours input inputs 
inscape insculp insipid inspan inspans inspect inspire instep insteps inswept inwrap inwraps 
ipecac ipecacs ipomoea irrupt irrupts isopach isopod isopods isospin isotope isotopy isotype 
jackpot jalap jalapic jalapin jalaps jalop jaloppy jalops jalopy jap japan japans 
jape japed japer japers japery japes jasper jaspers jaspery jaup jauped jaups 
jeep jeeped jeepers jeepney jeeps jeopard jetport jimp jimper jimpest jimply jimpy 
jodhpur joseph josephs joypop joypops julep juleps jump jumped jumper jumpers jumpier 
jumpily jumpoff jumps jumpy juniper jupe jupes jupon jupons kajeput kakapo kakapos 
kaliph kaliphs kalpa kalpac kalpacs kalpak kalpaks kalpas kampong kapa kapas kaph 
kaphs kapok kapoks kappa kappas kaput kaputt keep keeper keepers keeps kelep 
keleps kelp kelped kelpie kelpies kelps kelpy kemp kemps kempt kep kepi 
kepis kepp kepped keppen keps kept ketchup kewpie kewpies keypad keypads keypal 
keypals khaph khaphs kickup kickups kidnap kidnaps kingcup kingpin kinship kip kipp 
kipped kippen kipper kippers kips kipskin klepht klephts klepto kleptos knap knapped 
knapper knaps kneecap kneepad kneepan knop knopped knops knosp knosps kop kopeck 
kopecks kopek kopeks koph kophs kopiyka kopje kopjes koppa koppas koppie koppies 
kops kouprey kreep kreeps krypton lamp lampad lampads lampas lamped lampers lampion 
lampoon lamprey lamps lap lapdog lapdogs lapel lapeled lapels lapful lapfuls lapides 
lapilli lapin lapins lapis lapises lapp lapped lapper lappers lappet lappets laps 
lapse lapsed lapser lapsers lapses lapsus laptop laptops lapw larrup larrups layup 
layups leap leaped leaper leapers leaps leapt lempira leopard leper lepers leporid 
leprose leprosy leprous lept lepta leptin leptins lepton leptons letup letups limp 
limpa limpas limped limper limpers limpest limpet limpets limpid limpkin limply limps 
limpsey limpsy lineup lineups linkup linkups lip lipa lipase lipases lipe lipid 
lipide lipides lipidic lipids lipin lipins lipless liplike lipoid lipoids lipoma lipomas 
lipp lipped lippen lippens lipper lippers lippier lippy lipread lips liriope lisp 
lisped lisper lispers lisps lithops lockup lockups lollop lollops lollopy lookup lookups 
loop looped looper loopers loopier loopily loops loopy lop lope loped loper 
lopers lopes lopp lopped lopper loppers loppier loppy lops loup loupe louped 
loupen loupes loups lump lumped lumpen lumpens lumper lumpers lumpier lumpily lumpish 
lumps lumpy lupanar lupin lupine lupines lupins lupous lupulin lupus lupuses lycopod 
lymph lymphs madcap madcaps magilp magilps magpie magpies maintop makeup makeups maniple 
manpack manrope mantrap map maple maples maplike mapp mapped mapper mappers maps 
markup markups marplot matchup mayhap maypole maypop maypops medigap megapod megilp megilph 
megilps meropia meropic metepa metepas metopae metope metopes metopic metopon metump metumps 
midcap midship milksop milpa milpas mips miscopy mishap mishaps miskeep miskept mispage 
mispart mispen mispens misplan misplay mispled misstep misstop mistype mixup mixups mobcap 
mobcaps mockup mockups monopod mop mope moped mopeds moper mopers mopery mopes 
mopey mopier mopiest mopish mopoke mopokes mopp mopped mopper moppers moppet moppets 
mops mopy morph morphed morphia morphic morphin morpho morphos morphs mudcap mudcaps 
mudflap mudpack mugwump mump mumped mumper mumpers mumps murphy muspike myope myopes 
myopia myopias myopic myopies myopy nap napa napalm napalms napas nape napery 
napes naphtha naphtol napkin napkins napless napp nappa nappas nappe napped napper 
nappers nappes nappie nappier nappies nappy naps nauplii neap neaps neep neeps 
neotype nepeta nepetas nephew nephews nephric nephron nepotic netop netops ninepin nip 
nipa nipas nipp nipped nipper nippers nippier nippily nipple nippled nipples nippy 
nips nitpick nondrip nonpaid nonpar nonpast nonpeak nonplay nonplus nonpoor nonpros nonslip 
nonstop nonuple nopal nopales nopals nope noplace notepad nuptial nutpick nymph nympha 
nymphae nymphal nymphet nympho nymphos nymphs occiput occupy octopi octopod octopus octuple 
octuply oedipal offramp oilcamp oilcup oilcups okapi okapis omphali oompah oompahs oomph 
oomphs oophyte oops oosperm oospore op opacify opacity opah opahs opal opaline 
opals opaque opaqued opaquer opaques ope oped open opened opener openers openest 
openly opens opera operand operant operas operate operon operons operose opes ophite 
ophites ophitic opiate opiated opiates opin opine opined opines opinion opioid opioids 
opium opiums opossum oppidan oppose opposed opposer opposes oppress oppugn oppugns ops 
opsin opsins opsonic opsonin opt opted optic optical optics optima optimal optime 
optimes optimum option options opts opulent opuntia opus opuses orlop orlops orphan 
orphans orphic orphism orphrey orpin orpine orpines orpins osprey ospreys ouph ouphe 
ouphes ouphs outcrop outdrop outjump outkeep outkept outleap outpace outpass outpity outplan 
outplay outplod outplot outpoll outport outpost outpour outpray outpull outpush output outputs 
outspan outsped outweep outwept outyelp overapt overlap overpay overply oversup overtip overtop 
ovipara oxlip oxlips oxyphil p pa pablum pablums pabular pabulum pac paca 
pacas pace paced pacer pacers paces pacey pacha pachas pachisi pachuco pacier 
paciest pacific pacify pack package packed packer packers packet packets packly packman 
packmen packs packwax pacs pact paction pacts pacy pad padauk padauks padd 
padded padder padders paddies paddle paddled paddler paddles paddock paddy padi padis 
padle padles padlock padnag padnags padouk padouks padre padres padri padrone padroni 
pads padshah paean paeans paella paellas paeon paeons paesan paesani paesano paesans 
pag pagan pagans page pageant pageboy paged pageful pager pagers pages paginal 
pagings pagod pagoda pagodas pagods pagurid pah pahlavi paid paik paiked paiks 
pail pailful pails pain painch pained painful pains paint painted painter paints 
painty pair paired pairs paisa paisan paisana paisano paisans paisas paise paisley 
pajama pajamas pakeha pakehas pakora pakoras pal palabra palace palaced palaces paladin 
palais palapa palapas palatal palate palates palaver palazzi palazzo pale palea paleae 
paleal paleate paled palely paler pales palest palet paletot palets palette palfrey 
palier paliest palikar palings palish pall palled pallet pallets pallia pallial pallid 
pallier pallium pallor pallors palls pally palm palmar palmary palmate palmed palmer 
palmers palmful palmier palmist palms palmtop palmy palmyra palooka palp palpal palpate 
palped palpi palps palpus pals palship palsied palsies palsy palter palters paltry 
paludal paly pam pampa pampas pampean pamper pampero pampers pams pan panacea 
panache panada panadas panama panamas pancake panchax panda pandani pandas pandect pander 
panders pandied pandies pandit pandits pandoor pandora pandore pandour pandura pandy pane 
paned panel paneled panels panes panfish panfry panful panfuls pang panga pangas 
panged pangen pangene pangens pangram pangs panic panicky panicle panics panicum panier 
paniers panini panino pann panne panned panner panners pannes pannier panocha panoche 
panoply panpipe pans pansies pansy pant panted panther pantie panties pantile panto 
pantos pantoum pantry pants panty panzer panzers pap papa papacy papadam papadom 
papadum papain papains papal papally papas papaw papaws papaya papayan papayas paper 
papered paperer papers papery paphian papilla papism papisms papist papists papoose pappi 
pappier pappies pappose pappous pappus pappy paprica paprika paps papula papulae papular 
papule papules papyral papyri papyrus par para parable parade paraded parader parades 
parador parados paradox parae paragon paramo paramos parang parangs parapet paraph paraphs 
paras parasol parbake parboil parcel parcels parch parched parches pard pardah pardahs 
pardee pardi pardie pardine pardner pardon pardons pards pardy pare pared pareira 
parent parents pareo pareos parer parerga parers pares pareses paresis paretic pareu 
pareus pareve parfait parg parge parged parges parget pargets pargo pargos pariah 
pariahs parian parians paries parings paris parises parish parity park parka parkade 
parkas parked parker parkers parks parkway parl parlay parlays parle parled parles 
parley parleys parlor parlors parlour parlous parodic parodoi parodos parody parol parole 
paroled parolee paroles parols paronym parotic parotid parous parquet parr parral parrals 
parred parrel parrels parried parrier parries parrot parrots parroty parrs parry pars 
parse parsec parsecs parsed parser parsers parses parsley parsnip parson parsons part 
partake partan partans parted partial partied partier parties partita partite partlet partly 
partner parton partons partook parts partway party partyer parura paruras parure parures 
parve parvenu parvis parvise parvo parvos pas pascal pascals paschal pase paseo 
paseos pases pash pasha pashas pashed pashes pasquil pass passade passado passage 
passant passe passed passee passel passels passer passers passes passim passion passive 
passkey passus past pasta pastas paste pasted pastel pastels paster pastern pasters 
pastes pasteup pastie pastier pasties pastil pastils pastime pastina pastis pastor pastors 
pastry pasts pasture pasty pat pataca patacas patagia patamar patch patched patcher 
patches patchy pate pated patella paten patency patens patent patents pater paters 
pates path pathos paths pathway patient patin patina patinae patinas patine patined 
patines patins patio patios patly patness patois patriot patrol patrols patron patrons 
patroon pats patsies patsy patt patted pattee patten pattens patter pattern patters 
pattie patties patty paty patzer patzers paucity paughty paulin paulins paunch paunchy 
pauper paupers paus pausal pause paused pauser pausers pauses pav pavan pavane 
pavanes pavans pave paved paveed paver pavers paves pavid pavin pavings pavins 
pavior paviors paviour pavis pavise paviser pavises pavisse pavlova paw pawed pawer 
pawers pawkier pawkily pawky pawl pawls pawn pawnage pawned pawnee pawnees pawner 
pawners pawnor pawnors pawns pawpaw pawpaws paws pax paxes paxwax pay payable 
payably payback payday paydays payed payee payees payer payers payload payment paynim 
paynims payoff payoffs payola payolas payor payors payout payouts payroll pays pazazz 
pe pea peac peace peaced peaces peach peached peacher peaches peachy peacoat 
peacock peafowl peag peage peages peags peahen peahens peak peaked peakier peakish 
peaks peaky peal pealed pealike peals pean peans peanut peanuts pear pearl 
pearled pearler pearls pearly pears peart pearter peartly peas peasant peascod pease 
peasen peases peat peatier peats peaty peavey peaveys peavies peavy pebble pebbled 
pebbles pebbly pec pecan pecans peccant peccary peccavi pech pechan pechans peched 
pechs peck pecked pecker peckers peckier peckish pecks pecky pecs pectase pectate 
pecten pectens pectic pectin pectins pectize peculia ped pedagog pedal pedaled pedaler 
pedalo pedalos pedals pedant pedants pedate peddle peddled peddler peddles pedes pedicab 
pedicel pedicle pedlar pedlars pedlary pedler pedlers pedlery pedocal pedro pedros peds 
pee peebeen peed peek peeked peeks peel peeled peeler peelers peels peen 
peened peens peep peeped peeper peepers peeps peepul peepuls peer peerage peered 
peeress peerie peeries peers peery pees peev peeve peeved peeves peevish peewee 
peewees peewit peewits peg pegbox pegg pegged pegless peglike pegs peh pehs 
pein peined peins peis peise peised peises pekan pekans peke pekepoo pekes 
pekin pekins pekoe pekoes pelage pelages pelagic pele peles pelf pelfs pelican 
pelisse pelite pelites pelitic pellet pellets pelmet pelmets pelon peloria peloric pelorus 
pelota pelotas peloton pelt peltast peltate pelted pelter pelters peltry pelts pelves 
pelvic pelvics pelvis pembina pemican pemphix pen penal penally penalty penance penang 
penangs penates pence pencel pencels pencil pencils pend pendant pended pendent pends 
penes pengo pengos penguin penial penicil penile penis penises penlite penman penmen 
penn penna pennae penname pennant pennate penne penned penner penners penni pennia 
pennies pennine pennis pennon pennons penny penoche pens pensee pensees pensil pensile 
pensils pension pensive penster pent pentad pentads pentane pentene pentode pentose pentyl 
pentyls penuche penuchi penult penults penury peon peonage peones peonies peonism peons 
peony people peopled peopler peoples pep pepino pepinos pepla peplos peplum peplums 
peplus pepo pepos pepp pepped pepper peppers peppery peppier peppily peppy peps 
pepsin pepsine pepsins peptalk peptic peptics peptid peptide peptids peptize peptone per 
peracid percale percent percept perch perched percher perches percoid percuss perdie perdu 
perdue perdues perdure perdus perdy pere perea pereia pereion pereon pereons peres 
perfect perfidy perform perfume perfumy perfuse pergola perhaps peri periapt peridia peridot 
perigee perigon peril periled perilla perils perinea period periods perique peris perish 
periti peritus periwig perjure perjury perk perked perkier perkily perkish perks perky 
perlite perm permed permian permit permits perms permute pernio pernod pernods peroral 
peroxid peroxy perp perpend perpent perplex perps perries perron perrons perry persalt 
perse perses persist person persona persons perspex pert pertain perter pertest pertly 
perturb peruke peruked perukes perusal peruse perused peruser peruses perv pervade pervert 
pervs pes pesade pesades peseta pesetas pesewa pesewas peskier peskily pesky peso 
pesos pessary pest pester pesters pestier pestle pestled pestles pesto pestos pests 
pesty pet petal petaled petals petard petards petasos petasus petcock peter petered 
peters petiole petit petite petites petnap petnaps petrale petrel petrels petrify petrol 
petrols petrous pets petsai petsais pett petted petter petters petti pettier pettily 
pettish pettle pettled pettles petto petty petunia pew pewee pewees pewit pewits 
pews pewter pewters peyote peyotes peyotl peyotls peytral peytrel pfennig pfft pfui 
phaeton phage phages phalanx phalli phallic phallus phantom pharaoh pharos pharynx phas 
phase phaseal phased phases phasic phasis phasmid phat phatic phatter phellem phenate 
phenix phenol phenols phenom phenoms phenoxy phenyl phenyls phew phi phial phials 
philter philtra philtre phis phiz phizes phlegm phlegms phlegmy phloem phloems phlox 
phloxes phobia phobias phobic phobics phocine phoebe phoebes phoebus phoenix phon phonal 
phonate phone phoned phoneme phones phoney phoneys phonic phonics phonied phonier phonies 
phonily phono phonon phonons phonos phons phony phooey phorate phoresy phot photic 
photics photo photoed photog photogs photon photons photos phots phpht phrasal phrase 
phrased phrases phratry phreak phreaks phrenic phrensy pht phut phuts phyla phylae 
phylar phyle phylic phyllo phyllos phylon phylum physed physeds physes physic physics 
physis phytane phytin phytins phytoid phytol phytols phyton phytons pi pia piaffe 
piaffed piaffer piaffes pial pian pianic pianism pianist piano pianos pians pias 
piasaba piasava piaster piastre piazza piazzas piazze pibal pibals pibroch pic pica 
picacho picador pical picante picara picaras picaro picaros picas piccata piccolo pice 
piceous pick pickax pickaxe picked pickeer picker pickers picket pickets pickier pickle 
pickled pickles pickoff picks pickup pickups picky picnic picnics picolin picot picoted 
picotee picots picquet picrate picric picrite pics picture picul piculs piddle piddled 
piddler piddles piddly piddock pidgin pidgins pie piebald piec piece pieced piecer 
piecers pieces pied piefort piehole pier pierce pierced piercer pierces pierogi pierrot 
piers pies pieta pietas pieties pietism pietist piety piffle piffled piffles pig 
pigboat pigeon pigeons pigfish pigg pigged piggery piggie piggier piggies piggin piggins 
piggish piggy piglet piglets piglike pigment pigmies pigmy pignoli pignora pignus pignut 
pignuts pigout pigouts pigpen pigpens pigs pigskin pigsney pigsty pigtail pigweed pik 
pika pikake pikakes pikas pike piked pikeman pikemen piker pikers pikes piki 
pikis pil pilaf pilaff pilaffs pilafs pilar pilau pilaus pilaw pilaws pile 
pilea pileate piled pilei pileous piles pileum pileup pileups pileus pilfer pilfers 
pilgrim pili pilings pilis pill pillage pillar pillars pillbox pilled pillion pillory 
pillow pillows pillowy pills pilose pilot piloted pilots pilous pilsner pilular pilule 
pilules pilus pily pima pimas pimento pimp pimped pimple pimpled pimples pimply 
pimps pin pina pinang pinangs pinas pinata pinatas pinball pinbone pincer pincers 
pinch pinched pincher pinches pinder pinders pine pineal pineals pined pinene pinenes 
pinery pines pinesap pineta pinetum piney pinfish pinfold ping pinged pinger pingers 
pingo pingoes pingos pings pinguid pinhead pinhole pinier piniest pinion pinions pinite 
pinites pinitol pink pinked pinken pinkens pinker pinkers pinkest pinkey pinkeye pinkeys 
pinkie pinkies pinkish pinkly pinko pinkoes pinkos pinks pinky pinn pinna pinnace 
pinnae pinnal pinnas pinnate pinned pinner pinners pinnies pinnula pinnule pinny pinocle 
pinole pinoles pinon pinones pinons pinot pinots pins pint pinta pintada pintado 
pintail pintano pintas pintle pintles pinto pintoes pintos pints pinup pinups pinwale 
pinweed pinwork pinworm piny pinyin pinyon pinyons piolet piolets pion pioneer pionic 
pions piosity pious piously pip pipage pipages pipal pipals pipe pipeage piped 
pipeful piper pipers pipes pipet pipets pipette pipier pipiest pipings pipit pipits 
pipkin pipkins pipp pipped pippin pippins pips pipy piqu piquant pique piqued 
piques piquet piquets piracy piragua pirana piranas piranha pirate pirated pirates piratic 
piraya pirayas pirn pirns pirog pirogen piroghi pirogi pirogue pirojki piroque pis 
piscary piscina piscine pisco piscos pish pished pisher pishers pishes pishoge pismire 
piso pisos piss pissant pissed pisser pissers pisses pissoir piste pistes pistil 
pistils pistol pistole pistols piston pistons pistou pistous pit pita pitapat pitas 
pitaya pitayas pitch pitched pitcher pitches pitchy piteous pitfall pith pithead pithed 
pithier pithily piths pithy pitied pitier pitiers pities pitiful pitman pitmans pitmen 
piton pitons pits pitsaw pitsaws pitt pitta pittas pitted pity piu pivot 
pivotal pivoted pivots pix pixel pixels pixes pixie pixies pixy pixyish pizazz 
pizazzy pizza pizzas pizzaz pizzazz pizzle pizzles plac placard placate place placebo 
placed placer placers places placet placets placid plack placket placks placoid plafond 
plagal plage plages plague plagued plaguer plagues plaguey plaguy plaice plaices plaid 
plaided plaids plain plained plainer plainly plains plaint plaints plait plaited plaiter 
plaits plan planar planate planch planche plane planed planer planers planes planet 
planets planish plank planked planks planned planner plans plant plantar planted planter 
plants planula plaque plaques plash plashed plasher plashes plashy plasm plasma plasmas 
plasmic plasmid plasmin plasmon plasms plaster plastic plastid plat platan platane platans 
plate plateau plated platen platens plater platers plates platier platies platina platoon 
plats platted platter platy platypi platys plaudit play playa playact playas playboy 
playday played player players playful playlet playoff playpen plays plaza plazas plea 
pleach plead pleaded pleader pleads pleas please pleased pleaser pleases pleat pleated 
pleater pleats pleb plebe plebes plebs plectra pled pledge pledged pledgee pledger 
pledges pledget pledgor pleiad pleiads plena plenary plench plenish plenism plenist plenty 
plenum plenums pleon pleonal pleonic pleons pleopod plessor pleura pleurae pleural pleuras 
pleuron plew plews plex plexal plexes plexor plexors plexus pliable pliably pliancy 
pliant plica plicae plical plicate plie plied plier pliers plies plight plights 
plimsol plink plinked plinker plinks plinth plinths pliskie plisky plisse plisses plod 
plodded plodder plods ploidy plonk plonked plonks plop plopped plops plosion plosive 
plot plots plotted plotter plotty plotz plotzed plotzes plough ploughs plover plovers 
plow plowboy plowed plower plowers plowman plowmen plows ploy ployed ploys pluck 
plucked plucker plucks plucky plug plugged plugger plugola plugs plum plumage plumate 
plumb plumbed plumber plumbic plumbs plumbum plume plumed plumes plumier plummer plummet 
plummy plumose plump plumped plumpen plumper plumply plumps plums plumule plumy plunder 
plunge plunged plunger plunges plunk plunked plunker plunks plunky plural plurals plus 
pluses plush plusher plushes plushly plushy plusses plutei pluteus pluton plutons pluvial 
pluvian ply plyer plyers plywood pneuma pneumas poach poached poacher poaches poachy 
poblano poboy poboys pochard pock pocked pocket pockets pockier pockily pocks pocky 
poco pocosen pocosin pocoson pod podagra podd podded podesta podgier podgily podgy 
podia podite podites poditic podium podiums podlike pods podsol podsols podzol podzols 
poem poems poesies poesy poet poetess poetic poetics poetise poetize poetry poets 
pogey pogeys pogies pogonia pogonip pogrom pogroms pogy poh poi poilu poilus 
poind poinded poinds point pointe pointed pointer pointes points pointy pois poise 
poised poiser poisers poises poisha poison poisons poitrel pok pokable poke poked 
poker pokers pokes pokey pokeys pokier pokies pokiest pokily poky pol polar 
polaron polars polder polders pole poleax poleaxe polecat poled poleis polemic polenta 
poler polers poles poleyn poleyns police policed policer polices policy polies polio 
polios polis polish polite politer politic polity polka polkaed polkas poll pollack 
pollard polled pollee pollees pollen pollens poller pollers pollex pollist pollock polls 
pollute polo poloist polos pols poly polycot polyene polygon polymer polynya polynyi 
polyol polyols polyoma polyp polyped polypi polypod polyps polypus polys pom pomace 
pomaces pomade pomaded pomades pomatum pome pomelo pomelos pomes pomfret pommee pommel 
pommels pommie pommies pommy pomo pomos pomp pompano pompom pompoms pompon pompons 
pompous pomps poms ponc ponce ponced ponces poncho ponchos pond ponded ponder 
ponders ponds pone ponent pones pong ponged pongee pongees pongid pongids pongs 
poniard ponied ponies pons pontes pontiff pontil pontils pontine ponton pontons pontoon 
pony poo pooch pooched pooches pood poodle poodles poods pooed poof poofs 
pooftah poofter poofy pooh poohed poohs pool pooled pooler poolers pools poon 
poons poop pooped poops poor poorer poorest poori pooris poorish poorly poos 
poove pooves pop popcorn pope popedom popery popes popeyed popgun popguns popish 
poplar poplars poplin poplins popover popp poppa poppas popped popper poppers poppet 
poppets poppied poppies popple poppled popples poppy pops popsie popsies popsy popular 
por porch porches porcine porcini porcino pore pored pores porgies porgy porism 
porisms pork porked porker porkers porkier porkies porkpie porks porky porn pornier 
porno pornos porns porny porose porous porrect port portage portal portals ported 
portend portent porter porters portico portion portly portray ports pos posable posada 
posadas pose posed poser posers poses poseur poseurs posh posher poshest poshly 
posies posit posited posits posole posoles posse posses possess posset possets possum 
possums post postage postal postals postbag postbox postboy postdoc posted posteen poster 
postern posters postfix postie posties postin postins postman postmen postop postops posts 
posttax posture postwar posy pot potable potage potages potamic potash potato potboil 
potboy potboys poteen poteens potence potency potent potful potfuls pothead potheen pother 
potherb pothers pothole pothook pothos potiche potion potions potlach potlike potline potluck 
potman potmen potpie potpies pots potshot potsie potsies potsy pott pottage potted 
potteen potter potters pottery pottier potties pottle pottles potto pottos potty potzer 
potzers pouch pouched pouches pouchy pouf poufed pouff pouffe pouffed pouffes pouffs 
pouffy poufs poulard poult poulter poultry poults pounce pounced pouncer pounces pound 
poundal pounded pounder pounds pour poured pourer pourers pours poussie pout pouted 
pouter pouters poutful poutier poutine pouts pouty poverty pow powder powders powdery 
power powered powers pows powter powters powwow powwows pox poxed poxes poxier 
poxiest poxy poyou poyous pozole pozoles praam praams practic praetor prahu prahus 
prairie praise praised praiser praises prajna prajnas praline pram prams prance pranced 
prancer prances prang pranged prangs prank pranked pranks prao praos prase prases 
prat prate prated prater praters prates prats prattle prau praus prawn prawned 
prawner prawns praxes praxis pray prayed prayer prayers prays preach preachy preact 
preacts preaged preamp preamps preanal prearm prearms preaver prebade prebake prebend prebid 
prebids prebill prebind preboil prebook preboom prebuy prebuys precast precava precede precent 
precept precess precipe precis precise precode precook precool precoup precure precut precuts 
predate predawn predial predict predive predry predusk pree preed preedit preemie preempt 
preen preened preener preens prees prefab prefabs preface prefade prefect prefer prefers 
prefile prefire prefix preform prefund pregame preheat prelacy prelate prelaw prelect prelife 
prelim prelims preload prelude premade preman premeal premed premeds premeet premen premie 
premier premies premise premiss premium premix premixt premold premolt premune prename prenoon 
preop preops preoral prep prepack prepaid prepare prepave prepay prepays prepill preplan 
prepped preppie preppy prepreg preps prepuce prepupa prequel prerace preriot prerock presa 
presage presale prese presell present preset presets preship preshow preside presift presoak 
presold presong presort press pressed presser presses pressor prest prester presto prestos 
prests presume pretape pretax preteen pretell pretend preterm pretest pretext pretold pretor 
pretors pretrim pretty pretype pretzel prevail prevent preverb preview previse prevue prevued 
prevues prewar prewarm prewarn prewash prewire prework preworn prewrap prex prexes prexies 
prexy prey preyed preyer preyers preys prez prezes priapi priapic priapus pric 
price priced pricer pricers prices pricey pricier pricily prick pricked pricker pricket 
prickle prickly pricks pricky pricy prid pride prided prides pried prier priers 
pries priest priests prig prigged prigs prill prilled prills prim prima primacy 
primage primal primary primas primate prime primed primely primer primero primers primes 
primi primine primly primmed primmer primo primos primp primped primps prims primsie 
primula primus prince princes princox prink prinked prinker prinks print printed printer 
prints prion prions prior priorly priors priory pris prise prised prisere prises 
prism prisms prison prisons priss prissed prisses prissy prithee privacy private privet 
privets privier privies privily privity privy priz prize prized prizer prizers prizes 
pro proa proas prob proband probang probate probe probed prober probers probes 
probit probits probity problem procarp proceed process proctor procure prod prodded prodder 
prodigy prodrug prods produce product proem proems proette prof profane profess proffer 
profile profit profits profs profuse prog progeny progged progger program progs progun 
project projet projets prolan prolans prolate prole proleg prolegs proles proline prolix 
prolog prologs prolong prom promine promise promo promoed promos promote prompt prompts 
proms pronate prone pronely prong pronged prongs pronota pronoun pronto proof proofed 
proofer proofs prop propane propel propels propend propene proper propers prophet propine 
propjet propman propmen propone propose propped propria props propyl propyla propyls prorate 
pros prosaic prose prosect prosed proser prosers proses prosier prosily prosit proso 
prosody prosoma prosos prosper pross prosses prossie prost prostie prosy protea protean 
proteas protect protege protei proteid protein protend protest proteus protist protium proton 
protons protyl protyle protyls proud prouder proudly prov prove proved proven prover 
proverb provers proves provide proviso provoke provost prow prowar prower prowess prowest 
prowl prowled prowler prowls prows proxies proximo proxy prude prudent prudery prudes 
prudish prun prune pruned pruner pruners prunes prunus prurigo prussic pruta prutah 
prutot prutoth pry pryer pryers prythee psalm psalmed psalmic psalms psalter psaltry 
psammon pschent pseud pseudo pseudos pseuds pshaw pshawed pshaws psi psis psoae 
psoai psoas psoatic psocid psocids psst pst psych psyche psyched psyches psychic 
psycho psychos psychs psylla psyllas psyllid psyops psywar psywars pterin pterins pteryla 
ptisan ptisans ptomain ptooey ptoses ptosis ptotic ptui ptyalin pub puberal puberty 
pubes pubic pubis public publics publish pubs puccoon puce puces puck pucka 
pucker puckers puckery puckish pucks pud pudd puddle puddled puddler puddles puddly 
pudency pudenda pudgier pudgily pudgy pudic puds pueblo pueblos puerile puff puffed 
puffer puffers puffery puffier puffily puffin puffins puffs puffy pug pugaree pugg 
pugged puggier puggish puggree puggry puggy pugh pugmark pugree pugrees pugs puisne 
puisnes puja pujah pujahs pujas puk puke puked pukes pukka pul pula 
pule puled puler pulers pules puli pulik pulings pulis pull pulled puller 
pullers pullet pullets pulley pulleys pullman pullout pulls pullup pullups pulp pulpal 
pulped pulper pulpers pulpier pulpily pulpit pulpits pulpous pulps pulpy pulque pulques 
puls pulsant pulsar pulsars pulsate pulse pulsed pulser pulsers pulses pulsion pulvini 
puma pumas pumelo pumelos pumice pumiced pumicer pumices pummel pummelo pummels pump 
pumped pumper pumpers pumpkin pumps pun puna punas punch punched puncher punches 
punchy pundit pundits pung pungent pungle pungled pungles pungs punier puniest punily 
punish punji punjis punk punka punkah punkahs punkas punker punkers punkest punkey 
punkeys punkie punkier punkies punkin punkins punkish punks punky punn punned punner 
punners punnet punnets punnier punny puns punster punt punted punter punters punties 
punto puntos punts punty puny pup pupa pupae pupal puparia pupas pupate 
pupated pupates pupfish pupil pupilar pupils pupp pupped puppet puppets puppies puppy 
pups pupu pupus pur purana puranas puranic purda purdah purdahs purdas pure 
puree pureed purees purely purer purest purfle purfled purfler purfles purg purge 
purged purger purgers purges puri purify purin purine purines purins puris purism 
purisms purist purists puritan purity purl purled purlieu purlin purline purlins purloin 
purls purple purpled purpler purples purply purport purpose purpura purpure purr purred 
purrs purs purse pursed purser pursers purses pursier pursily pursue pursued pursuer 
pursues pursuit pursy purtier purty purvey purveys purview pus puses push pushed 
pusher pushers pushes pushful pushier pushily pushpin pushrod pushup pushups pushy pusley 
pusleys puslike puss pusses pussier pussies pussley pussly pussy pustule put putamen 
putdown putlog putlogs putoff putoffs puton putons putout putouts putrefy putrid puts 
putsch putt putted puttee puttees putter putters putti puttie puttied puttier putties 
putto putts putty putz putzed putzes puzzle puzzled puzzler puzzles pya pyaemia 
pyaemic pyas pye pyemia pyemias pyemic pyes pygidia pygmean pygmies pygmoid pygmy 
pyic pyin pyins pyjama pyjamas pyknic pyknics pylon pylons pylori pyloric pylorus 
pyoid pyoses pyosis pyralid pyramid pyran pyrans pyre pyrene pyrenes pyres pyretic 
pyrex pyrexes pyrexia pyrexic pyric pyridic pyrite pyrites pyritic pyro pyrogen pyrola 
pyrolas pyrone pyrones pyrope pyropes pyros pyrosis pyrrhic pyrrol pyrrole pyrrols python 
pythons pyuria pyurias pyx pyxes pyxides pyxidia pyxie pyxies pyxis qoph qophs 
quip quipped quipper quippu quippus quippy quips quipu quipus ragtop ragtops ralph 
ralphed ralphs ramp rampage rampant rampart ramped rampike rampion rampole ramps ranpike 
rap rape raped raper rapers rapes raphae raphe raphes raphia raphias raphide 
raphis rapid rapider rapidly rapids rapier rapiers rapine rapines rapini rapist rapists 
rapp rapped rappee rappees rappel rappels rappen rapper rappers rappini rapport raps 
rapt raptly raptor raptors rapture rasp rasped rasper raspers raspier raspish rasps 
raspy rattrap readapt readopt reap reaped reaper reapers reapply reaps rebop rebops 
recap recaps receipt recept recepts recipe recipes reclasp recopy recoup recoupe recoups 
redcap redcaps redip redips redipt redpoll redtop redtops reequip reexpel regroup relapse 
remap remaps reopen reopens rep repack repacks repaid repaint repair repairs repand 
repanel repaper repark reparks repass repast repasts repatch repave repaved repaves repay 
repays repeal repeals repeat repeats repeg repegs repel repels repent repents reperk 
reperks repin repine repined repiner repines repins replace replan replans replant replate 
replay replays replead repled replete replevy replica replied replier replies replot replots 
replow replows replumb reply repo repoll repolls report reports repos reposal repose 
reposed reposer reposes reposit repot repots repour repours repower repp repped repps 
repress reprice reprint reprise repro reprobe reproof repros reprove reps reptant reptile 
repugn repugns repulse repump repumps repute reputed reputes reshape reship reships respace 
respade respeak respect respell respelt respire respite resplit respoke respond respool respot 
respots respray restamp retape retaped retapes retype retyped retypes revamp revamps rewrap 
rewraps rewrapt rhaphae rhaphe rhaphes rhizopi riflip riflips rimple rimpled rimples rip 
ripcord ripe riped ripely ripen ripened ripener ripens riper ripes ripest ripieni 
ripieno ripoff ripoffs ripost riposte riposts ripp ripped ripper rippers ripple rippled 
rippler ripples ripplet ripply riprap ripraps rips ripsaw ripsawn ripsaws ripstop riptide 
rollmop rolltop romp romped romper rompers rompish romps rooftop rootcap rop ropable 
rope roped roper ropers ropery ropes ropeway ropey ropier ropiest ropily ropy 
rosehip roundup roup rouped roupet roupier roupily roups roupy rump rumple rumpled 
rumples rumply rumps rumpus rupee rupees rupiah rupiahs rupture salep saleps saloop 
saloops salp salpa salpae salpas salpian salpid salpids salpinx salps saltpan samp 
sampan sampans sample sampled sampler samples samps sandpit sannop sannops sannup sannups 
sap sapajou saphead saphena sapid sapiens sapient sapl sapless saponin sapor sapors 
sapota sapotas sapote sapotes sapour sapours sapp sapped sapper sappers sapphic sappier 
sappily sappy saprobe saps sapsago sapwood sarape sarapes satrap satraps satrapy scaleup 
scallop scalp scalped scalpel scalper scalps scamp scamped scamper scampi scamps scap 
scape scaped scapes scapose scapula scarp scarped scarper scarph scarphs scarps scaup 
scauper scaups scepter sceptic sceptre schappe schlep schlepp schleps schlump schnaps scollop 
scoop scooped scooper scoops scop scope scoped scopes scops scopula scrap scrape 
scraped scraper scrapes scrapie scrappy scraps screwup scrimp scrimps scrimpy scrip scrips 
script scripts scroop scroops scruple sculp sculped sculpin sculps sculpt sculpts scup 
scupper scups scyphi scyphus seaport secpar secpars seedpod seep seepage seeped seepier 
seeps seepy semipro semple sempre sendup sendups senopia sepal sepaled sepals sepia 
sepias sepic sepoy sepoys seppuku sepses sepsis sept septa septage septal septate 
septet septets septic septics septime septs septum septums serape serapes seraph seraphs 
serpent serpigo setup setups sexpot sexpots shakeup shallop shampoo shap shape shaped 
shapely shapen shaper shapers shapes shapeup sharp sharped sharpen sharper sharpie sharply 
sharps sharpy sheep sherpa sherpas shilpit ship shiplap shipman shipmen shipped shippen 
shipper shippon ships shipway shlep shlepp shlepps shleps shlump shlumps shlumpy shnapps 
shnaps shoepac shop shopboy shophar shopman shopmen shoppe shopped shopper shoppes shops 
shrimp shrimps shrimpy simp simper simpers simple simpler simples simplex simply simps 
sinopia sinopie sip sipe siped sipes siphon siphons sipp sipped sipper sippers 
sippet sippets sips sirup siruped sirups sirupy situp situps skelp skelped skelpit 
skelps skep skeps skepsis skeptic skimp skimped skimps skimpy skip skipped skipper 
skippet skips skycap skycaps skyphoi skyphos slap slapped slapper slaps sleep sleeper 
sleeps sleepy slept slimpsy slip slipe sliped slipes slipout slipped slipper slippy 
slips slipt slipup slipups slipway sloop sloops slop slope sloped sloper slopers 
slopes slopped sloppy slops slump slumped slumps slurp slurped slurps slype slypes 
smashup snap snapped snapper snappy snaps sneap sneaped sneaps snip snipe sniped 
sniper snipers snipes snipped snipper snippet snippy snips snoop snooped snooper snoops 
snoopy snowcap soap soapbox soaped soaper soapers soapier soapily soaps soapy sonship 
sop soph sophies sophism sophist sophs sophy sopite sopited sopites sopor sopors 
sopp sopped soppier soppy soprani soprano sops soup soupcon souped soupier soups 
soupy soursop spa spac space spaced spacer spacers spaces spacey spacial spacier 
spackle spacy spad spade spaded spader spaders spades spadix spado spae spaed 
spaes spahee spahees spahi spahis spail spails spait spaits spake spale spales 
spall spalled spaller spalls spam spambot spammed spammer spams span spancel spandex 
spang spangle spangly spaniel spank spanked spanker spanks spanned spanner spans spar 
spare spared sparely sparer sparers spares sparest sparge sparged sparger sparges sparid 
sparids spark sparked sparker sparkle sparkly sparks sparky sparoid sparred sparrow sparry 
spars sparse sparser spartan spas spasm spasmed spasms spastic spat spate spates 
spathal spathe spathed spathes spathic spatial spats spatted spatter spatula spatzle spavie 
spavies spaviet spavin spavins spawn spawned spawner spawns spay spayed spays spaz 
spazz spazzes speak speaker speaks spean speaned speans spear speared spearer spears 
spec specced special specie species specify speck specked speckle specks specs specter 
spectra spectre specula sped speech speed speeded speeder speedo speedos speeds speedup 
speedy speel speeled speels speer speered speers speil speiled speils speir speired 
speirs speise speises speiss spelean spell spelled speller spells spelt spelter spelts 
speltz spelunk spence spencer spences spend spender spends spendy spense spenses spent 
sperm spermic sperms spew spewed spewer spewers spews sphene sphenes sphenic spheral 
sphere sphered spheres spheric sphery sphinx sphynx spic spica spicae spicas spicate 
spice spiced spicer spicers spicery spices spicey spicier spicily spick spicks spics 
spicula spicule spicy spider spiders spidery spied spiegel spiel spieled spieler spiels 
spier spiered spiers spies spiff spiffed spiffs spiffy spigot spigots spik spike 
spiked spiker spikers spikes spikey spikier spikily spiks spiky spil spile spiled 
spiles spill spilled spiller spills spilt spilth spilths spin spinach spinage spinal 
spinals spinate spindle spindly spine spined spinel spinels spines spinet spinets spinier 
spinner spinney spinny spinoff spinor spinors spinose spinous spinout spins spinto spintos 
spinula spinule spiny spir spiraea spiral spirals spirant spire spirea spireas spired 
spirem spireme spirems spires spirier spirit spirits spiroid spirt spirted spirts spirula 
spiry spit spital spitals spite spited spites spits spitted spitter spittle spitz 
spitzes spiv spivs spivvy splake splakes splash splashy splat splats splay splayed 
splays spleen spleens spleeny splenia splenic splenii splent splents splice spliced splicer 
splices spliff spliffs spline splined splines splint splints split splits splodge splore 
splores splosh splotch splurge splurgy spode spodes spoil spoiled spoiler spoils spoilt 
spok spoke spoked spoken spokes spondee sponge sponged sponger sponges spongin spongy 
sponsal sponson sponsor spoof spoofed spoofer spoofs spoofy spook spooked spooks spooky 
spool spooled spooler spools spoon spooned spooney spoons spoony spoor spoored spoors 
spor sporal spore spored spores sporoid sporran sport sported sporter sportif sports 
sporty sporule spot spotlit spots spotted spotter spotty spousal spouse spoused spouses 
spout spouted spouter spouts spr sprag sprags sprain sprains sprang sprangs sprat 
sprats sprawl sprawls sprawly spray sprayed sprayer sprays spread spreads spree sprees 
sprent sprier spriest sprig spriggy spright sprigs springe springs springy sprint sprints 
sprit sprite sprites sprits spritz sprout sprouts spruce spruced sprucer spruces sprucy 
sprue sprues sprug sprugs sprung spry spryer spryest spryly spu spud spudded 
spudder spuds spue spued spues spum spume spumed spumes spumier spumone spumoni 
spumous spumy spun spunk spunked spunkie spunks spunky spur spurge spurges spurn 
spurned spurner spurns spurred spurrer spurrey spurry spurs spurt spurted spurter spurtle 
spurts sputa sputnik sputter sputum spy stackup stamp stamped stamper stamps standup 
stapes staph staphs staple stapled stapler staples startup steep steeped steepen steeper 
steeple steeply steeps step steppe stepped stepper steppes steps stepson stewpan stickup 
stipe stiped stipel stipels stipend stipes stipple stipule stirp stirpes stirps stirrup 
stomp stomped stomper stomps stoop stooped stooper stoops stop stope stoped stoper 
stopers stopes stopgap stopoff stopped stopper stopple stops stopt stoup stoups stowp 
stowps strap strappy straps strep streps strip stripe striped striper stripes strips 
stript stripy strop strophe stroppy strops stump stumped stumper stumps stumpy stupa 
stupas stupe stupefy stupes stupid stupids stupor stupors stypsis styptic subpar subpart 
subpena subplot subtype sulpha sulphas sulphid sulphur sump sumps sumpter sunlamp sunspot 
sunup sunups sup supe super superb supered supers supes supine supines supp 
supped supper suppers supple suppled suppler supples supply support suppose supra supreme 
supremo sups surpass surplus suspect suspend suspire swamp swamped swamper swamps swampy 
swanpan swap swapped swapper swaps sweep sweeper sweeps sweepy swept swip swipe 
swiped swipes swiple swiples swipple swoop swooped swooper swoops swoopy swop swopped 
swops sylph sylphic sylphid sylphs sylphy symptom synapse syncarp syncope syph sypher 
syphers syphon syphons syphs syrphid syrup syruped syrups syrupy sysop sysops tadpole 
taipan taipans takeup takeups taliped talipes talipot tamp tampala tampan tampans tamped 
tamper tampers tampion tampon tampons tamps tap tapa tapalo tapalos tapas tape 
taped taper tapered taperer tapers tapes tapeta tapetal tapetum taphole tapioca tapir 
tapirs tapis tapises tapp tapped tapper tappers tappet tappets taproom taproot taps 
tapster tarp tarpan tarpans tarpon tarpons tarps taupe taupes tawpie tawpies taxpaid 
teacup teacups teapot teapots teapoy teapoys teashop teepee teepees telpher temp temped 
tempeh tempehs temper tempera tempers tempest tempi templar temple templed temples templet 
tempo tempos temps tempt tempted tempter tempts tempura tenpin tenpins teopan teopans 
tepa tepal tepals tepas tepee tepees tepefy tephra tephras tepid tepidly tepoy 
tepoys teraph terpene therapy thesp thesps thorp thorpe thorpes thorps threap threaps 
threep threeps thrip thrips thruput thump thumped thumper thumps tiderip tiepin tiepins 
tilapia timpana timpani timpano tinpot tintype tip tipcart tipcat tipcats tipi tipis 
tipless tipoff tipoffs tipp tipped tipper tippers tippet tippets tippier tipple tippled 
tippler tipples tippy tips tipsier tipsily tipster tipsy tiptoe tiptoed tiptoes tiptop 
tiptops tittup tittups toecap toecaps tompion top topaz topazes topcoat tope toped 
topee topees toper topers topes topful topfull toph tophe tophes tophi tophs 
tophus topi topiary topic topical topics topis topkick topknot topless topline topmast 
topmost topo topoi toponym topos topp topped topper toppers topple toppled topples 
tops topsail topside topsoil topspin topwork torpedo torpid torpids torpor torpors tosspot 
tossup tossups touchup toupee toupees towpath towrope toyshop traipse tramp tramped tramper 
trample tramps trampy trap trapan trapans trapes trapeze trapped trapper traps trapt 
treetop trepan trepang trepans trepid tricep triceps trip tripack tripart tripe tripes 
triple tripled triples triplet triplex triply tripod tripods tripody tripoli tripos tripped 
tripper trippet trippy trips triptan triumph trollop tromp trompe tromped trompes tromps 
troop trooped trooper troops trop trope tropes trophic trophy tropic tropics tropin 
tropine tropins tropism troupe trouped trouper troupes trump trumped trumpet trumps trypsin 
tryptic tulip tulips tump tumped tumps tuneup tuneups tup tupelo tupelos tupik 
tupiks tupp tupped tups turnip turnips turnup turnups turpeth turps twerp twerps 
twirp twirps tympan tympana tympani tympano tympans tympany typ typable typal type 
typebar typed types typeset typey typhoid typhon typhons typhoon typhose typhous typhus 
typic typical typier typiest typify typist typists typo typos typp typps typy 
ulpan ulpanim ump umped umpire umpired umpires umps umpteen unadept unapt unaptly 
uncap uncaps unclamp unclasp unclip unclips undrape unhappy unhip unhoped unipod unipods 
unkempt unkept unopen unpack unpacks unpaged unpaid unpaved unpeg unpegs unpen unpens 
unpent unpick unpicks unpile unpiled unpiles unpin unpins unplait unplug unplugs unposed 
unpure unrip unripe unriper unrips unroped unsharp unship unships unsnap unsnaps unspeak 
unspent unspilt unsplit unspoke unspool unspun unstep unsteps unstop unstops unstrap unswept 
unwept unwrap unwraps unzip unzips up upas upases upbear upbears upbeat upbeats 
upbind upbinds upboil upboils upbore upborne upbound upbow upbows upbraid upbuild upbuilt 
upby upbye upcast upcasts upchuck upclimb upcoast upcoil upcoils upcourt upcurl upcurls 
upcurve updart updarts update updated updater updates updive updived updives updo updos 
updove updraft updried updries updry upend upended upends upfield upfl upflow upflows 
upflung upfold upfolds upfront upgaze upgazed upgazes upgird upgirds upgirt upgo upgrade 
upgrew upgrow upgrown upgrows upheap upheaps upheave upheld uphill uphills uphoard uphold 
upholds uphove uphroe uphroes upkeep upkeeps upland uplands upleap upleaps upleapt uplift 
uplifts uplight uplink uplinks uplit upload uploads upmost upo upon upp upped 
upper uppers uppile uppiled uppiles uppings uppish uppity upprop upprops upraise uprate 
uprated uprates upreach uprear uprears upright uprise uprisen upriser uprises upriver uproar 
uproars uproot uproots uprose uprouse uprush ups upscale upsend upsends upsent upset 
upsets upshift upshoot upshot upshots upside upsides upsilon upsize upsized upsizes upslope 
upsoar upsoars upstage upstair upstand upstare upstart upstate upstep upsteps upstir upstirs 
upstood upsurge upsw upsweep upswell upswept upswung uptake uptakes uptalk uptalks uptear 
uptears uptempo upthrew upthrow uptick upticks uptight uptilt uptilts uptime uptimes uptore 
uptorn uptoss uptown uptowns uptrend upturn upturns upwaft upwafts upward upwards upwell 
upwells upwind upwinds uropod uropods urp urped urps usurp usurped usurper usurps 
utopia utopian utopias utopism utopist vamp vamped vamper vampers vampier vampire vampish 
vamps vampy vanpool vapid vapidly vapor vapored vaporer vapors vapory vapour vapours 
vapoury veep veepee veepees veeps vesper vespers vespid vespids vespine viper vipers 
vulpine walkup walkups wallop wallops wampish wampum wampums wampus wap wapiti wapitis 
wapp wapped waps warmup warmups warp warpage warpath warped warper warpers warps 
warship washup washups wasp waspier waspily waspish wasps waspy watap watape watapes 
wataps wattape weapon weapons webpage weep weeper weepers weepie weepier weepies weeps 
weepy wept whap whapped whapper whaps whaup whaups wheep wheeped wheeple wheeps 
whelp whelped whelps whimper whip whipped whipper whippet whippy whipray whips whipsaw 
whipt whisper whomp whomped whomps whoop whooped whoopee whooper whoopie whoopla whoops 
whop whopped whopper whops whump whumped whumps whup whupped whups wickape wickiup 
wickyup wicopy wikiup wikiups wimp wimped wimpier wimpish wimple wimpled wimples wimps 
wimpy windup windups winesap winesop wingtip wip wipe wiped wipeout wiper wipers 
wipes wiretap wisp wisped wispier wispily wispish wisps wispy woops woopsed woopses 
wop wops workup workups worship wrap wrapped wrapper wraps wrapt xenopus xiphoid 
yap yapock yapocks yapok yapoks yapon yapons yapp yapped yapper yappers yaps 
yaup yauped yauper yaupers yaupon yaupons yaups yawp yawped yawper yawpers yawps 
ycleped yclept yelp yelped yelper yelpers yelps yep yeps yip yipe yipes 
yipp yipped yippee yippie yippies yips youpon youpons yperite yup yupon yupons 
yuppie yuppies yuppify yuppy yups zap zapateo zapp zapped zapper zappers zappier 
zappy zaps zaptiah zaptieh zep zephyr zephyrs zeppole zeppoli zeps zip zipless 
ziplock zipp zipped zipper zippers zippier zippy zips     
);

my @B_words = qw(
ab aba abaca abacas abaci aback abacus abaft abaka abakas abalone abamp 
abamps abandon abas abase abased abaser abasers abases abash abashed abashes abasia 
abasias abat abate abated abater abaters abates abatis abator abators abattis abaxial 
abaxile abaya abayas abba abbacy abbas abbe abbes abbess abbey abbeys abbot 
abbotcy abbots abdomen abduce abduced abduces abduct abducts abeam abed abele abeles 
abelia abelian abelias abet abets abettal abetted abetter abettor abeyant abfarad abhenry 
abhor abhors abid abide abided abider abiders abides abigail ability abioses abiosis 
abiotic abject abjure abjured abjurer abjures ablate ablated ablates ablator ablaut ablauts 
ablaze able abled ableism ableist abler ables ablest ablings ablins abloom abluent 
ablush abluted ably abmho abmhos abo aboard abod abode aboded abodes abohm 
abohms aboil abolish abolla abollae aboma abomas abomasa abomasi aboon aboral abort 
aborted aborter aborts abortus abos abought aboulia aboulic abound abounds about above 
aboves abrade abraded abrader abrades abreact abreast abri abridge abris abroach abroad 
abrosia abrupt abs abscess abscise abscond abseil abseils absence absent absents absinth 
absolve absorb absorbs abstain absurd absurds abubble abulia abulias abulic abus abuse 
abused abuser abusers abuses abusive abut abuts abuttal abutted abutter abuzz abvolt 
abvolts abwatt abwatts aby abye abyes abys abysm abysmal abysms abyss abyssal 
abysses acerb acerber acerbic acrobat actable addable addible adhibit adobe adobes adobo 
adobos adsorb adsorbs adverb adverbs aerobat aerobe aerobes aerobia aerobic affable affably 
aiblins airbag airbags airboat airbus akimbo alb alba albas albata albatas albedo 
albedos albeit albinal albinic albino albinos albite albites albitic albizia albs album 
albumen albumin albums alembic algebra alibi alibied alibies alibis alible allobar ambage 
ambages ambari ambaris ambary ambeer ambeers amber ambers ambery ambient ambit ambits 
ambl amble ambled ambler amblers ambles ambo amboina ambones ambos amboyna ambries 
ambroid ambry ambsace ambush ameba amebae ameban amebas amebean amebic ameboid amiable 
amiably amoeba amoebae amoeban amoebas amoebic anabas antbear antibug anybody aplomb aplombs 
arabesk arabic arabica arabize arable arables araroba arb arbiter arbor arbored arbores 
arbors arbour arbours arbs arbute arbutes arbutus ardeb ardebs armband arriba arroba 
arrobas ascribe astilbe atabal atabals attaboy aubade aubades auberge auburn auburns aucuba 
aucubas audible audibly ausubo ausubos autobus ba baa baaed baal baalim baalism 
baals baas baases baaskap baba babas babassu babbitt babble babbled babbler babbles 
babe babel babels babes babesia babiche babied babier babies babiest babka babkas 
baboo babool babools baboon baboons baboos babu babul babuls babus baby babyish 
babysat babysit bacalao bacca baccae baccara baccate bacchic bacchii bach bached baches 
bacilli back backbit backed backer backers backfit backhoe backlit backlog backout backs 
backsaw backset backup backups bacon bacons bacula baculum bad badass badder baddest 
baddie baddies baddy bade badg badge badged badger badgers badges badland badly 
badman badmen badness bads baff baffed baffies baffle baffled baffler baffles baffs 
baffy bag bagass bagasse bagel bagels bagful bagfuls bagg baggage bagged bagger 
baggers baggie baggier baggies baggily baggy baglike bagman bagmen bagnio bagnios bagpipe 
bags bagsful baguet baguets bagwig bagwigs bagworm bah bahadur baht bahts bail 
bailed bailee bailees bailer bailers bailey baileys bailie bailies bailiff bailor bailors 
bailout bails bairn bairnly bairns bait baited baiter baiters baith baits baiza 
baizas baize baizes bak bake baked baker bakers bakery bakes bakings baklava 
baklawa bal balance balas balases balata balatas balboa balboas balcony bald balded 
balder baldest baldies baldish baldly baldric balds baldy bale baled baleen baleens 
baleful baler balers bales balk balked balker balkers balkier balkily balks balky 
ball ballad ballade ballads ballast balled baller ballers ballet ballets ballies ballon 
ballons balloon ballot ballots balls ballsy ballute bally balm balmier balmily balms 
balmy balneal baloney bals balsa balsam balsams balsas bam bambini bambino bamboo 
bamboos bamm bammed bams ban banal banally banana bananas banco bancos band 
banda bandage bandaid bandana bandas bandbox bandeau banded bander banders bandied bandies 
bandit bandito bandits bandog bandogs bandora bandore bands bandsaw bandy bane baned 
baneful banes bang banged banger bangers bangkok bangle bangles bangs bani banian 
banians banish banjax banjo banjoes banjos bank banked banker bankers bankit bankits 
banks banksia bann banned banner banners bannet bannets bannock banns banquet bans 
banshee banshie bantam bantams banteng banter banters banties banty banyan banyans banzai 
banzais baobab baobabs bap baps baptise baptism baptist baptize bar barb barbal 
barbate barbe barbed barbel barbell barbels barber barbers barbes barbet barbets barbie 
barbies barbs barbule barbut barbuts barca barcas barchan bard barde barded bardes 
bardic bards bare bared barefit barege bareges barely barer bares barest barf 
barfed barfly barfs barg bargain barge barged bargee bargees barges barhop barhops 
baric barilla barista barite barites barium bariums bark barked barkeep barker barkers 
barkier barks barky barless barley barleys barlow barlows barm barmaid barman barmen 
barmie barmier barms barmy barn barned barney barneys barnier barns barny baron 
baronet barong barongs baronne barons barony baroque barque barques barr barrack barrage 
barre barred barrel barrels barren barrens barres barret barrets barrier barrio barrios 
barroom barrow barrows bars bartend barter barters barware barye baryes baryon baryons 
baryta barytas baryte barytes barytic baryton bas basal basally basalt basalts bascule 
base based basely baseman basemen basenji baser bases basest bash bashaw bashaws 
bashed basher bashers bashes bashful bashlyk basic basics basidia basify basil basilar 
basilic basils basin basinal basined basinet basins basion basions basis bask basked 
basket baskets basks basmati basque basques bass basses basset bassets bassett bassi 
bassist bassly basso bassoon bassos bassy bast bastard baste basted baster basters 
bastes bastile bastion basts bat batboy batboys batch batched batcher batches bate 
bateau bateaux bated bates batfish batfowl batgirl bath bathe bathed bather bathers 
bathes bathmat bathos baths bathtub bathyal batik batiked batiks batiste batlike batman 
batmen baton batons bats batsman batsmen batt batteau batted batten battens batter 
batters battery battier battik battiks battle battled battler battles batts battu battue 
battues batty batw baubee baubees bauble baubles baud bauds baulk baulked baulks 
baulky bausond bauxite bawbee bawbees bawcock bawd bawdier bawdies bawdily bawdric bawdry 
bawds bawdy bawl bawled bawler bawlers bawls bawsunt bawtie bawties bawty bay 
bayamo bayamos bayard bayards bayed bayman baymen bayonet bayou bayous bays baywood 
bazaar bazaars bazar bazars bazoo bazooka bazooms bazoos be beach beached beaches 
beachy beacon beacons bead beaded beader beaders beadier beadily beadle beadles beadman 
beadmen beads beady beagle beagles beak beaked beaker beakers beakier beaks beaky 
beam beamed beamier beamily beamish beams beamy bean beanbag beaned beanery beanie 
beanies beano beanos beans bear bearcat beard bearded beards bearer bearers bearhug 
bearish bears beast beastie beastly beasts beat beaten beater beaters beatify beatnik 
beats beau beauish beaus beaut beauts beauty beaux beaver beavers bebeeru beblood 
bebop bebops becalm becalms became becap becaps because bechalk becharm beck becked 
becket beckets beckon beckons becks beclasp becloak beclog beclogs becloud beclown become 
becomes becrawl becrime becrowd becrust becurse becurst bed bedamn bedamns bedaub bedaubs 
bedbug bedbugs bedd bedded bedder bedders bedeck bedecks bedel bedell bedells bedels 
bedeman bedemen bedevil bedew bedewed bedews bedfast bedgown bedight bedim bedims bedirty 
bedizen bedlam bedlamp bedlams bedless bedlike bedmate bedouin bedpan bedpans bedpost bedrail 
bedrape bedrid bedrock bedroll bedroom bedrug bedrugs beds bedside bedsit bedsits bedsore 
bedtick bedtime bedu beduin beduins bedumb bedumbs bedunce bedward bedwarf bee beebee 
beebees beech beechen beeches beechy beedi beedies beef beefalo beefed beefier beefily 
beefs beefy beehive beelike beeline been beep beeped beeper beepers beeps beer 
beerier beers beery bees beeswax beet beetle beetled beetler beetles beets beeves 
beeyard beezer beezers befall befalls befell befit befits beflag beflags beflea befleas 
befleck befog befogs befool befools before befoul befouls befret befrets beg begall 
begalls began begat begaze begazed begazes beget begets begg beggar beggars beggary 
begged begin begins begird begirds begirt beglad beglads begloom begone begonia begorah 
begorra begot begrim begrime begrims begroan begs beguile beguine begulf begulfs begum 
begums begun behalf behave behaved behaver behaves behead beheads beheld behest behests 
behind behinds behold beholds behoof behoove behove behoved behoves behowl behowls beige 
beiges beigne beignes beignet beigy beings bejesus bejewel bekiss beknot beknots bel 
belabor belaced belady belated belaud belauds belay belayed belayer belays belch belched 
belcher belches beldam beldame beldams beleap beleaps beleapt belfry belga belgas belie 
belied belief beliefs belier beliers belies believe belike belive bell bellboy belle 
belled belleek belles bellhop bellied bellies bellman bellmen bellow bellows bells belly 
belon belong belongs belons beloved below belows bels belt belted belter belters 
belts beltway beluga belugas bely bema bemadam bemas bemata bemean bemeans bemire 
bemired bemires bemist bemists bemix bemixed bemixes bemixt bemoan bemoans bemock bemocks 
bemuse bemused bemuses ben bename benamed benames bench benched bencher benches bend 
benday bendays bended bendee bendees bender benders bendier bends bendy bendys bene 
beneath benefic benefit benempt benes benign benison benne bennes bennet bennets benni 
bennies bennis benny benomyl bens bent benthal benthic benthon benthos bento bentos 
bents benumb benumbs benzal benzene benzin benzine benzins benzoic benzoin benzol benzole 
benzols benzoyl benzyl benzyls bepaint bequest berake beraked berakes berate berated berates 
bereave bereft beret berets beretta berg bergere bergs berhyme berime berimed berimes 
berk berks berlin berline berlins berm berme bermed bermes berms berobed berried 
berries berry berseem berserk berth bertha berthas berthed berths beryl beryls bes 
bescour beseech beseem beseems beses beset besets beshame beshout beshrew beside besides 
besiege beslime besmear besmile besmoke besmut besmuts besnow besnows besom besoms besot 
besots bespake bespeak bespoke best bestead bested bestial bestir bestirs bestow bestows 
bestrew bestrid bestrow bests bestud bestuds beswarm bet beta betaine betake betaken 
betakes betas betaxed betel betels beth bethank bethel bethels bethink bethorn beths 
bethump betide betided betides betime betimes betise betises betoken beton betons betony 
betook betray betrays betroth bets bett betta bettas betted better betters bettor 
bettors between betwixt bevel beveled beveler bevels bevies bevomit bevor bevors bevy 
bewail bewails beware bewared bewares beweary beweep beweeps bewept bewig bewigs bewitch 
beworm beworms beworry bewrap bewraps bewrapt bewray bewrays bey beylic beylics beylik 
beyliks beyond beyonds beys bezant bezants bezazz bezel bezels bezil bezils bezique 
bezoar bezoars bezzant bhakta bhaktas bhakti bhaktis bhang bhangra bhangs bharal bharals 
bheesty bhistie bhoot bhoots bhut bhuts bi biali bialies bialis bialy bialys 
bias biased biases biassed biasses biaxal biaxial bib bibasic bibb bibbed bibber 
bibbers bibbery bibbs bibcock bibelot bible bibles bibless biblike biblist bibs bicarb 
bicarbs bice bicep biceps bices bicker bickers bicolor bicorn bicorne bicorns bicron 
bicrons bicycle bid bidarka bidd bidden bidder bidders biddies biddy bide bided 
bider biders bides bidet bidets bidi bidis bids bield bielded bields biennia 
bier biers biface bifaces biff biffed biffies biffin biffins biffs biffy bifid 
bifidly bifilar biflex bifocal bifold biform big bigamy bigeye bigeyes bigfeet bigfoot 
bigg bigger biggest biggety biggie biggies biggin biggins biggish biggity biggy bighead 
bighorn bight bighted bights bigly bigness bigos bigoses bigot bigoted bigotry bigots 
bigs bigtime bigwig bigwigs bijou bijous bijoux bik bike biked biker bikers 
bikes bikeway bikie bikies bikini bikinis bilayer bilbies bilbo bilboa bilboas bilboes 
bilbos bilby bile biles bilevel bilg bilge bilged bilges bilgier bilgy biliary 
bilious bilk bilked bilker bilkers bilks bill billbug billed biller billers billet 
billets billie billies billion billon billons billow billows billowy bills billy bilobed 
bilsted biltong bima bimah bimahs bimas bimbo bimboes bimbos bimetal bimodal bimorph 
bin binal binary binate bind binder binders bindery bindi bindis bindle bindles 
binds bine biner biners bines bing binge binged binger bingers binges bingo 
bingoes bingos binit binits binn binned binocle binocs bins bint bints bio 
biochip biocide biofilm biofuel biog biogas biogen biogens biogeny biogs bioherm biology 
biomass biome biomes bionic bionics bionomy biont biontic bionts biopic biopics biopsic 
biopsy bioptic bios biota biotas biotech biotic biotics biotin biotins biotite biotope 
biotron biotype bipack bipacks biparty biped bipedal bipeds biplane bipod bipods bipolar 
birch birched birchen birches bird birddog birded birder birders birdie birdied birdies 
birdman birdmen birds bireme biremes biretta biriani birk birkie birkies birks birl 
birle birled birler birlers birles birls biro biros birr birred birrs birse 
birses birth birthed births biryani bis biscuit bise bisect bisects bises bishop 
bishops bisk bisks bismuth bisnaga bison bisons bisque bisques bistate bister bisters 
bistort bistre bistred bistres bistro bistros bit bitable bitch bitched bitchen bitches 
bitchy bite biter biters bites bitmap bitmaps bits bitsier bitsy bitt bitted 
bitten bitter bittern bitters bittier bittock bitts bitty bitumen bivalve bivinyl bivouac 
biz bizarre bizarro bize bizes biznaga bizonal bizone bizones bizzes blab blabbed 
blabber blabby blabs black blacked blacken blacker blackly blacks blad bladder blade 
bladed blader bladers blades blae blaff blaffs blah blahs blain blains blam 
blame blamed blamer blamers blames blams blanch bland blander blandly blank blanked 
blanker blanket blankly blanks blar blare blared blares blarney blase blast blasted 
blaster blastie blasts blasty blat blatant blate blather blats blatted blatter blaubok 
blaw blawed blawn blaws blaz blaze blazed blazer blazers blazes blazon blazons 
bleach bleak bleaker bleakly bleaks blear bleared blears bleary bleat bleated bleater 
bleats bleb blebby blebs bled bleed bleeder bleeds bleep bleeped bleeper bleeps 
blellum blemish blench blend blende blended blender blendes blends blenny blent blesbok 
bless blessed blesser blesses blest blet blether blets blew blight blights blighty 
blimey blimp blimps blimy blin blind blinded blinder blindly blinds blini blinis 
blink blinked blinker blinks blintz blintze blip blipped blips bliss blissed blisses 
blister blite blites blithe blither blitz blitzed blitzer blitzes bloat bloated bloater 
bloats blob blobbed blobs bloc block blocked blocker blocks blocky blocs blog 
blogger blogs bloke blokes blond blonde blonder blondes blonds blood blooded bloods 
bloody blooey blooie bloom bloomed bloomer blooms bloomy bloop blooped blooper bloops 
blossom blot blotch blotchy blots blotted blotter blotto blotty blouse bloused blouses 
blouson blousy blow blowby blowbys blowed blower blowers blowfly blowgun blowier blowjob 
blown blowoff blowout blows blowsed blowsy blowup blowups blowy blowzed blowzy blu 
blub blubbed blubber blubs blucher bludge bludged bludger bludges blue bluecap blued 
bluefin bluegum blueish bluejay bluely bluer blues bluest bluesy bluet bluets bluey 
blueys bluff bluffed bluffer bluffly bluffs bluings bluish blum blume blumed blumes 
blunder blunge blunged blunger blunges blunt blunted blunter bluntly blunts blur blurb 
blurbed blurbs blurred blurry blurs blurt blurted blurter blurts blush blushed blusher 
blushes bluster blype blypes bo boa boar board boarded boarder boards boarish 
boars boart boarts boas boast boasted boaster boasts boat boated boatel boatels 
boater boaters boatful boatman boatmen boats bob bobb bobbed bobber bobbers bobbery 
bobbies bobbin bobbins bobble bobbled bobbles bobby bobcat bobcats bobeche bobs bobsled 
bobstay bobtail bocce bocces bocci boccia boccias boccie boccies boccis boche boches 
bock bocks bod bode boded bodega bodegas bodes bodhran bodice bodices bodied 
bodies bodily bodings bodkin bodkins bods body boff boffed boffin boffins boffo 
boffola boffos boffs bog bogan bogans bogart bogarts bogbean bogey bogeyed bogeys 
bogg bogged boggier boggish boggle boggled boggler boggles boggy bogie bogies bogle 
bogles bogs bogus bogusly bogwood bogy bogyism bogyman bogymen bohea boheas bohemia 
boho bohos bohrium bohunk bohunks boil boiled boiler boilers boiloff boils boings 
boink boinked boinks boite boites bola bolar bolas bolases bold bolder boldest 
boldly bolds bole bolero boleros boles bolete boletes boleti boletus bolide bolides 
bolivar bolivia boll bollard bolled bollix bollox bolls bolo bologna boloney bolos 
bolshie bolshy bolson bolsons bolster bolt bolted bolter bolters bolts bolus boluses 
bomb bombard bombast bombax bombe bombed bomber bombers bombes bomblet bombs bombyx 
bon bonaci bonacis bonanza bonbon bonbons bond bondage bonded bonder bonders bondman 
bondmen bonds bonduc bonducs bone boned boner boners bones boneset boney boneyer 
bonfire bong bonged bongo bongoes bongos bongs boniato bonier boniest bonita bonitas 
bonito bonitos bonk bonked bonkers bonks bonne bonnes bonnet bonnets bonnie bonnier 
bonnily bonnock bonny bonobo bonobos bonsai bonus bonuses bony bonze bonzer bonzes 
boo boob boobed boobie boobies boobird boobish booboo booboos boobs booby boocoo 
boocoos boodies boodle boodled boodler boodles boody booed booger boogers boogey boogeys 
boogie boogied boogies boogy boohoo boohoos boojum boojums book booked bookend booker 
bookers bookful bookie bookies bookish booklet bookman bookmen bookoo bookoos books boom 
boombox boomed boomer boomers boomier boomkin boomlet booms boomy boon boonies boons 
boor boorish boors boos boost boosted booster boosts boot booted bootee bootees 
bootery booth booths bootie booties bootleg boots booty booz booze boozed boozer 
boozers boozes boozier boozily boozy bop bopeep bopeeps bopp bopped bopper boppers 
bops bor bora boraces boracic borage borages boral borals borane boranes boras 
borate borated borates borax boraxes bordel bordels border borders bordure bore boreal 
boreas bored boredom boreen boreens borer borers bores boric boride borides borings 
bork borked borks born borne borneol bornite boron boronic borons borough borrow 
borrows borsch borscht borsht borshts borstal bort borts borty bortz bortzes borzoi 
borzois bos boscage bosh boshbok boshes bosk boskage bosker bosket boskets boskier 
bosks bosky bosom bosomed bosoms bosomy boson bosonic bosons bosque bosques bosquet 
boss bossdom bossed bosses bossier bossies bossily bossism bossy boston bostons bosun 
bosuns bot bota botanic botany botas botch botched botcher botches botchy botel 
botels botfly both bother bothers bothies bothria bothy botonee bots bott bottle 
bottled bottler bottles bottom bottoms botts botulin boubou boubous bouchee boucle boucles 
boudin boudins boudoir bouffe bouffes bough boughed boughs bought bougie bougies boulder 
boule boules boulle boulles bounce bounced bouncer bounces bouncy bound bounded bounden 
bounder bounds bounty bouquet bourbon bourdon bourg bourgs bourn bourne bournes bourns 
bourree bourse bourses boursin bous bouse boused bouses bousy bout bouton boutons 
bouts bouvier bovid bovids bovine bovines bow bowed bowel boweled bowels bower 
bowered bowers bowery bowfin bowfins bowhead bowings bowknot bowl bowlder bowled bowleg 
bowlegs bowler bowlers bowless bowlful bowlike bowline bowls bowman bowmen bowpot bowpots 
bows bowse bowsed bowses bowshot bowwow bowwows bowyer bowyers box boxball boxcar 
boxcars boxed boxer boxers boxes boxfish boxful boxfuls boxhaul boxier boxiest boxily 
boxings boxlike boxwood boxy boy boyar boyard boyards boyars boychik boycott boyhood 
boyish boyla boylas boyo boyos boys bozo bozos br bra brabble brac 
brace braced bracer bracero bracers braces brach braches brachet brachia brachs bracken 
bracket bract bracted bracts brad bradawl bradded bradoon brads brae braes brag 
bragged bragger braggy brags brahma brahmas braid braided braider braids brail brailed 
braille brails brain brained brains brainy braise braised braises braize braizes brak 
brake braked brakes brakier braky braless bramble brambly bran branch branchy brand 
branded brander brands brandy brank branks branned branner branny brans brant brants 
bras brash brasher brashes brashly brashy brasier brasil brasils brass brassed brasses 
brassie brassy brat brats brattle bratty brav brava bravado bravas brave braved 
bravely braver bravers bravery braves bravest bravi bravo bravoed bravoes bravos bravura 
bravure braw brawer brawest brawl brawled brawler brawlie brawls brawly brawn brawns 
brawny braws braxies braxy bray brayed brayer brayers brays braz braza brazas 
braze brazed brazen brazens brazer brazers brazes brazier brazil brazils breach bread 
breaded breads breadth bready break breaker breaks breakup bream breamed breams breast 
breasts breath breathe breaths breathy breccia brecham brechan bred brede bredes bree 
breech breed breeder breeds breeks brees breeze breezed breezes breezy bregma bren 
brens brent brents breve breves brevet brevets brevier brevity brew brewage brewed 
brewer brewers brewery brewis brewpub brews brewski briar briard briards briars briary 
brib bribe bribed bribee bribees briber bribers bribery bribes brick bricked brickle 
bricks bricky bricole bridal bridals bride brides bridge bridged bridges bridle bridled 
bridler bridles bridoon brie brief briefed briefer briefly briefs brier briers briery 
bries brig brigade brigand bright brights brigs brill brillo brillos brills brim 
brimful brimmed brimmer brims brin brinded brindle brine brined briner briners brines 
bringer brings brinier brinies brinish brink brinks brins briny brio brioche briony 
brios briquet bris brisant brises brisk brisked brisker brisket briskly brisks briss 
brisses bristle bristly bristol brit brith briths brits britska britt brittle brittly 
britts britzka bro broach broad broadax broaden broader broadly broads brocade broche 
brock brocket brocks brocoli brogan brogans brogue brogues broider broil broiled broiler 
broils brok brokage broke broken broker brokers brolly bromal bromals bromate brome 
bromes bromic bromid bromide bromids bromin bromine bromins bromism bromize bromo bromos 
bronc bronchi broncho bronco broncos broncs bronze bronzed bronzer bronzes bronzy broo 
brooch brood brooded brooder broods broody brook brooked brookie brooks broom broomed 
brooms broomy broos bros brose broses brosy broth brothel brother broths brothy 
brought brow browed brown browned browner brownie browns browny brows browse browsed 
browser browses brr brrr brucin brucine brucins brugh brughs bruin bruins bruise 
bruised bruiser bruises bruit bruited bruiter bruits brulot brulots brulyie brulzie brumal 
brumby brume brumes brumous brunch brunet brunets brung brunt brunts brush brushed 
brusher brushes brushup brushy brusk brusker brusque brut brutal brute bruted brutely 
brutes brutify brutish brutism bruts brux bruxed bruxes bruxism bryony bub bubal 
bubale bubales bubalis bubals bubba bubbas bubbies bubble bubbled bubbler bubbles bubbly 
bubby bubinga bubkes bubo buboed buboes bubonic bubs bubu bubus buccal buck 
bucked buckeen bucker buckers bucket buckets buckeye buckish buckle buckled buckler buckles 
bucko buckoes buckos buckra buckram buckras bucks bucksaw bucolic bud budd budded 
budder budders buddha buddhas buddied buddies buddle buddles buddy budg budge budged 
budger budgers budges budget budgets budgie budgies budless budlike buds budworm buff 
buffalo buffed buffer buffers buffest buffet buffets buffi buffier buffo buffoon buffos 
buffs buffy bug bugaboo bugbane bugbear bugeye bugeyes bugg bugged bugger buggers 
buggery buggier buggies buggy bugl bugle bugled bugler buglers bugles bugloss bugout 
bugouts bugs bugseed bugsha bugshas buhl buhls buhr buhrs build builded builder 
builds buildup built buirdly bulb bulbar bulbed bulbel bulbels bulbil bulbils bulblet 
bulbous bulbs bulbul bulbuls bulg bulge bulged bulger bulgers bulges bulghur bulgier 
bulgur bulgurs bulgy bulimia bulimic bulk bulkage bulked bulkier bulkily bulks bulky 
bull bulla bullace bullae bullate bullbat bulldog bulled bullet bullets bullied bullier 
bullies bullion bullish bullock bullous bullpen bulls bully bulrush bulwark bum bumble 
bumbled bumbler bumbles bumboat bumelia bumf bumfs bumkin bumkins bumm bummalo bummed 
bummer bummers bummest bump bumped bumper bumpers bumph bumphs bumpier bumpily bumpkin 
bumps bumpy bums bun buna bunas bunch bunched bunches bunchy bunco buncoed 
buncos bund bundist bundle bundled bundler bundles bunds bundt bundts bung bunged 
bungee bungees bungle bungled bungler bungles bungs bunion bunions bunk bunked bunker 
bunkers bunko bunkoed bunkos bunks bunkum bunkums bunn bunnies bunns bunny bunraku 
buns bunt bunted bunter bunters bunts bunya bunyas buoy buoyage buoyant buoyed 
buoys bupkes bupkus buppie buppies buppy buqsha buqshas bur bura buran burans 
buras burb burble burbled burbler burbles burbly burbot burbots burbs burd burden 
burdens burdie burdies burdock burds bureau bureaus bureaux buret burets burette burg 
burgage burgee burgees burgeon burger burgers burgess burgh burghal burgher burghs burglar 
burgle burgled burgles burgoo burgoos burgout burgs burial burials buried burier buriers 
buries burin burins burk burka burkas burke burked burker burkers burkes burkite 
burl burlap burlaps burled burler burlers burlesk burley burleys burlier burlily burls 
burly burn burned burner burners burnet burnets burnie burnies burnish burnous burnout 
burns burnt burp burped burps burqa burqas burr burred burrer burrers burrier 
burrito burro burros burrow burrows burrs burry burs bursa bursae bursal bursar 
bursars bursary bursas bursate burse burseed bursera burses burst bursted burster bursts 
burthen burton burtons burweed bury bus busbar busbars busbies busboy busboys busby 
bused buses busgirl bush bushed bushel bushels busher bushers bushes bushido bushier 
bushily bushman bushmen bushpig bushtit bushwa bushwah bushwas bushy busied busier busies 
busiest busily busings busk busked busker buskers buskin buskins busks busload busman 
busmen buss bussed busses bust bustard busted buster busters bustic bustics bustier 
bustle bustled bustler bustles busts busty busy but butane butanes butanol butch 
butcher butches bute butene butenes buteo buteos butes butl butle butled butler 
butlers butlery butles buts butt buttals butte butted butter butters buttery buttes 
butties buttock button buttons buttony butts butty butut bututs butyl butyls butyral 
butyric butyrin butyryl buxom buxomer buxomly buy buyable buyback buyer buyers buyoff 
buyoffs buyout buyouts buys buzuki buzukia buzukis buzz buzzard buzzcut buzzed buzzer 
buzzers buzzes buzzwig bwana bwanas by bycatch bye byelaw byelaws byes bygone 
bygones bylaw bylaws byline bylined byliner bylines byname bynames bypass bypast bypath 
bypaths byplay byplays byre byres byrl byrled byrls byrnie byrnies byroad byroads 
bys byssal byssi byssus bytalk bytalks byte bytes byway byways byword bywords 
bywork byworks byzant byzants cab cabal cabala cabalas cabals cabana cabanas cabaret 
cabb cabbage cabbagy cabbala cabbed cabbie cabbies cabby caber cabers cabezon cabildo 
cabin cabined cabinet cabins cabl cable cabled cabler cablers cables cablet cablets 
cabman cabmen cabob cabobs cabomba caboose cabs caliber calibre callboy camber cambers 
cambia cambial cambism cambist cambium cambric capable capably carabao carabid carabin caramba 
carb carbarn carbide carbine carbo carbon carbons carbora carbos carboy carboys carbs 
caribe caribes caribou carob carobs casaba casabas casbah casbahs cashbox cassaba catawba 
catbird catboat cebid cebids ceboid ceboids ceiba ceibas celeb celebs cembali cembalo 
cerebra chablis chabouk chabuk chabuks chaebol chamber chebec chebecs cherub cherubs chibouk 
chimb chimbly chimbs chub chubby chubs cibol cibols ciboria ciboule citable clabber 
clamber climb climbed climber climbs clobber clomb club clubbed clubber clubby clubman 
clubmen clubs clumber coalbin coalbox cob cobalt cobalts cobb cobber cobbers cobbier 
cobble cobbled cobbler cobbles cobbs cobby cobia cobias coble cobles cobnut cobnuts 
cobra cobras cobs cobweb cobwebs codable cohabit colby colbys colobi colobus comb 
combat combats combe combed comber combers combes combine combo combos combs combust 
confab confabs coomb coombe coombes coombs copaiba copyboy corban corbans corbeil corbel 
corbels corbie corbies corbina corby cordoba corncob corymb corymbs coulomb cowbane cowbell 
cowbind cowbird cowboy cowboys cowherb coxcomb crab crabbed crabber crabby crabs crambe 
crambes crambo crambos crib cribbed cribber cribs crowbar crumb crumbed crumber crumble 
crumbly crumbs crumbum crumby crybaby cub cubage cubages cubbies cubbish cubby cube 
cubeb cubebs cubed cuber cubers cubes cubic cubical cubicle cubicly cubics cubism 
cubisms cubist cubists cubit cubital cubiti cubits cubitus cuboid cuboids cubs cudbear 
cumber cumbers cumbia cumbias curable curably curb curbed curber curbers curbs cutback 
cutbank cyber cyborg cyborgs cymbal cymbals dab dabb dabbed dabber dabbers dabble 
dabbled dabbler dabbles dabs dabster dagoba dagobas darb darbar darbars darbies darbs 
datable daub daube daubed dauber daubers daubery daubes daubier daubry daubs dauby 
daybed daybeds daybook deb debacle debag debags debar debark debarks debars debase 
debased debaser debases debate debated debater debates debauch debeak debeaks debeard debit 
debited debits debone deboned deboner debones debouch debride debrief debris debs debt 
debtor debtors debts debug debugs debunk debunks debut debuted debuts debye debyes 
decibel demob demobs deorbit derbies derby desorb desorbs dhobi dhobis diabase diabolo 
dib dibasic dibb dibbed dibber dibbers dibble dibbled dibbler dibbles dibbuk dibbuks 
dibs dicamba dieback dingbat diobol diobols dirtbag disable disband disbar disbars disbud 
disbuds disobey disrobe disturb djebel djebels doable dobber dobbers dobbies dobbin dobbins 
dobby dobie dobies dobla doblas doblon doblons dobra dobras dobro dobros dobson 
dobsons doby dogbane doobie doobies dorbug dorbugs double doubled doubler doubles doublet 
doubly doubt doubted doubter doubts dowable downbow drab drabbed drabber drabbet drabble 
drably drabs drawbar drib dribbed dribble dribbly driblet dribs drub drubbed drubber 
drubs drumble dryable dub dubb dubbed dubber dubbers dubbin dubbins dubiety dubious 
dubnium dubs dumb dumbed dumber dumbest dumbly dumbo dumbos dumbs dupable durable 
durably durbar durbars dustbin dweeb dweebs dweeby dyable dybbuk dybbuks dyeable earbud 
earbuds earlobe eatable ebb ebbed ebbet ebbets ebbs ebon ebonics ebonies ebonise 
ebonite ebonize ebons ebony ebook ebooks ecbolic edible edibles effable elbow elbowed 
elbows embalm embalms embank embanks embar embargo embark embarks embars embassy embay 
embayed embays embed embeds ember embers emblaze emblem emblems embody emboli embolic 
embolus emboly embosk embosks embosom emboss embow embowed embowel embower embows embrace 
embroil embrown embrue embrued embrues embrute embryo embryon embryos enable enabled enabler 
enables ennoble enrobe enrobed enrober enrobes entomb entombs enwomb enwombs eobiont ephebe 
ephebes ephebi ephebic epheboi ephebos ephebus epiboly equable equably erbium erbiums errable 
exabyte exhibit exurb exurban exurbia exurbs eyeable eyeball eyebar eyebars eyebeam eyebolt 
eyebrow fab fabber fabbest fabl fable fabled fabler fablers fables fabliau fabric 
fabrics fabs fabular fadable falbala farebox fatback fatbird febrile feeb feeble feebler 
feebly feebs feedbag feedbox ferbam ferbams fib fibb fibbed fibber fibbers fiber 
fibered fibers fibre fibres fibril fibrils fibrin fibrins fibroid fibroin fibroma fibrous 
fibs fibster fibula fibulae fibular fibulas filbert filibeg fimble fimbles fimbria finable 
finback firebox firebug fixable flab flabby flabs flambe flambee flambes flatbed fleabag 
flub flubbed flubber flubdub flubs flyable flybelt flyblew flyblow flyboat flyboy flyboys 
flyby flybys fob fobb fobbed fobs fogbow fogbows foible foibles footbag footboy 
forb forbad forbade forbare forbear forbid forbids forbode forbore forbs forby forbye 
forebay foreby forebye freebee freebie friable fribble frisbee fryable fub fubar fubb 
fubbed fubs fubsier fubsy fumble fumbled fumbler fumbles furbish fusible fusibly fynbos 
gab gabb gabbard gabbart gabbed gabber gabbers gabbier gabble gabbled gabbler gabbles 
gabbro gabbros gabby gabelle gabfest gabies gabion gabions gabl gable gabled gables 
gaboon gaboons gabs gaby galabia gamb gamba gambade gambado gambas gambe gambes 
gambia gambias gambier gambir gambirs gambit gambits gamble gambled gambler gambles gamboge 
gambol gambols gambrel gambs garb garbage garbagy garbed garble garbled garbler garbles 
garboil garbs gasbag gasbags gazabo gazabos gazebo gazebos gearbox gelable gemsbok gerbera 
gerbil gerbils getable ghibli ghiblis gib gibb gibbed gibber gibbers gibbet gibbets 
gibbon gibbons gibbose gibbous gibe gibed giber gibers gibes giblet giblets gibs 
gibson gibsons gigabit gilbert gimbal gimbals gleba glebae glebe glebes glib glibber 
glibly glob global globate globby globe globed globes globin globins globoid globose 
globous globs globule gob goban gobang gobangs gobans gobb gobbed gobbet gobbets 
gobble gobbled gobbler gobbles gobies gobioid goblet goblets goblin goblins gobo goboes 
gobonee gobony gobos gobs goby goldbug gombeen gombo gombos goober goobers goodby 
goodbye goodbys goombah goombay grab grabbed grabber grabble grabby graben grabens grabs 
grebe grebes gribble grub grubbed grubber grubby grubs grumble grumbly gumball gumbo 
gumboil gumboot gumbos gunboat gyb gybe gybed gybes habile habit habitan habitat 
habited habits habitue habitus haboob haboobs habu habus hackbut hagborn hagbush hagbut 
hagbuts halberd halbert halibut hambone hamburg handbag harbor harbors harbour hatable hatband 
hatbox hauberk hautboy hebe hebes hebetic hellbox henbane henbit henbits herb herbage 
herbal herbals herbed herbier herbs herby hereby hewable hibachi hidable highboy hijab 
hijabs hipbone hirable hob hobb hobbed hobber hobbers hobbies hobbit hobbits hobble 
hobbled hobbler hobbles hobby hoblike hobnail hobnob hobnobs hobo hoboed hoboes hoboism 
hobos hobs hogback holibut hombre hombres homburg homeboy hotbed hotbeds hotbox howbeit 
hub hubbies hubbly hubbub hubbubs hubby hubcap hubcaps hubris hubs humble humbled 
humbler humbles humbly humbug humbugs husband hushaby hybrid hybrids hybris iamb iambi 
iambic iambics iambs iambus ibex ibexes ibices ibidem ibis ibises iceberg iceboat 
icebox ignoble ignobly ikebana imbalm imbalms imbark imbarks imbed imbeds imbibe imbibed 
imbiber imbibes imblaze imbody imbosom imbower imbrown imbrue imbrued imbrues imbrute imbu 
imbue imbued imbues inbe inboard inborn inbound inbred inbreds inbreed inbuilt inburst 
inby inbye incubi incubus indaba indabas inhabit inhibin inhibit inkblot intomb intombs 
isba isbas isobar isobare isobars isobath jab jabb jabbed jabber jabbers jabiru 
jabirus jabot jabots jabs jacobin jacobus jamb jambe jambeau jambed jambes jambs 
jawbone jaybird jazzbo jazzbos jebel jebels jellaba jerboa jerboas jetbead jezebel jib 
jibb jibbed jibber jibbers jibboom jibbs jibe jibed jiber jibers jibes jibs 
jigaboo job jobb jobbed jobber jobbers jobbery jobless jobname jobs jojoba jojobas 
juba jubas jubbah jubbahs jube jubes jubhah jubhahs jubile jubilee jubiles jujube 
jujubes jukebox jumbal jumbals jumble jumbled jumbler jumbles jumbo jumbos jumbuck kab 
kabab kababs kabaka kabakas kabala kabalas kabar kabars kabaya kabayas kabbala kabiki 
kabikis kabob kabobs kabs kabuki kabukis kalimba kanban kanbans kasbah kasbahs kbar 
kbars kebab kebabs kebar kebars kebbie kebbies kebbock kebbuck keblah keblahs kebob 
kebobs kerb kerbed kerbs kibbe kibbeh kibbehs kibbes kibbi kibbis kibbitz kibble 
kibbled kibbles kibbutz kibe kibei kibeis kibes kibitz kibla kiblah kiblahs kiblas 
kibosh kickbox kilobar kilobit kitbag kitbags knob knobbed knobbly knobby knobs knubby 
kob kobo kobold kobolds kobos kobs kolbasi kombu kombus krubi krubis krubut 
krubuts kurbash kybosh lab labara labarum label labeled labeler labella labels labia 
labial labials labiate labile labium labor labored laborer labors labour labours labra 
labret labrets labroid labrum labrums labs ladybug lakebed lamb lambada lambast lambda 
lambdas lambed lambent lamber lambers lambert lambie lambier lambies lambkin lambs lamby 
lavabo lavabos lawbook leben lebens legible legibly lesbian lesbo lesbos liable lib 
libber libbers libel libeled libelee libeler libels liber liberal libers liberty libido 
libidos liblab liblabs libra librae library libras librate libri libs likable limb 
limba limbas limbate limbeck limbed limber limbers limbi limbic limbier limbo limbos 
limbs limbus limby linable linkboy livable lob lobar lobate lobated lobb lobbed 
lobber lobbers lobbied lobbies lobby lobbyer lobe lobed lobefin lobelia lobes lobo 
lobos lobs lobster lobular lobule lobules lobworm lockbox logbook longbow loobies looby 
losable lovable lovably lovebug lowball lowborn lowboy lowboys lowbred lowbrow lub lubber 
lubbers lube lubed lubes lubric lullaby lumbago lumbar lumbars lumber lumbers mabe 
mabes macaber macabre macumba mailbag mailbox makable mamba mambas mambo mamboed mamboes 
mambos mangaby marabou marble marbled marbler marbles marbly marimba mastaba maybe maybes 
maybird maybush mbira mbiras megabar megabit member members mib mibs microbe midrib 
midribs mihrab mihrabs milneb milnebs mimbar mimbars minable minibar minibus minicab minilab 
misbias misbill misbind mistbow mixable mixible mob mobb mobbed mobber mobbers mobbish 
mobbism mobcap mobcaps mobile mobiles mobled mobs mobster moonbow morbid movable movably 
mudbug mudbugs mumble mumbled mumbler mumbles mumbly mutable mutably nab nabb nabbed 
nabber nabbers nabe nabes nabis nabob nabobs nabs namable nawab nawabs nearby 
neb nebbish nebs nebula nebulae nebular nebulas nebule nebuly nelumbo newbie newbies 
newborn newsboy nib nibb nibbed nibble nibbled nibbler nibbles niblick niblike nibs 
nimbi nimble nimbler nimbly nimbus niobate niobic niobite niobium niobous nob nobbier 
nobbily nobble nobbled nobbler nobbles nobby noble nobler nobles noblest nobly nobody 
nobs nombles nombril nonbank nonbody nonbook nosebag notable notably nub nubbier nubbin 
nubbins nubble nubbles nubbly nubby nubia nubias nubile nubs nubuck nubucks numb 
numbat numbats numbed number numbers numbest numbles numbly numbs oba obas obconic 
obe obeah obeahs obeli obelia obelias obelise obelisk obelism obelize obelus obento 
obentos obes obese obesely obesity obey obeyed obeyer obeyers obeys obi obia 
obias obiism obiisms obis obit obits object objects objet objets oblast oblasti 
oblasts oblate oblates oblige obliged obligee obliger obliges obligor oblique oblong oblongs 
obloquy oboe oboes oboist oboists obol obole oboles oboli obols obolus obovate 
obovoid obscene obscure obsequy observe obsess obtain obtains obtect obtest obtests obtrude 
obtund obtunds obtuse obtuser obverse obvert obverts obviate obvious oddball offbeat oilbird 
omber ombers ombre ombres omnibus onboard orb orbed orbier orbiest orbit orbital 
orbited orbiter orbits orbless orbs orby oribi oribis ouabain ourebi ourebis outback 
outbake outbark outbawl outbeam outbeg outbegs outbid outbids outbox outbrag outbred outbulk 
outburn outbuy outbuys outby outbye overbed overbet overbid overbig overbuy overdub ovibos 
ownable oxblood oxbow oxbows pablum pablums pabular pabulum pageboy palabra parable parbake 
parboil payable payably payback pebble pebbled pebbles pebbly pedicab peebeen pegbox pembina 
perturb phobia phobias phobic phobics phoebe phoebes phoebus piasaba pibal pibals pibroch 
piebald pigboat pillbox pinball pinbone placebo playboy pleb plebe plebes plebs pliable 
pliably plowboy plumb plumbed plumber plumbic plumbs plumbum poblano poboy poboys pokable 
posable postbag postbox postboy potable potboil potboy potboys potherb prebade prebake prebend 
prebid prebids prebill prebind preboil prebook preboom prebuy prebuys prefab prefabs preverb 
prob proband probang probate probe probed prober probers probes probit probits probity 
problem proverb pub puberal puberty pubes pubic pubis public publics publish pubs 
pueblo pueblos qabala qabalah qabalas qubit qubits qubyte qubytes quibble rabat rabato 
rabatos rabats rabbet rabbets rabbi rabbies rabbin rabbins rabbis rabbit rabbits rabbity 
rabble rabbled rabbler rabbles rabboni rabic rabid rabidly rabies ragbag ragbags railbus 
rainbow rambla ramblas ramble rambled rambler rambles rarebit rasbora ratable ratably ratbag 
ratbags reb rebait rebaits rebar rebars rebate rebated rebater rebates rebato rebatos 
rebbe rebbes rebec rebeck rebecks rebecs rebegan rebegin rebegun rebel rebels rebid 
rebids rebill rebills rebind rebinds rebirth reblend reblent rebloom reboant reboard rebody 
reboil reboils rebook rebooks reboot reboots rebop rebops rebore rebored rebores reborn 
rebound rebozo rebozos rebred rebreed rebs rebuff rebuffs rebuild rebuilt rebuke rebuked 
rebuker rebukes rebury rebus rebuses rebut rebuts rebuy rebuys recomb recombs redbait 
redbay redbays redbird redbone redbud redbuds redbug redbugs redoubt redub redubs rehab 
rehabs reitbok relabel replumb reprobe resorb resorbs retable reverb reverbs rhabdom rhebok 
rheboks rhomb rhombi rhombic rhombs rhombus rhubarb rhumb rhumba rhumbas rhumbs rib 
ribald ribalds riband ribands ribb ribband ribbed ribber ribbers ribbier ribbon ribbons 
ribbony ribby ribes ribier ribiers ribless riblet riblets riblike ribose riboses ribs 
ribwort ridable risible risibly roadbed rob robalo robalos roband robands robb robbed 
robber robbers robbery robbin robbins robe robed robes robin robins roble robles 
robot robotic robotry robots robs robust robusta rockaby roebuck ropable rosebay rosebud 
rouble roubles rowable rowboat rub rubaboo rubace rubaces rubasse rubati rubato rubatos 
rubb rubbed rubber rubbers rubbery rubbies rubbish rubble rubbled rubbles rubbly rubby 
rubdown rube rubel rubella rubels rubeola rubes rubidic rubied rubier rubies rubiest 
rubigo rubigos rubious ruble rubles ruboff ruboffs rubout rubouts rubric rubrics rubs 
rubus ruby rudesby rugbies rugby rulable rumba rumbaed rumbas rumble rumbled rumbler 
rumbles rumbly runback rurban sab sabal sabals sabaton sabayon sabb sabbat sabbath 
sabbats sabbed sabe sabed saber sabered sabers sabes sabin sabine sabines sabins 
sabir sabirs sable sables sabot sabots sabr sabra sabras sabre sabred sabres 
sabs sacbut sacbuts sackbut sagbut sagbuts sahib sahibs salable salably saltbox samba 
sambaed sambal sambals sambar sambars sambas sambhar sambhur sambo sambos sambuca sambuke 
sambur samburs sandbag sandbar sandbox sandbur sanddab saprobe sassaby savable sawbill sawbuck 
saxtuba sayable scab scabbed scabble scabby scabies scabs scarab scarabs schlub schlubs 
scribal scribe scribed scriber scribes scrub scrubby scrubs scuba scubaed scubas scumbag 
scumble seabag seabags seabed seabeds seabird seaboot sebacic sebasic sebum sebums seeable 
seedbed serdab serdabs setback sewable shabby shamble shebang shebean shebeen sherbet shibah 
shibahs shlub shlubs shoebox shopboy showbiz shrub shrubby shrubs sib sibb sibbs 
sibl sibs sibyl sibylic sibyls sickbay sickbed sidebar sizable sizably sjambok skiable 
skibob skibobs skybox slab slabbed slabber slabs slob slobber slobby slobs slub 
slubbed slubber slubs slumber slurb slurban slurbs snib snibbed snibs snob snobby 
snobs snub snubbed snubber snubby snubs soapbox sob soba sobas sobb sobbed 
sobber sobbers sobeit sober sobered soberer soberly sobers sobful sobs sofabed soluble 
solubly somber sombre sorb sorbate sorbed sorbent sorbet sorbets sorbic sorbose sorbs 
soubise sowable soybean spambot squab squabby squabs squib squibs stab stabbed stabber 
stabile stable stabled stabler stables stably stabs standby stewbum stibial stibine stibium 
stob stobbed stobs strobe strobes strobic strobil stub stubbed stubble stubbly stubby 
stubs stumble suable suably sub suba subacid subadar subah subahs subalar subarea 
subarid subas subatom subb subbase subbass subbed subcell subclan subcode subcool subcult 
subdean subdeb subdebs subdual subduce subduct subdue subdued subduer subdues subecho subedit 
suber suberic suberin subers subfile subfix subfusc subgoal subgum subgums subhead subidea 
subitem subito subject subjoin sublate sublet sublets sublime subline sublot sublots submenu 
submiss submit submits subnet subnets suboral suborn suborns suboval subpar subpart subpena 
subplot subr subrace subrent subrule subs subsale subsea subsect subsere subset subsets 
subside subsidy subsist subsite subsoil subsume subtask subtaxa subteen subtend subtest subtext 
subtile subtle subtler subtly subtone subtype subunit suburb suburbs subvene subvert subway 
subways subzero subzone succuba succubi succumb sunback sunbath sunbeam sunbelt sunbird sunbow 
sunbows sunburn superb surbase swab swabbed swabber swabbie swabby swabs swingby swob 
swobbed swobber swobs sybo syboes syllabi symbion symbiot symbol symbols tab tabanid 
tabard tabards tabaret tabb tabbed tabbied tabbies tabbis tabby taber tabered tabers 
tabes tabetic tabid tabl tabla tablas table tableau tabled tables tablet tablets 
tabloid taboo tabooed taboos tabor tabored taborer taboret taborin tabors tabouli tabour 
tabours tabs tabu tabued tabular tabuli tabulis tabun tabuns tabus takable tallboy 
tamable tambac tambacs tambak tambaks tambala tambour tambur tambura tamburs tanbark tarbush 
taskbar taxable taxably taxicab teabowl teabox temblor tenable tenably terbia terbias terbic 
terbium terebic thebe thebes theorbo thereby thimble throb throbs thrombi thumb thumbed 
thumbs tibia tibiae tibial tibias tidbit tidbits tieback tilbury timbal timbale timbals 
timber timbers timbery timbral timbre timbrel timbres titbit titbits tobacco tobies toby 
tollbar tomb tombac tomback tombacs tombak tombaks tombal tombed tombola tombolo tomboy 
tomboys tombs toolbar toolbox totable towable towboat treble trebled trebles trebly tremble 
trembly triable tribade tribal tribals tribe tribes tribune tribute trilby trouble tsuba 
tub tuba tubae tubaist tubal tubas tubate tubb tubbed tubber tubbers tubbier 
tubby tube tubed tuber tubers tubes tubful tubfuls tubifex tubings tubist tubists 
tublike tubs tubular tubule tubules tubulin tugboat tumble tumbled tumbler tumbles tumbrel 
tumbril tunable tunably turban turbans turbary turbeth turbid turbine turbit turbith turbits 
turbo turbos turbot turbots twibil twibill twibils tymbal tymbals typable typebar ubiety 
ubique umbel umbeled umbels umber umbered umbers umbles umbo umbonal umbones umbonic 
umbos umbra umbrae umbrage umbral umbras unable unbaked unbale unbaled unbales unban 
unbans unbar unbars unbased unbated unbe unbear unbears unbelt unbelts unbend unbends 
unbent unbid unbind unbinds unblest unblock unbolt unbolts unboned unborn unbosom unbound 
unbowed unbox unboxed unboxes unbrace unbraid unbrake unbred unbroke unbuild unbuilt unbulky 
unburnt unbusy uncurb uncurbs unibody unlobed unrobe unrobed unrobes unsober upbear upbears 
upbeat upbeats upbind upbinds upboil upboils upbore upborne upbound upbow upbows upbraid 
upbuild upbuilt upby upbye upclimb urb urban urbane urbaner urbia urbias urbs 
usable usably useable useably verb verbal verbals verbena verbid verbids verbify verbile 
verbose verbs viable viably vibe vibes vibist vibists vibrant vibrate vibrato vibrio 
vibrion vibrios visible visibly vocab vocable vocably vocabs voluble volubly votable wab 
wabble wabbled wabbler wabbles wabbly wabs wadable wallaby wamble wambled wambles wambly 
wannabe warble warbled warbler warbles wasabi wasabis washtub waxable waxbill waybill web 
webb webbed webbier webby webcam webcams webcast weber webers webfed webfeet webfoot 
webless weblike weblog weblogs webpage webs website webster webwork webworm wetback whereby 
wimble wimbled wimbles windbag wingbow wirable wobble wobbled wobbler wobbles wobbly womb 
wombat wombats wombed wombier wombs womby woodbin woodbox workbag workbox xebec xebecs 
yabber yabbers yabbie yabbies yabby yerba yerbas yob yobbo yobboes yobbos yobs 
yohimbe zareba zarebas zareeba zariba zaribas zebec zebeck zebecks zebecs zebra zebraic 
zebrano zebras zebrass zebrine zebroid zebu zebus zibet zibeth zibeths zibets zineb 
zinebs zombi zombie zombies zombify zombis
);

my @V_words = qw(
above aboves absolve abusive abvolt abvolts achieve active actives advance advect advects 
advent advents adverb adverbs adverse advert adverts advice advices advise advised advisee 
adviser advises advisor agave agaves agravic airwave aiver aivers ajiva ajivas akvavit 
alcove alcoved alcoves alevin alevins alive allover alluvia alveoli alvine amative amusive 
anchovy anvil anviled anvils approve aquavit aquiver archive arrival arrive arrived arriver 
arrives arval arvo arvos atavic atavism atavist ava avail availed avails avant 
avarice avast avatar avatars avaunt ave avellan avenge avenged avenger avenges avens 
avenses avenue avenues aver average averred avers averse avert averted averter averts 
aves avgas avgases avian avians aviary aviate aviated aviates aviatic aviator avid 
avidin avidins avidity avidly avion avionic avions aviso avisos avo avocado avocet 
avocets avodire avoid avoided avoider avoids avos avoset avosets avouch avow avowal 
avowals avowed avower avowers avows avulse avulsed avulses baklava beaver beavers bedevil 
beehive beeves behave behaved behaver behaves behoove behove behoved behoves believe belive 
beloved bereave bevel beveled beveler bevels bevies bevomit bevor bevors bevy bilevel 
bivalve bivinyl bivouac bolivar bolivia bouvier bovid bovids bovine bovines brav brava 
bravado bravas brave braved bravely braver bravers bravery braves bravest bravi bravo 
bravoed bravoes bravos bravura bravure breve breves brevet brevets brevier brevity cadaver 
calv calvary calve calved calves canvas canvass captive caravan caravel carv carve 
carved carvel carvels carven carver carvers carves casava casavas cassava cav cavalla 
cavally cavalry cave caveat caveats caved caveman cavemen caver cavern caverns cavers 
caves cavetti cavetto caviar caviare caviars cavie cavies cavil caviled caviler cavils 
cavings cavity cavort cavorts cavy centavo cerveza cervid cervine cervix ceviche chervil 
chevied chevies cheviot chevre chevres chevret chevron chevy chivari chive chives chivied 
chivies chivvy chivy civet civets civic civics civie civies civil civilly civism 
civisms civvies civvy clavate clave claver clavers claves clavi clavier clavus cleave 
cleaved cleaver cleaves clever clevis clivers clivia clivias clove cloven clover clovers 
clovery cloves coaeval codrive codrove coeval coevals commove concave connive convect convene 
convent convert convex convey conveys convict convoke convoy convoys corvee corvees corves 
corvet corvets corvid corvids corvina corvine costive couvade cov covary cove coved 
coven covens cover covered coverer covers covert coverts coverup coves covet coveted 
coveter covets covey coveys covin covings covins crav cravat cravats crave craved 
craven cravens craver cravers craves crevice culver culvers culvert cursive curv curve 
curved curves curvet curvets curvey curvier curvy cutover cuvee cuvees cuvette datival 
dative datives daven davened davens davies davit davits davy deav deave deaved 
deaves deceive decurve deleave deliver delv delve delved delver delvers delves deprave 
deprive derive derived deriver derives dervish deserve dev deva devalue devas devein 
deveins devel develed develop devels devest devests deviant deviate device devices devil 
deviled devilry devils devious devisal devise devised devisee deviser devises devisor devoice 
devoid devoir devoirs devolve devon devons devote devoted devotee devotes devour devours 
devout devs diluvia disavow dissave div diva divan divans divas dive dived 
diver diverge divers diverse divert diverts dives divest divests divide divided divider 
divides divine divined diviner divines divisor divorce divot divots divulge divulse divvied 
divvies divvy dogvane dove dovecot dovekey dovekie doven dovened dovens doves dovish 
drave driv drive drivel drivels driven driver drivers drives drov drove droved 
drover drovers droves duumvir duvet duvets duvetyn dwarves dyvour dyvours eave eaved 
eaves eightvo elative elevate eleven elevens elevon elevons elusive eluvia eluvial eluvium 
elver elvers elves elvish emotive enclave endive endives enfever engrave enliven enslave 
envelop envenom envied envier enviers envies envious enviro environ enviros envoi envois 
envoy envoys envy erosive ervil ervils estival evacuee evad evade evaded evader 
evaders evades evangel evanish evasion evasive eve even evened evener eveners evenest 
evenly evens event events ever evert everted evertor everts every eves evict 
evicted evictee evictor evicts evident evil eviler evilest eviller evilly evils evince 
evinced evinces evit evite evited evites evok evoke evoked evoker evokers evokes 
evolute evolve evolved evolver evolves evulse evulsed evulses evzone evzones exclave exuvia 
exuviae exuvial exuvium fauve fauves fauvism fauvist fava favas fave favela favelas 
favella faves favism favisms favor favored favorer favors favour favours favus favuses 
fervent fervid fervor fervors fervour festive fever fevered fevers fictive five fiver 
fivers fives flavin flavine flavins flavone flavor flavors flavory flavour flivver fluvial 
flyover forever forgave forgive fovea foveae foveal foveas foveate foveola foveole frivol 
frivols fulvous furtive ganev ganevs garvey garveys gavage gavages gave gavel gaveled 
gavels gavial gavials gavot gavots gavotte geneva genevas gingiva giv give given 
givens giver givers gives glaive glaived glaives glov glove gloved glover glovers 
gloves govern governs grav grave graved gravel gravels gravely graven graver gravers 
graves gravest gravid gravida gravies gravity gravlax gravure gravy greave greaved greaves 
grieve grieved griever grieves grivet grivets groove grooved groover grooves groovy grove 
groved grovel grovels groves guava guavas guv guvs gyv gyve gyved gyves 
halavah halv halva halvah halvahs halvas halve halved halvers halves harvest hav 
havarti have haven havened havens haver havered haverel havers haves havior haviors 
haviour havoc havocs heav heave heaved heaven heavens heaver heavers heaves heavier 
heavies heavily heavy helluva helv helve helved helves hiv hive hived hives 
hooved hoover hoovers hooves hove hovel hoveled hovels hover hovered hoverer hovers 
however hryvna hryvnas hryvnia humvee humvees illuvia impavid improv improve improvs incivil 
incurve innerve invade invaded invader invades invalid invar invars inveigh invent invents 
inverse invert inverts invest invests invital invite invited invitee inviter invites invoice 
invoke invoked invoker invokes involve inweave inwove inwoven isogriv ivied ivies ivories 
ivory ivy ivylike jarvey jarveys java javas javelin jayvee jayvees jiv jive 
jiveass jived jiver jivers jives jivey jivier jiviest jivy jovial jussive juvenal 
kava kavas kavass keeve keeves kelvin kelvins kevel kevels kevil kevils khedive 
kidvid kidvids kiva kivas klavern knave knavery knaves knavish knives kuvasz kvas 
kvases kvass kvasses kvell kvelled kvells kvetch kvetchy laevo larva larvae larval 
larvas lav lava lavabo lavabos lavage lavages lavas lavash lave laved laveer 
laveers laver lavers laves lavish lavrock lavs layover leav leave leaved leaven 
leavens leaver leavers leaves leavier leavy lekvar lekvars lev leva levant levants 
levator levee leveed levees level leveled leveler levelly levels lever levered leveret 
levers levied levier leviers levies levin levins levis levity levo levulin levy 
lieve liever lievest liv livable live lived lively liven livened livener livens 
liver livered livers livery lives livest livid lividly livier liviers livings livre 
livres livyer livyers lixivia loaves louver louvers louvre louvred louvres lov lovable 
lovably lovage lovages lovat lovats love lovebug loved lovely lover loverly lovers 
loves luv luvs maglev maglevs marvel marvels marvy massive mauve mauves maven 
mavens mavie mavies mavin mavins mavis mavises mayvin mayvins medevac medivac mikvah 
mikvahs mikveh mikvehs mikvos mikvot mikvoth minivan miniver misaver misgave misgive mislive 
mismove missive mitsvah mitzvah moshav motive motived motives motivic mov movable movably 
move moved mover movers moves movie movies moviola naevi naevoid naevus naive 
naively naiver naives naivest naivete naivety native natives navaid navaids naval navally 
navar navars nave navel navels naves navette navies navvies navvy navy nerv 
nervate nerve nerved nerves nervier nervily nervine nervous nervule nervure nervy neve 
never neves nevi nevoid nevus nieve nieves nirvana nival niveous nouveau nova 
novae novas novel novella novelle novelly novels novelty novena novenae novenas novice 
novices oaves obovate obovoid observe obverse obvert obverts obviate obvious octaval octave 
octaves octavo octavos oeuvre oeuvres ogival ogive ogives olivary olive olives olivine 
ottava ottavas outgave outgive outlive outlove outmove outrave outvie outvied outvies outvote 
ova oval ovality ovally ovals ovarial ovarian ovaries ovary ovate ovately ovation 
oven ovens over overact overage overall overapt overarm overate overawe overbed overbet 
overbid overbig overbuy overcoy overcut overdid overdo overdog overdry overdub overdue overdye 
overeat overed overfar overfat overfed overfit overfly overhot overjoy overlap overlax overlay 
overlet overlie overlit overly overman overmen overmix overnew overpay overply overran overrun 
overs oversad oversaw oversea oversee overset oversew oversup overt overtax overtip overtly 
overtop overuse overwet ovibos ovicide oviduct oviform ovine ovines ovipara ovisac ovisacs 
ovoid ovoidal ovoids ovoli ovolo ovolos ovonic ovonics ovular ovulary ovulate ovule 
ovules ovum pahlavi palaver pareve parve parvenu parvis parvise parvo parvos passive 
pav pavan pavane pavanes pavans pave paved paveed paver pavers paves pavid 
pavin pavings pavins pavior paviors paviour pavis pavise paviser pavises pavisse pavlova 
peavey peaveys peavies peavy peccavi peev peeve peeved peeves peevish pelves pelvic 
pelvics pelvis pensive perv pervade pervert pervs piasava pivot pivotal pivoted pivots 
plosive plover plovers pluvial pluvian poove pooves popover poverty preaver precava predive 
prepave prevail prevent preverb preview previse prevue prevued prevues privacy private privet 
privets privier privies privily privity privy prov prove proved proven prover proverb 
provers proves provide proviso provoke provost pulvini purvey purveys purview qiviut qiviuts 
quaver quavers quavery quiver quivers quivery rav ravage ravaged ravager ravages rave 
raved ravel raveled raveler ravelin ravelly ravels raven ravened ravener ravens raver 
ravers raves ravin ravine ravined ravines ravings ravins ravioli ravish reav reavail 
reave reaved reaver reavers reaves reavow reavows receive recover recurve redrive redrove 
reev reeve reeved reeves reevoke regave regive regiven regives reiv reive reived 
reiver reivers reives releve releves relieve relievo relive relived relives removal remove 
removed remover removes renvoi renvois repave repaved repaves replevy reprove reserve reshave 
resolve restive rev revalue revamp revamps reveal reveals revel reveled reveler revelry 
revels revenge revenue reverb reverbs revere revered reverer reveres reverie revers reverse 
reverso revert reverts revery revest revests revet revets review reviews revile reviled 
reviler reviles revisal revise revised reviser revises revisit revisor revival revive revived 
reviver revives revoice revoke revoked revoker revokes revolt revolts revolve revote revoted 
revotes revs revue revues revuist revv revved reweave rewove rewoven riever rievers 
rilievi rilievo riv rivage rivages rival rivaled rivalry rivals rive rived riven 
river rivers rives rivet riveted riveter rivets riviera riviere rivulet rov rove 
roved roven rover rovers roves rovings runover saliva salivas salv salvage salve 
salved salver salvers salves salvia salvias salvo salvoed salvoes salvor salvors salvos 
samovar sav savable savage savaged savager savages savanna savant savants savarin savate 
savates save saved saveloy saver savers saves savin savine savines savings savins 
savior saviors saviour savor savored savorer savors savory savour savours savoury savoy 
savoys savvied savvier savvies savvily savvy scarves schav schavs scrieve scrive scrived 
scrives scurvy selva selvage selvas selves serovar serv serval servals servant serve 
served server servers serves service servile servo servos seven sevens seventh seventy 
sever several severe severed severer severs seviche sevruga shav shave shaved shaven 
shaver shavers shaves shavie shavies sheave sheaved sheaves sheeve sheeves shelve shelved 
shelver shelves shelvy shiv shiva shivah shivahs shivas shive shiver shivers shivery 
shives shiviti shivs shov shove shoved shovel shovels shover shovers shoves shrieve 
shrive shrived shrivel shriven shriver shrives shrove siev sieve sieved sievert sieves 
silva silvae silvan silvans silvas silver silvern silvers silvery silvex silvics siver 
sivers skiv skive skived skiver skivers skives skivvy skydive skydove slav slave 
slaved slaver slavers slavery slaves slavey slaveys slavish sleave sleaved sleaves sleeve 
sleeved sleeves slieve slieves sliver slivers sloven slovens snivel snivels soave soaves 
soever solv solvate solve solved solvent solver solvers solves sonovox soviet soviets 
sovkhoz sovran sovrans spavie spavies spaviet spavin spavins spiv spivs spivvy starve 
starved starver starves stative stav stave staved staves steeve steeved steeves stiver 
stivers stove stover stovers stoves strive strived striven striver strives strove stuiver 
suasive suave suavely suaver suavest suavity suboval subvene subvert surveil survey surveys 
survive svaraj svelte svelter swerve swerved swerver swerves sweven swevens swiv swive 
swived swivel swivels swives swivet swivets sylva sylvae sylvan sylvans sylvas sylvin 
sylvine sylvins sylvite synovia tantivy tardive tav tavern taverna taverns tavs tensive 
thieve thieved thieves thrave thraves thrive thrived thriven thriver thrives throve tivy 
travail trave travel travels traves travois trevet trevets trivet trivets trivia trivial 
trivium trove trover trovers troves turves tussive twelve twelves ulva ulvas uncivil 
uncover uneven unglove unitive unlevel unlive unlived unlives unloved unmoved unnerve unpaved 
unravel unreeve unrove unroven unsaved unveil unveils unvexed unvext unvocal unvoice unweave 
unwove unwoven upcurve updive updived updives updove upheave uphove upriver uvea uveal 
uveas uveitic uveitis uveous uvula uvulae uvular uvulars uvulas vac vacancy vacant 
vacate vacated vacates vaccina vaccine vacs vacua vacuity vacuole vacuous vacuum vacuums 
vadose vagal vagally vagary vagi vagile vagina vaginae vaginal vaginas vagrant vagrom 
vague vaguely vaguer vaguest vagus vahine vahines vail vailed vails vain vainer 
vainest vainly vair vairs vakeel vakeels vakil vakils valance vale valence valency 
valeric vales valet valeted valets valgoid valgus valiant valid validly valine valines 
valise valises valkyr valkyrs vallate valley valleys valonia valor valors valour valours 
valse valses valu valuate value valued valuer valuers values valuta valutas valv 
valval valvar valvate valve valved valves valvula valvule vamoose vamose vamosed vamoses 
vamp vamped vamper vampers vampier vampire vampish vamps vampy van vanadic vanda 
vandal vandals vandas vandyke vane vaned vanes vang vangs vanilla vanish vanity 
vanload vanman vanmen vann vanned vanner vanners vanpool vans vantage vanward vapid 
vapidly vapor vapored vaporer vapors vapory vapour vapours vapoury vaquero var vara 
varas varia variant varias variate varices varied varier variers varies variety variola 
variole various varix varlet varlets varment varmint varna varnas varnish varoom varooms 
vars varsity varus varuses varve varved varves vary vas vasa vasal vascula 
vase vases vassal vassals vast vaster vastest vastier vastity vastly vasts vasty 
vat vatful vatfuls vatic vatical vats vatt vatted vatu vatus vau vault 
vaulted vaulter vaults vaulty vaunt vaunted vaunter vauntie vaunts vaunty vaus vav 
vavasor vavs vaw vaward vawards vawntie vaws veal vealed vealer vealers vealier 
veals vealy vector vectors vedalia vedette vee veejay veejays veena veenas veep 
veepee veepees veeps veer veered veeries veers veery vees veg vegan vegans 
veges vegetal vegete vegg vegged veggie veggies vegie vegies vehicle veil veiled 
veiler veilers veils vein veinal veined veiner veiners veinier veinlet veins veinule 
veiny vela velamen velar velaria velars velate velcro velcros veld velds veldt 
veldts veliger velites vellum vellums veloce velour velours veloute velum velure velured 
velures velvet velvets velvety vena venae venal venally venatic vend vendace vended 
vendee vendees vender venders vendor vendors vends vendue vendues veneer veneers venene 
venenes venery veng venge venged venges venial venin venine venines venins venire 
venires venison venom venomed venomer venoms venose venous vent ventage ventail vented 
venter venters ventral vents venture venturi venue venues venular venule venules venus 
venuses vera veranda verb verbal verbals verbena verbid verbids verbify verbile verbose 
verbs verdant verdict verdin verdins verdure verg verge verged verger vergers verges 
verglas veridic verier veriest verify verily verism verismo verisms verist verists veritas 
verite verites verity vermeil vermes vermian vermin vermis vermuth vernal vernier vernix 
verruca vers versal versant verse versed verser versers verses verset versets versify 
versine version verso versos verst verste verstes versts versus vert vertex vertigo 
verts vertu vertus vervain verve verves vervet vervets very vesica vesicae vesical 
vesicle vesper vespers vespid vespids vespine vessel vessels vest vesta vestal vestals 
vestas vested vestee vestees vestige vestral vestry vests vesture vet vetch vetches 
veteran vetiver veto vetoed vetoer vetoers vetoes vets vett vetted vetter vetters 
vex vexed vexedly vexer vexers vexes vexil vexilla vexils vext via viable 
viably viaduct vial vialed vialled vials viand viands viatic viatica viator viators 
vibe vibes vibist vibists vibrant vibrate vibrato vibrio vibrion vibrios vic vicar 
vicarly vicars vice viced viceroy vices vichies vichy vicinal vicious vicomte victim 
victims victor victors victory victual vicugna vicuna vicunas vid vide video videos 
vidette vidicon vids viduity vie vied vier viers vies view viewed viewer 
viewers viewier views viewy vig viga vigas vigia vigias vigil vigils vigor 
vigors vigour vigours vigs vik vikings vilayet vile vilely viler vilest vilify 
vill villa villae village villain villas villein villi villose villous vills villus 
vim vimen vimina viminal vims vin vina vinal vinals vinas vinasse vinca 
vincas vincula vine vineal vined vinegar vinery vines vinic vinier viniest vinify 
vino vinos vinous vintage vintner viny vinyl vinylic vinyls viol viola violas 
violate violent violet violets violin violins violist violone viols viper vipers virago 
viragos viral virally virelai virelay viremia viremic vireo vireos vires virga virgas 
virgate virgin virgins virgule virid virile virion virions virl virls viroid viroids 
viroses virosis virtu virtual virtue virtues virtus virus viruses vis visa visaed 
visage visaged visages visard visards visas viscera viscid viscoid viscose viscous viscus 
vise vised viseed vises visible visibly vision visions visit visited visiter visitor 
visits visive visor visored visors vista vistaed vistas visual visuals vita vitae 
vital vitally vitals vitamer vitamin vitesse vitiate vitrain vitric vitrics vitrify vitrine 
vitriol vitta vittae vittate vittle vittled vittles viva vivace vivaces vivaria vivary 
vivas vive vivers vivid vivider vividly vivific vivify vixen vixenly vixens vizard 
vizards vizier viziers vizir vizirs vizor vizored vizors vizsla vizslas vocab vocable 
vocably vocabs vocal vocalic vocally vocals voces vocoder vodka vodkas vodou vodoun 
vodouns vodous vodun voduns voe voes vogie vogu vogue vogued voguer voguers 
vogues voguish voic voice voiced voicer voicers voices void voided voider voiders 
voids voila voile voiles vol volant volante volar volcano vole voled volery 
voles volley volleys volost volosts volt volta voltage voltaic volte voltes volti 
volts voluble volubly volume volumed volumes volute voluted volutes volutin volva volvas 
volvate volvox volvuli vomer vomers vomica vomicae vomit vomited vomiter vomito vomitos 
vomits vomitus voodoo voodoos vorlage vortex vot votable votary vote voted voter 
voters votes votive votives votress vouch vouched vouchee voucher vouches voudon voudons 
voudoun vouvray vow vowed vowel vowels vower vowers vowless vows vox voyage 
voyaged voyager voyages voyeur voyeurs vroom vroomed vrooms vrouw vrouws vrow vrows 
vug vugg vuggier vuggs vuggy vugh vughs vugs vulgar vulgars vulgate vulgo 
vulgus vulpine vulture vulva vulvae vulval vulvar vulvas vulvate vum vy vyingly 
waiv waive waived waiver waivers waives wav wave waved wavelet waveoff waver 
wavered waverer wavers wavery waves wavey waveys wavicle wavier wavies waviest wavily 
wavy weav weave weaved weaver weavers weaves weever weevers weevil weevils weevily 
wharve wharves wherve wherves whoever wiv wive wived wiver wivern wiverns wivers 
wives wolver wolvers wolves wove woven wovens wyvern wyverns yeshiva zelkova zemstva 
zemstvo zouave zouaves zyzzyva         
);

my @K_words = qw(
aback abaka abakas ackee ackees acock adzuki adzukis aikido aikidos airlike airpark 
airsick akee akees akela akelas akene akenes akimbo akin akvavit alack alaska 
alaskas alfaki alfakis alike alkali alkalic alkalin alkalis alkane alkanes alkanet alkene 
alkenes alkie alkies alkine alkines alkoxy alky alkyd alkyds alkyl alkylic alkyls 
alkyne alkynes alsike alsikes amok amoks amtrack amuck amucks ananke anankes angakok 
ankh ankhs ankl ankle ankled ankles anklet anklets ankus ankuses ankush anorak 
anoraks antick anticks antlike apeak apeek apelike arabesk arak araks arck arcked 
ark arkose arkoses arkosic arks armlike armlock arrack arracks artwork ashcake ask 
askance askant asked asker askers askeses askesis askew askings askoi askos asks 
asslike attack attacks auk auklet auklets auks autarky awak awake awaked awaken 
awakens awakes awkward awoke awoken axlike azuki azukis baaskap babka babkas back 
backbit backed backer backers backfit backhoe backlit backlog backout backs backsaw backset 
backup backups baglike bak bake baked baker bakers bakery bakes bakings baklava 
baklawa balk balked balker balkers balkier balkily balks balky bangkok bank banked 
banker bankers bankit bankits banks banksia bannock bark barked barkeep barker barkers 
barkier barks barky barrack bashlyk bask basked basket baskets basks batik batiked 
batiks batlike battik battiks baulk baulked baulks baulky bawcock bazooka beak beaked 
beaker beakers beakier beaks beaky beatnik bechalk beck becked becket beckets beckon 
beckons becks becloak bedeck bedecks bedlike bedrock bedtick beelike befleck bekiss beknot 
beknots belike belleek bemock bemocks berake beraked berakes berk berks berserk besmoke 
bespake bespeak bespoke betake betaken betakes bethank bethink betoken betook beylik beyliks 
bhakta bhaktas bhakti bhaktis bibcock biblike bicker bickers bidarka bik bike biked 
biker bikers bikes bikeway bikie bikies bikini bikinis bilk bilked bilker bilkers 
bilks bipack bipacks birk birkie birkies birks bisk bisks bittock black blacked 
blacken blacker blackly blacks blank blanked blanker blanket blankly blanks blaubok bleak 
bleaker bleakly bleaks blesbok blink blinked blinker blinks block blocked blocker blocks 
blocky bloke blokes bock bocks bodkin bodkins bohunk bohunks boink boinked boinks 
bonk bonked bonkers bonks bonnock book booked bookend booker bookers bookful bookie 
bookies bookish booklet bookman bookmen bookoo bookoos books boomkin bork borked borks 
boshbok bosk boskage bosker bosket boskets boskier bosks bosky bowknot bowlike boxlike 
boychik bracken bracket brak brake braked brakes brakier braky brank branks break 
breaker breaks breakup breeks brewski brick bricked brickle bricks bricky brink brinks 
brisk brisked brisker brisket briskly brisks britska britzka brock brocket brocks brok 
brokage broke broken broker brokers brook brooked brookie brooks brusk brusker bubkes 
buck bucked buckeen bucker buckers bucket buckets buckeye buckish buckle buckled buckler 
buckles bucko buckoes buckos buckra buckram buckras bucks bucksaw budlike bulk bulkage 
bulked bulkier bulkily bulks bulky bullock bulwark bumkin bumkins bumpkin bunk bunked 
bunker bunkers bunko bunkoed bunkos bunks bunkum bunkums bunraku bupkes bupkus burdock 
burk burka burkas burke burked burker burkers burkes burkite burlesk busk busked 
busker buskers buskin buskins busks buttock buyback buzuki buzukia buzukis bytalk bytalks 
bywork byworks cackle cackled cackler cackles cak cake caked cakes cakey cakier 
cakiest caky calk calked calker calkers calkin calkins calks calpack canakin canikin 
canker cankers caprock carack caracks carjack cark carked carks carrack carsick cask 
casked casket caskets casks casky cassock catkin catkins catlike catwalk caulk caulked 
caulker caulks chabouk chabuk chabuks chachka chakra chakras chalk chalked chalks chalky 
champak chark charka charkas charked charkha charks check checked checker checks checkup 
cheek cheeked cheeks cheeky chewink chibouk chick chickee chicken chicks chink chinked 
chinks chinky chinook chirk chirked chirker chirks chock chocked chocks chok choke 
choked choker chokers chokes chokey chokier choky chook chooks chuck chucked chuckle 
chucks chucky chukar chukars chukka chukkar chukkas chukker chunk chunked chunks chunky 
clack clacked clacker clacks clank clanked clanks clanky clarkia cleek cleeked cleeks 
clerk clerked clerkly clerks click clicked clicker clicks clink clinked clinker clinks 
cloak cloaked cloaks clock clocked clocker clocks clonk clonked clonks cluck clucked 
clucks clunk clunked clunker clunks clunky cock cockade cocked cocker cockers cockeye 
cockier cockily cockish cockle cockled cockles cockney cockpit cocks cockshy cockup cockups 
cocky cok coke coked cokes coky colicky comake comaker comakes comatik conk 
conked conker conkers conks conky convoke cook cooked cooker cookers cookery cookey 
cookeys cookie cookies cookoff cookout cooks cooktop cooky copeck copecks cork corkage 
corked corker corkers corkier corks corky cossack cowlick cowpoke cowskin crack cracked 
cracker crackle crackly cracks crackup cracky crake crakes crank cranked cranker crankle 
crankly cranks cranky creak creaked creaks creaky creek creeks crick cricked cricket 
crickey cricks crikey crinkle crinkly croak croaked croaker croaks croaky crock crocked 
crocket crocks crojik crojiks crook crooked crooker crooks cruck crucks cuckold cuckoo 
cuckoos cuke cukes cupcake cuplike cusk cusks cutback cutbank cutwork dacker dackers 
daglock daiker daikers daikon daikons dak dakoit dakoits dakoity daks damask damasks 
dank danker dankest dankly dark darked darken darkens darker darkest darkey darkeys 
darkie darkies darkish darkle darkled darkles darkly darks darky dashiki dawk dawks 
daybook daywork debark debarks debeak debeaks debunk debunks deck decked deckel deckels 
decker deckers deckle deckles decks defrock dek dekare dekares deke deked dekes 
dekko dekkos demark demarks derrick desk deskman deskmen desks desktop detick deticks 
dhak dhaks dibbuk dibbuks dick dicked dickens dicker dickers dickey dickeys dickie 
dickier dickies dicks dicky dieback dik dikdik dikdiks dike diked diker dikers 
dikes dikey diktat diktats dink dinked dinkey dinkeys dinkier dinkies dinkly dinks 
dinkum dinkums dinky dirk dirked dirks disk disked disks dislike disyoke dock 
dockage docked docker dockers docket dockets docks doeskin doglike donkey donkeys dorhawk 
dork dorkier dorks dorky dorneck dornick dornock dovekey dovekie drake drakes drank 
dreck drecks drecky drek dreks drink drinker drinks droshky drosky drouk drouked 
drouks drunk drunken drunker drunks duck ducked ducker duckers duckie duckier duckies 
duckpin ducks ducky duiker duikers duk duke duked dukedom dukes dumka dumky 
dunk dunked dunker dunkers dunks dusk dusked duskier duskily duskish dusks dusky 
dybbuk dybbuks dyk dyke dyked dykes dykey earlock earmark ebook ebooks eek 
eellike eikon eikones eikons einkorn ek eke eked ekes ekistic ekpwele ekuele 
elflike elflock elk elks embank embanks embark embarks embosk embosks enoki enokis 
enskied enskies ensky enskyed erlk eskar eskars esker eskers eureka euroky euryoky 
evok evoke evoked evoker evokers evokes eyehook eyelike eyewink fadlike fak fake 
faked fakeer fakeers faker fakers fakery fakes fakey fakir fakirs fanlike fartlek 
fatback fatlike feck feckly fecks fetlock fickle fickler fickly finback finicky finikin 
fink finked finks finlike finmark firkin firkins flack flacked flacks flak flake 
flaked flaker flakers flakes flakey flakier flakily flaky flank flanked flanken flanker 
flanks flask flasket flasks fleck flecked flecks flecky flick flicked flicker flicks 
flock flocked flocks flocky flokati fluk fluke fluked flukes flukey flukier flukily 
fluky flunk flunked flunker flunkey flunkie flunks flunky folk folkie folkier folkies 
folkish folkmot folks folksy folkway folky fork forked forker forkers forkful forkier 
forks forky forsake forsook fossick foxlike foxskin fraktur frank franked franker frankly 
franks freak freaked freaks freaky freckle freckly frisk frisked frisker frisket frisks 
frisky frock frocked frocks funk funked funker funkers funkia funkias funkier funkily 
funks funky futhark futhork futtock fyke fykes gagaku gagakus galyak galyaks garpike 
gask gasket gaskets gaskin gaskins gawk gawked gawker gawkers gawkier gawkies gawkily 
gawkish gawks gawky geck gecked gecko geckoes geckos gecks geek geekdom geeked 
geekier geeks geeky gemlike gemsbok geoduck gerenuk gherkin gimmick gingko gingkos gink 
ginkgo ginkgos ginks glaiket glaikit gleek gleeked gleeks godlike gook gooks gooky 
gopik gorcock goshawk gowk gowks grackle greek griskin grok grokked groks guck 
gucks gumlike gunk gunkier gunks gunky gunlock gutlike gweduck hacek haceks hack 
hackbut hacked hackee hackees hacker hackers hackie hackies hackle hackled hackler hackles 
hackly hackman hackmen hackney hacks hacksaw haddock haik haika haiks haiku haikus 
hake hakeem hakeems hakes hakim hakims haku hakus halakah halakha halakic hammock 
hank hanked hanker hankers hankie hankies hanks hanky hapkido hark harked harken 
harkens harks hassock hatlike hatrack hauberk hawk hawked hawker hawkers hawkey hawkeys 
hawkie hawkies hawkish hawks haycock hayfork hayrack hayrick hearken heck heckle heckled 
heckler heckles hecks hektare hemlock henlike henpeck hick hickey hickeys hickie hickies 
hickish hickory hicks hijack hijacks hijinks hik hike hiked hiker hikers hikes 
hillock hinkier hinky hiplike hoblike hock hocked hocker hockers hockey hockeys hocks 
hoecake hoelike hogback hoglike hoick hoicked hoicks hok hoke hoked hokes hokey 
hokier hokiest hokily hokku hokum hokums holk holked holks hommock honk honked 
honker honkers honkey honkeys honkie honkies honks honky hook hooka hookah hookahs 
hookas hooked hooker hookers hookey hookeys hookier hookies hooklet hooks hookup hookups 
hooky hopsack hotcake hotlink howk howked howks huck huckle huckles hucks hulk 
hulked hulkier hulks hulky hummock hunk hunker hunkers hunkey hunkeys hunkie hunkier 
hunkies hunks hunky husk husked husker huskers huskier huskies huskily husks husky 
hutlike icelike ick icker ickers ickier ickiest ickily icky ikat ikats ikebana 
ikon ikons ilk ilka ilks imbark imbarks impark imparks ink inkblot inked 
inker inkers inkhorn inkier inkiest inkjet inkl inkle inkles inkless inklike inkpot 
inkpots inks inkwell inkwood inky intake intakes invoke invoked invoker invokes irk 
irked irks irksome iroko irokos ivylike jack jackal jackals jackass jackdaw jacked 
jacker jackers jacket jackets jackies jackleg jackpot jacks jacky jake jakes jamlike 
jauk jauked jauks jawlike jaywalk jerk jerked jerker jerkers jerkier jerkies jerkily 
jerkin jerkins jerks jerky jetlike jiglike jingko jink jinked jinker jinkers jinks 
jock jockey jockeys jocko jockos jocks jok joke joked joker jokers jokes 
jokey jokier jokiest jokily joky jouk jouked jouks judoka judokas juk juke 
jukebox juked jukes juku jukus jumbuck junk junked junker junkers junket junkets 
junkie junkier junkies junkman junkmen junks junky k kaas kab kabab kababs 
kabaka kabakas kabala kabalas kabar kabars kabaya kabayas kabbala kabiki kabikis kabob 
kabobs kabs kabuki kabukis kachina kaddish kadi kadis kae kaes kaf kaffir 
kaffirs kafir kafirs kafs kaftan kaftans kagu kagus kahuna kahunas kaiak kaiaks 
kaif kaifs kail kails kain kainit kainite kainits kains kaiser kaisers kajeput 
kaka kakapo kakapos kakas kaki kakis kalam kalams kale kalends kales kalian 
kalians kalif kalifs kalimba kaliph kaliphs kalium kaliums kalmia kalmias kalong kalongs 
kalpa kalpac kalpacs kalpak kalpaks kalpas kamala kamalas kame kames kami kamik 
kamiks kampong kamseen kamsin kamsins kana kanaka kanakas kanas kanban kanbans kane 
kanes kanji kanjis kantar kantars kantele kanzu kanzus kaolin kaoline kaolins kaon 
kaonic kaons kapa kapas kaph kaphs kapok kapoks kappa kappas kaput kaputt 
karakul karaoke karat karate karates karats karma karmas karmic karn karns karoo 
karoos kaross karroo karroos karst karstic karsts kart karts kas kasbah kasbahs 
kasha kashas kasher kashers kashmir kashrut kat kata katas katcina kathode kation 
kations kats katsura katydid kauri kauries kauris kaury kava kavas kavass kay 
kayak kayaked kayaker kayaks kayles kayo kayoed kayoes kayos kays kazoo kazoos 
kbar kbars kea keas kebab kebabs kebar kebars kebbie kebbies kebbock kebbuck 
keblah keblahs kebob kebobs keck kecked keckle keckled keckles kecks keddah keddahs 
kedg kedge kedged kedges keef keefs keek keeked keeks keel keelage keeled 
keels keelson keen keened keener keeners keenest keenly keens keep keeper keepers 
keeps keester keet keets keeve keeves kef kefir kefirs kefs keg kegeler 
kegg kegged kegger keggers kegl kegler keglers kegs keir keirs keister keitloa 
kelep keleps kelim kelims kellies kelly keloid keloids kelp kelped kelpie kelpies 
kelps kelpy kelson kelsons kelt kelter kelters kelts kelvin kelvins kemp kemps 
kempt ken kenaf kenafs kench kenches kendo kendos kenn kenned kennel kennels 
keno kenos kenosis kenotic kens kent kente kentes kep kepi kepis kepp 
kepped keppen keps kept keramic keratin kerb kerbed kerbs kerchoo kerf kerfed 
kerfs kermes kermess kermis kern kerne kerned kernel kernels kernes kernite kerns 
kerogen kerria kerrias kerries kerry kersey kerseys kerygma kestrel ketch ketches ketchup 
ketene ketenes keto ketol ketols ketone ketones ketonic ketose ketoses ketosis ketotic 
kettle kettles kevel kevels kevil kevils kewpie kewpies kex kexes key keycard 
keyed keyhole keyless keynote keypad keypads keypal keypals keys keyset keysets keyster 
keyway keyways keyword khaddar khadi khadis khaf khafs khaki khakis khalif khalifa 
khalifs khamsin khan khanate khans khaph khaphs khat khats khazen khazens kheda 
khedah khedahs khedas khedive khet kheth kheths khets khi khirkah khis khoum 
khoums kiang kiangs kiaugh kiaughs kibbe kibbeh kibbehs kibbes kibbi kibbis kibbitz 
kibble kibbled kibbles kibbutz kibe kibei kibeis kibes kibitz kibla kiblah kiblahs 
kiblas kibosh kick kickbox kicked kicker kickers kickier kickoff kicks kickup kickups 
kicky kid kidd kidded kidder kidders kiddie kiddies kiddish kiddo kiddoes kiddos 
kiddush kiddy kidlike kidnap kidnaps kidney kidneys kids kidskin kidvid kidvids kief 
kiefs kier kiers kiester kif kifs kike kikes kilim kilims kill killdee 
killed killer killers killick killie killies killjoy killock kills kiln kilned kilns 
kilo kilobar kilobit kilorad kilos kiloton kilt kilted kilter kilters kiltie kilties 
kilts kilty kimchee kimchi kimchis kimono kimonos kin kina kinara kinaras kinas 
kinase kinases kind kinder kindest kindle kindled kindler kindles kindly kindred kinds 
kine kinema kinemas kines kineses kinesic kinesis kinetic kinetin kinfolk king kingcup 
kingdom kinged kinglet kingly kingpin kings kinin kinins kink kinked kinkier kinkily 
kinks kinky kinless kino kinos kins kinship kinsman kinsmen kiosk kiosks kip 
kipp kipped kippen kipper kippers kips kipskin kir kirk kirkman kirkmen kirks 
kirmess kirn kirned kirns kirs kirsch kirtle kirtled kirtles kis kishka kishkas 
kishke kishkes kismat kismats kismet kismets kiss kissed kisser kissers kisses kissy 
kist kistful kists kit kitbag kitbags kitchen kite kited kiter kiters kites 
kith kithara kithe kithed kithes kiths kitl kits kitsch kitschy kitt kitted 
kittel kitten kittens kitties kittle kittled kittler kittles kitty kiva kivas kiwi 
kiwis klatch klatsch klavern klaxon klaxons kleagle kleenex klepht klephts klepto kleptos 
klezmer klick klicks klik kliks klister klong klongs kloof kloofs kludge kludged 
kludges kludgey kludgy klug kluge kluged kluges klutz klutzes klutzy knack knacked 
knacker knacks knap knapped knapper knaps knar knarred knarry knars knaur knaurs 
knave knavery knaves knavish knawe knawel knawels knawes knead kneaded kneader kneads 
knee kneecap kneed kneel kneeled kneeler kneels kneepad kneepan knees knell knelled 
knells knelt knesset knew knif knife knifed knifer knifers knifes knight knights 
knish knishes knit knits knitted knitter knives knob knobbed knobbly knobby knobs 
knock knocked knocker knocks knoll knolled knoller knolls knolly knop knopped knops 
knosp knosps knot knots knotted knotter knotty knout knouted knouts know knower 
knowers known knowns knows knubby knuckle knuckly knur knurl knurled knurls knurly 
knurs koa koala koalas koan koans koas kob kobo kobold kobolds kobos 
kobs koel koels kohl kohls koi koine koines kois koji kojis kokanee 
kola kolacky kolas kolbasi kolhoz kolhozy kolkhos kolkhoz kolkoz kolkozy kolo kolos 
komatik kombu kombus konk konked konks koodoo koodoos kook kookie kookier kooks 
kooky kop kopeck kopecks kopek kopeks koph kophs kopiyka kopje kopjes koppa 
koppas koppie koppies kops kor kora korai koras korat korats kore korma 
kormas kors korun koruna korunas koruny kos kosher koshers koss koto kotos 
kotow kotowed kotower kotows koumis koumiss koumys koumyss kouprey kouroi kouros kousso 
koussos kowtow kowtows kraal kraaled kraals kraft krafts krait kraits kraken krakens 
krater kraters kraut krauts kreep kreeps kremlin kreuzer krewe krewes krill krills 
krimmer kris krises krona krone kronen kroner kronor kronur kroon krooni kroons 
krubi krubis krubut krubuts kruller krypton kuchen kuchens kudo kudos kudu kudus 
kudzu kudzus kue kues kufi kufis kugel kugels kukri kukris kulak kulaki 
kulaks kultur kulturs kumiss kummel kummels kumquat kumys kumyses kuna kune kunzite 
kurbash kurgan kurgans kurta kurtas kuru kurus kusso kussos kuvasz kvas kvases 
kvass kvasses kvell kvelled kvells kvetch kvetchy kwacha kwachas kwanza kwanzas kyack 
kyacks kyak kyaks kyanise kyanite kyanize kyar kyars kyat kyats kybosh kye 
kyes kylikes kylix kyrie kyries kyte kytes kyth kythe kythed kythes lack 
lacked lacker lackers lackey lackeys lacks ladykin lak lake lakebed laked laker 
lakers lakes lakh lakhs lakier lakiest lakings laky lambkin lank lanker lankest 
lankier lankily lankly lanky lark larked larker larkers larkier larkish larks larky 
lashkar latakia latke latkes lavrock lawbook lawlike leak leakage leaked leaker leakers 
leakier leakily leaks leaky leek leeks leglike legwork lek leke lekk lekked 
leks leku lekvar lekvars lekythi lentisk leukoma leukon leukons lick licked licker 
lickers licks lik likable like liked likely liken likened likens liker likers 
likes likest likings likuta limbeck limpkin link linkage linkboy linked linker linkers 
linkman linkmen links linkup linkups linky liplike lock lockage lockbox locked locker 
lockers locket lockets lockjaw locknut lockout lockram locks lockset lockup lockups logbook 
look looked looker lookers lookism lookist lookout looks lookup lookups luck lucked 
luckie luckier luckies luckily lucks lucky lunk lunker lunkers lunks lurk lurked 
lurker lurkers lurks lutfisk mack mackle mackled mackles macks maffick mak makable 
makar makars make maker makers makes makeup makeups makings mako makos makuta 
malarky malkin malkins mamluk mamluks mammock manakin manikin mankind manlike manpack maplike 
mark marka markas marked marker markers market markets markhor markka markkaa markkas 
marks markup markups mask masked maskeg maskegs masker maskers masks mattock mawkish 
mazurka medaka medakas medick medicks meek meeker meekest meekly meerkat meikle menfolk 
merk merks mick mickey mickeys mickle mickler mickles micks midweek mik mikado 
mikados mike miked mikes mikra mikron mikrons mikvah mikvahs mikveh mikvehs mikvos 
mikvot mikvoth milk milked milker milkers milkier milkily milkman milkmen milks milksop 
milky minikin miniski mink minke minkes minks mirk mirker mirkest mirkier mirkily 
mirks mirky miscook miskal miskals miskeep miskept miskick misknew misknow mislike mismake 
mismark mistake misteuk mistook misyoke mock mocked mocker mockers mockery mocks mockup 
mockups mohawk mohawks moke mokes mollusk moniker monk monkery monkey monkeys monkish 
monks mopoke mopokes mosk mosks moujik moujiks mousaka muck mucked mucker muckers 
muckier muckily muckle muckles mucks mucky mudlark mudpack mudrock mujik mujiks mukluk 
mukluks muktuk muktuks mullock muntjak murk murker murkest murkier murkily murkly murks 
murky musick musicks musk muskeg muskegs musket muskets muskie muskier muskies muskily 
muskit muskits muskox muskrat musks musky muspike muzhik muzhiks muzjik muzjiks naked 
nakeder nakedly nakfa nakfas nankeen nankin nankins napkin napkins nark narked narks 
narky neatnik neck necked necker neckers necks necktie nekton nektons netlike netsuke 
network neuk neuks niblick niblike nick nicked nickel nickels nicker nickers nickle 
nickled nickles nicks nitpick nock nocked nocks nonbank nonbook nonpeak nonsked nonskid 
nonwork nook nookie nookies nooks nooky nubuck nubucks nudnick nudnik nudniks nuk 
nuke nuked nukes nunatak nunlike nutlike nutpick oak oaken oakier oakiest oaklike 
oakmoss oaks oakum oakums oaky oarlike oarlock oatcake oatlike obelisk ocker ockers 
odalisk offkey oilskin oink oinked oinks oka okapi okapis okas okay okayed 
okays oke okeh okehs okes okra okras olicook omikron oomiack oomiak oomiaks 
ostmark ostraka outask outasks outback outbake outbark outbulk outcook outkeep outkept outkick 
outkill outkiss outlook outrank outrock outsulk outtake outtalk outtask outwalk outwork owllike 
oxlike pack package packed packer packers packet packets packly packman packmen packs 
packwax padauk padauks paddock padlock padouk padouks paik paiked paiks pakeha pakehas 
pakora pakoras palikar palooka pancake panicky paprika parbake park parka parkade parkas 
parked parker parkers parks parkway partake partook passkey pawkier pawkily pawky payback 
peacock peak peaked peakier peakish peaks peaky pealike peck pecked pecker peckers 
peckier peckish pecks pecky peek peeked peeks peglike pekan pekans peke pekepoo 
pekes pekin pekins pekoe pekoes peptalk perk perked perkier perkily perkish perks 
perky peruke peruked perukes peskier peskily pesky petcock phreak phreaks pick pickax 
pickaxe picked pickeer picker pickers picket pickets pickier pickle pickled pickles pickoff 
picks pickup pickups picky piddock piglike pigskin pik pika pikake pikakes pikas 
pike piked pikeman pikemen piker pikers pikes piki pikis pink pinked pinken 
pinkens pinker pinkers pinkest pinkey pinkeye pinkeys pinkie pinkies pinkish pinkly pinko 
pinkoes pinkos pinks pinky pinwork pipkin pipkins pirojki plack placket placks plank 
planked planks plink plinked plinker plinks pliskie plisky plonk plonked plonks pluck 
plucked plucker plucks plucky plunk plunked plunker plunks plunky pock pocked pocket 
pockets pockier pockily pocks pocky podlike pok pokable poke poked poker pokers 
pokes pokey pokeys pokier pokies pokiest pokily poky polka polkaed polkas pollack 
pollock pork porked porker porkers porkier porkies porkpie porks porky pothook potlike 
potluck prank pranked pranks prebake prebook precook predusk prepack prerock presoak prework 
prick pricked pricker pricket prickle prickly pricks pricky prink prinked prinker prinks 
provoke puck pucka pucker puckers puckery puckish pucks pugmark puk puke puked 
pukes pukka pulik pumpkin punk punka punkah punkahs punkas punker punkers punkest 
punkey punkeys punkie punkier punkies punkin punkins punkish punks punky puslike pyknic 
pyknics quack quacked quacks quacky quak quake quaked quaker quakers quakes quakier 
quakily quaky quark quarks quick quicken quicker quickie quickly quicks quirk quirked 
quirks quirky quokka quokkas rack racked racker rackers racket rackets rackety rackful 
rackle racks rak rake raked rakee rakees rakeoff raker rakers rakes raki 
rakis rakish raku rakus ramekin rampike rank ranked ranker rankers rankest rankish 
rankle rankled rankles rankly ranks ranpike ransack ratfink ratlike raylike reawake reawoke 
rebeck rebecks rebook rebooks rebuke rebuked rebuker rebukes recheck reck recked reckon 
reckons recks recock recocks recook recooks recork recorks redneck redock redocks redskin 
reek reeked reeker reekers reekier reeks reeky reevoke reink reinked reinks reitbok 
rekey rekeyed rekeys reknit reknits reknot reknots relink relinks relock relocks relook 
relooks remake remaker remakes remark remarks repack repacks repark reparks reperk reperks 
rerack reracks reseek reseeks resoak resoaks respeak respoke restack restock restoke retack 
retacks retake retaken retaker retakes rethink retook retrack revoke revoked revoker revokes 
rewake rewaked rewaken rewakes rewoke rewoken rework reworks rhebok rheboks riblike rick 
ricked rickets rickety rickey rickeys ricks ricksha rikisha rikshaw rimrock rink rinks 
risk risked risker riskers riskier riskily risks risky rock rockaby rocked rocker 
rockers rockery rocket rockets rockier rockoon rocks rocky rodlike roebuck rollick rook 
rooked rookery rookie rookier rookies rooks rooky rowlock ruck rucked ruckle ruckled 
ruckles rucks ruckus ruddock ruglike rumaki rumakis runback runkle runkled runkles rusk 
rusks ryk ryke ryked rykes ryokan ryokans sack sackbut sacked sacker sackers 
sackful sacks saclike sake saker sakers sakes saki sakis saluki salukis sambuke 
samek samekh samekhs sameks sanjak sanjaks sank sark sarkier sarks sarky sawbuck 
sawlike schlock schmuck schnook schrik schriks schtick schtik schtiks screak screaks screaky 
sculk sculked sculker sculks seacock seamark seasick seek seeker seekers seeks selkie 
selkies seppuku setback shack shacked shackle shacko shackos shacks shak shake shaken 
shaker shakers shakes shakeup shakier shakily shako shakoes shakos shaky shank shanked 
shanks shark sharked sharker sharks shaslik sheik sheikh sheikhs sheiks shekel shekels 
shicker shicksa shikar shikari shikars shikker shiksa shiksas shikse shikseh shikses shirk 
shirked shirker shirks shitake shlock shlocks shlocky shmuck shmucks shnook shnooks shock 
shocked shocker shocks shook shooks shrank shriek shrieks shrieky shrike shrikes shrink 
shrinks shrunk shtick shticks shticky shtik shtiks shuck shucked shucker shucks shylock 
sick sickbay sickbed sicked sickee sickees sicken sickens sicker sickest sickie sickies 
sickish sickle sickled sickles sickly sicko sickos sickout sicks sifaka sifakas sika 
sikas sike siker sikes silk silked silken silkie silkier silkies silkily silks 
silky sink sinkage sinker sinkers sinks siskin siskins sjambok ska skag skags 
skald skaldic skalds skank skanked skanker skanks skanky skas skat skate skated 
skater skaters skates skatol skatole skatols skats skean skeane skeanes skeans skee 
skeed skeen skeens skees skeet skeeter skeets skeg skegs skeigh skein skeined 
skeins skell skells skellum skelm skelms skelp skelped skelpit skelps skelter skene 
skenes skep skeps skepsis skeptic skerry sketch sketchy skew skewed skewer skewers 
skews ski skiable skibob skibobs skid skidded skidder skiddoo skiddy skidoo skidoos 
skids skidway skied skier skiers skies skiey skiff skiffle skiffs skiings skilful 
skill skilled skillet skills skim skimmed skimmer skimo skimos skimp skimped skimps 
skimpy skims skin skinful skink skinked skinker skinks skinned skinner skinny skins 
skint skip skipped skipper skippet skips skirl skirled skirls skirr skirred skirret 
skirrs skirt skirted skirter skirts skis skit skite skited skites skits skitter 
skittle skiv skive skived skiver skivers skives skivvy skiwear sklent sklents skoal 
skoaled skoals skookum skort skorts skosh skoshes skreegh skreigh skua skuas skulk 
skulked skulker skulks skull skulled skulls skunk skunked skunks skunky sky skybox 
skycap skycaps skydive skydove skyed skyey skyhook skyjack skylark skylike skyline skylit 
skyman skymen skyphoi skyphos skysail skysurf skywalk skyward skyway skyways slack slacked 
slacken slacker slackly slacks slak slake slaked slaker slakers slakes slank sleek 
sleeked sleeken sleeker sleekit sleekly sleeks sleeky slick slicked slicken slicker slickly 
slicks slink slinked slinks slinky slunk smack smacked smacker smacks smeek smeeked 
smeeks smerk smerked smerks smirk smirked smirker smirks smirky smock smocked smocks 
smok smoke smoked smoker smokers smokes smokey smokier smokily smoky snack snacked 
snacker snacks snak snake snaked snakes snakey snakier snakily snaky snark snarks 
snarky sneak sneaked sneaker sneaks sneaky sneck snecks snick snicked snicker snicks 
snook snooked snooker snooks snorkel snuck soak soakage soaked soaker soakers soaks 
sock socked socket sockets sockeye sockman sockmen socko socks soke sokeman sokemen 
sokes sokol sokols sonlike sook sooks souk soukous souks souslik sovkhoz soymilk 
spackle spake spank spanked spanker spanks spark sparked sparker sparkle sparkly sparks 
sparky speak speaker speaks speck specked speckle specks spelunk spick spicks spik 
spike spiked spiker spikers spikes spikey spikier spikily spiks spiky splake splakes 
spok spoke spoked spoken spokes spook spooked spooks spooky spunk spunked spunkie 
spunks spunky sputnik squark squarks squawk squawks squeak squeaks squeaky stack stacked 
stacker stacks stackup stak stake staked stakes stalk stalked stalker stalks stalky 
stank stanks stark starker starkly steak steaks steek steeked steeks stenoky stick 
sticked sticker stickit stickle sticks stickum stickup sticky stink stinker stinko stinks 
stinky stirk stirks stock stocked stocker stocks stocky stok stoke stoked stoker 
stokers stokes stook stooked stooker stooks stork storks strake straked strakes streak 
streaks streaky streek streeks strick stricks strike striker strikes stroke stroked stroker 
strokes strook struck stuck stunk subtask suck sucked sucker suckers suckier suckle 
suckled suckler suckles sucks sucky suk sukkah sukkahs sukkot sukkoth suks sulk 
sulked sulker sulkers sulkier sulkies sulkily sulks sulky sunback sundeck sunk sunken 
sunket sunkets sunlike suslik susliks swacked swank swanked swanker swanks swanky swink 
swinked swinks syke sykes tack tacked tacker tackers tacket tackets tackey tackier 
tackify tackily tackle tackled tackler tackles tacks tacky taglike tak taka takable 
takahe takahes takas take taken takeoff takeout taker takers takes takeup takeups 
takin takings takins talcked talcky talk talked talker talkers talkie talkier talkies 
talks talky talooka taluk taluka talukas taluks tambak tambaks tanbark tank tanka 
tankage tankard tankas tanked tanker tankers tankful tankini tanks tanuki tanukis tarok 
taroks task taskbar tasked tasks teacake teak teaks tealike tekkie tekkies tektite 
thack thacked thacks thank thanked thanker thanks thick thicken thicker thicket thickly 
thicks think thinker thinks thunk thunked thunks thwack thwacks tick ticked ticker 
tickers ticket tickets tickle tickled tickler tickles ticks tieback tike tikes tiki 
tikis tikka tikkas tilak tilaks tinker tinkers tinkle tinkled tinkler tinkles tinkly 
tinlike tinwork titlark toelike tok tokamak tokay tokays toke toked token tokened 
tokens toker tokers tokes tokomak tomback tombak tombaks took topkick topknot topwork 
torsk torsks towsack toylike track tracked tracker tracks traik traiked traiks trank 
tranks trek trekked trekker treks trick tricked tricker trickie trickle trickly tricks 
tricksy tricky trike trikes trinket tripack troak troaked troaks trock trocked trocks 
troika troikas trok troke troked trokes truck trucked trucker truckle trucks trunk 
trunked trunks tsaddik tsatske tsk tsked tsks tsktsk tsktsks tublike tuck tucked 
tucker tuckers tucket tuckets tucks tughrik tugrik tugriks tupik tupiks turfski turk 
turkey turkeys turkois turks turnkey tusk tusked tusker tuskers tusks tussock tussuck 
twanky tweak tweaked tweaks tweaky twinkie twinkle twinkly tyke tykes tzaddik uakari 
uakaris ukase ukases uke ukelele ukes ukulele umiack umiacks umiak umiaks unakin 
unakite unalike unasked unawake unbaked unblock unbrake unbroke unbulky uncake uncaked uncakes 
unchoke uncloak uncock uncocks uncork uncorks undock undocks undrunk unfaked unfrock unhook 
unhooks unhusk unhusks unkempt unkend unkent unkept unkind unkink unkinks unknit unknits 
unknot unknots unknown unlike unliked unlink unlinks unlock unlocks unlucky unmake unmaker 
unmakes unmask unmasks unpack unpacks unpick unpicks unraked unslick unspeak unspoke unstack 
unstick unstuck unsunk untack untacks untaken unthink untrack untuck untucks unyoke unyoked 
unyokes upchuck upkeep upkeeps uplink uplinks uptake uptakes uptalk uptalks uptick upticks 
urnlike vakeel vakeels vakil vakils valkyr valkyrs vandyke vik vikings vodka vodkas 
wack wacke wacker wackes wackest wackier wackily wacko wackos wacks wacky waesuck 
wak wakame wakames wakanda wake waked wakeful waken wakened wakener wakens waker 
wakers wakes wakiki wakikis walk walked walker walkers walkout walks walkup walkups 
walkway wank wanked wanker wankers wanks wark warked warks warlike warlock warwork 
wauk wauked wauks waxlike waxwork weak weaken weakens weaker weakest weakish weakly 
weakon weakons weblike webwork wedlock week weekday weekend weekly weeks weka wekas 
welkin welkins weskit weskits wetback whack whacked whacker whacko whackos whacks whacky 
whelk whelks whelky whicker whisk whisked whisker whiskey whisks whisky wick wickape 
wicked wicker wickers wicket wickets wickiup wicks wickyup wiglike wikiup wikiups wink 
winked winker winkers winkle winkled winkles winks winnock wok woke woken woks 
wonk wonkier wonks wonky work workbag workbox workday worked worker workers workman 
workmen workout works workup workups wrack wracked wracks wreak wreaked wreaker wreaks 
wreck wrecked wrecker wrecks wrick wricked wricks wrinkle wrinkly wryneck yack yacked 
yacks yak yakk yakked yakker yakkers yaks yakuza yamalka yamulka yank yanked 
yanks yapock yapocks yapok yapoks yashmak yasmak yasmaks yelk yelks yerk yerked 
yerks yeuk yeuked yeuks yeuky yikes yock yocked yocks yoicks yok yoke 
yoked yokel yokels yokes yoks yolk yolked yolkier yolks yolky yonker yonkers 
younker yuck yucked yuckier yucks yucky yuk yukk yukked yukkier yukky yuks 
zaddick zaddik zaikai zaikais zebeck zebecks zek zeks zelkova zerk zerks zikurat 
zincked zincky zinkify zinky ziplock zonk zonked zonks zooks zouk zouks  
);

my @X_words = qw(
abaxial abaxile adaxial addax addaxes adieux admix admixed admixes admixt adnexa adnexal 
affix affixal affixed affixer affixes afflux alexia alexias alexin alexine alexins alkoxy 
alloxan annex annexe annexed annexes anorexy anoxia anoxias anoxic antefix anthrax antisex 
antitax anxiety anxious apex apexes apraxia apraxic apteryx aruspex asexual asphyxy ataraxy 
ataxia ataxias ataxic ataxics ataxies ataxy auspex auxeses auxesis auxetic auxin auxinic 
auxins ax axal axe axed axel axels axeman axemen axenic axes axial 
axially axil axile axilla axillae axillar axillas axils axiom axioms axion axions 
axis axised axises axite axites axle axled axles axlike axman axmen axolotl 
axon axonal axone axoneme axones axonic axons axseed axseeds bandbox banjax bateaux 
bauxite beaux beeswax bemix bemixed bemixes bemixt betaxed betwixt biaxal biaxial biflex 
bijoux bollix bollox bombax bombyx boombox borax boraxes box boxball boxcar boxcars 
boxed boxer boxers boxes boxfish boxful boxfuls boxhaul boxier boxiest boxily boxings 
boxlike boxwood boxy braxies braxy broadax brux bruxed bruxes bruxism bureaux buxom 
buxomer buxomly cachexy calix calx calxes calyx calyxes carapax carex cashbox caudex 
celotex cervix chamoix cimex claxon claxons climax coalbox coannex coax coaxal coaxed 
coaxer coaxers coaxes coaxial coccyx codex coexert coexist comix commix commixt complex 
conflux context convex cortex coteaux cowpox cox coxa coxae coxal coxalgy coxcomb 
coxed coxes coxitis coxless crux cruxes culex culexes cylix deixis deluxe deoxy 
desex desexed desexes desoxy detox detoxed detoxes dewax dewaxed dewaxes dex dexes 
dexie dexies dexter dextral dextran dextrin dextro dexy digoxin dioxan dioxane dioxans 
dioxid dioxide dioxids dioxin dioxins diplex dixit dixits doux doxie doxies doxy 
duplex earwax eaux editrix efflux elixir elixirs epitaxy epoxide epoxied epoxies epoxy 
epoxyed equinox ethoxy ethoxyl eutaxy ex exabyte exact exacta exactas exacted exacter 
exactly exactor exacts exalt exalted exalter exalts exam examen examens examine example 
exams exapted exarch exarchs exarchy exceed exceeds excel excels except excepts excerpt 
excess excide excided excides excimer exciple excise excised excises excite excited exciter 
excites exciton excitor exclaim exclave exclude excreta excrete excuse excused excuser excuses 
exec execs execute exed exedra exedrae exegete exempla exempt exempts exequy exergue 
exert exerted exerts exes exeunt exhale exhaled exhales exhaust exhedra exhibit exhort 
exhorts exhume exhumed exhumer exhumes exigent exil exile exiled exiler exilers exiles 
exilian exilic exine exines exist existed exists exit exited exits exocarp exoderm 
exodoi exodos exodus exogamy exogen exogens exon exonic exons exonym exonyms exordia 
exosmic exotic exotica exotics exotism expand expands expanse expat expats expect expects 
expel expels expend expends expense expert experts expiate expire expired expirer expires 
expiry explain explant explode exploit explore expo export exports expos exposal expose 
exposed exposer exposes exposit expound express expulse expunge exscind exsect exsects exsert 
exserts extant extend extends extent extents extern externe externs extinct extol extoll 
extolls extols extort extorts extra extract extras extrema extreme extrude exud exudate 
exude exuded exudes exult exulted exults exurb exurban exurbia exurbs exuvia exuviae 
exuvial exuvium falx farebox faux fax faxed faxes fedex fedexed fedexes feedbox 
firebox fix fixable fixate fixated fixates fixatif fixed fixedly fixer fixers fixes 
fixings fixit fixity fixt fixture fixure fixures flax flaxen flaxes flaxier flaxy 
flex flexed flexes flexile flexion flexor flexors flexure flummox flux fluxed fluxes 
fluxion fornix fowlpox fox foxed foxes foxfire foxfish foxhole foxhunt foxier foxiest 
foxily foxings foxlike foxskin foxtail foxtrot foxy funplex galax galaxes galaxy gateaux 
gearbox gox goxes gravlax hallux handax hapax hapaxes hatbox helix helixes hellbox 
hex hexad hexade hexades hexadic hexads hexagon hexane hexanes hexapla hexapod hexed 
hexer hexerei hexers hexes hexone hexones hexosan hexose hexoses hexyl hexylic hexyls 
hoax hoaxed hoaxer hoaxers hoaxes homosex hotbox humidex hydroxy hypoxia hypoxic hyrax 
hyraxes ibex ibexes icebox ilex ilexes immix immixed immixes index indexed indexer 
indexes indoxyl inexact infix infixed infixes influx ixia ixias ixodid ixodids ixora 
ixoras ixtle ixtles jeux jinx jinxed jinxes jukebox kex kexes kickbox klaxon 
klaxons kleenex kylix larynx latex latexes lax laxer laxes laxest laxity laxly 
laxness lex lexeme lexemes lexemic lexes lexica lexical lexicon lexis lixivia lockbox 
lox loxed loxes lummox lurex lurexes lux luxate luxated luxates luxe luxes 
luxury lynx lynxes mailbox mastix matrix max maxed maxes maxi maxilla maxim 
maxima maximal maximin maxims maximum maxis maxixe maxixes maxwell meninx methoxy milieux 
minimax minx minxes minxish mirex mirexes mix mixable mixed mixedly mixer mixers 
mixes mixible mixt mixture mixup mixups monaxon moxa moxas moxie moxies murex 
murexes muskox myxoid myxoma myxomas narthex next nexus nexuses nix nixe nixed 
nixes nixie nixies nixy nontax noxious onyx onyxes oratrix oryx oryxes outbox 
outfox outjinx overlax overmix overtax ox oxalate oxalic oxalis oxazine oxblood oxbow 
oxbows oxcart oxcarts oxen oxes oxeye oxeyes oxford oxfords oxheart oxid oxidant 
oxidase oxidate oxide oxides oxidic oxidise oxidize oxids oxim oxime oximes oxims 
oxlike oxlip oxlips oxo oxtail oxtails oxter oxters oxy oxyacid oxygen oxygens 
oxymora oxyphil oxysalt oxysome oxytone packwax panchax paradox pax paxes paxwax pegbox 
pemphix peroxid peroxy perplex perspex phalanx pharynx phenix phenoxy phlox phloxes phoenix 
pickax pickaxe pillbox pix pixel pixels pixes pixie pixies pixy pixyish plex 
plexal plexes plexor plexors plexus poleax poleaxe pollex postbox postfix posttax pox 
poxed poxes poxier poxiest poxy praxes praxis prefix premix premixt pretax pretext 
prex prexes prexies prexy princox prolix proxies proximo proxy pyrex pyrexes pyrexia 
pyrexic pyx pyxes pyxides pyxidia pyxie pyxies pyxis quixote radix radixes rax 
raxed raxes reaffix reannex rectrix redox redoxes redux reexpel refix refixed refixes 
reflex reflux reindex relax relaxed relaxer relaxes relaxin remex remix remixed remixes 
remixt reseaux retax retaxed retaxes rewax rewaxed rewaxes rex rexes rexine rexines 
roux salpinx saltbox sandbox sax saxes saxhorn saxony saxtuba scolex sex sexed 
sexes sexier sexiest sexily sexism sexisms sexist sexists sexless sexpot sexpots sext 
sextain sextan sextans sextant sextet sextets sextile sexto sexton sextons sextos sexts 
sexual sexy shoebox silex silexes silvex simplex six sixes sixfold sixmo sixmos 
sixte sixteen sixtes sixth sixthly sixths sixties sixty skybox smilax soapbox sonovox 
sox spadix spandex sphinx sphynx storax styrax subfix subtaxa subtext suffix surtax 
syntax syrinx tax taxa taxable taxably taxed taxeme taxemes taxemic taxer taxers 
taxes taxi taxicab taxied taxies taximan taximen taxis taxite taxites taxitic taxiway 
taxless taxman taxmen taxol taxols taxon taxons taxpaid taxus taxwise taxy teabox 
tectrix telefax telex telexed telexes texas texases text textile texts textual texture 
thorax toolbox tortrix toxemia toxemic toxic toxical toxics toxin toxine toxines toxins 
toxoid toxoids trioxid triplex tubifex tux tuxedo tuxedos tuxes twixt ulexite unaxed 
unbox unboxed unboxes unfix unfixed unfixes unfixt unisex unmix unmixed unmixes unmixt 
unsex unsexed unsexes unsexy untaxed unvexed unvext unwaxed urtext urtexts uxorial varix 
vernix vertex vex vexed vexedly vexer vexers vexes vexil vexilla vexils vext 
vixen vixenly vixens volvox vortex vox wax waxable waxbill waxed waxen waxer 
waxers waxes waxier waxiest waxily waxings waxlike waxw waxweed waxwork waxworm waxy 
woadwax woodbox woodwax workbox xanthan xanthic xanthin xebec xebecs xenia xenial xenias 
xenic xenon xenons xenopus xerarch xeric xeroses xerosis xerotic xerox xeroxed xeroxes 
xerus xeruses xi xiphoid xis xu xylan xylans xylem xylems xylene xylenes 
xylidin xylitol xyloid xylol xylols xylose xyloses xylyl xylyls xyst xyster xysters 
xysti xystoi xystos xysts xystus zax zaxes      
);

my @Q_words = qw(
acequia acquest acquire acquit acquits alfaqui aliquot antique aqua aquae aquaria aquas 
aquatic aquavit aqueous aquifer aquiver asquint banquet baroque barque barques basque basques 
bequest bezique bisque bisques bosque bosques bosquet bouquet briquet brusque buqsha buqshas 
burqa burqas cacique caique caiques calque calqued calques casque casqued casques cazique 
charqui cheque chequer cheques cinque cinques cirque cirques claque claquer claques clique 
cliqued cliques cliquey cliquy cloque cloques coequal conquer coquet coquets coquina coquito 
croquet croquis cumquat diquat diquats enquire enquiry equable equably equal equaled equally 
equals equate equated equates equator equerry equid equids equine equines equinox equip 
equips equites equity esquire exequy faqir faqirs faquir faquirs fique fiques inquest 
inquiet inquire inquiry jonquil kumquat lacquer lacquey lalique liquate liquefy liqueur liquid 
liquids liquify liquor liquors loquat loquats macaque manque maqui maquila maquis marque 
marquee marques marquis masque masquer masques mesquit mezquit mosque mosques oblique obloquy 
obsequy opaque opaqued opaquer opaques oquassa parquet pasquil perique picquet piqu piquant 
pique piqued piques piquet piquets piroque plaque plaques prequel pulque pulques qabala 
qabalah qabalas qadi qadis qaid qaids qanat qanats qat qats qi qindar 
qindars qintar qintars qis qiviut qiviuts qoph qophs qua quack quacked quacks 
quacky quad quadded quadrat quadric quads quaere quaeres quaff quaffed quaffer quaffs 
quag quagga quaggas quaggy quags quahaug quahog quahogs quai quaich quaichs quaigh 
quaighs quail quailed quails quaint quais quak quake quaked quaker quakers quakes 
quakier quakily quaky quale qualia qualify quality qualm qualms qualmy quamash quango 
quangos quant quanta quantal quanted quantic quants quantum quare quark quarks quarrel 
quarry quart quartan quarte quarter quartes quartet quartic quarto quartos quarts quartz 
quasar quasars quash quashed quasher quashes quasi quass quasses quassia quassin quate 
quatre quatres quaver quavers quavery quay quayage quays qubit qubits qubyte qubytes 
quean queans queasy queazy queen queened queenly queens queer queered queerer queerly 
queers quelea queleas quell quelled queller quells quench querida queried querier queries 
querist quern querns query quest quested quester questor quests quetzal queu queue 
queued queuer queuers queues quey queys quezal quezals quibble quiche quiches quick 
quicken quicker quickie quickly quicks quid quids quiet quieted quieten quieter quietly 
quiets quietus quiff quiffs quill quillai quilled quillet quills quilt quilted quilter 
quilts quin quinary quinate quince quinces quinela quinic quinin quinina quinine quinins 
quinnat quinoa quinoas quinoid quinol quinols quinone quins quinsy quint quinta quintal 
quintan quintar quintas quinte quintes quintet quintic quintin quints quip quipped quipper 
quippu quippus quippy quips quipu quipus quir quire quired quires quirk quirked 
quirks quirky quirt quirted quirts quit quitch quite quits quitted quitter quittor 
quiver quivers quivery quixote quiz quizzed quizzer quizzes quod quods quohog quohogs 
quoin quoined quoins quoit quoited quoits quokka quokkas quoll quolls quomodo quondam 
quorum quorums quot quota quotas quote quoted quoter quoters quotes quoth quotha 
qursh qurshes qurush qwerty qwertys racquet reequip relique request requiem requin requins 
require requite risque roque roques roquet roquets rorqual sacque sacques sequel sequela 
sequels sequent sequin sequins sequoia sheqel sheqels siliqua silique squab squabby squabs 
squad squads squalid squall squalls squally squalor squama squamae square squared squarer 
squares squark squarks squash squashy squat squatly squats squatty squaw squawk squawks 
squaws squeak squeaks squeaky squeal squeals squeeze squeg squegs squelch squib squibs 
squid squids squiffy squill squilla squills squinch squinny squint squints squinty squire 
squired squires squirm squirms squirmy squirt squirts squish squishy squoosh squush suq 
suqs tequila toque toques toquet toquets torque torqued torquer torques tranq tranqs 
tuque tuques ubique umiaq umiaqs unequal unique uniquer uniques unquiet unquote usque 
usques vaquero yanqui yanquis         
);

my @J_words = qw(
abject abjure abjured abjurer abjures acajou acajous adjoin adjoins adjoint adjourn adjudge 
adjunct adjure adjured adjurer adjures adjuror adjust adjusts ajar ajee ajiva ajivas 
ajowan ajowans ajuga ajugas alforja antijam aparejo azulejo banjax banjo banjoes banjos 
basenji bejesus bejewel bijou bijous bijoux blowjob bluejay boojum boojums cajaput cajeput 
cajole cajoled cajoler cajoles cajon cajones cajuput carjack catjang cojoin cojoins cojones 
conjoin conjure crojik crojiks deejay deejays deject dejecta dejects disject disjoin djebel 
djebels djin djinn djinni djinns djinny djins dojo dojos donjon donjons eject 
ejecta ejected ejector ejects enjoin enjoins enjoy enjoyed enjoyer enjoys fajita fajitas 
fanjet fanjets feijoa feijoas fjeld fjelds fjord fjordic fjords frijol frijole fuji 
fujis gadje gadjo gaijin ganja ganjah ganjahs ganjas gjetost gyttja gyttjas hadj 
hadjee hadjees hadjes hadji hadjis haj hajes haji hajis hajj hajjes hajji 
hajjis harijan hejira hejiras hijab hijabs hijack hijacks hijinks hijra hijrah hijrahs 
hijras inject injects injure injured injurer injures injury inkjet jab jabb jabbed 
jabber jabbers jabiru jabirus jabot jabots jabs jacal jacales jacals jacamar jacana 
jacanas jacinth jack jackal jackals jackass jackdaw jacked jacker jackers jacket jackets 
jackies jackleg jackpot jacks jacky jacobin jacobus jaconet jacuzzi jad jade jaded 
jadedly jadeite jades jadish jaditic jaeger jaegers jag jager jagers jagg jaggary 
jagged jagger jaggers jaggery jaggier jaggies jaggs jaggy jagless jagra jagras jags 
jaguar jaguars jail jailed jailer jailers jailor jailors jails jake jakes jalap 
jalapic jalapin jalaps jalop jaloppy jalops jalopy jam jamb jambe jambeau jambed 
jambes jambs jamlike jamm jammed jammer jammers jammier jammies jammy jams jane 
janes jangle jangled jangler jangles jangly janitor janty jap japan japans jape 
japed japer japers japery japes jar jarful jarfuls jargon jargons jargony jargoon 
jarhead jarina jarinas jarl jarldom jarls jarr jarrah jarrahs jarred jars jarsful 
jarvey jarveys jasmin jasmine jasmins jasper jaspers jaspery jassid jassids jato jatos 
jauk jauked jauks jaunce jaunced jaunces jaunt jaunted jaunts jaunty jaup jauped 
jaups java javas javelin jaw jawan jawans jawbone jawed jawless jawlike jawline 
jaws jay jaybird jaygee jaygees jays jayvee jayvees jaywalk jazz jazzbo jazzbos 
jazzed jazzer jazzers jazzes jazzier jazzily jazzman jazzmen jazzy jealous jean jeaned 
jeans jebel jebels jee jeed jeep jeeped jeepers jeepney jeeps jeer jeered 
jeerer jeerers jeers jees jeez jefe jefes jehad jehads jehu jehus jejuna 
jejunal jejune jejunum jell jellaba jelled jellied jellies jellify jello jellos jells 
jelly jemadar jemidar jemmied jemmies jemmy jennet jennets jennies jenny jeon jeopard 
jerboa jerboas jereed jereeds jerid jerids jerk jerked jerker jerkers jerkier jerkies 
jerkily jerkin jerkins jerks jerky jerreed jerrid jerrids jerries jerry jersey jerseys 
jess jessant jesse jessed jesses jest jested jester jesters jestful jests jesuit 
jesuits jet jetbead jete jetes jetfoil jetlag jetlags jetlike jeton jetons jetport 
jets jetsam jetsams jetsom jetsoms jett jetted jettied jettier jetties jetton jettons 
jetty jetway jetways jeu jeux jew jewed jewel jeweled jeweler jewelry jewels 
jewfish jews jezail jezails jezebel jiao jib jibb jibbed jibber jibbers jibboom 
jibbs jibe jibed jiber jibers jibes jibs jicama jicamas jiff jiffies jiffs 
jiffy jig jigaboo jigg jigged jigger jiggers jiggier jiggish jiggle jiggled jiggles 
jiggly jiggy jiglike jigs jigsaw jigsawn jigsaws jihad jihads jill jillion jills 
jilt jilted jilter jilters jilts jiminy jimjams jimmie jimmied jimmies jimminy jimmy 
jimp jimper jimpest jimply jimpy jin jingal jingall jingals jingko jingle jingled 
jingler jingles jingly jingo jingoes jink jinked jinker jinkers jinks jinn jinnee 
jinni jinnis jinns jins jinx jinxed jinxes jism jisms jitney jitneys jitter 
jitters jittery jiv jive jiveass jived jiver jivers jives jivey jivier jiviest 
jivy jnana jnanas joannes job jobb jobbed jobber jobbers jobbery jobless jobname 
jobs jock jockey jockeys jocko jockos jocks jocose jocular jocund jodhpur joe 
joes joey joeys jog jogg jogged jogger joggers joggle joggled joggler joggles 
jogs john johnnie johnny johns johnson join joinder joined joiner joiners joinery 
joins joint jointed jointer jointly joints joist joisted joists jojoba jojobas jok 
joke joked joker jokers jokes jokey jokier jokiest jokily joky jole joles 
jollied jollier jollies jollify jollily jollity jolly jolt jolted jolter jolters joltier 
joltily jolts jolty jomon jones jonesed joneses jonquil joram jorams jordan jordans 
jorum jorums joseph josephs josh joshed josher joshers joshes joss josses jostle 
jostled jostler jostles jot jota jotas jots jott jotted jotter jotters jotty 
joual jouals jouk jouked jouks joule joules jounce jounced jounces jouncy journal 
journey journo journos joust jousted jouster jousts jovial jow jowar jowars jowed 
jowl jowled jowlier jowls jowly jows joy joyance joyed joyful joyless joyous 
joypop joypops joyride joyrode joys juba jubas jubbah jubbahs jube jubes jubhah 
jubhahs jubile jubilee jubiles juco jucos judas judases judder judders judg judge 
judged judger judgers judges judo judoist judoka judokas judos jug juga jugal 
jugate jugful jugfuls jugg jugged juggle juggled juggler juggles jughead jugs jugsful 
jugula jugular jugulum jugum jugums juic juice juiced juicer juicers juices juicier 
juicily juicy jujitsu juju jujube jujubes jujuism jujuist jujus jujutsu juk juke 
jukebox juked jukes juku jukus julep juleps jumbal jumbals jumble jumbled jumbler 
jumbles jumbo jumbos jumbuck jump jumped jumper jumpers jumpier jumpily jumpoff jumps 
jumpy jun junco juncoes juncos jungle jungled jungles jungly junior juniors juniper 
junk junked junker junkers junket junkets junkie junkier junkies junkman junkmen junks 
junky junta juntas junto juntos jupe jupes jupon jupons jura jural jurally 
jurant jurants jurat jurats jurel jurels juridic juried juries jurist jurists juror 
jurors jury juryman jurymen jus jussive just justed juster justers justest justice 
justify justle justled justles justly justs jut jute jutes juts jutt jutted 
juttied jutties jutty juvenal kajeput kanji kanjis killjoy koji kojis kopje kopjes 
lockjaw logjam logjams mahjong majagua majesty major majored majorly majors masjid masjids 
misjoin mojarra mojo mojoes mojos moujik moujiks mujik mujiks muntjac muntjak musjid 
musjids muzjik muzjiks ninja ninjas nonjury object objects objet objets outjinx outjump 
outjut outjuts overjoy pajama pajamas perjure perjury pirojki prajna prajnas project projet 
projets propjet puja pujah pujahs pujas punji punjis pyjama pyjamas raj raja 
rajah rajahs rajas rajes ramjet ramjets reeject reenjoy reject rejects rejig rejigs 
rejoice rejoin rejoins rejudge resojet rioja riojas romaji romajis sajou sajous sanjak 
sanjaks sapajou sejant sejeant shoji shojis sjambok skyjack slojd slojds soja sojas 
sojourn subject subjoin svaraj swaraj taj tajes thuja thujas traject trijet trijets 
twinjet unjaded unjam unjams unjoint unjust veejay veejays
);

my @Z_words = qw(
ablaze abuzz adoze adz adze adzed adzes adzuki adzukis agatize agaze agenize 
agnize agnized agnizes agonize albizia alcazar amaz amaze amazed amazes amazon amazons 
analyze anodize apprize arabize assize assizes atomize azalea azaleas azan azans azide 
azides azido azimuth azine azines azlon azlons azo azoic azole azoles azon 
azonal azonic azons azote azoted azotes azoth azoths azotic azotise azotize azuki 
azukis azulejo azure azures azurite azygos azygous baiza baizas baize baizes banzai 
banzais baptize bazaar bazaars bazar bazars bazoo bazooka bazooms bazoos bedizen beezer 
beezers begaze begazed begazes benzal benzene benzin benzine benzins benzoic benzoin benzol 
benzole benzols benzoyl benzyl benzyls bezant bezants bezazz bezel bezels bezil bezils 
bezique bezoar bezoars bezzant biz bizarre bizarro bize bizes biznaga bizonal bizone 
bizones bizzes blaz blaze blazed blazer blazers blazes blazon blazons blintz blintze 
blitz blitzed blitzer blitzes blowzed blowzy bonanza bonze bonzer bonzes booz booze 
boozed boozer boozers boozes boozier boozily boozy bortz bortzes borzoi borzois bozo 
bozos braize braizes braz braza brazas braze brazed brazen brazens brazer brazers 
brazes brazier brazil brazils breeze breezed breezes breezy britzka bromize bronze bronzed 
bronzer bronzes bronzy brulzie buzuki buzukia buzukis buzz buzzard buzzcut buzzed buzzer 
buzzers buzzes buzzwig byzant byzants cabezon cadenza calzone canzona canzone canzoni capiz 
capizes capsize cazique cerveza chalaza chalutz chazan chazans chazzan chazzen chez chintz 
chintzy chorizo chutzpa citizen cloze clozes cognize colza colzas coryza coryzal coryzas 
coz cozen cozened cozener cozens cozes cozey cozeys cozie cozied cozier cozies 
coziest cozily cozy cozzes craz craze crazed crazes crazier crazies crazily crazy 
croze crozer crozers crozes crozier cruzado cyclize czar czardas czardom czarina czarism 
czarist czars damozel danazol daz daze dazed dazedly dazes dazzle dazzled dazzler 
dazzles defuze defuzed defuzes deglaze denizen deutzia dezinc dezincs dialyze diazin diazine 
diazins diazo diazole ditz ditzes ditzier ditzy dizen dizened dizens dizzied dizzier 
dizzies dizzily dizzy donzel donzels doozer doozers doozie doozies doozy doz doze 
dozed dozen dozened dozens dozenth dozer dozers dozes dozier doziest dozily dozy 
drizzle drizzly dualize ebonize ectozoa eczema eczemas elegize emblaze emprize entozoa enzym 
enzyme enzymes enzymic enzyms epazote epizoa epizoic epizoon erotize ersatz evzone evzones 
fanzine faz faze fazed fazenda fazes feaz feaze feazed feazes feez feeze 
feezed feezes fez fezes fezzed fezzes fezzy fiz fizgig fizgigs fizz fizzed 
fizzer fizzers fizzes fizzier fizzle fizzled fizzles fizzy floozie floozy foozle foozled 
foozler foozles fozier foziest fozy frazil frazils frazzle freeze freezer freezes frenzy 
frieze friezes fritz fritzes friz frized frizer frizers frizes frizz frizzed frizzer 
frizzes frizzle frizzly frizzy frouzy frowzy froze frozen furze furzes furzier furzy 
futz futzed futzes fuz fuze fuzed fuzee fuzees fuzes fuzil fuzils fuzz 
fuzzed fuzzes fuzzier fuzzily fuzzy gauze gauzes gauzier gauzily gauzy gaz gazabo 
gazabos gazania gazar gazars gaze gazebo gazebos gazed gazelle gazer gazers gazes 
gazette gazoo gazoos gazump gazumps geez geezer geezers ghazi ghazies ghazis ginzo 
ginzoes gizmo gizmos gizzard glaz glaze glazed glazer glazers glazes glazier glazily 
glazy glitz glitzed glitzes glitzy gloz gloze glozed glozes gonzo graz graze 
grazed grazer grazers grazes grazier grecize grizzle grizzly grosz grosze groszy guzzle 
guzzled guzzler guzzles gyoza gyozas hafiz hafizes halutz hamza hamzah hamzahs hamzas 
haz hazan hazanim hazans hazard hazards haze hazed hazel hazelly hazels hazer 
hazers hazes hazier haziest hazily hazings hazmat hazmats hazy hazzan hazzans heez 
heeze heezed heezes heroize hertz hertzes hoatzin horizon hutzpa hutzpah hutzpas huzza 
huzzaed huzzah huzzahs huzzas idolize imblaze iodize iodized iodizer iodizes ionize ionized 
ionizer ionizes ironize isozyme itemize izar izars izzard izzards jacuzzi jazz jazzbo 
jazzbos jazzed jazzer jazzers jazzes jazzier jazzily jazzman jazzmen jazzy jeez jezail 
jezails jezebel kanzu kanzus kazoo kazoos khazen khazens kibbitz kibbutz kibitz klezmer 
klutz klutzes klutzy kolhoz kolhozy kolkhoz kolkoz kolkozy kreuzer kudzu kudzus kunzite 
kuvasz kwanza kwanzas kyanize laicize laz lazar lazaret lazars laze lazed lazes 
lazied lazier lazies laziest lazily lazuli lazulis lazy lazyish lez lezzes lezzie 
lezzies lezzy lionize lizard lizards lozenge lutz lutzes machzor madzoon mahzor mahzors 
maize maizes mamzer mamzers matza matzah matzahs matzas matzo matzoh matzohs matzoon 
matzos matzot matzoth maz mazard mazards maze mazed mazedly mazer mazers mazes 
mazier maziest mazily mazuma mazumas mazurka mazy mazzard menazon mestiza mestizo metazoa 
mezcal mezcals meze mezes mezquit mezuza mezuzah mezuzas mezuzot mezzo mezzos midsize 
mirza mirzas mitzvah mizen mizens mizuna mizunas mizzen mizzens mizzle mizzled mizzles 
mizzly momzer momzers mozetta mozette mozo mozos muezzin muzhik muzhiks muzjik muzjiks 
muzzier muzzily muzzle muzzled muzzler muzzles muzzy nazi nazify nazis nertz netizen 
nizam nizams nonzero nozzle nozzles nudzh nudzhed nudzhes nuzzle nuzzled nuzzler nuzzles 
obelize odorize ooz ooze oozed oozes oozier ooziest oozily oozy organza orzo 
orzos outgaze outsize ouzel ouzels ouzo ouzos oxazine oxidize oyez oyezes ozalid 
ozalids ozonate ozone ozones ozonic ozonide ozonise ozonize ozonous palazzi palazzo panzer 
panzers patzer patzers pazazz pectize peptize phiz phizes piazza piazzas piazze pizazz 
pizazzy pizza pizzas pizzaz pizzazz pizzle pizzles plaza plazas plotz plotzed plotzes 
podzol podzols poetize potzer potzers pozole pozoles pretzel prez prezes priz prize 
prized prizer prizers prizes putz putzed putzes puzzle puzzled puzzler puzzles quartz 
queazy quetzal quezal quezals quiz quizzed quizzer quizzes raz raze razed razee 
razeed razees razer razers razes razor razored razors razz razzed razzes realize 
rebozo rebozos refroze reglaze reseize resize resized resizes rezero rezeros rezone rezoned 
rezones rhizoid rhizoma rhizome rhizopi ritz ritzes ritzier ritzily ritzy rozzer rozzers 
scherzi scherzo schizo schizos schizy schizzy schmalz schnoz schnozz scuzz scuzzes scuzzy 
seiz seize seized seizer seizers seizes seizin seizins seizor seizors seizure seltzer 
shazam shegetz shiatzu shmaltz shmooze showbiz siz sizable sizably sizar sizars size 
sized sizer sizers sizes sizier siziest sizings sizy sizzle sizzled sizzler sizzles 
sleaze sleazes sleazo sleazy smaze smazes snazzy sneeze sneezed sneezer sneezes sneezy 
snooze snoozed snoozer snoozes snoozle snoozy sovkhoz soyuz soyuzes sozin sozine sozines 
sozins sozzled spatzle spaz spazz spazzes speltz spitz spitzes spritz squeeze stanza 
stanzas stylize subzero subzone swizzle syzygal syzygy tarzan tarzans tazza tazzas tazze 
teazel teazels teazle teazled teazles thiazin thiazol tizzies tizzy topaz topazes touzle 
touzled touzles trapeze triazin trooz tweeze tweezed tweezer tweezes tzaddik tzar tzardom 
tzarina tzarism tzarist tzars tzetze tzetzes tzigane tzimmes tzitzis tzitzit tzuris uncrazy 
unfazed unfroze unisize unitize unrazed unsized unzip unzips unzoned upgaze upgazed upgazes 
upsize upsized upsizes utilize vizard vizards vizier viziers vizir vizirs vizor vizored 
vizors vizsla vizslas waltz waltzed waltzer waltzes wazoo wazoos weazand wheeze wheezed 
wheezer wheezes wheezy whiz whizz whizzed whizzer whizzes whizzy winze winzes wiz 
wizard wizards wizen wizened wizens wizes wizzen wizzens wizzes woozier woozily woozy 
wurzel wurzels yakuza yutz yutzes z za zacaton zaddick zaddik zaffar zaffars 
zaffer zaffers zaffir zaffirs zaffre zaffres zaftig zag zagg zagged zags zaikai 
zaikais zaire zaires zamarra zamarro zamia zamias zanana zananas zander zanders zanier 
zanies zaniest zanily zany zanyish zanza zanzas zap zapateo zapp zapped zapper 
zappers zappier zappy zaps zaptiah zaptieh zareba zarebas zareeba zarf zarfs zariba 
zaribas zas zax zaxes zayin zayins zazen zazens zeal zealot zealots zealous 
zeals zeatin zeatins zebec zebeck zebecks zebecs zebra zebraic zebrano zebras zebrass 
zebrine zebroid zebu zebus zecchin zechin zechins zed zedoary zeds zee zees 
zein zeins zek zeks zelkova zemstva zemstvo zenaida zenana zenanas zenith zeniths 
zeolite zep zephyr zephyrs zeppole zeppoli zeps zerk zerks zero zeroed zeroes 
zeros zeroth zest zested zester zesters zestful zestier zestily zests zesty zeta 
zetas zeugma zeugmas zibet zibeth zibeths zibets zig zigg zigged zigs zigzag 
zigzags zikurat zilch zilches zill zillah zillahs zillion zills zin zinc zincate 
zinced zincic zincify zincite zincked zincky zincoid zincous zincs zincy zine zineb 
zinebs zines zing zingani zingano zingara zingare zingari zingaro zinged zinger zingers 
zingier zings zingy zinkify zinky zinnia zinnias zins zip zipless ziplock zipp 
zipped zipper zippers zippier zippy zips ziram zirams zircon zircons zit zither 
zithern zithers ziti zitis zits zizit zizith zizzle zizzled zizzles zlote zloties 
zloty zlotych zlotys zoa zoaria zoarial zoarium zocalo zocalos zodiac zodiacs zoea 
zoeae zoeal zoeas zoecia zoecium zoftig zoic zoisite zombi zombie zombies zombify 
zombis zon zona zonae zonal zonally zonary zonate zonated zone zoned zoner 
zoners zones zonk zonked zonks zonula zonulae zonular zonulas zonule zonules zoo 
zooecia zooey zoogeny zooglea zooid zooidal zooids zooier zooiest zooks zoology zoom 
zoomed zooms zoon zoonal zooned zoons zoos zootier zootomy zooty zori zoril 
zorilla zorille zorillo zorils zoris zoster zosters zouave zouaves zouk zouks zounds 
zowie zoysia zoysias zuz zuzim zydeco zydecos zygoid zygoma zygomas zygose zygoses 
zygosis zygote zygotes zygotic zymase zymases zyme zymes zymogen zymosan zymoses zymosis 
zymotic zymurgy zyzzyva zzz         
);

# Combined from plural sources.
my @words_common = qw(
*ar* *as* *bk* *kn* *sk* 73 
a about above across act add after again against age agn ago air all alone along already 
also always am america american among an and another answer ant any anything appear are 
arm army around as ask at back bank be beam became because become been before began begin 
being believe best better between big bill body book both boy bring brought built business 
but by call came can car care carry case cause chance change child children city close 
color come coming company condition consider continue cost could country court cover cq 
cry cut dear demand did die do doctor does dollar don't done dont door down dress drop 
during dx each early either end enough es even evening ever every eye face fact fall 
family far father fb feet felt few fight figure fill find fine fire first five follow for 
force found four friend from front full ga garden gave ge get girl give given go god gone 
good got government great green had half hand happen happy hard has have he head hear 
heard heart held help her here herself hi high him himself his hold home hope horse hour 
house how however hr human hundred husband hw i idea if ill important in increase interest 
into is it it's its just keep kept kind king knew know labor lady land large last late 
laugh law learn least leave left less let letter lie life light like line little live long 
look lost love low made make man many mark marry matter may me mean men might mile mind miss 
moment money month more morning most mother move mrs much must my myself name national near 
need new next night no nor not note nothing now nr number of off office often oh old om on 
once one only open or order other our out over own paper part party pass pay people perhaps 
person picture place plant point poor possible power present president price produce pse 
public put pwr qrl qrm qrn qrq qrs qrz qsb qsy qth question quite r rather reach read real 
really reason receive red remain remember rest result return right river road room round rst 
rtu run said same sat saw say school sea second see seem seen serve set several shall she 
ship short should show side since sir small smile so some something son soon sort sound 
speak stand start state step still stood stop story such sun supply suppose sure system 
table take taken talk tell ten than that that's the their them themselves then there these 
they thime thing think this those three through thus till time tnx to today together told 
too took toward town tree tried true try tu turn twenty two uh under until up upon us use 
very voice wait walk wall want war was washington watch water way we week well went were 
what when where whether which white who whole whom whose why wide will wind wish with 
without wonder word work world would write wrong wx xyl yeah year yes yet yl you young your
);

# Modified from fisher-yates_shuffle from the Perl Cookbook, 4.17. 
sub jumble { 
    my @words = @_; 
    my $i;
    for ($i = @words; --$i;) {
        my $j = int rand ($i+1);
        next if $i == $j;
        @words[$i,$j] = @words[$j,$i];
    }
    return @words;
}

my @puncts = qw( . , : ? - ; / ! " @ ), ('(', ')');
sub punctuate { 
    my $j = shift; # Lower = more often
    my @words = @_; 
    my $i;
    for ($i = @words; --$i;) {
	next unless $i % $j == 0;
	my $j = int rand (scalar @puncts);
        @words[$i] .= $puncts[$j];
    }
    return @words;
}

sub numerate {
    my $j = shift; # Lower = more often
    my @words = @_; 
    my $i;
    for ($i = @words; --$i;) {
	next unless $i % $j == 0;
	my $k = int rand 99;
        $k *= int rand 9 if rand > 0.5;
        $k *= int rand 9 if rand > 0.5;
        $k += int rand 9 if rand > 0.5;        
        @words[$i] .= " $k";
    }
    return @words;
}

sub flip_coin { return rand(10) <=5 }

my @all_letters = qw(q w e r t y u i o p a s d f g h j k l z x c v b n m);
my @all_nums = qw(0 1 2 3 4 5 6 7 8 9);
my @all_chars = (@all_letters, @all_nums, @puncts); 

sub random_callsign { # Generate a totally arbitrary ham call.
    my $lh = $all_letters[int(rand scalar @all_letters)];
    $lh .= $all_letters[int(rand scalar @all_letters)] if flip_coin();
    $lh .= $all_nums[int(rand scalar @all_nums)];
    my $rh = $all_letters[int(rand scalar @all_letters)];
    $rh .= $all_letters[int(rand scalar @all_letters)] if flip_coin();
    $rh .= $all_letters[int(rand scalar @all_letters)] if flip_coin();
    $rh .= $all_letters[int(rand scalar @all_letters)] if length $lh == 2 && length $rh == 1;
    return uc("$lh$rh");
}

sub nonsense {
    my $j = 2 + int(rand shift);
    my $wtf = "";
    for (my $i=0; $i!=$j; ++$i) {
	$wtf .= $all_chars[int(rand scalar @all_chars)];
    } 
    return $wtf; 
}

sub gobbledegook {
    my $j = shift; # Lower = more often
    my @words = @_; 
    my $i;
    for ($i = @words; --$i;) {
	next unless $i % $j == 0;
        if ( flip_coin() ) {
            splice @words, $i, 0, nonsense(4);    
        } else { 
            splice @words, $i, 0, random_callsign();
        
        }
    }
    return @words;
}

sub pick_rand {
    my $i = shift; # How many to pick?
    
}

sub backwards {
    my $j = shift; # Lower = more often
    my @words = @_; 
    my $i;
    for ($i = @words; --$i;) {
	next unless $i % $j == 0;
	my $s = reverse $words[$i];
        @words[$i] = $s;
    }
    return @words;
}

# Mix up groups before they are culled.
@Z_words = jumble(@Z_words); 
@J_words = jumble(@J_words);
@Q_words = jumble(@Q_words);
@X_words = jumble(@X_words);
@K_words = jumble(@K_words);
@V_words = jumble(@V_words);
@B_words = jumble(@B_words);
@P_words = jumble(@P_words);
@G_words = jumble(@G_words);
@W_words = jumble(@W_words);
@Y_words = jumble(@Y_words);
@F_words = jumble(@F_words);
@M_words = jumble(@M_words);
@C_words = jumble(@C_words);
@U_words = jumble(@U_words);

# Prepare for culling.
my @arefs = (
  \@Z_words,
  \@J_words,
  \@Q_words,
  \@X_words,
  \@K_words,
  \@V_words,
  \@B_words,
  \@P_words,
  \@G_words,
  \@W_words,
  \@Y_words,
  \@F_words,
  \@M_words,
  \@C_words,
  \@U_words,
); 

# What is size of smallest word array?
my $least = 1_000_000;
for my $aref (@arefs) {
	$least = @$aref if scalar @$aref < $least;
}
$least--;

# Cull lists to keep the balance of letters roughly even.
my @Words = (
  @Z_words[0..$least],
  @J_words[0..$least],
  @Q_words[0..$least],
  @X_words[0..$least],
  @K_words[0..$least],
  @V_words[0..$least],
  @B_words[0..$least],
  @P_words[0..$least],
  @G_words[0..$least],
  @W_words[0..$least],
  @Y_words[0..$least],
  @F_words[0..$least],
  @M_words[0..$least],
  @C_words[0..$least],
  @U_words[0..$least],
);

@Words = punctuate($punc, @Words) if $punc;     # 5
@Words = numerate($numr, @Words) if $numr;      # 7
@Words = backwards($back, @Words) if $back;     # 11
@Words = gobbledegook($rand, @Words) if $rand;  # 19

my %unique   = map { $_, 1 } @Words;
@Words = sort(keys %unique);

my @Jumble = jumble(@Words, @words_common); 

# print "STRING: $string \n";

if ( open my $fh, '>', "$path" ) {  
	my $string;
	while (stat($fh)->size < $max_filesize) {
		for my $i (1 .. 12) {	
			unless (scalar @Jumble) { 
				# Renew source when has run out.
				@Jumble = jumble(@Words, @words_common) 
			}
			$string .= shift( @Jumble ) . ' ';
        	if ($i % 12 == 0) {
                $string =~ s/\s+/ /g;
				print $fh "$string\n";
				$string = '';
			}
		} 
	}
	print "All done.\n";
	sleep 3 if $windoze_flag;
} else { 
        die "Oops! Cannot open '$path' for writing.\n"; 
}

__END__

=head1 NAME

Jumbled Words Generator

=head1 SYNOPSIS

C<perl   gus_jumbled_words.pl --path './morse.txt' --size 120 --othr 5 --numr 7 --back 11 --rand 19 -->

=head1 DESCRIPTION

Writes out jumbled-words text files suitable for input to Morse code audio generators.

=head1 MODULES USED

C<Getopt::Long>
C<File::Stat>

C<Config>

=head1 COMMAND LINE OPTIONS

Control character-inclusion and randomness behavior of text file generator.

=head2 --p[ath]
 
Valid system file path to input text file. Default = './morse.txt'

=head2 --s[ize] 

Size of output text file in kB. Default = 120.

=head2 --b[ack]    

Insert random spelling reverals at specified average intervals. Default = 11.

=head2 --n[umr]    

Insert random numeral groups at specified average intervals. Default = 7.

=head2 --o[thr]    

Insert random punctuation at specified average intervals. Default = 5.

=head2 --r[and]    

Insert random gobbledegook at specified average intervals. One in two will simulate (totally arbitrary!) call signs. Default = 19.

=head2 --h[elp] 

Display basic help/usage message.

=head1 AUTHOR

Gan Uesli Starling <F<gan@starling.us>>

=head1 COPYRIGHT

Copyright (c) 2015, Gan Uesli Starling, KY8D. All rights reserved.

This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.

=head1 SCRIPT CATEGORIES

Text Generator

=cut
